/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(qb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(m){h[2]=m}function q(){return h[2]}function ob(pb){var r=pb.a;var s=r.buffer;r.grow=mb;var t=new Int8Array(s);var u=new Int16Array(s);var v=new Int32Array(s);var w=new Uint8Array(s);var x=new Uint16Array(s);var y=new Uint32Array(s);var z=new Float32Array(s);var A=new Float64Array(s);var B=Math.imul;var C=Math.fround;var D=Math.abs;var E=Math.clz32;var F=Math.min;var G=Math.max;var H=Math.floor;var I=Math.ceil;var J=Math.trunc;var K=Math.sqrt;var L=pb.abort;var M=NaN;var N=Infinity;var O=pb.b;var P=pb.c;var Q=pb.d;var R=pb.e;var S=pb.f;var T=pb.g;var U=pb.h;var V=pb.i;var W=pb.j;var X=pb.k;var Y=pb.l;var Z=pb.m;var _=pb.n;var $=pb.o;var aa=pb.p;var ba=pb.q;var ca=pb.r;var da=pb.s;var ea=pb.t;var fa=pb.u;var ga=pb.v;var ha=pb.w;var ia=pb.x;var ja=pb.y;var ka=pb.z;var la=pb.A;var ma=pb.B;var na=pb.C;var oa=pb.D;var pa=pb.E;var qa=pb.F;var ra=pb.G;var sa=pb.H;var ta=pb.I;var ua=pb.J;var va=pb.K;var wa=pb.L;var xa=pb.M;var ya=pb.N;var za=pb.O;var Aa=pb.P;var Ba=pb.Q;var Ca=pb.R;var Da=pb.S;var Ea=pb.T;var Fa=pb.U;var Ga=pb.V;var Ha=pb.W;var Ia=pb.X;var Ja=pb.Y;var Ka=pb.Z;var La=pb._;var Ma=pb.$;var Na=pb.aa;var Oa=pb.ba;var Pa=pb.ca;var Qa=pb.da;var Ra=pb.ea;var Sa=pb.fa;var Ta=pb.ga;var Ua=pb.ha;var Va=pb.ia;var Wa=pb.ja;var Xa=pb.ka;var Ya=pb.la;var Za=pb.ma;var _a=pb.na;var $a=pb.oa;var ab=pb.pa;var bb=pb.qa;var cb=5708288;var db=0;var eb=0;var fb=0;
// EMSCRIPTEN_START_FUNCS
function Wr(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,T=0,V=0,W=C(0),X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=C(0),Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=C(0),Xa=0;$=cb-48|0;cb=$;fa=$+40|0;v[fa>>2]=49680;v[fa>>2]=49580;d=vI($+32|0);f=vI($+24|0);k=v[d+4>>2];v[$+16>>2]=v[d>>2];v[$+20>>2]=k;d=v[f+4>>2];v[$+8>>2]=v[f>>2];v[$+12>>2]=d;ha=b;pa=c;b=0;T=cb-112|0;cb=T;e=a;qa=e+24604|0;a=qa;a:{if(!v[a+16>>2]){break a}c=v[a+20>>2];if(c>>>0>4|!(1<<c&22)){break a}a=v[a+28>>2];if(a>>>0>4){break a}b=23>>>a&1}if(!b){c=T+96|0;LL(c,9162,13038,220,45);a=cb+-64|0;cb=a;v[a+56>>2]=0;d=Bs(a+56|0);b=jc(a+24|0,17784);v[22440]=0;U(5,a+8|0,1,17447);f=v[22440];v[22440]=0;b:{c:{d:{e:{if((f|0)!=1){v[22440]=0;U(2,a+40|0,b|0,a+8|0);f=v[22440];v[22440]=0;if((f|0)==1){break e}v[22440]=0;ga(867,d|0,c|0,1,13640,a+40|0);c=v[22440];v[22440]=0;if((c|0)!=1){break b}c=P()|0;O()|0;rb(a+40|0);break d}c=P()|0;O()|0;break c}c=P()|0;O()|0}rb(a+8|0)}rb(b);S(c|0);L()}rb(a+40|0);rb(a+8|0);rb(b);cb=a- -64|0}ra=$+16|0;sa=$+8|0;ta=e+8204|0;ua=e+397452|0;va=e+397448|0;ca=e+393352|0;J=e+397456|0;aa=e+12|0;wa=e+1298300|0;Ga=e+1074376|0;Ha=e+1298420|0;Ia=e+1074365|0;while(1){f:{g:{b=v[e+480208>>2];if(!(!ha|b&512)){h:{if(v[e+1074380>>2]){break h}a=b|512;i:{if(b&256){break i}k=0;n=cb-48|0;cb=n;H=cb-32|0;cb=H;j=e+1074312|0;c=e+1074992|0;l=e+1298264|0;m=e+1074424|0;g=e+484344|0;f=e+484360|0;h=e+1074448|0;q=e+1074376|0;a=v[e+1074392>>2];p=e+480210|0;s=e+484376|0;j:{k:{l:while(1){m:{a=a+1|0;v[e+1074392>>2]=a;if(dl(q)>>>0>a>>>0){break m}_M(H+24|0,e,q,(v[e+480208>>2]&524288)>>>19|0);n:{o:{p:{q:{r:{if(w[e+480208|0]&32){a=x[e+1074446>>1];break r}a=65535;b=Nb(f);b=Fc(v[b>>2],v[b+4>>2]);d=x[h>>1];if(b>>>0>d>>>0){a=x[Xb(v[Nb(f)>>2],d)>>1]}u[e+1074446>>1]=a;s:{t:{b=a&65535;if(Cf(g)>>>0<=b>>>0){break t}if(Vh(Sb(g,b))){break t}b=0;break s}b=1}while(1){u:{v:{if(!b){a=65534;u[e+1074446>>1]=65534;break v}w:{x:{y:{b=a&65535;if(Cf(g)>>>0<=b>>>0){z:{if((b|0)!=65535){a=Nb(f);if(Fc(v[a>>2],v[a+4>>2])>>>0>(d&65535)>>>0){break z}}a=x[Nb(f)+28>>1];if(a){break x}b=d&65535;a=Nb(f);if(!b|Fc(v[a>>2],v[a+4>>2])>>>0<b>>>0){break y}while(1){a=b;b=a-1|0;if(!b){break y}if(x[Xb(v[Nb(f)>>2],b)>>1]!=65535){continue}break}break x}d=d+1|0;u[h>>1]=d;break w}u[e+1074450>>1]=d;break r}a=0}u[e+1074448>>1]=a;v[e+480208>>2]=v[e+480208>>2]&-524289;while(1){A:{b=Nb(f);d=Fc(v[b>>2],v[b+4>>2]);b=a&65535;if(d>>>0<=b>>>0){break A}if(x[Xb(v[Nb(f)>>2],b)>>1]!=65534){break A}a=a+1|0;u[h>>1]=a;continue}break}a=Nb(f);if(Fc(v[a>>2],v[a+4>>2])>>>0<=b>>>0){break q}if(!oq(Nb(f),b)){break q}d=x[h>>1]}a=65535;b=Nb(f);E=Fc(v[b>>2],v[b+4>>2]);b=d&65535;if(E>>>0>b>>>0){a=x[Xb(v[Nb(f)>>2],b)>>1]}u[e+1074446>>1]=a;b=a&65535;if(Cf(g)>>>0<=b>>>0){break v}if(!Vh(Sb(g,b))){break u}}b=1;continue}b=0;continue}}b=a&65535;if(!ve(g,b)){break k}a=v[m>>2];if(a>>>0>=y[Sb(g,b)+12>>2]){v[m>>2]=0;a=0}if(v[e+480208>>2]&32?v[e+480272>>2]!=-1:0){break n}if(!Us(l,x[h>>1],a,Bp(H+16|0,c),w[H+24|0])){break n}a=v[e+480272>>2];if(a){if((a|0)>0){v[e+480272>>2]=a-1}In(l,1);Us(l,x[h>>1],v[m>>2],Bp(H+16|0,c),w[H+24|0]);break n}if(!(w[p|0]&64)){break q}a=0;if(vN(l,h,m,1)){break o}v[e+1074448>>2]=0;v[e+1074424>>2]=0;v[e+1074428>>2]=0;d=qj(f)-1|0;b=w[s|0];if((d|0)>(b|0)){break p}Hi(f,0)}In(l,1);break k}Hi(f,b+1&255);In(l,1)}while(1){if((a|0)==256){zL(e);v[e+1074416>>2]=v[e+480196>>2];v[e+1074420>>2]=v[e+480204>>2];v[e+1074456>>2]=v[e+480200>>2];a=x[e+1074448>>1];u[e+1074450>>1]=a;b=v[e+1074424>>2];v[e+1074428>>2]=b;d=Nb(f);if(Fc(v[d>>2],v[d+4>>2])>>>0>a>>>0){Ua=e,Va=x[Xb(v[Nb(f)>>2],a)>>1],u[Ua+1074446>>1]=Va}Us(l,a,b,Bp(H+16|0,c),w[H+24|0]);if(!ve(g,x[e+1074446>>1])){break k}}else{Ln((B(a,872)+e|0)+1074992|0,e,a&65535,134217728);a=a+1|0;continue}break}}ZM(e,q,(v[e+480208>>2]&32)>>>5|0);b=Zc(Sb(g,x[e+1074446>>1]),v[e+1074424>>2],0);i=(B(x[e+480188>>1],872)+e|0)+1074992|0;a=c;while(1){if((a|0)==(i|0)){d=e+1074412|0;B:{C:{a=e+484344|0;b=x[e+1074446>>1];if(Dm(a,b)){i=Sb(a,b);if(WM(v[i+16>>2],v[i+20>>2])){break C}}v[e+1074408>>2]=v[e+480216>>2];a=e+480220|0;break B}Ua=e+1074408|0,Va=v[Sb(a,b)+16>>2],v[Ua>>2]=Va;a=Sb(a,b)+20|0}v[d>>2]=v[a>>2];if(!w[H+24|0]){break m}a=v[e+1074416>>2];v[e+1074392>>2]=a;continue l}ub(H+16|0,j,82);D:{if(!tb(v[v[H+16>>2]>>2],v[H+20>>2])|w[a+805|0]!=1){break D}d=w[b+3|0];if((d|0)!=2&(d|0)!=3){break D}Ua=a,Va=ch(e,w[a+800|0],u[a+772>>1],v[a+704>>2]),v[Ua+700>>2]=Va}ub(H+16|0,j,91);E:{if(!tb(v[v[H+16>>2]>>2],v[H+20>>2])){break E}if(Rc(w[b|0])){break E}d=w[a+788|0];if(!Rc(d)|w[a+791|0]!=19){break E}o=w[a+793|0];if((o&240)!=208|y[e+1074416>>2]>(o&15)>>>0){break E}Ua=a,Va=ch(e,d,u[a+772>>1],0),v[Ua+700>>2]=Va}ub(H+16|0,j,92);F:{if(!tb(v[v[H+16>>2]>>2],v[H+20>>2])){break F}ub(H+8|0,j,5);if(tb(v[v[H+8>>2]>>2],v[H+12>>2])|v[e+1074416>>2]!=1|w[a+791|0]!=17){break F}v[e+1074420>>2]=B(w[a+793|0],1e4)}d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a+788|0]=d;t[a+789|0]=d>>>8;t[a+790|0]=d>>>16;t[a+791|0]=d>>>24;d=w[b+4|0]|w[b+5|0]<<8;t[a+792|0]=d;t[a+793|0]=d>>>8;d=v[a+676>>2];v[a+20>>2]=v[a+672>>2];v[a+24>>2]=d;v[a+88>>2]=v[a+88>>2]&-393217;ub(H+16|0,j,21);if(!tb(v[v[H+16>>2]>>2],v[H+20>>2])){t[a+831|0]=0}v[a+860>>2]=0;t[a+805|0]=0;b=b+6|0;a=a+872|0;continue}}break}d=v[e+1074416>>2];if(!d){v[e+1074416>>2]=1;d=1}a=v[e+480208>>2];c=v[e+1074392>>2];G:{H:{if(c){b=a&-4097;v[e+480208>>2]=b;f=v[e+480180>>2];if(f&1048580|(a&2097152?0:(f|0)==1)){break G}if(dl(q)>>>0<=c>>>0){break G}if(!((c>>>0)%(v[e+1074400>>2]+d>>>0)|0)){break H}break G}b=a&-528385}v[e+480208>>2]=b|4096}h=0;i=cb-16|0;cb=i;u[e+1074444>>1]=65535;a=e+1074436|0;v[a>>2]=-1;v[a+4>>2]=-1;K=e+480180|0;ba=e+1075809|0;F=e+1298300|0;r=e+1074312|0;G=e+480208|0;I=e+1074376|0;Z=e+480188|0;_=e+480190|0;M=e+480192|0;while(1){I:{if(x[Z>>1]<=h>>>0){J:{if(!(w[G+1|0]&16)){break J}if(!PM(e,I,Nb(e+484360|0),1)){break J}v[G>>2]=v[G>>2]|524288}cb=i+16|0;break I}o=B(h,872)+e|0;j=o+1075785|0;d=w[j|0];m=o+1075783|0;N=w[m|0];p=o+1075784|0;A=w[p|0];V=o+1075782|0;l=w[V|0];X=o+1075781|0;b=w[X|0];a=v[e+1074392>>2];c=v[e+1074400>>2];f=v[e+1074416>>2];R=o+1075780|0;g=Rs(R);q=o+1075843|0;t[q|0]=v[e+480208>>2]>>>12&1|w[q|0]&254;f=(a>>>0)%(c+f>>>0)|0;a=w[R|0];K:{L:{M:{if((a|0)==252){s=ek(l,A);E=ek(N,d);a=252;if((b-1&255)>>>0>249){break M}c=v[(B(b,160)+e|0)+906140>>2];if(!c){break M}gb[v[v[c>>2]+44>>2]](c,s,C(C(E>>>0)/C(999)));a=w[R|0]}if((a&255)==251){break L}}if(z[o+1075852>>2]==C(0)|N){break K}}s=v[G>>2]&4096;N:{if(!s){c=w[o+1075862|0];break N}c=w[X|0];t[o+1075862|0]=c}if((c-1&255)>>>0>249){break K}E=(B(c&255,160)+e|0)+906140|0;c=v[E>>2];if(!c){break K}O:{if(!s){a=x[o+1075860>>1];break O}a=Gy(w[V|0],w[p|0]);u[o+1075860>>1]=a;W=C(C(Gy(w[m|0],w[j|0])>>>0)/C(999));z[o+1075856>>2]=W;Ua=o+1075852|0,Wa=C(C(W-C(gb[v[v[c>>2]+48>>2]](c,a)))/C(dl(I)>>>0)),z[Ua>>2]=Wa;c=v[E>>2]}j=a;a=(v[e+1074392>>2]+1|0)==(dl(I)|0);gb[v[v[c>>2]+(a?44:104)>>2]](c,j,z[(a?o+1075856|0:o+1075852|0)>>2]);a=w[R|0]}j=o+1074992|0;if(GM(a&255)){a=cb-16|0;cb=a;u[a+12>>1]=0;v[a+8>>2]=0;tg(a+8|0);b=x[a+12>>1];t[j+792|0]=b;t[j+793|0]=b>>>8;b=v[a+8>>2];t[j+788|0]=b;t[j+789|0]=b>>>8;t[j+790|0]=b>>>16;t[j+791|0]=b>>>24;cb=a+16|0;g=0;N=0;A=0;l=0;d=0;b=0}P:{if(!(w[G+1|0]&16)){iM(e,j);break P}if(!b){break P}v[o+1075752>>2]=0}Q:{R:{if((N|0)==33){ub(i+8|0,r,30);a=d>>>4|0;vy(e,h&65535,a+(d&15)|0,tb(v[v[i+8>>2]>>2],v[i+12>>2]));break R}a=0;if((N-19&255)>>>0>1){break R}S:{if(!(!(v[K>>2]&16777250)|d)){d=w[o+1075825|0];break S}t[o+1075825|0]=d}c=d&240;if((c|0)==208){c=d&15;if(!c){c=v[K>>2];if(c&16777248){a=1;break R}if((c|0)!=2){break R}break Q}if(c>>>0>=v[e+1074400>>2]+v[e+1074416>>2]>>>0){ub(i+8|0,r,14);a=c;if(!tb(v[v[i+8>>2]>>2],v[i+12>>2])){break R}if(!b){break Q}t[o+1075795|0]=b;break Q}a=c;break R}if(!(w[G+1|0]&16)|(c|0)!=224){break R}c=v[K>>2];if(v[e+1074396>>2]?c&16777250:0){break R}p=c&2;c=d&15;if(c?0:p){break R}v[e+1074396>>2]=c+1}c=v[K>>2]==16&(N|0)==19&(d&240)==208;E=c?0:a;T:{if(!E|w[R|0]!=255|w[V|0]!=2){break T}ub(i+8|0,r,74);if(!tb(v[v[i+8>>2]>>2],v[i+12>>2])){break T}t[V|0]=0}Y=d&15;a=v[e+1074392>>2];ub(i+8|0,r,72);U:{if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){p=0;if(E>>>0>=y[e+1074416>>2]){break U}}ub(i+8|0,r,88);p=(f|0)==(E|0)|(a|0)==(E|0);if(!(!tb(v[v[i+8>>2]>>2],v[i+12>>2])|!E)){break U}p=(a|0)==(E|0)}ub(i+8|0,r,44);c=c?Y|144:d;V:{if(!tb(v[v[i+8>>2]>>2],v[i+12>>2])){a=w[q|0];break V}a=w[q|0]&-2|(f|0)==(E|0)}t[q|0]=a&253|(p?2:0);ub(i+8|0,r,66);g=(!E|tb(v[v[i+8>>2]>>2],v[i+12>>2])^1)&g;W:{X:{if(!(v[e+1074392>>2]|(!(w[G+2|0]&32)|!b))){v[o+1075652>>2]=0;if(p){break X}a=o+1075e3|0;if(!zi(v[a>>2],v[a+4>>2])){break W}t[o+1075795|0]=b;if(x[_>>1]<b>>>0){break W}a=B(b,104)+e|0;v[o+1075680>>2]=x[a+484410>>1];u[o+1075764>>1]=t[a+484417|0];break W}if(!p){break W}}d=w[R|0];if(b){t[o+1075795|0]=b}Y:{Z:{if(!Rc(d)){break Z}ub(i+8|0,r,67);if(!tb(v[v[i+8>>2]>>2],v[i+12>>2])){break Z}a=u[o+1075762>>1];_:{if(!b|g){break _}f=dq(e,d,b);if(!f){break _}a=t[Fi(e,f)+36|0]}d=(a+d|0)-132>>>0<4294967176?0:d;break Y}if(!(v[K>>2]&25165856)){break Y}m=x[M>>1];if(!m){break Y}if(d){a=Rc(d)}else{a=1}if(!a){break Y}f=b;$:{if(!b){f=w[o+1075796|0];if(!f){break $}}if(v[((f<<2)+e|0)+900380>>2]?f>>>0<=m>>>0:0){break Y}d=0}b=0}if(!((N|0)!=25|c)){ub(i+8|0,r,55);a=tb(v[v[i+8>>2]>>2],v[i+12>>2]);b=a?0:b;d=a?0:d}ub(i+8|0,r,65);a=(b|0)!=0;f=tb(v[v[i+8>>2]>>2],v[i+12>>2]);m=!d;Q=1;aa:{if(v[K>>2]&16777248){break aa}ub(i+8|0,r,107);if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){break aa}ub(i,r,85);Q=0;if(!tb(v[v[i>>2]>>2],v[i+4>>2])){break aa}s=o+1075e3|0;if(zi(v[s>>2],v[s+4>>2])){break aa}Q=1;s=v[o+1075096>>2];if(!s){break aa}Q=Sd(s)^1}s=a&f;a=a&m;ba:{ca:{da:{ea:{fa:{ga:{ha:{if(!(v[K>>2]&1048580)){break ha}ia:{if((d|0)!=255){break ia}if(!(!((l|0)==1|b)&(N|0)!=13)){ub(i+8|0,r,55);if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){break ia}}f=v[o+1075648>>2];if(t[f+60|0]&1?f:0){break ia}v[o+1075680>>2]=0;a=o+1075080|0;v[a>>2]=v[a>>2]|2097152;ja:{if(!(v[e+480208>>2]&4096)){break ja}ub(i+8|0,r,86);if(!tb(v[v[i+8>>2]>>2],v[i+12>>2])){break ja}v[a>>2]=v[a>>2]|4096}b=0;d=0;a=0;f=0;m=1;if(s){break ca}break ba}ub(i+8|0,r,59);if(!tb(v[v[i+8>>2]>>2],v[i+12>>2])|v[G>>2]&4096){break ha}if(!d){d=w[o+1075789|0]-w[o+1075762|0]|0;break ga}if(d>>>0>250){Q=0;s=1;d=0;break ga}if(!b){ub(i+8|0,r,98);if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){break ga}}Q=1;s=1;break ga}f=0;if(!a){break ea}break fa}f=d;g=0}ub(i+8|0,r,65);if(!tb(v[v[i+8>>2]>>2],v[i+12>>2])){break da}d=f;f=1}a=d;m=1;if(s){break ca}break ba}d=f;f=1;m=s}ka:{la:{if(!x[M>>1]){if(x[_>>1]<b>>>0){break ka}a=(B(b,104)+e|0)+484380|0;break la}a=v[o+1075096>>2];if(!a){break ka}}ma:{if(u[a+34>>1]<0){break ma}if(v[K>>2]==2){if(!Sd(a)){break ma}}v[o+1075680>>2]=x[a+30>>1]}if(!m){break ka}Mp(j,x[a+28>>1],e)}a=d}ub(i+8|0,r,71);if(!(!tb(v[v[i+8>>2]>>2],v[i+12>>2])|!b)){t[o+1075831|0]=32}na:{if(!x[M>>1]){break na}ub(i+8|0,r,100);if(!tb(v[v[i+8>>2]>>2],v[i+12>>2])|!b){break na}if(Rc(a&255)){break na}d=v[G>>2];oa:{if(g){if(d&8){break oa}break na}if(!(d&4)){break na}}hm(j);v[o+1075688>>2]=65536;d=o+1075080|0;v[d>>2]=v[d>>2]|2097152}if(f){ub(i+8|0,r,11);pa:{qa:{ra:{if(!(tb(v[v[i+8>>2]>>2],v[i+12>>2])|v[K>>2]==268435456)){d=x[M>>1];break ra}ub(i+8|0,r,87);f=0;if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){d=o+1075e3|0;f=zi(v[d>>2],v[d+4>>2])^1}d=x[M>>1];sa:{if(d){if(b>>>0>d>>>0){break qa}if(v[o+1075648>>2]!=v[((b<<2)+e|0)+900380>>2]|f){break sa}break qa}if((f^-1)&v[o+1075096>>2]==((B(b,104)+e|0)+484380|0)){break pa}}a=w[o+1075789|0]}if(!(d&65535)){break pa}}if(!(v[K>>2]&1048588)){break pa}hm(j);t[o+1075810|0]=0;v[o+1075748>>2]=0;v[o+1075688>>2]=65536;d=o+1075080|0;v[d>>2]=v[d>>2]&-2101249|2097152;ub(i+8|0,r,86);if(!tb(v[v[i+8>>2]>>2],v[i+12>>2])){break pa}v[d>>2]=v[d>>2]&-2049}b=Q?b:0}m=a&255;ta:{if(m>>>0<251){break ta}ub(i+8|0,r,50);ua:{if(!tb(v[v[i+8>>2]>>2],v[i+12>>2])|!b){break ua}d=dq(e,w[o+1075791|0],b);if(!d){break ua}d=B(d,104)+e|0;if(u[d+484414>>1]<0){break ua}v[o+1075680>>2]=x[d+484410>>1]}ub(i+8|0,r,100);if(Ua=tb(v[v[i+8>>2]>>2],v[i+12>>2]),Va=0,Xa=v[G>>2]&4,Xa?Ua:Va){break ta}b=0}d=Rc(m);va:{if(!d){break va}t[o+1075794|0]=a;t[o+1075791|0]=a;if(!g){jM(e,h&65535,b,m,0)}f=o+1075776|0;a=u[f>>1];if(a){v[o+1075684>>2]=(a&32767)-1;if((a|0)<0){a=o+1075080|0;v[a>>2]=v[a>>2]|256}u[f>>1]=0}a=o+1075787|0;f=w[a|0];if(f){t[o+1075830|0]=f-1;t[a|0]=0}a=o+1075788|0;f=w[a|0];if(!f){break va}t[o+1075829|0]=f-1;t[a|0]=0}wa:{xa:{ya:{za:{Aa:{if(b){f=o+1075096|0;s=v[f>>2];Ap(e,j,b,g,1,1);a=v[f>>2];Ba:{if(!a|!(w[a+35|0]&2)){break Ba}if(!Bd(F)){break Ba}$y(v[F>>2],h&65535,a+68|0)}Ca:{Da:{if(v[K>>2]==1){if(!g){break Da}ub(i+8|0,r,85);if(!tb(v[v[i+8>>2]>>2],v[i+12>>2])){break Da}break Ca}ub(i+8|0,r,50);if((d|tb(v[v[i+8>>2]>>2],v[i+12>>2])^1)!=1){break Ca}}t[o+1075795|0]=0}ub(i+8|0,r,42);if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){if(!d|(s|0)==v[f>>2]){break za}break Aa}if(v[K>>2]&16777248){a=0;if(d&(s|0)!=v[f>>2]){break ya}}ub(i+8|0,r,107);Ea:{if(!tb(v[v[i+8>>2]>>2],v[i+12>>2])|(s|0)==v[f>>2]){break Ea}if((d^1|g)==1){a=o+1075068|0;if(y[a>>2]>=y[j+4>>2]){break Ea}v[a>>2]=0;break za}g=0}ub(i+8|0,r,85);if(!tb(v[v[i+8>>2]>>2],v[i+12>>2])){break za}a=o+1075e3|0;if(!zi(v[a>>2],v[a+4>>2])){break Aa}break za}if(!m){a=g;break wa}f=0;s=o+1075795|0;a=w[s|0];if(!(!a|d^1)){Ap(e,j,a,g,!(v[o+1075096>>2]?1:v[o+1075648>>2]),!(v[K>>2]&1048580));t[s|0]=0;f=1}a=g;break xa}v[j>>2]=0;v[j+4>>2]=0}a=g}f=0;if(!m){break wa}}d=v[o+1075096>>2];Fa:{if(!d|!(w[d+35|0]&2)){break Fa}if(!Bd(F)){break Fa}if(!f){if(kM(v[F>>2],h&65535)){break Fa}}$y(v[F>>2],h&65535,d+68|0)}d=h&65535;Qs(e,j,m,a,!(v[K>>2]&1048580),0,d);UM(e,I,d);if(!(!a|(!(v[K>>2]&1048580)|!b))){b=o+1075080|0;v[b>>2]=v[b>>2]|2097152;hm(j);t[o+1075810|0]=0;v[o+1075748>>2]=0}if(!(v[o+1075080>>2]&512)){break wa}if(!Bd(F)){break wa}if(m>>>0<=253){if((m|0)!=253){break wa}ub(i+8|0,r,99);if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){break wa}}ub(i+8|0,r,110);if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){az(v[F>>2],d,0,1,0)}fk(v[F>>2],d)}Ga:{Ha:{switch(l-1|0){case 0:A=A>>>0<64?A:64;v[o+1075680>>2]=A<<2;b=o+1075080|0;v[b>>2]=v[b>>2]|2097152;break Ga;case 1:break Ha;default:break Ga}}im(e,j,A,6)}if(x[M>>1]){hM(e,h&65535)}g=a}ub(i+8|0,r,77);if(Ua=tb(v[v[i+8>>2]>>2],v[i+12>>2]),Va=0,Xa=v[((h<<5)+e|0)+480280>>2]&1024,Xa?Ua:Va){break Q}a=v[e+1074392>>2];ub(i+8|0,r,75);d=a>>>0>=E>>>0;Ia:{Ja:{Ka:{La:{if(!tb(v[v[i+8>>2]>>2],v[i+12>>2])|!E){break La}b=v[e+1074392>>2];if(!b){break Ka}d=1;if((b|0)!=(E|0)){break La}d=!w[X|0]&(l|0)!=11}a=l;if(!d|a>>>0<3){break Ka}if((a|0)==11){a=i+8|0;Jy(a,e,R,E);b=w[Oe(a)|0];zn(e,j,x[a>>1]);if(b){break Ja}l=11;break Ka}ub(i+8|0,r,62);Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{if(!(!tb(v[v[i+8>>2]>>2],v[i+12>>2])|A)){A=0;l=0;Ta:{switch(a-8|0){case 0:break Sa;case 1:break Ta;default:break Ka}}if(w[G+1|0]&16){break Ka}v[o+1075684>>2]=0;break Ka}ub(i+8|0,r,41);Ua:{if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ua}if(A){t[o+1075826|0]=A;break Ua}A=w[o+1075826|0]}Va:{switch(a-3|0){case 0:case 1:Wa:{Xa:{if(A){break Xa}ub(i+8|0,r,41);if(!tb(v[v[i+8>>2]>>2],v[i+12>>2])){break Xa}A=w[o+1075826|0];if(A){break Wa}A=0;break Ka}t[o+1075826|0]=A}Fn(e,j,((a|0)==3?A<<4:A)&255);break Ka;case 2:if((E|0)!=v[e+1074392>>2]){ub(i+8|0,r,41);l=5;if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ka}}ub(i+8|0,r,41);En(e,j,A,tb(v[v[i+8>>2]>>2],v[i+12>>2]));l=5;break Ka;case 3:if((E|0)!=v[e+1074392>>2]){ub(i+8|0,r,41);l=6;if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ka}}ub(i+8|0,r,41);Dn(e,j,A,tb(v[v[i+8>>2]>>2],v[i+12>>2]));l=6;break Ka;case 11:break Ma;case 12:break Na;case 10:break Oa;case 9:break Pa;case 7:break Qa;case 6:break Ra;case 5:break Sa;case 4:break Va;default:break Ka}}ub(i+8|0,r,53);if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){t[o+1075815|0]=A&15;l=7;break Ka}cl(j,A<<4);l=7;break Ka}cl(j,A);l=8;break Ka}ub(i+8|0,r,62);uy(e,j,A,tb(v[v[i+8>>2]>>2],v[i+12>>2])^1);l=9;break Ka}ub(i+8|0,r,62);uy(e,j,A<<4&240,tb(v[v[i+8>>2]>>2],v[i+12>>2])^1);l=10;break Ka}l=12;ub(i+8|0,r,12);gM(e,h&65535,A<<2&252,tb(v[v[i+8>>2]>>2],v[i+12>>2]));break Ka}ub(i+8|0,r,12);fM(e,h&65535,A<<2&252,tb(v[v[i+8>>2]>>2],v[i+12>>2]));l=13;break Ka}l=15;if(!p){break Ka}a=v[o+1075096>>2];if(!a|A>>>0>9){break Ka}Ya:{if(!A){b=v[o+1075656>>2];break Ya}b=v[Ib(a+68|0,A-1|0)>>2];v[o+1075656>>2]=b}Gn(e,j,b);break Ka}l=14;if(A>>>0>1){break Ka}t[q|0]=w[q|0]&247|!A<<3}b=c;Za:{_a:{$a:{ab:{switch(N-1|0){case 12:if(!(w[G+1|0]&16)){break Ja}a=B(h,872)+e|0;v[a+1075680>>2]=c>>>0<64?c<<2:256;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Ja;case 1:if(!c){b=0;if(t[K|0]&1){break Ia}}gM(e,h&65535,c,0);break Ja;case 2:if(!c){b=0;if(t[K|0]&1){break Ia}}fM(e,h&65535,c,0);break Ja;case 10:if(!c){b=0;if(v[K>>2]==1){break Ia}}Fn(e,j,c);break Ja;case 3:zn(e,j,c);break Ja;case 5:if(!(!c&v[K>>2]==1)){Fn(e,j,c)}zn(e,j,0);break Ja;case 4:cl(j,c);break Ja;case 6:if(!(!c&v[K>>2]==1)){Fn(e,j,c)}cl(j,0);break Ja;case 15:if(!(w[G+1|0]&16)){break Ja}break Za;case 16:ub(i+8|0,r,5);if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){if(!(w[G+1|0]&16)){break Ja}if(c){break Za}break Ja}b=Cn(e,x[e+1074446>>1],v[e+1074424>>2],h&65535,0);bb:{if(!(v[e+480180>>2]&16777250)){break bb}if(b){t[(B(h,872)+e|0)+1075827|0]=b;break bb}b=w[(B(h,872)+e|0)+1075827|0]}v[i+8>>2]=B(b,1e4);qc(i+8|0,B(v[v[e+8>>2]+24>>2],1e4));a=cb-16|0;cb=a;d=v[i+8>>2];v[a+8>>2]=d;c=v[e+8>>2];cb:{if(d>>>0>=(v[e+480180>>2]&16393?1e4:32e4)>>>0){d=v[e+480208>>2];ub(a,e+1074312|0,92);if((tb(v[v[a>>2]>>2],v[a+4>>2])|0)==((d&4096)>>>12|0)){break cb}v[a>>2]=B(v[c+24>>2],1e4);Ua=e+1074420|0,Va=v[Bb(a+8|0,a)>>2],v[Ua>>2]=Va;break cb}if(w[e+480209|0]&16){break cb}f=e+1074420|0;d=(d>>>0)/1e4|0;g=B(d&15,1e4);v[f>>2]=v[f>>2]+((d&240)==16?g:0-g|0);d=v[c+20>>2];c=v[c+24>>2];ub(a,e+1074312|0,8);xo(f,B(d,1e4),tb(v[v[a>>2]>>2],v[a+4>>2])?255e4:B(c,1e4))}cb=a+16|0;break Ia;case 9:if(!p|(v[K>>2]==4?g:0)){break Ja}TM(e,j,h&65535,v[e+1074424>>2],x[e+1074446>>1]);break Ja;case 43:if(!p){break Ja}b=kka(v[(B(h,872)+e|0)+1075068>>2],0,c,0);a=fb;g=a>>>8|0;Gn(e,j,wc((a&255)<<24|b>>>8,g));break Ja;case 0:if(v[e+1074392>>2]){break Ja}a=B(h,872)+e|0;db:{if(w[a+1075789|0]?v[a+1075692>>2]:0){break db}a=v[a+1075648>>2];if(a){if(sj(w[a+31|0])){break db}}ub(i+8|0,r,13);if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){break db}if(v[K>>2]&16777248){break Ja}}if(!c){b=0;if(w[K|0]&5){break Ia}t[(B(h,872)+e|0)+1075797|0]=1;break Ia}a=B(h,872)+e|0;t[a+1075798|0]=c;t[a+1075797|0]=1;break Ja;case 14:if(v[K>>2]&1048580){c=c&240?c:w[(B(h,872)+e|0)+1075799|0]&240|c;if(!(c&15)){c=w[(B(h,872)+e|0)+1075799|0]&15|c}b=c|256}else{b=c}ub(i+8|0,r,23);if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){c=e;d=h&65535;if(b){t[(B(h,872)+e|0)+1075799|0]=b;a=b}else{a=w[(B(h,872)+e|0)+1075799|0]}ty(c,d,a&255,(l|0)==15?A+1|0:0);break Ia}eb:{if(b){t[(B(h,872)+e|0)+1075799|0]=b;break eb}b=w[(B(h,872)+e|0)+1075799|0]}ty(e,h&65535,b,(l|0)==15?A+1|0:0);break Ia;case 17:if(!(w[G+1|0]&16)){break Ja}ub(i+8|0,r,22);fb:{gb:{if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){if(!c){c=0;break gb}if(w[G|0]&4){break gb}a=c&240?c-16|0:c;c=a-((a&15)!=0)|0;t[(B(h,872)+e|0)+1075832|0]=c;break gb}ub(i+8|0,r,71);if(!tb(v[v[i+8>>2]>>2],v[i+12>>2])){break fb}}a=(B(h,872)+e|0)+1075831|0;t[a|0]=w[a|0]|128}a=B(h,872)+e|0;t[a+1075797|0]=18;if(!c){b=0;break Ia}t[a+1075832|0]=c;break Ja;case 22:if(!(w[G+1|0]&16)){break Ja}a=v[K>>2];b=c<<!(a&59593760);if(b>>>0<=128){v[e+1074456>>2]=b<<1;break Ia}if(a&16777250){break Ia}v[e+1074456>>2]=256;break Ia;case 23:ub(i+8|0,r,9);if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){eM(e,c,(B(h,872)+e|0)+1075809|0);break Ja}eM(e,c,ba);break Ja;case 8:if(!(w[G+1|0]&16)){break Ja}im(e,j,c,8);break Ja;case 28:uy(e,j,c,1);break Ja;case 7:LM(j,c);break Ja;case 25:MM(e,j,c);break Ja;case 18:g=e+1074376|0;d=h&65535;f=B(d,872);b=(g+f|0)+616|0;a=c&15;hb:{ib:{switch(c>>>4|0){case 0:a=(c&1)<<14;b=x[e+480188>>1];g=0;while(1){if((b|0)==(g|0)){break hb}d=(B(g,872)+e|0)+1075080|0;v[d>>2]=(a|v[d>>2]&-16385)^16384;g=g+1|0;continue};case 1:if(a){sy(e,b,a);break hb}if(!(v[e+480180>>2]&1048580)){break hb}sy(e,b,0);break hb;case 2:if(a){ry(e,b,a);break hb}if(!(v[e+480180>>2]&1048580)){break hb}ry(e,b,0);break hb;case 3:b=(e+f|0)+1075080|0;v[b>>2]=v[b>>2]&-1048577|((a|0)!=0)<<20;break hb;case 4:t[(e+f|0)+1075814|0]=c&7;break hb;case 5:if(!(w[e+480209|0]&16)){break hb}f=v[e+480180>>2];if(f&69206025){b=B(d,872)+e|0;u[b+1075764>>1]=a<<28>>24;f=b+1075692|0;if(!v[f>>2]){break hb}if(!Rc(w[b+1075780|0])){break hb}b=B(d,872)+e|0;Ua=f,Va=ch(e,w[b+1075789|0],a<<28>>24,v[b+1075696>>2]),v[Ua>>2]=Va;break hb}b=Rc(w[(B(d,872)+e|0)+1075780|0]);if((f|0)==16){if(!b){break hb}b=B(d,872)+e|0;f=v[b+1075096>>2];if(!f){break hb}t[f+37|0]=a;u[b+1075764>>1]=a;b=b+1075692|0;if(!v[b>>2]){break hb}f=b;b=B(d,872)+e|0;Ua=f,Va=ch(e,w[b+1075789|0],a,v[b+1075696>>2]),v[Ua>>2]=Va;break hb}if(!b){break hb}a=B(d,872)+e|0;b=(c<<4^-128)<<24>>24;u[a+1075764>>1]=b;d=a+1075692|0;if(!v[d>>2]){break hb}Ua=d,Va=ch(e,w[a+1075789|0],b,v[a+1075696>>2]),v[Ua>>2]=Va;break hb;case 6:if(!(w[e+480209|0]&16)){break hb}Ps(e,g,b,a);break hb;case 7:t[(e+f|0)+1075817|0]=c&7;break hb;case 8:if(!(w[e+480209|0]&16)){break hb}im(e,b,a,4);break hb;case 9:ty(e,d,a,0);break hb;case 10:if(a){En(e,b,a,0);break hb}if(!(v[e+480180>>2]&1048580)){break hb}En(e,b,0,0);break hb;case 11:if(a){Dn(e,b,a,0);break hb}if(!(v[e+480180>>2]&1048580)){break hb}Dn(e,b,0,0);break hb;case 12:vy(e,d,a,0);break hb;case 15:break ib;default:break hb}}if(v[e+480180>>2]==1){t[(B(d,872)+e|0)+1075838|0]=a;if(!(w[e+480209|0]&16)){break hb}iM(e,b);break hb}t[(B(d,872)+e|0)+1075836|0]=a}break Ja;case 19:ub(i+8|0,r,78);if(!(!tb(v[v[i+8>>2]>>2],v[i+12>>2])|c)){b=w[(B(h,872)+e|0)+1075798|0]}dM(e,h&65535,b);break Ia;case 24:ub(i+8|0,r,55);if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){if(v[e+1074392>>2]!=(c|0)){break Ja}a=v[(B(h,872)+e|0)+1075648>>2];if(t[a+60|0]&1?a:0){break _a}if(!(!(w[V|0]?1:w[X|0])|c)){a=(B(h,872)+e|0)+1075080|0;v[a>>2]=v[a>>2]|4096;break _a}a=B(h,872)+e|0;v[a+1075680>>2]=0;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break _a}if(w[G+1|0]&16){break _a}break Ja;case 27:a=(c&240)-16>>>4|0;if(a>>>0>9){break Ja}if(!(1<<a&880)){if(!a){break $a}if((a|0)!=1){break Ja}cM(e,j,c&15);break Ja}ub(i+8|0,r,58);if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ja}dM(e,h&65535,c);break Ja;case 34:case 35:if(!(w[G+1|0]&16)&(N|0)!=36){break Ja}b=h&65535;QM(e,b,I,(N|0)==36);a=Is(e,j);if(!a){break Ja}gb[v[v[a>>2]+80>>2]](a,(x[(B(h,872)+e|0)+1075766>>1]&65532)>>>2^8192,b);break Ja;case 20:if(!(w[G+1|0]&16)|c>>>0>64){break Ja}a=B(h,872)+e|0;v[a+1075740>>2]=c;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Ja;case 21:a=c;jb:{if(a){t[j+816|0]=a;break jb}a=w[j+816|0]}d=a&255;f=a&240;b=a&15;kb:{lb:{if(!(!f|(b|0)!=15)){if(!(w[e+480209|0]&16)){break kb}a=d>>>4|0;break lb}g=v[e+480208>>2]&4096;if(!(!b|(f|0)!=240)){if(!g){break kb}a=0-b|0;break lb}if(g){break kb}if(b){a=0-b|0;if(!(v[e+480180>>2]&25690144)|!f){break lb}break kb}if((a&255)>>>0<16){break kb}a=d>>>4|0}Ua=j,Va=Vb(a+v[j+748>>2]|0,0,64),v[Ua+748>>2]=Va}break Ja;case 26:KM(j,c);break Ja;case 29:if(!(w[G+1|0]&16)){break Ja}a=B(h,872)+e|0;v[a+1075716>>2]=c;ub(i+8|0,r,60);if(Ua=0,Va=tb(v[v[i+8>>2]>>2],v[i+12>>2]),Xa=w[a+1075722|0]&4,Xa?Ua:Va){break Ja}a=B(h,872)+e|0;v[a+1075732>>2]=c;v[a+1075724>>2]=c;break Ja;case 11:OM(e,I,h&65535);break Ja;case 13:a=NM(e,I,h&65535,c);if((a|0)==-1){break Ja}v[e+1074436>>2]=a;if(!(w[e+480208|0]&32)){break Ja}u[e+1074444>>1]=x[e+1074448>>1];break Ja;case 37:case 38:case 39:case 40:a=(N|0)==38|(N|0)==40;b=(N&254)==40;mb:{nb:{ob:{if(w[e+480209|0]&16){g=w[j+848|0];d=c&240;if(d){g=d|g&15;t[j+848|0]=g}d=c&15;if(d){g=d|g&-16;t[j+848|0]=g}t[j+849|0]=(g&240)>>>4;if(v[e+480180>>2]!=32768){break mb}break ob}if(v[e+480180>>2]==32768){break ob}d=w[j+849|0]-1|0;t[j+849|0]=d;if(d&255){break mb}g=w[j+848|0];break nb}g=w[j+848|0];if((g&240)==16){break nb}if(!(w[e+480209|0]&16)){break mb}}t[j+849|0]=(g&240)>>>4;d=g&15;a=a?d:0-d|0;d=v[j+656>>2];pb:{if(uj(d)){v[j+852>>2]=v[j+852>>2]+B(a,v[v[d+44>>2]+36>>2]);break pb}Ua=j,Va=ch(e,Hs(e,v[j+700>>2],u[j+772>>1],v[j+704>>2])+a|0,u[j+772>>1],v[j+704>>2]),v[Ua+700>>2]=Va}if(!b){break mb}v[j>>2]=0;v[j+4>>2]=0}break Ja;case 41:SM(j,c);break Ja;case 42:if(v[e+1074392>>2]|Y>>>0>1|c>>>0>47){break Ja}b=h;f=b;if((c&240)==16){f=x[e+480188>>1]-1|0;b=0}a=((Y|0)==1)<<26;while(1){d=b&65535;if(d>>>0>(f&65535)>>>0){break Ja}g=((d<<5)+e|0)+480280|0;v[g>>2]=a|v[g>>2]&-67108865;d=(B(d,872)+e|0)+1075080|0;v[d>>2]=a|v[d>>2]&-67108865;b=b+1|0;continue};case 44:break ab;default:break Ia}}RM(j,c);break Ja}bM(e,j,c&15);break Ja}Bn(e,j);break Ja}Ly(e,I,c)}b=c}ub(i+8|0,r,78);if(!(!tb(v[v[i+8>>2]>>2],v[i+12>>2])|!b)){a=b&255;t[j+840|0]=a;t[j+812|0]=a;t[j+811|0]=a;t[j+809|0]=a;t[j+807|0]=a;t[j+806|0]=a;t[j+826|0]=a>>>4;t[j+827|0]=a<<2&60}a=w[X|0];if(!a){break Q}t[o+1075796|0]=a}h=h+1|0;continue}break}a=1;break j}a=0}cb=H+32|0;qb:{if(!a|!v[e+1074420>>2]){break qb}a=VM(e,e+1074376|0);v[e+1074380>>2]=a;v[e+1074404>>2]=a;b=wd(x[e+480188>>1],1,31);rb:{if(Ed(w[e+1074366|0])){a=v[e+24628>>2];if((a|0)>=129){a=((B(a-128|0,b+4|0)|0)/16|0)+128|0}l=((B(v[e+480228>>2],a)<<1&-128)>>>0)/w[(b>>>1|0)+32272|0]|0;break rb}l=v[e+480228>>2]}u[e+480212>>1]=0;i=e+1298300|0;q=e+1074312|0;R=e+1074365|0;r=e+480180|0;E=e+480210|0;F=e+480209|0;Q=e+1074366|0;V=e+1074364|0;X=e+1074360|0;N=0;while(1){if((N|0)==256){k=1;a=v[e+24608>>2];f=x[e+480212>>1];if(a>>>0>f>>>0){break qb}d=cb-16|0;cb=d;v[d+8>>2]=e;b=e+1074478|0;c=b;f=b+(f<<1)|0;sb:{a=b+(a<<1)|0;b=a-b|0;if((b|0)<3){break sb}k=b>>1;b=(k-2|0)/2|0;while(1){if((b|0)<0){break sb}$x(c,v[d+8>>2],k,c+(b<<1)|0);b=b-1|0;continue}}k=a-c>>1;b=a;while(1){if((b|0)!=(f|0)){if(np(v[d+8>>2],x[b>>1],x[c>>1])){ay(b,c);$x(c,v[d+8>>2],k,c)}b=b+2|0;continue}break}b=a-c>>1;while(1){if((b|0)>1){a=a-2|0;ay(c,a);b=b-1|0;$x(c,v[d+8>>2],b,c);continue}break}cb=d+16|0}else{j=B(N,872)+e|0;m=j+1075080|0;tb:{if(!(v[m>>2]&4096)|(v[j+1075016>>2]|(v[j+1075012>>2]|v[j+1075688>>2]))){break tb}ub(n+16|0,q,64);if(tb(v[v[n+16>>2]>>2],v[n+20>>2])){break tb}v[j+1075068>>2]=0;a=j+1075084|0;v[a>>2]=0;v[a+4>>2]=0}c=x[e+480188>>1];b=v[m>>2];ub:{if(v[j+1075068>>2]|c>>>0>N>>>0?b&1024:1){if(c>>>0>N>>>0){oL(e,N&65535)}u[j+1075834>>1]=0;break ub}d=0;I=j+1075712|0;v[I>>2]=0;H=j+1075672|0;v[H>>2]=0;o=j+1075e3|0;a=o;v[a>>2]=0;v[a+4>>2]=0;v[j+1075092>>2]=0;v[n+44>>2]=1065353216;u[n+42>>1]=0;K=j+1075648|0;G=v[K>>2];v[n+36>>2]=0;k=0;s=j+1075692|0;k=v[s>>2]?v[j+1075068>>2]!=0:k;a=j+1074992|0;vb:{wb:{xb:{if(c>>>0<=N>>>0){break xb}if(w[((N<<5)+e|0)+480288|0]){break wb}if(!G){break xb}d=w[G+34|0]!=0}if((d|k)!=1){break vb}}v[n+8>>2]=v[j+1075680>>2];v[n+32>>2]=v[j+1075744>>2];ub(n+16|0,q,28);g=n+8|0;b=tb(v[v[n+16>>2]>>2],v[n+20>>2])?n+32|0:g;c=cb-16|0;cb=c;d=e+1074312|0;ub(c+8|0,d,28);yb:{if(tb(v[v[c+8>>2]>>2],v[c+12>>2])){v[b>>2]=v[b>>2]+u[a+776>>1];oe(b,0,64);break yb}ub(c+8|0,d,1);d=u[a+776>>1];if(tb(v[v[c+8>>2]>>2],v[c+12>>2])){v[b>>2]=d+v[b>>2];oe(b,0,256);break yb}v[a+688>>2]=d+v[a+688>>2];oe(a+688|0,0,256);v[b>>2]=v[a+688>>2];u[a+776>>1]=0}cb=c+16|0;b=cb-16|0;cb=b;c=e+1074312|0;ub(b+8|0,c,28);zb:{Ab:{if(!tb(v[v[b+8>>2]>>2],v[b+12>>2])){ub(b,c,1);if(!tb(v[v[b>>2]>>2],v[b+4>>2])){break Ab}}v[a+684>>2]=v[a+692>>2]+u[a+778>>1];oe(a+684|0,0,256);break zb}v[a+692>>2]=v[a+692>>2]+u[a+778>>1];oe(a+692|0,0,256);u[a+778>>1]=0;v[a+684>>2]=v[a+692>>2]}cb=b+16|0;c=cb-16|0;cb=c;Bb:{if(!(w[a+90|0]&4)|(v[e+480208>>2]&2101248)==2101248){break Bb}Cb:{if(v[g>>2]<=0){ub(c+8|0,e+1074312|0,21);if(!tb(v[v[c+8>>2]>>2],v[c+12>>2])){break Cb}}d=5;if(!(v[e+480180>>2]&5)){ub(c+8|0,e+1074312|0,21);d=tb(v[v[c+8>>2]>>2],v[c+12>>2])?5:6}b=dy(e,w[a+825|0],w[a+820|0]);Db:{if((w[a+825|0]&3)!=1){break Db}ub(c+8|0,e+1074312|0,89);if(!tb(v[v[c+8>>2]>>2],v[c+12>>2])){break Db}b=w[a+819|0];h=w[a+820|0];f=h<<2&124;b=(!(w[a+90|0]&2)|w[e+480209|0]&16?b:w[a+823|0]+b|0)&32?f^127:f;b=h&32?0-b|0:b}if(v[e+480180>>2]!=131072){b=v[g>>2]+((B(w[a+827|0],b)|0)/(1<<d)|0)|0}else{d=64-b|0;b=v[g>>2];b=((B(w[a+827|0],B(d,b))|0)/-8192|0)+b|0}v[g>>2]=b}b=v[e+480208>>2];if(!(v[e+480180>>2]&16777248)|b&4?b&4096:0){break Bb}ub(c+8|0,e+1074312|0,21);b=w[a+826|0];d=w[a+820|0];f=tb(v[v[c+8>>2]>>2],v[c+12>>2]);t[a+820|0]=(f?b<<2:d)+(f?d:b)}cb=c+16|0;h=N&65535;d=cb-16|0;cb=d;b=e+1074312|0;ub(d+8|0,b,71);Eb:{if(tb(v[v[d+8>>2]>>2],v[d+12>>2])){b=(B(h,872)+e|0)+1075831|0;c=t[b|0];if((c|0)>=0){break Eb}if(!(w[e+480209|0]&16|w[(B(h,872)+e|0)+1075797|0]!=18)){f=c&-33;t[b|0]=f;Fb:{Gb:{if((f|0)!=-64){c=c&223;if((c|0)!=128){break Gb}c=w[(B(h,872)+e|0)+1075832|0]>>>4|-64;break Fb}c=w[(B(h,872)+e|0)+1075832|0]&15|-128;break Fb}c=c-1|0}t[b|0]=c;b=(B(h,872)+e|0)+1075080|0;v[b>>2]=v[b>>2]|2097152}if((c&224)!=128){break Eb}v[g>>2]=0;break Eb}if(w[(B(h,872)+e|0)+1075797|0]!=18){break Eb}ub(d+8|0,b,22);Hb:{if(tb(v[v[d+8>>2]>>2],v[d+12>>2])){p=B(h,872)+e|0;b=p+1075831|0;f=w[b|0];c=f<<24>>24;if(!((c|0)>=0|!v[p+1075068>>2])){Ib:{Jb:{if((f|0)!=192){if((f|0)!=128){break Jb}c=w[(B(h,872)+e|0)+1075832|0]>>>4|-64;break Ib}c=w[(B(h,872)+e|0)+1075832|0]&15|-128;break Ib}c=c-1|0}t[b|0]=c}if((c&192)!=128){break Hb}v[g>>2]=0;break Hb}b=w[(B(h,872)+e|0)+1075832|0];f=b>>>4|0;A=f+(b&15)|0;p=v[e+480180>>2];if(!(w[e+480208|0]&4?0:p&16777248)){A=A+2|0;f=f+1|0}b=(B(h,872)+e|0)+1075831|0;c=w[b|0];if(!(p&4)){c=(c&255)>>>0<A>>>0?c:0;if((c&255)>>>0>=f>>>0){v[g>>2]=0}t[b|0]=c+1;break Hb}Kb:{if(w[e+480209|0]&16){c=c&255?c-1|0:0;break Kb}t[b|0]=c+1}if(((c&255)>>>0)%(A>>>0)>>>0<f>>>0){break Hb}v[g>>2]=0}b=(B(h,872)+e|0)+1075080|0;v[b>>2]=v[b>>2]|2097152}b=B(h,872)+e|0;Lb:{if(w[b+1075797|0]!=18){break Lb}c=v[b+1075648>>2];if(!c){break Lb}b=w[c+34|0];if(!b|w[c+15|0]&2){break Lb}f=B(h,872)+e|0;if(v[f+1075080>>2]&134218752){break Lb}f=f+1075791|0;p=w[f|0];if(!Rc(p)){break Lb}b=v[(B(b,160)+e|0)+906140>>2];if(!b){break Lb}p=gb[v[v[b>>2]+100>>2]](b,p,h)|0;A=v[g>>2];if(!(!p|A)){gb[v[v[b>>2]+92>>2]](b,c,w[f|0]+255|0,0,h);break Lb}if(p|!A){break Lb}gb[v[v[b>>2]+92>>2]](b,c,w[f|0],x[(B(h,872)+e|0)+1075680>>1],h)}cb=d+16|0;oe(g,0,256);v[n+8>>2]=v[n+8>>2]<<6;Mb:{if(G){ub(n+16|0,q,31);if(tb(v[v[n+16>>2]>>2],v[n+20>>2])){Ns(e,a)}d=n+8|0;b=cb-16|0;cb=b;Nb:{if(!by(e,a,0)){break Nb}f=v[a+656>>2];g=e+1074312|0;ub(b+8|0,g,31);Ob:{if(tb(v[v[b+8>>2]>>2],v[b+12>>2])){c=v[a+724>>2];if(c){break Ob}break Nb}c=v[a+724>>2]}ub(b+8|0,g,31);A=c-tb(v[v[b+8>>2]>>2],v[b+12>>2])|0;c=Lp(f+48|0,A,256,64);M=w[f+65|0];Pb:{if((M|0)==255){break Pb}p=u[a+728>>1];if((p|0)==-1){break Pb}M=Ib(v[f+48>>2],M);f=w[M+2|0];M=x[M>>1];ub(b+8|0,g,94);g=f<<2;c=(A|0)==(M|0)?g:c;if(tb(v[v[b+8>>2]>>2],v[b+12>>2])){c=p+(c-g<<1)|0;break Pb}if(!f){c=0;break Pb}c=(B(c,p)|0)/(g|0)|0}Ua=d,Va=(B(Vb(c,0,512),v[d>>2])|0)/256|0,v[Ua>>2]=Va}cb=b+16|0;CM(a,d);b=cb-16|0;cb=b;Qb:{if(!by(e,a,1)){break Qb}d=v[a+656>>2];f=e+1074312|0;ub(b+8|0,f,31);Rb:{if(tb(v[v[b+8>>2]>>2],v[b+12>>2])){c=v[a+732>>2];if(c){break Rb}break Qb}c=v[a+732>>2]}ub(b+8|0,f,31);d=Lp(d+68|0,c-tb(v[v[b+8>>2]>>2],v[b+12>>2])|0,64,64)-32|0;c=v[a+684>>2];Ua=a,Va=Vb(((B(d,(c|0)>127?256-c|0:c)|0)/32|0)+c|0,0,256),v[Ua+684>>2]=Va}cb=b+16|0;ub(n+16|0,q,115);if(tb(v[v[n+16>>2]>>2],v[n+20>>2])){break Mb}c=w[j+1075789|0];if(!c){break Mb}b=v[K>>2];if(!b|!w[b+26|0]){break Mb}EM(j+1075676|0,c,b);break Mb}if(!(w[m+1|0]&16)){break Mb}v[j+1075688>>2]=0;v[n+8>>2]=0}Sb:{if(w[j+1075843|0]&8){c=0;v[n+8>>2]=0;break Sb}c=v[n+8>>2];if(!c){c=0;break Sb}if(w[m+3|0]&8){v[H>>2]=0;break Sb}if(Ed(w[R|0])){b=B(v[n+32>>2],v[j+1075740>>2]);d=b;f=b>>31;b=c<<8;Ua=H,Va=yc(lka(kka(d,f,b,b>>31),fb,1048576,0),fb),v[Ua>>2]=Va;break Sb}b=B(v[n+32>>2],v[j+1075740>>2]);d=b;f=b>>31;b=B(v[e+1074456>>2],c);Ua=H,Va=yc(lka(kka(d,f,b,b>>31),fb,1048576,0),fb),v[Ua>>2]=Va}v[I>>2]=c;Tb:{Ub:{c=v[s>>2];if(!(v[r>>2]==2|(c|0)>=v[e+480260>>2])){if(!lj(e)){break Ub}c=v[s>>2]}if((c|0)<v[e+480264>>2]){break Tb}ub(n+16|0,q,113);if(!tb(v[v[n+16>>2]>>2],v[n+20>>2])){break Tb}if(lj(e)){break Tb}v[s>>2]=v[e+480264>>2];break Tb}v[s>>2]=v[e+480260>>2]}ub(n+16|0,q,73);b=v[s>>2];v[n+36>>2]=b;Vb:{if((v[m>>2]&1572864)!=1572864){break Vb}c=v[e+480208>>2];if(c&2097152){if(!Rs(j+1075780|0)|c&4096){break Vb}}c=j+1075704|0;Wb:{if((b|0)==v[c>>2]){c=v[j+1075708>>2];break Wb}v[c>>2]=b;d=b;b=j+1075764|0;c=j+1075696|0;c=ch(e,Hs(e,d,u[b>>1],v[c>>2]),u[b>>1],v[c>>2]);v[j+1075708>>2]=c}v[n+36>>2]=c}g=cb-16|0;cb=g;M=B(h,872)+e|0;Y=M+1075648|0;b=v[Y>>2];Xb:{if(!b){break Xb}c=w[b+34|0];if(!c|w[b+15|0]&2|(!v[(B(c,160)+e|0)+906140>>2]|v[(B(h,872)+e|0)+1075080>>2]&134218752)){break Xb}c=B(h,872)+e|0;_=c+1075783|0;A=w[_|0];d=0;f=w[c+1075791|0];if(Rc(f)){d=w[Eb(b+108|0,f-1|0)|0]}p=c+1075780|0;Yb:{Zb:{if((A|0)==1){f=0;_b:{$b:{switch((y[e+1074392>>2]%3|0)-1|0){case 0:f=w[(B(h,872)+e|0)+1075798|0]>>>4|0;break _b;case 1:break $b;default:break _b}}f=w[(B(h,872)+e|0)+1075798|0]&15}b=B(h,872)+e|0;t[b+1075793|0]=d;if(w[b+1075792|0]==(d+f|0)){break Yb}b=d;if(!(w[e+480209|0]&16)){break Zb}b=d;if(!Rc(w[p|0])){break Zb}break Yb}f=0;if(w[p|0]){break Yb}b=B(h,872)+e|0;if(!w[b+1075792|0]){break Yb}b=w[b+1075793|0]}gm(e,h,(b&255)+f|0,x[(B(h,872)+e|0)+1075680>>1])}b=(B(h,872)+e|0)+1075792|0;c=w[b|0];ac:{if(!c){if(!(w[e+480209|0]&16)|(A|0)!=1){break ac}if(Rc(w[p|0])){break ac}c=d;if(!Rc(c)){break ac}}gm(e,h,(c&255)+255|0,0)}t[b|0]=w[_|0]==1?w[(B(h,872)+e|0)+1075793|0]+f|0:0}bc:{if(w[M+1075797|0]!=1){break bc}if(uj(v[Y>>2])){f=0;cc:{dc:{ec:{switch(y[e+1074392>>2]%3|0){case 1:f=w[(B(h,872)+e|0)+1075798|0]>>>4|0;break dc;case 0:break dc;case 2:break ec;default:break cc}}f=w[(B(h,872)+e|0)+1075798|0]&15}u[n+42>>1]=f}b=(B(h,872)+e|0)+1075843|0;t[b|0]=w[b|0]|96;break bc}if(!(!(w[e+480209|0]&16)|v[e+480180>>2]!=1048576)){b=B(h,872)+e|0;c=ch(e,w[b+1075789|0],u[b+1075764>>1],v[b+1075696>>2]);v[n+36>>2]=c;v[b+1075692>>2]=c}b=e+1074312|0;ub(g+8|0,b,13);if(tb(v[v[g+8>>2]>>2],v[g+12>>2])){f=w[(B(h,872)+e|0)+1075798|0];if(!f){break bc}b=65536;fc:{switch(((y[e+1074392>>2]%(v[e+1074400>>2]+v[e+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:f=f<<4;case 0:b=v[((f&240)<<2)+37248>>2];break;default:break fc}}f=lj(e);c=v[n+36>>2];d=c;c=c>>31;if(f){b=kka(d,c,b,b>>31)+32768|0;c=fb;b=lka(b,b>>>0<32768?c+1|0:c,65536,0)}else{f=(b|0)/2|0;h=f>>31;p=c<<16|d>>>16;c=f;f=d<<16;d=c+f|0;c=h+p|0;b=lka(d,d>>>0<f>>>0?c+1|0:c,b,b>>31)}c=fb;Ua=n,Va=yc(b,c),v[Ua+36>>2]=Va;break bc}ub(g+8|0,b,51);if(tb(v[v[g+8>>2]>>2],v[g+12>>2])){if(w[e+480209|0]&16){break bc}gc:{hc:{b=v[e+1074416>>2];b=b-(y[e+1074392>>2]%(b>>>0)|0)|0;if((b|0)>16){break hc}if((b|0)==16){break bc}d=0;ic:{switch((b|0)%3|0){case 0:break bc;case 2:break hc;case 1:break ic;default:break gc}}d=w[(B(h,872)+e|0)+1075798|0]>>>4|0;break gc}d=w[(B(h,872)+e|0)+1075798|0]&15}b=B(h,872)+e|0;c=b+1075764|0;b=b+1075696|0;d=Hs(e,v[n+36>>2],u[c>>1],v[b>>2])+d|0;c=ch(e,d,u[c>>1],v[b>>2]);v[n+36>>2]=c;if(d>>>0<109){break bc}v[g+8>>2]=c;Ua=g,Va=ch(e,109,0,v[b>>2]),v[Ua+4>>2]=Va;Ua=n,Va=v[Pc(g+8|0,g+4|0)>>2],v[Ua+36>>2]=Va;break bc}c=v[e+1074392>>2];p=e+480180|0;f=v[p>>2];jc:{if((f|0)!=1){d=w[(B(h,872)+e|0)+1075789|0];break jc}d=B(h,872)+e|0;d=Hs(e,v[n+36>>2],u[d+1075764>>1],v[d+1075696>>2]);f=v[p>>2]}kc:{lc:{switch((((f&67633152?c+2|0:c)>>>0)%3|0)-1|0){case 0:d=(w[(B(h,872)+e|0)+1075798|0]>>>4|0)+d|0;break kc;case 1:break lc;default:break kc}}d=(w[(B(h,872)+e|0)+1075798|0]&15)+d|0}if(!(f&67633408|w[(B(h,872)+e|0)+1075789|0]!=(d&255))){ub(g+8|0,b,82);if(!tb(v[v[g+8>>2]>>2],v[g+12>>2])){break bc}}if(w[e+480210|0]&32){c=d&255;if((c|0)==85){v[n+36>>2]=2147483647;break bc}d=c>>>0>85?d-37|0:d}c=B(h,872)+e|0;f=ch(e,d&255,u[c+1075764>>1],v[c+1075696>>2]);v[n+36>>2]=f;if(v[e+480180>>2]&71860480){v[c+1075692>>2]=f;break bc}ub(g+8|0,b,82);if(!tb(v[v[g+8>>2]>>2],v[g+12>>2])){break bc}t[(B(h,872)+e|0)+1075792|0]=d}cb=g+16|0;if(!(!(w[E|0]&33)|v[n+36>>2]==2147483647)){mc:{if(v[r>>2]==2){c=452;b=3424;break mc}b=B(x[j+1075764>>1]>>>4&15,24);c=x[b+32982>>1]>>>1|0;c=c>>>0>452?c:452;b=x[b+32960>>1]<<1}oe(n+36|0,c,b);oe(s,c,b)}IM(e,a);b=v[m>>2]}nc:{if(!(b&256)|w[F|0]&64){break nc}ub(n+16|0,q,37);if(!tb(v[v[n+16>>2]>>2],v[n+20>>2])){break nc}v[j+1075676>>2]=128}s=N&65535;oL(e,s);oc:{if(!k){break oc}b=DM(e,a,n+36|0);if((b|0)<0|!(w[m+1|0]&2)){break oc}if(!Bd(i)){break oc}Ip(v[i>>2],s,b>>>2&255,1)}pc:{if(w[j+1075782|0]!=8){break pc}qc:{rc:{b=w[j+1075783|0];switch(b-5|0){case 1:break pc;case 0:case 2:break qc;default:break rc}}if((b|0)!=26){break pc}}b=v[r>>2];if((b|0)==4){if(w[F|0]&16){break pc}b=j+1075811|0;t[b|0]=w[b|0]+w[j+1075815|0];break pc}if(!(b&16777248)){break pc}cl(a,w[j+1075784|0]);nL(e,s,n+36|0,n+44|0)}nL(e,s,n+36|0,n+44|0);sc:{if(!k){break sc}v[n+32>>2]=0;c=n+36|0;p=cb-16|0;cb=p;f=v[a+104>>2];tc:{if(!f|!w[f+40|0]){break tc}M=uj(v[a+656>>2]);k=lj(e);ub(p+8|0,e+1074312|0,21);b=k?38272:37248;g=k?37248:38272;if(!(M|!tb(v[v[p+8>>2]>>2],v[p+12>>2])|v[e+480180>>2]==1048576)){if(!w[f+41|0]){break tc}d=w[a+818|0];v[p+4>>2]=v[a+756>>2]+w[f+39|0];Zh(p+4|0,w[f+40|0]<<8);h=v[p+4>>2];v[a+756>>2]=h;t[a+818|0]=w[a+818|0]+w[f+41|0];h=(h|0)/256|0;uc:{vc:{switch(w[f+38|0]-1|0){case 3:d=lL(An(e))+-64|0;break uc;case 2:d=64-(d+1>>>1|0)|0;break uc;case 1:d=(d+1>>>1|0)+-64|0;break uc;case 0:d=(d>>>1^-1)&64;break uc;default:break vc}}d=t[d+33552|0]}Zh(c,8388607);f=v[c>>2]<<8;v[c>>2]=f;h=B(d,h);A=(h|0)/64|0;d=A>>31;A=d^d+A;M=A>>>2|0;d=f;wc:{xc:{if((h|0)<=-64){h=f>>31;b=v[(M<<2)+b>>2];b=yc(lka(kka(f,h,b,b>>31),fb,65536,0),fb)-f|0;g=A&3;if(!g){break wc}k=(g<<2)+(k?37184:37120)|0;break xc}h=f>>31;b=v[g+(M<<2)>>2];b=yc(lka(kka(f,h,b,b>>31),fb,65536,0),fb)-f|0;g=A&3;if(!g){break wc}k=(g<<2)+(k?37120:37184)|0}g=b;b=v[k>>2];b=(g+yc(lka(kka(b,b>>31,f,h),fb,65536,0),fb)|0)-f|0}v[c>>2]=(b+d|0)/256;v[n+32>>2]=b&255;break tc}k=v[e+480180>>2]&16777248;d=w[f+39|0];yc:{if(!(k|d)){v[a+756>>2]=w[f+40|0]<<8;break yc}zc:{Ac:{if(k){A=d<<1;h=v[a+756>>2];d=a+756|0;break Ac}if(w[a+89|0]&8){break zc}h=((w[f+40|0]<<8&65280)>>>0)/(d>>>0)|0;A=v[a+756>>2];d=a+756|0}v[d>>2]=h+A}Zh(a+756|0,w[f+40|0]<<8)}d=w[a+818|0]+w[f+41|0]|0;t[a+818|0]=d;d=d<<24>>24;Bc:{Cc:{switch(w[f+38|0]-1|0){case 3:t[a+818|0]=d+1;k=t[(d&63)+33488|0];break Bc;case 2:k=(64-(d>>>1|0)&127)+-64|0;break Bc;case 1:k=((d>>>1|0)- -64&127)+-64|0;break Bc;case 0:k=(d|0)>=0?-64:64;break Bc;default:break Cc}}k=0-t[(d&255)+33552|0]|0;if(v[e+480180>>2]!=1048576){break Bc}k=(64-t[(d+-64&255)+33552|0]|0)/2<<16>>16}d=k;k=B(d,v[a+756>>2]);h=(k|0)/256|0;if(M){z[n+44>>2]=z[n+44>>2]+C(C(C(C(w[f+40|0])*C(.05000000074505806))*C(d|0))*C(.000244140625));t[a+851|0]=w[a+851|0]|64;break tc}if(v[e+480180>>2]!=4){Dc:{if((k|0)<=-256){h=0-h|0;k=0-k>>>16|0;d=(k<<2)+b|0;break Dc}b=g;k=(k|0)/65536|0;d=b+(k<<2)|0}f=v[c>>2];g=v[((k<<2)+b|0)+4>>2];b=v[d>>2];b=((B(g-b|0,(h|0)/4&63)|0)/64|0)+b|0;b=yc(lka(kka(f,f>>31,b,b>>31),fb,256,0),fb);v[c>>2]=b;v[n+32>>2]=b&255;v[c>>2]=v[c>>2]/256;break tc}v[c>>2]=v[c>>2]+((k|0)/16384|0)}cb=p+16|0;k=v[n+36>>2];if((k|0)<=v[e+480260>>2]){ub(n+16|0,q,81);if(tb(v[v[n+16>>2]>>2],v[n+20>>2])){v[j+1075068>>2]=0}k=v[e+480260>>2];v[n+36>>2]=k}Ec:{if(!uj(v[K>>2])){break Ec}b=j+1075843|0;c=w[b|0];if(!(v[e+1074392>>2]|!(c&32)?c&64:1)){break Ec}GO(a,z[n+44>>2],u[n+42>>1],e);c=b;b=w[b|0];t[c|0]=(b&64?-65:-33)&b}b=n+16|0;Ky(b,e,a,k,v[n+32>>2]);c=xb(b);d=kka(v[b>>2],v[b+4>>2],v[e+480240>>2],0);g=fb;f=lka(d,g,65536,0);k=fb;d=d+65535|0;g=d>>>0<65535?g+1|0:g;d=!g&d>>>0<131071;f=d?1:f;v[b>>2]=f;g=b;b=d?0:k;v[g+4>>2]=b;v[o>>2]=f;v[o+4>>2]=b;if((v[m>>2]&134219264)!=512){break sc}if(!Bd(i)){break sc}ub(n+8|0,q,99);Fc:{Gc:{if(Ua=tb(v[v[n+8>>2]>>2],v[n+12>>2]),Va=1,Xa=w[m+1|0]&16,Xa?Ua:Va){b=v[r>>2];break Gc}b=v[r>>2];if((b|0)!=2){break Fc}}d=v[m>>2];f=d&2048;Hc:{if(f?(b|0)==2:0){break Hc}b=kka(v[c>>2],0,261625,0)+66904|0;c=fb;c=wc(nka(b,b>>>0<66904?c+1|0:c,133808,0),fb);b=1;Ic:{if(f){break Ic}b=0;if(!(d&4096)){break Ic}b=!v[j+1075688>>2]}ub(n+8|0,q,110);if(Ua=tb(v[v[n+8>>2]>>2],v[n+12>>2]),Va=0,Xa=b,Xa?Ua:Va){break Hc}d=v[i>>2];ub(n+8|0,q,95);az(d,s,c,b,tb(v[v[n+8>>2]>>2],v[n+12>>2]))}c=v[i>>2];b=kka(B(v[j+1075744>>2],B(v[j+1075740>>2],v[I>>2])),0,63,0)+33554432|0;g=fb;g=b>>>0<33554432?g+1|0:g;Ip(c,s,wc((g&67108863)<<6|b>>>26,g>>>26|0)&255,0);b=j+1075676|0;k=b;d=v[b>>2];c=0;b=v[i>>2];f=hl(b,s);Jc:{if((f|0)==255){break Jc}if(gk(b)){break Jc}c=Eb(rd(b+318|0,f),10);g=b;f=$s(f)|192;b=w[c|0]&-49;b=(d|0)<171?b|16:b;b=((d|0)>84?b|32:b)&255;fh(g,s,f,b);c=(b>>>5&1)+(b<<27>>31)|0}v[k>>2]=(c<<7)+128}Kc:{b=v[K>>2];if(!b|(w[b+60|0]&7)!=1){break Kc}c=v[b+48>>2];b=v[b+52>>2];if(hc(c,b)){break Kc}c=v[mL(a,0)>>2];b=zj(b);if(c>>>0<x[b>>1]|w[b+2|0]){break Kc}pj(v[i>>2],s,1);ub(n+8|0,q,109);b=v[m>>2];Ua=m,Va=(tb(v[v[n+8>>2]>>2],v[n+12>>2])?b:b&-4609)|4096,v[Ua>>2]=Va;v[j+1075688>>2]=0;break sc}ub(n+8|0,q,99);if(!tb(v[v[n+8>>2]>>2],v[n+12>>2])|!(w[m+1|0]&16)|v[j+1075688>>2]){break sc}pj(v[i>>2],s,1);v[m>>2]=v[m>>2]&-513}Lc:{if(!G){break Lc}ub(n+16|0,q,31);if(tb(v[v[n+16>>2]>>2],v[n+20>>2])){break Lc}Ns(e,a)}c=v[m>>2];b=c&-65537;s=j+1075012|0;h=v[H>>2];A=j+1075016|0;c=v[s>>2]|(h|v[A>>2])?(b|c<<7&65536)^65536:b;v[m>>2]=c;H=j+1075664|0;b=H;v[b>>2]=0;v[b+4>>2]=0;g=j+1075834|0;b=w[g|0];d=b-4|0;k=b>>>0<d>>>0?0:d;t[g|0]=k;p=j+1075835|0;b=w[p|0];d=b-4|0;b=b>>>0<d>>>0?0:d;t[p|0]=b;Mc:{Nc:{Oc:{Pc:{Qc:{Rc:{Sc:{Tc:{Uc:{d=v[j+1075096>>2];Vc:{if(!d){break Vc}if(!Sd(d)|!v[j+1075068>>2]){break Vc}if(zi(v[o>>2],v[o+4>>2])){break Uc}}v[j+1075008>>2]=0;break Tc}d=v[d+20>>2];v[j+1075008>>2]=d;if(d){break Sc}}if(!dk(v[K>>2])){break Rc}d=0;if(c&6144){break Rc}}G=v[j+1075676>>2];f=(B(h,256-G|0)|0)/16384|0;f=f>>>0<127?f:127;if(k<<24>>24<0){t[g|0]=f;k=f}f=f>>>1|0;if((k&255)>>>0<f>>>0){t[g|0]=f}f=(B(h,G)|0)/16384|0;f=f>>>0<127?f:127;k=f>>>1|0;if(b<<24>>24<0){t[p|0]=f;b=f}if((b&255)>>>0<k>>>0){break Qc}break Pc}if((k&255)>>>0>=129){t[g|0]=0}d=0;k=0;if((b&255)>>>0<129){break Oc}}t[p|0]=k}if(!d){break Oc}c=128;if(y[e+24624>>2]>=2){c=Vb(v[j+1075676>>2],0,256)}v[n+16>>2]=c;b=B(h,l)>>>(Ed(w[Q|0])?7:8)|0;Wc:{Xc:{Yc:{switch(w[V|0]){case 0:if(!(w[e+24616|0]&16)){break Xc}case 1:if((c|0)<=127){d=b>>>1|0;b=(B(b,c)|0)/256|0;break Wc}d=(B(b,256-c|0)|0)/256|0;b=b>>>1|0;break Wc;case 3:break Yc;default:break Xc}}Zh(n+16|0,255);c=v[n+16>>2];if((c|0)<=0){d=65536}else{d=x[(0-c<<1)+39808>>1]}d=B(d,b)>>>16|0;b=B(b,x[(c<<1)+39296>>1])>>>16|0;break Wc}d=(B(b,256-c|0)|0)/256|0;b=(B(b,c)|0)/256|0}c=v[K>>2];Zc:{if(c){k=w[c+14|0];if(qo(k)){break Zc}}k=w[e+480268|0];if(qo(k)){break Zc}if(w[E|0]&128){k=255;if(v[e+24668>>2]){break Zc}}k=w[e+24648|0]}f=j+1075668|0;h=j+1075786|0;t[h|0]=k;g=v[m>>2];c=v[o>>2];p=v[o+4>>2];if(!(g&131072|((c|0)!=0|(p|0)!=1)|(v[j+1075748>>2]|(k&255)==255))){t[h|0]=0}k=d;d=1<<v[X>>2];v[H>>2]=(k|0)/(d|0);b=(b|0)/(d|0)|0;v[f>>2]=b;if(!(!(g&256)|v[e+24624>>2]!=2)){v[f>>2]=0-b}if(g&128){v[o>>2]=0-c;v[o+4>>2]=0-(((c|0)!=0)+p|0)}h=0;g=cb-16|0;cb=g;v[a+28>>2]=0;v[a+32>>2]=0;Zh(a+672|0,524287);Zh(a+676|0,524287);d=a;d=a;_c:{$c:{c=v[a+88>>2];if(!(c&65536)){a=v[d+676>>2];b=v[d+672>>2];break $c}b=v[d+20>>2];f=v[d+672>>2];ad:{if((b|0)!=(f|0)){a=v[d+24>>2];k=v[d+676>>2];break ad}a=v[d+24>>2];k=v[d+676>>2];if((a|0)==(k|0)){break $c}}c=v[e+24620>>2];f=(b|0)<(f|0)|(a|0)<(k|0);bd:{if(f){b=dt(c,v[e+24636>>2]);break bd}b=dt(c,v[e+24640>>2])}ub(g,e+1074312|0,4);if(!(!tb(v[v[g>>2]>>2],v[g+4>>2])|!(v[e+480180>>2]&4))){a=v[e+24620>>2];a=kka(a,a>>31,5,0)+500|0;c=fb;b=yc(lka(a,a>>>0<500?c+1|0:c,1e3,0),fb)}c=v[d+656>>2];cd:{if(!c){a=b;break cd}a=b;if(!f){break cd}c=x[c+12>>1];if(c){a=(B(c,v[e+24620>>2])>>>0)/1e5|0}h=(c|0)!=0}f=a?a:1;c=v[d+676>>2];a=v[d+24>>2];p=c-a<<12;k=v[d+672>>2];s=v[d+20>>2];o=k-s<<12;if(!(w[d+90|0]&32|(!(c|k)|(!(a|s)|h)))){v[g+12>>2]=v[e+1074380>>2];oe(g+12|0,b,2048);k=v[d+672>>2];f=v[g+12>>2];c=v[d+676>>2]}h=(p|0)/(f|0)|0;v[d+32>>2]=h;p=(o|0)/(f|0)|0;v[d+28>>2]=p;a=((B(f,h)|0)/-4096|0)+c|0;v[d+24>>2]=a;b=((B(f,p)|0)/-4096|0)+k|0;v[d+20>>2]=b;if(h|p){v[d+100>>2]=f;c=v[d+88>>2];break _c}v[d+24>>2]=c;v[d+20>>2]=k;a=c;b=k;c=v[d+88>>2]&-65537;break _c}v[d+24>>2]=a;v[d+20>>2]=b;c=c&-65537}v[d+88>>2]=c&-2097153;v[d+40>>2]=a<<12;v[d+36>>2]=b<<12;cb=g+16|0;c=v[m>>2];if(!(c&512)){break Nc}break Mc}v[s>>2]=0;v[A>>2]=0;v[j+1075068>>2]=0;if(v[j+1075088>>2]){break Nc}if(!v[j+1075084>>2]){break Mc}}a=x[e+480212>>1];u[e+480212>>1]=a+1;u[((a<<1)+e|0)+1074478>>1]=N}v[j+1075660>>2]=c}N=N+1|0;continue}break}k=1}cb=n+48|0;if(k){b=v[e+480208>>2];break h}if(Ed(w[Ha|0])){a=v[e+480208>>2]|512;break i}l=0;dd:{a=v[e+24620>>2]/10|0;b=yc(a,a>>31);if(!b){break dd}c=b>>>0<1048576?b:1048576;v[e+1074380>>2]=c;f=x[e+480212>>1];d=e+1074376|0;while(1){if((f|0)==(l|0)){break dd}a=d+B(x[(d+(l<<1)|0)+102>>1],872)|0;k=a+1288|0;v[k>>2]=0;v[k+4>>2]=0;v[a+716>>2]=c;k=v[a+640>>2]<<12;v[a+656>>2]=k;g=v[a+636>>2]<<12;v[a+652>>2]=g;v[a+704>>2]=v[a+704>>2]|65536;v[a+644>>2]=(0-g|0)/(c|0);v[a+648>>2]=(0-k|0)/(c|0);l=l+1|0;continue}}c=v[e+480208>>2];a=c|256;if(b){break i}a=c|512}b=a;v[e+480208>>2]=b}if(!(b&512)){break g}Ua=e+1074392|0,Va=dl(Ga),v[Ua>>2]=Va}cb=T+112|0;break f}v[T+96>>2]=512;a=v[e+1074380>>2];v[T+104>>2]=ha;v[T+100>>2]=a;j=xB(T+96|0);if(v[e+24632>>2]){b=0;a=cb-48|0;cb=a;c=j<<2;while(1){if((b|0)==4){ed:{b=0;while(1){if((b|0)==4){break ed}v[(a+32|0)+(b<<2)>>2]=((b<<11)+e|0)+16396;b=b+1|0;continue}}}else{v[a+32>>2]=0;d=((b<<11)+e|0)+16396|0;Pz(d,c+d|0,a+32|0);b=b+1|0;continue}break}b=pg(a+16|0,a+32|0,v[e+24632>>2],j);c=v[v[fa>>2]+8>>2];v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;gb[c|0](fa,a);cb=a+48|0}if(jL(sa)){b=0;while(1){if((b|0)==4){b=v[sa>>2];a=pg(T+80|0,T+96|0,v[e+24632>>2],j);c=v[v[b>>2]+8>>2];v[T+40>>2]=v[a+8>>2];d=v[a+4>>2];v[T+32>>2]=v[a>>2];v[T+36>>2]=d;gb[c|0](b,T+32|0)}else{v[(T+96|0)+(b<<2)>>2]=((b<<11)+e|0)+16396;b=b+1|0;continue}break}}ia=0;F=cb-48|0;cb=F;if(j){i=e+12|0;o=e+24592|0;r=e+24588|0;Om(i,j,o,r);if(y[e+24624>>2]>=3){Om(e+8204|0,j,e+24600|0,e+24596|0)}u[F+42>>1]=0;xa=e+1074312|0;Ja=e+24648|0;A=e+24596|0;N=e+24600|0;K=e+8204|0;H=e+397452|0;G=e+397448|0;s=e+393352|0;ya=e+397456|0;na=e+1074376|0;Ka=e+480190|0;while(1){if(x[e+480212>>1]<=ia>>>0){Ua=e,Va=x[ie(e+480214|0,F+42|0)>>1],u[Ua+480214>>1]=Va}else{l=(ia<<1)+na|0;a=B(x[l+102>>1],872);h=a+na|0;Q=h;fd:{gd:{if(v[h+632>>2]){break gd}b=a+e|0;if(v[b+1075088>>2]){break gd}if(!v[b+1075084>>2]){break fd}}g=a+e|0;a=w[g+1075786|0]+1|0;if((a&255)>>>0<=5){k=v[(a<<24>>24<<2)+27888>>2]}else{k=0}I=g+1075080|0;f=v[I>>2];hd:{if(!(!(f&16777216)&w[e+24612|0]>>>5)){b=o;a=r;c=f;d=i;if(!(c&8388608)){break hd}}b=G;a=H;if(!w[ya+12|0]){Om(s,j,b,a)}t[ya+12|0]=1;c=v[I>>2];d=s}if(!(!(c&256)|y[e+24624>>2]<3)){d=K;b=N;a=A}oa=Il(e,na,x[l+102>>1],2,1);za=(oa-1&255)>>>0>249;id:{if(za){break id}l=v[(B(oa,160)+e|0)+906140>>2];if(!l){break id}c=v[l+24>>2];if(!c){break id}a=l+36|0;b=l+40|0;if(!(t[l+28|0]&1)){Om(c,j,b,a);v[l+28>>2]=v[l+28>>2]|1}d=c}m=h+616|0;if(w[g+1075843|0]&8){$C(m,d,j);c=b;d=v[b>>2];b=g+1075084|0;v[c>>2]=d+v[b>>2];v[a>>2]=v[a>>2]+v[g+1075088>>2];v[b>>2]=0;v[b+4>>2]=0;break fd}V=0;l=cb-16|0;cb=l;ja=F+16|0;c=ja;v[c>>2]=0;v[c+4>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;h=l+8|0;n=e+1074312|0;ub(h,n,33);Ua=c,Va=tb(v[v[l+8>>2]>>2],v[l+12>>2]),t[Ua+16|0]=Va;ub(h,n,116);Ua=c,Va=tb(v[v[l+8>>2]>>2],v[l+12>>2])^1,t[Ua+17|0]=Va;if(v[m+16>>2]){_C(ja,m);h=v[m+12>>2];n=h;c=h>>31;h=c+v[m+8>>2]|0;p=c+n|0;p=h>>>0<c>>>0?p+1|0:p;c=c^p;v[ja+12>>2]=c>>>0>8191?2:16384/(c+1>>>0)|0}La=f>>>12&8|(f>>>5&2|(k|f&1));Ma=g+1075795|0;Na=g+1075778|0;Oa=g+1075688|0;Pa=g+1075024|0;Qa=g+1075020|0;Ra=g+1075668|0;Sa=g+1075664|0;X=g+1075088|0;Y=g+1075084|0;Aa=g+1075016|0;Ba=g+1075012|0;ka=g+1075096|0;_=g+1075076|0;R=g+1075068|0;M=g+1075e3|0;la=g+1075072|0;ba=g+1075092|0;cb=l+16|0;k=j;while(1){jd:{c=v[ba>>2];ma=c?c>>>0<k>>>0?c:k:k;v[F+8>>2]=ma;kd:{ld:{if(!ma){break ld}f=v[M>>2];h=v[M+4>>2];if(!(f|h)){break ld}q=v[R>>2];if(!q){break ld}c=v[F+16>>2];if(!c){break ld}E=v[I>>2];p=v[la>>2];v[Q+632>>2]=c;c=v[m+4>>2];l=c;g=v[m>>2];md:{nd:{n=p&E<<30>>31;if((n|0)>(c|0)){if((h|0)<0){g=Tg(0,n<<1,g,l);c=fb;l=c;v[m>>2]=g;v[m+4>>2]=c;if(!(c>>>0<n+q>>>1>>>0&(c|0)>=(n|0))){g=0;v[m>>2]=g;l=n;v[m+4>>2]=n}od:{if(E&4){E=E&-129;v[I>>2]=E;h=0-(((f|0)!=0)+h|0)|0;f=0-f|0;v[M>>2]=f;v[M+4>>2]=h;break od}c=q-1|0;l=c;v[m>>2]=g;v[m+4>>2]=c}if(!(E&2)){break ld}if(l>>>0<q>>>0){break md}break ld}if((l|0)>0|(l|0)>=0){break md}l=0;break nd}if(c>>>0<q>>>0){break md}if(!(E&2)){break ld}if(E&4){if(!!f&(h|0)>=0|(h|0)>0){h=0-(((f|0)!=0)+h|0)|0;f=0-f|0;v[M>>2]=f;v[M+4>>2]=h}v[I>>2]=E|128;if(w[F+33|0]){E=w[F+32|0];Z=v[_>>2]-(E+p|0)|0;g=Tg(g,l,0,q);c=fb;l=c;if(c>>>0<Z>>>0){g=Tg(0,q-E|0,g,l);l=fb;break nd}g=0;l=p;break nd}l=c;c=1-((g|0)!=0)|0;g=0-g|0;c=(q<<1)-(l+c|0)|0;E=g;v[m>>2]=g;Z=0;l=Z|c;v[m+4>>2]=l;if(c>>>0<q>>>0&c>>>0>p>>>0){break md}v[F+44>>2]=w[F+32|0]+1;g=E;l=Z|q-v[Bb(R,F+44|0)>>2];break nd}if((h|0)<0){h=0-(((f|0)!=0)+h|0)|0;f=0-f|0;v[M>>2]=f;v[M+4>>2]=h}Jb(m,0,n-q|0);v[I>>2]=v[I>>2]|8192;g=v[m>>2];l=v[m+4>>2];break md}v[m>>2]=g;v[m+4>>2]=l}E=l;pd:{if((l|0)<(n|0)){if((l|0)<0){break ld}if((h|0)>0|(h|0)>=0){break pd}break ld}if((l|0)<0){break ld}}if(y[R>>2]<=E>>>0){break ld}v[F+44>>2]=ma;qc(F+8|0,v[F+28>>2]);c=h>>31;da=c;p=c+f|0;q=c;c=c+h|0;c=p>>>0<q>>>0?c+1|0:c;Ta=p;ea=v[la>>2];Ca=ea+16|0;Da=v[F+8>>2];Z=dv(f,h,Da-1|0)+g|0;p=l+fb|0;p=g>>>0>Z>>>0?p+1|0:p;ea=E>>>0<ea>>>0;if(!(!ea&E>>>0<Ca>>>0)){v[I>>2]=v[I>>2]&-8193}Z=da^Ta;da=c^q;q=p;qd:{rd:{p=v[F+20>>2];sd:{if(p){c=v[F+24>>2];if(c>>>0<=E>>>0){td:{if((h|0)<0){f=0;h=c;break td}f=g;h=l;g=0;l=v[_>>2]}Ua=F,Va=yo(Tg(Tg(g,l,f,h),fb,1,0),fb,Z,da)+1|0,v[Ua+44>>2]=Va;v[Q+632>>2]=p;break qd}if(!(ea|!(w[I+1|0]&32)|E>>>0>=Ca>>>0)){Ua=F,Va=yo(Tg(Tg(0,n+16|0,g,l),fb,1,0),fb,Z,da)+1|0,v[Ua+44>>2]=Va;Ua=Q,Va=p+B(v[_>>2]-n|0,Ak(x[v[ka>>2]+34>>1]))|0,v[Ua+632>>2]=Va;break qd}if(!f&(h|0)<=0|(h|0)<0){break sd}if(ma>>>0<2|c>>>0>q>>>0){break rd}Ua=F,Va=yo(Tg(Tg(0,c,g,l),fb,1,0),fb,Z,da)+1|0,v[Ua+44>>2]=Va;break qd}if((h|0)>0|(h|0)>=0){break rd}}if((n|0)<=(q|0)){break qd}Ua=F,Va=yo(Tg(Tg(g,l,0,n),fb,1,0),fb,Z,da)+1|0,v[Ua+44>>2]=Va;break qd}c=v[R>>2];if((c|0)>(q|0)){break qd}Ua=F,Va=yo(Tg(Tg(0,c,g,l),fb,1,0),fb,Z,da)+1|0,v[Ua+44>>2]=Va}xo(F+44|0,1,Da);f=v[F+44>>2];if((f|0)>0){break kd}}v[Q+632>>2]=0;v[R>>2]=0;v[m>>2]=0;v[m+4>>2]=0;v[ba>>2]=0;$C(m,d,k);v[b>>2]=v[b>>2]+v[Y>>2];v[a>>2]=v[a>>2]+v[X>>2];v[X>>2]=0;v[Y>>2]=0;v[I>>2]=v[I>>2]&-129;E=x[F+42>>1];break jd}ud:{vd:{E=x[F+42>>1];if(E>>>0<y[e+24608>>2]){V=4;if(v[ba>>2]){break vd}V=0;if(v[Aa>>2]|v[Ba>>2]){break vd}}Jb(m,kka(v[M>>2],v[M+4>>2],f,f>>31),fb);V=0;v[X>>2]=0;v[Y>>2]=0;c=(f<<3)+d|0;break ud}c=(f<<3)+d|0;g=c-8|0;v[Y>>2]=0-v[g>>2];l=c-4|0;v[X>>2]=0-v[l>>2];gb[v[((V|La)<<2)+27504>>2]](m,Ja,d,f);v[Y>>2]=v[Y>>2]+v[g>>2];v[X>>2]=v[X>>2]+v[l>>2];V=1}d=c;c=v[ba>>2];wd:{if(!c){break wd}if(c>>>0<=f>>>0){v[ba>>2]=0;v[Ba>>2]=v[Sa>>2];v[Aa>>2]=v[Ra>>2];v[Qa>>2]=0;v[Pa>>2]=0;if(v[Oa>>2]|!(w[I+1|0]&16)){break wd}v[R>>2]=0;v[Q+632>>2]=0;break wd}v[ba>>2]=c-f}g=0;c=0;l=v[m+4>>2];c=l>>>0>=y[_>>2]?(w[I|0]&2)>>>1|0:c;h=l;l=v[R>>2];g=h>>>0<l>>>0|(!l|w[I|0]&2)?g:!x[Na>>1];k=k-f|0;ub(F+8|0,xa,85);xd:{yd:{zd:{Ad:{if(!tb(v[v[F+8>>2]>>2],v[F+12>>2])){break Ad}f=w[Ma|0];if(!f|f>>>0>x[Ka>>1]){break Ad}h=!(c|g);f=B(f,104)+e|0;g=f+484380|0;l=v[ka>>2];if(h|(g|0)==(l|0)){break zd}v[ka>>2]=g;v[Q+632>>2]=v[f+484400>>2];c=x[f+484414>>1];v[I>>2]=c|v[I>>2]&-768;l=c<<30>>31;c=v[f+484388>>2];v[R>>2]=l&c;f=v[f+484384>>2];v[la>>2]=f;v[_>>2]=c;v[m+4>>2]=f;_C(ja,m);if(!v[Q+632>>2]){break jd}if((k|0)>0){continue}break jd}if(c){break yd}break xd}if(!c|(g|0)!=(l|0)){break xd}}ub(F+8|0,xa,83);if(!tb(v[v[F+8>>2]>>2],v[F+12>>2])|v[la>>2]){break xd}v[m>>2]=v[m>>2];v[m+4>>2]=0;c=v[v[ka>>2]+8>>2];v[R>>2]=c;v[_>>2]=c}if((k|0)>0){continue}}break}v[Q+632>>2]=v[F+16>>2];u[F+42>>1]=E+V;if(za|!V){break fd}a=v[(B(oa,160)+e|0)+906140>>2];if(!a){break fd}gb[v[v[a>>2]+148>>2]](a)}ia=ia+1|0;continue}break}}cb=F+48|0;if(Bd(wa)){a=aa;b=j;c=(B(v[e+480232>>2],v[e+480236>>2])>>>0)/48|0;h=cb-16|0;cb=h;Bd:{o=v[wa>>2];if(!w[o+534|0]){break Bd}f=kka(c,0,6169,0);d=fb;c=d>>>16|0;s=wc((d&65535)<<16|f>>>16,c);while(1){if(!b){break Bd}g=v[o>>2];n=v[g>>2];d=v[g+4>>2];while(1){if((d|0)>=(n|0)){v[g+8>>2]=v[g+12>>2];n=0;f=0;l=0;c=cb-16|0;cb=c;while(1){if((l|0)==18){d=(n|0)<32767?n:32767;u[g+12>>1]=(d|0)>-32768?d:-32768;d=(f|0)<32767?f:32767;u[g+14>>1]=(d|0)>-32768?d:-32768;u[g+3832>>1]=x[g+3832>>1]+1;d=(x[g+3834>>1]+1>>>0)%13440|0;u[g+3834>>1]=d;d=d>>>0<6720?d:13440-d|0;u[g+3836>>1]=(d&65280)>>>8;if(!w[g+3843|0]){u[g+3836>>1]=(d&64512)>>>10}d=x[g+3838>>1]+1|0;u[g+3838>>1]=d;if((d&65535)>>>0>=1024){u[g+3838>>1]=0;u[g+3840>>1]=x[g+3840>>1]+1&7}cb=c+16|0}else{k=g+B(l,44)|0;Cd:{if(!w[k+56|0]){u[c+12>>1]=0;u[c+14>>1]=0;break Cd}m=v[k+32>>2];d=x[m+3840>>1];if(d&3){m=(x[k+36>>1]>>>7&7)>>>(w[m+3844|0]^1)>>>(d&1)<<x[k+38>>1];d=d&4?0-m|0:m}else{d=0}m=v[k+52>>2];Dd:{if(m){r=x[m+32>>1];i=x[k+48>>1];m=hg(v[k+16>>2],v[k+40>>2],d<<16>>16,0,u[k+46>>1]);q=v[k+40>>2];p=v[k+20>>2];if(!r){if(!i){d=d<<16>>16;m=hg(p,q,d,m,0);m=hg(v[k+24>>2],v[k+40>>2],d,m,0);d=hg(v[k+28>>2],v[k+40>>2],d,m,0);break Dd}d=d<<16>>16;q=hg(p,q,d,0,0);q=hg(v[k+24>>2],v[k+40>>2],d,q,0);d=hg(v[k+28>>2],v[k+40>>2],d,q,0)+m|0;break Dd}if(!i){d=d<<16>>16;m=hg(p,q,d,m,0);q=hg(v[k+24>>2],v[k+40>>2],d,0,0);d=hg(v[k+28>>2],v[k+40>>2],d,q,0)+m|0;break Dd}d=d<<16>>16;q=hg(p,q,d,0,0);d=(hg(v[k+24>>2],v[k+40>>2],d,q,0)+m|0)+hg(v[k+28>>2],v[k+40>>2],d,0,0)|0;break Dd}i=x[k+48>>1];d=d<<16>>16;m=hg(v[k+16>>2],v[k+40>>2],d,0,u[k+46>>1]);q=v[k+40>>2];p=v[k+20>>2];if(!i){d=hg(p,q,d,m,0);break Dd}d=hg(p,q,d,0,0)+m|0}u[c+14>>1]=w[k+57|0]?d:0;u[c+12>>1]=w[k+58|0]?d:0}l=l+1|0;f=u[c+12>>1]+f|0;n=u[c+14>>1]+n|0;continue}break}n=v[g>>2];d=v[g+4>>2]-n|0;v[g+4>>2]=d;continue}break}c=n-d|0;u[h+14>>1]=(B(u[g+12>>1],d)+B(c,u[g+8>>1])|0)/(n|0);u[h+12>>1]=(B(u[g+14>>1],d)+B(c,u[g+10>>1])|0)/(n|0);v[g+4>>2]=d+49716;v[a>>2]=v[a>>2]+B(s,u[h+14>>1]);v[a+4>>2]=v[a+4>>2]+B(s,u[h+12>>1]);a=a+8|0;b=b-1|0;continue}}cb=h+16|0}Ed:{if(!w[J+12|0]){if(!v[J+16>>2]){break Ed}Om(ca,j,va,ua)}a=v[J>>2];b=v[J+80>>2];c=B(a,b)>>>4|0;c=c>>>0<32767?c:32767;u[J+98>>1]=c;u[J+96>>1]=c;c=v[J+49948>>2];d=B(c,a)>>>4|0;d=d>>>0<65536?d:65536;f=d+127>>>3|0;u[J+49946>>1]=f;d=d+255>>>4|0;u[J+49944>>1]=d;u[J+49942>>1]=d;u[J+49940>>1]=f;b=(b|0)>(c|0)?b:c;a=36-a>>>1|0;a=16-(a>>>0>8?a:8)|0;a=16-(B((b|0)<32768?b:32768,a>>>0>16?0:a)>>15)|0;b=0;while(1){if((b|0)!=(j|0)){c=b<<3;d=c+aa|0;v[d>>2]=v[d>>2]+B(a,v[c+ca>>2]>>4);c=c|4;d=c+aa|0;v[d>>2]=v[d>>2]+B(a,v[c+ca>>2]>>4);b=b+1|0;continue}break}q=J+68|0;b=0;f=u[J+84>>1];a=v[J+40>>2];d=v[J+36>>2];while(1){if((b|0)==(j|0)){v[J+40>>2]=a;v[J+36>>2]=d;d=j}else{c=ca+(b<<3)|0;k=v[c>>2]>>12;d=(B(f,k-d|0)>>15)+k|0;v[c>>2]=d;l=c;c=v[c+4>>2]>>12;a=(B(f,c-a|0)>>15)+c|0;v[l+4>>2]=a;b=b+1|0;continue}break}if(d){b=ca;a=d;n=v[q>>2]-1|0;c=x[q+22>>1];k=u[q+26>>1];s=u[q+18>>1];h=x[q+20>>1];g=u[q+24>>1];i=u[q+16>>1];f=v[q+4>>2];l=q+32928|0;while(1){if(a){m=$c(v[b>>2]);p=$c(v[b+4>>2]);h=$c((h<<16>>16)-m|0);c=$c((c<<16>>16)-p|0);h=Wc($c((B(h,i)|0)/65536<<1)+m|0);c=Wc($c((B(c,s)|0)/65536<<1)+p|0);p=l+(f<<2)|0;o=u[p>>1];m=Wc(((B(o,g)|0)/-65536|0)+h|0);f=f+1&127;r=l+(f<<2)|0;p=u[p+2>>1];A=Wc(((B(p,k)|0)/-65536|0)+c|0);u[r+2>>1]=A;u[r>>1]=m;n=n+1&8191;r=q+(n<<2)|0;Ua=r,Va=Wc(o+((B(g,m)|0)/65536|0)|0),u[Ua+160>>1]=Va;Ua=r,Va=Wc(p+((B(k,A)|0)/65536|0)|0),u[Ua+162>>1]=Va;b=b+8|0;a=a-1|0;continue}break}u[q+22>>1]=c;u[q+20>>1]=h;v[q+4>>2]=f}g=J+49892|0;A=J+33508|0;a=d;b=ca;while(1){if(a){f=v[J+76>>2];k=f&4095;h=A+(k<<2)|0;c=b;k=4096-k|0;r=f-v[J+49892>>2]&4095;f=4096-r|0;f=f>>>0>k>>>0?k:f;f=a>>>0>f>>>0?f:a;k=f>>>0<64?f:64;n=k;f=0;p=cb-32|0;cb=p;l=v[q>>2];while(1){if((f|0)==7){Fd:{i=u[q+28>>1]/8<<16>>16;Gd:while(1){if(!n){break Fd}n=n-1|0;f=0;m=0;l=0;while(1)if((f|0)==4){f=4;E=0;o=Wc((l|0)/32768|0);N=Wc((m|0)/32768|0);m=0;while(1)if((f|0)==7){f=Wc(o+((m|0)/32768|0)|0);u[h>>1]=f;v[c>>2]=B(f,i);f=Wc(N+((E|0)/32768|0)|0);u[h+2>>1]=f;v[c+4>>2]=B(f,i);c=c+8|0;h=h+4|0;continue Gd}else{l=p+(f<<2)|0;s=v[l>>2]+1&8191;v[l>>2]=s;s=q+(s<<2)|0;K=u[s+160>>1];l=q+(f<<4)|0;s=u[s+162>>1];E=(B(K,u[l+44>>1])+E|0)+B(s,u[l+46>>1])|0;m=(B(K,u[l+40>>1])+m|0)+B(s,u[l+42>>1])|0;f=f+1|0;continue}}else{s=p+(f<<2)|0;o=v[s>>2]+1&8191;v[s>>2]=o;E=m;m=q+(o<<2)|0;o=u[m+160>>1];s=q+(f<<4)|0;N=u[m+162>>1];m=(E+B(o,u[s+44>>1])|0)+B(N,u[s+46>>1])|0;l=(B(o,u[s+40>>1])+l|0)+B(N,u[s+42>>1])|0;f=f+1|0;continue}}}}else{v[p+(f<<2)>>2]=l+(v[(q+(f<<4)|0)+32>>2]^-1);f=f+1|0;continue}break}cb=p+32|0;h=A+(r<<2)|0;c=b;f=k;m=v[g+4>>2];l=g+8256|0;n=g- -64|0;p=g+24640|0;s=g+16448|0;while(1){i=m&2047;if(f){N=u[l+((m+1206&2047)<<2)>>1];K=u[(l+((m+754&2047)<<2)|0)+2>>1];r=u[(n+((m+1602&2047)<<2)|0)+2>>1];H=u[n+((m+1750&2047)<<2)>>1];o=u[h>>1];E=u[h+2>>1];G=p+((m+502&2047)<<2)|0;F=u[G>>1];I=$c(u[g+32>>1]-F|0);G=u[G+2>>1];M=$c(u[g+34>>1]-G|0);R=u[g+26>>1];Q=p+((m+22&2047)<<2)|0;V=u[Q>>1];X=$c(u[g+36>>1]-V|0);Y=u[g+28>>1];Q=u[Q+2>>1];_=$c(u[g+38>>1]-Q|0);ba=u[g+30>>1];F=Wc($c((B(I,u[g+24>>1])|0)/65536<<1)+F|0);u[g+32>>1]=F;Ua=g,Va=Wc($c((B(M,R)|0)/65536<<1)+G|0),u[Ua+34>>1]=Va;Ua=g,Va=Wc($c((B(X,Y)|0)/65536<<1)+V|0),u[Ua+36>>1]=Va;G=Wc($c((B(_,ba)|0)/65536<<1)+Q|0);u[g+38>>1]=G;F=$c((B(F,u[g+16>>1])|0)/32768|0);I=$c((B(G,u[g+22>>1])|0)/32768|0);G=$c(F+((o|0)/4<<16>>16)|0);E=$c(I+((E|0)/4<<16>>16)|0);F=u[g+8>>1];I=$c(G+((B(F,H)|0)/-65536|0)|0);o=i<<2;R=o+n|0;M=u[g+10>>1];Q=$c(E+((B(M,r)|0)/-65536|0)|0);u[R+2>>1]=Q;u[R>>1]=I;H=$c(H+((B(F,I)|0)/65536|0)|0);I=o+s|0;r=$c(r+((B(M,Q)|0)/65536|0)|0);u[I+2>>1]=r;u[I>>1]=H;H=$c(G+H|0);G=$c(r+E|0);r=s+((m+682&2047)<<2)|0;E=u[r+2>>1];I=u[r>>1];r=$c((B(E,u[g+42>>1])+B(I,u[g+40>>1])|0)/32768|0);m=s+((m+426&2047)<<2)|0;R=u[m+2>>1];Q=u[m>>1];m=$c((B(R,u[g+46>>1])+B(Q,u[g+44>>1])|0)/32768|0);I=$c($c(H+I|0)-r|0);E=$c($c(E+G|0)-m|0);H=$c($c(H+Q|0)-r|0);G=$c($c(G+R|0)-m|0);r=$c(r+((B(F,N)|0)/-65536|0)|0);F=u[g+8>>1];R=u[g+10>>1];Q=l+o|0;M=$c(m+((B(K,M)|0)/-65536|0)|0);u[Q+2>>1]=M;u[Q>>1]=r;r=(B(r,F)|0)/65536|0;m=$c(r+N|0);o=o+p|0;N=(B(M,R)|0)/65536|0;K=$c(N+K|0);u[o+2>>1]=K;u[o>>1]=m;Ua=c,Va=(v[c>>2]+B($c(m+I|0),u[g+48>>1])|0)+B($c(E+K|0),u[g+50>>1])|0,v[Ua>>2]=Va;Ua=c,Va=(v[c+4>>2]+B($c($c(r)+H|0),u[g+52>>1])|0)+B($c($c(N)+G|0),u[g+54>>1])|0,v[Ua+4>>2]=Va;c=c+8|0;m=i+1|0;h=h+4|0;f=f-1|0;continue}break}v[g+4>>2]=i;v[J+76>>2]=k+v[J+76>>2]&4095;v[J+68>>2]=k+v[J+68>>2]&8191;a=a-k|0;b=(k<<3)+b|0;continue}break}v[J+68>>2]=v[J+68>>2]&8191;h=ca;c=aa;f=d;b=0;a=0;n=v[J+56>>2];l=v[J- -64>>2];m=v[J+52>>2];k=v[J+60>>2];while(1){if(f){b=v[h>>2];a=v[h+4>>2];g=l-a|0;g=(((g|0)/1024|0)-g|0)+n|0;v[c+4>>2]=g+v[c+4>>2];k=k-b|0;k=(((k|0)/1024|0)-k|0)+m|0;v[c>>2]=k+v[c>>2];n=g+((g|0)/-512|0)|0;m=k+((k|0)/-512|0)|0;c=c+8|0;h=h+8|0;f=f-1|0;k=b;l=a;continue}break}v[J+64>>2]=a;v[J+60>>2]=b;v[J+56>>2]=n;v[J+52>>2]=m;Hd:{if(w[J+12|0]){v[J+16>>2]=v[J+20>>2];break Hd}a=v[J+16>>2];if(a>>>0>d>>>0){v[J+16>>2]=a-d;break Hd}xJ(J,va,ua);v[J+16>>2]=0}t[J+12|0]=0}if(v[e+946300>>2]){Id:{f=0;h=0;d=j<<2;p=x[e+480214>>1]!=0;Ea=z[e+1074336>>2];W=z[e+1074332>>2];while(1)if((f|0)==250){k=e+12|0;m=e+12300|0;n=e+14348|0;cv(k,m,n,j,W);a=e+1074476|0;r=w[a|0];t[a|0]=0;b=n;a=m;while(1){Jd:{Kd:{Ld:{if((h|0)!=250){q=(B(h,160)+e|0)+906300|0;g=v[q>>2];if(!g|!v[g+24>>2]){break Jd}c=g+44|0;if(!Yh(c)){break Jd}l=g;Md:{if(bv(q)){break Md}d=gb[v[v[g>>2]+144>>2]](g)|0;l=v[q>>2];if(d){break Md}f=0;if(w[l+28|0]&2){break Md}while(1){if((f|0)==(h|0)){break Jd}d=B(f,160);f=f+1|0;if((Mm((e+d|0)+906300|0)|0)!=(h|0)){continue}break}}s=Ud(c,0);o=Ud(c,1);i=(a|0)==(s|0);a=i?m:a;c=a;b=i?n:b;d=b;Nd:{if(!(w[q+28|0]|w[q+29|0]<<8|(w[q+30|0]<<16|w[q+31|0]<<24))){break Nd}c=a;f=Mm(q);d=b;if(f>>>0<=h>>>0){break Nd}d=b;if(f>>>0>249){break Nd}f=v[(B(f,160)+e|0)+906300>>2];d=b;if(!f){break Nd}if(!(w[l+28|0]&4)){gb[v[v[f>>2]+148>>2]](f)}f=f+44|0;d=b;if(!Yh(f)){break Nd}c=Ud(f,0);d=Ud(f,1)}if(!bv(q)){break Kd}f=0;Od:{if(i){break Od}while(1){if((f|0)==(j|0)){break Od}i=f<<2;A=i+s|0;N=a+i|0;z[A>>2]=z[N>>2]+z[A>>2];A=i+o|0;i=b+i|0;z[A>>2]=z[i>>2]+z[A>>2];v[N>>2]=0;v[i>>2]=0;f=f+1|0;continue}}b=d;a=c;if(!(p&1)){break Kd}a=v[q>>2];if(a){gb[v[v[a>>2]+148>>2]](a)}f=Mm(q);b=h;while(1){a=f;f=a&255;if(f>>>0>249|f>>>0<=(b&255)>>>0){break Ld}i=(B(f,160)+e|0)+906300|0;f=Mm(i);b=a;a=v[i>>2];if(!a){continue}gb[v[v[a>>2]+148>>2]](a);continue}}c=0;while(1){if((c|0)!=(j|0)){W=C(z[a>>2]*Ea);Pd:{if(C(D(W))<C(2147483648)){d=~~W;break Pd}d=-2147483648}v[k>>2]=d;W=C(z[b>>2]*Ea);Qd:{if(C(D(W))<C(2147483648)){d=~~W;break Qd}d=-2147483648}v[k+4>>2]=d;c=c+1|0;k=k+8|0;b=b+4|0;a=a+4|0;continue}break}break Id}b=d;a=c}f=0;Rd:{Sd:{if(!((w[q+24|0]&2)>>>1|0)){if(!YC(q)|!(w[l+28|0]&4)){break Sd}}while(1){if((f|0)==(j|0)){break Rd}g=f<<2;q=g+c|0;z[q>>2]=z[g+s>>2]+z[q>>2];q=d+g|0;z[q>>2]=z[g+o>>2]+z[q>>2];f=f+1|0;continue}}if(r){gb[v[v[g>>2]+128>>2]](g)}gb[v[v[g>>2]+60>>2]](g,c,d,j);v[l+32>>2]=j+v[l+32>>2];if(!YC(q)){break Rd}if((gb[v[v[g>>2]+156>>2]](g)|0)<=0|y[l+32>>2]<v[e+24620>>2]<<2>>>0){break Rd}Td:{while(1){if((f|0)==(j|0)){break Td}g=f<<2;W=z[g+c>>2];Ud:{if(W>=C(1.1920928955078125e-7)|W<=C(-1.1920928955078125e-7)){break Ud}W=z[d+g>>2];if(W>=C(1.1920928955078125e-7)){break Ud}f=f+1|0;if(!(W<=C(-1.1920928955078125e-7))){continue}}break}v[l+32>>2]=0;break Rd}v[l+28>>2]=v[l+28>>2]|4}v[l+28>>2]=v[l+28>>2]&-3}h=h+1|0;continue}}else{k=(B(f,160)+e|0)+906300|0;a=v[k>>2];Vd:{if(!a|!v[a+24>>2]){break Vd}c=a+44|0;if(!Yh(c)){break Vd}if(!(gb[v[v[a>>2]+112>>2]](a)|0)){gb[v[v[a>>2]+108>>2]](a,1);gb[v[v[a>>2]+120>>2]](a)}b=Ud(c,0);c=Ud(c,1);Wd:{if(t[a+28|0]&1){cv(v[a+24>>2],b,c,j,W);break Wd}g=a+40|0;if(v[a+36>>2]?1:v[g>>2]){Om(v[a+24>>2],j,g,a+36|0);cv(v[a+24>>2],b,c,j,W);break Wd}Hb(b,0,d);Hb(c,0,d)}b=a;a=v[a+28>>2];v[b+28>>2]=a&-2;if(bv(k)){break Vd}p=!(a&4)|p}f=f+1|0;continue}}}if(v[e+24624>>2]==1){a=0;while(1){if((a|0)!=(j|0)){b=(a<<3)+aa|0;v[(a<<2)+aa>>2]=(v[b+4>>2]+v[b>>2]|0)/2;a=a+1|0;continue}break}}if(Ed(w[Ia|0])){k=0;c=cb-16|0;cb=c;Xd:{if(!v[e+1074376>>2]){l=e+1074460|0;a=l;v[a>>2]=0;v[a+4>>2]=0;b=v[e+1074456>>2];v[e+1074468>>2]=b;break Xd}a=v[e+1074468>>2];b=v[e+1074456>>2];Yd:{if((a|0)==(b|0)){d=v[e+1074460>>2];break Yd}v[e+1074468>>2]=b;d=v[e+24620>>2];f=e+1074460|0;Zd:{if((a|0)<(b|0)){d=dt(d,v[e+24636>>2]);break Zd}d=dt(d,v[e+24640>>2])}v[f>>2]=d;v[e+1074464>>2]=d;a=b}l=e+1074460|0;if((d|0)<=0){break Xd}a=(a<<12)-v[e+1074472>>2]|0;k=(a|0)/(d|0)|0;if(w[e+1074368|0]!=2){break Xd}v[c+12>>2]=50;f=v[e+1074464>>2];v[c+8>>2]=1e4/(f+1|0);g=v[Ke(c+12|0,c+8|0)>>2];while(1){h=k>>31;if((g|0)>=(h+k^h)){break Xd}d=d+f|0;v[l>>2]=d;k=(a|0)/(d|0)|0;continue}}_d:{$d:{switch(v[e+24624>>2]-1|0){case 0:a=0;g=(j|0)>0?j:0;h=b<<12;d=e+12|0;m=b>>31;while(1){if((a|0)==(g|0)){break _d}ae:{if(v[l>>2]>0){f=v[e+1074472>>2]+k|0;v[e+1074472>>2]=f;n=v[d>>2];Ua=d,Va=yc(lka(kka(n,n>>31,f,f>>31),fb,1048576,0),fb),v[Ua>>2]=Va;v[e+1074460>>2]=v[e+1074460>>2]-1;break ae}f=v[d>>2];Ua=d,Va=yc(lka(kka(f,f>>31,b,m),fb,256,0),fb),v[Ua>>2]=Va;v[e+1074472>>2]=h}a=a+1|0;d=d+4|0;continue};case 1:a=0;h=(j|0)>0?j:0;m=b<<12;d=e+12|0;f=b>>31;while(1){if((a|0)==(h|0)){break _d}be:{if(v[l>>2]>0){g=v[e+1074472>>2]+k|0;v[e+1074472>>2]=g;n=v[d>>2];Ua=d,Va=yc(lka(kka(n,n>>31,g,g>>31),fb,1048576,0),fb),v[Ua>>2]=Va;g=v[e+1074472>>2];n=g;p=g>>31;g=v[d+4>>2];Ua=d,Va=yc(lka(kka(n,p,g,g>>31),fb,1048576,0),fb),v[Ua+4>>2]=Va;v[e+1074460>>2]=v[e+1074460>>2]-1;break be}g=v[d>>2];Ua=d,Va=yc(lka(kka(g,g>>31,b,f),fb,256,0),fb),v[Ua>>2]=Va;g=v[d+4>>2];Ua=d,Va=yc(lka(kka(g,g>>31,b,f),fb,256,0),fb),v[Ua+4>>2]=Va;v[e+1074472>>2]=m}a=a+1|0;d=d+8|0;continue};case 3:break $d;default:break _d}}h=0;m=(j|0)>0?j:0;n=b<<12;d=e+8204|0;a=e+12|0;f=b>>31;while(1){if((h|0)==(m|0)){break _d}ce:{if(v[l>>2]>0){g=v[e+1074472>>2]+k|0;v[e+1074472>>2]=g;q=v[a>>2];Ua=a,Va=yc(lka(kka(q,q>>31,g,g>>31),fb,1048576,0),fb),v[Ua>>2]=Va;g=v[e+1074472>>2];p=g;q=g>>31;g=v[a+4>>2];Ua=a,Va=yc(lka(kka(p,q,g,g>>31),fb,1048576,0),fb),v[Ua+4>>2]=Va;g=v[e+1074472>>2];p=g;q=g>>31;g=v[d>>2];Ua=d,Va=yc(lka(kka(p,q,g,g>>31),fb,1048576,0),fb),v[Ua>>2]=Va;g=v[e+1074472>>2];p=g;q=g>>31;g=v[d+4>>2];Ua=d,Va=yc(lka(kka(p,q,g,g>>31),fb,1048576,0),fb),v[Ua+4>>2]=Va;v[e+1074460>>2]=v[e+1074460>>2]-1;break ce}g=v[a>>2];Ua=a,Va=yc(lka(kka(g,g>>31,b,f),fb,256,0),fb),v[Ua>>2]=Va;g=v[a+4>>2];Ua=a,Va=yc(lka(kka(g,g>>31,b,f),fb,256,0),fb),v[Ua+4>>2]=Va;g=v[d>>2];Ua=d,Va=yc(lka(kka(g,g>>31,b,f),fb,256,0),fb),v[Ua>>2]=Va;g=v[d+4>>2];Ua=d,Va=yc(lka(kka(g,g>>31,b,f),fb,256,0),fb),v[Ua+4>>2]=Va;v[e+1074472>>2]=n}h=h+1|0;d=d+8|0;a=a+8|0;continue}}cb=c+16|0}if(v[qa>>2]!=128){b=e+12|0;c=e+8204|0;a=v[e+24604>>2];d=v[e+24624>>2];de:{if((a|0)==128|d>>>0<2){break de}iL(b,j,a);if(d>>>0<4){break de}iL(c,j,a)}}if(v[e+24624>>2]==4){b=j;while(1){b=b-1|0;if((b|0)>=0){a=(b<<4)+aa|0;c=b<<3;d=c|4;v[a+12>>2]=v[d+ta>>2];v[a+8>>2]=v[c+ta>>2];v[a+4>>2]=v[d+aa>>2];v[a>>2]=v[c+aa>>2];continue}break}}if(jL(ra)){b=v[ra>>2];a=pg(T- -64|0,aa,v[e+24624>>2],j);c=v[v[b>>2]+8>>2];v[T+24>>2]=v[a+8>>2];d=v[a+4>>2];v[T+16>>2]=v[a>>2];v[T+20>>2]=d;gb[c|0](b,T+16|0)}a=pg(T+48|0,aa,v[e+24624>>2],j);b=v[v[pa>>2]+8>>2];v[T+8>>2]=v[a+8>>2];c=v[a+4>>2];v[T>>2]=v[a>>2];v[T+4>>2]=c;gb[b|0](pa,T);v[e+1074380>>2]=v[e+1074380>>2]-j;v[e+1074376>>2]=j+v[e+1074376>>2];ha=ha-j|0;Fa=j+Fa|0;continue}break}cb=$+48|0;return Fa}function vg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),m=0,o=0,p=0,r=0,s=0,E=0,F=C(0),G=0,H=0,I=C(0),J=0,K=0,M=0,N=0,R=0;i=cb-2608|0;cb=i;a:{b:{c:{d:{e:{f:{if(Lq(c)){qc(b,268435456);K=v[c+8>>2];H=i+2584|0;e=H;v[e>>2]=0;v[e+4>>2]=0;Rb(e+8|0);v[i+2580>>2]=0;g:{h:{i:{j:{k:{l:{e=w[a+3|0];m:{n:{if(e-4>>>0<=4){v[22440]=0;d=T(204,c|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break l}v[i+2580>>2]=d;break n}if(e>>>0>17){break m}o:{f=1<<e;if(!(f&63503)){if(!(f&198144)){break m}break o}if(w[a|0]){break o}break n}e=0;g=DA(a,v[b>>2]);v[22440]=0;U(205,i+416|0,c|0,g|0);g=v[22440];v[22440]=0;if((g|0)==1){break k}d=i+416|0;g=v[d+4>>2];v[H>>2]=v[d>>2];v[H+4>>2]=g;xm(H+8|0,d+8|0);vc(d);g=ce(H);d=v[H>>2];v[i+2580>>2]=d;if(!g){break g}}e=w[a+3|0]}o=1;p:{q:{switch(e&255){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:o=!w[a|0];break p;case 9:case 10:case 16:case 17:break q;default:break p}}o=0}h=v[b>>2];if(!(h>>>0<262145|o)){e=e&255;v[i+416>>2]=((e|0)==10)<<4;f=d-v[Bb(i+416|0,i+2580|0)>>2]|0;if(e>>>0>15){break j}r:{if(!(1<<e&63503)){if((e|0)==10){break r}break j}if(!(w[a|0]&7)){break j}}e=(f|0)>=0?f<<1:-1;break i}e=e&255;if(e>>>0>8){break h}if(!(1<<e&432)){if((e|0)!=6){break h}e=0;if(d>>>0<10){break g}v[22440]=0;Q(190,c|0,4)|0;d=v[22440];v[22440]=0;if((d|0)==1){break l}v[22440]=0;e=T(159,c|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){v[i+416>>2]=e;v[i+392>>2]=v[i+2580>>2];d=v[Bb(i+416|0,i+392|0)>>2];xg(c,8);e=((d>>>0>50529027?-1:B(d,85))>>>0)/(w[a|0]>>>3>>>0)|0;break i}a=P()|0;O()|0;break a}e=8/(Zp(w[a+1|0])>>>0)|0;kka(e,0,d,0);e=fb?-1:B(e,d);break i}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}h=0;d=Zp(w[a+1|0]);s:{t:{switch(e|0){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:h=w[a|0];break s;case 9:h=16;break s;case 10:h=4;break s;case 16:case 17:break t;default:break s}}h=8}e=B(d,h&255)>>>3|0;d=(e+f|0)-1|0;e=((d>>>0<f>>>0?-1:d)>>>0)/(e>>>0)|0}qc(b,e);h=v[b>>2]}if(!h){e=0;break g}u[b+34>>1]=x[b+34>>1]&65470|w[a|0]>15|(w[a+1|0]!=1)<<6;if(!Lg(b)){e=0;v[b>>2]=0;break g}u:{if(me(a,Nc(i+416|0,8,1,0,10))){v[22440]=0;d=Q(206,c|0,i+416|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){e=0;if(!d){break u}a=v[b>>2];d=0;v[22440]=0;v[i+392>>2]=a+1>>>1;e=T(204,c|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break b}qc(i+392|0,e);a=g+16|0;b=v[b+20>>2];h=v[i+392>>2];e=h;while(1)if(e){f=i+416|0;g=d+w[f|w[a|0]&15]|0;t[b|0]=g;d=w[f|w[a|0]>>>4]+(g&255)|0;t[b+1|0]=d;e=e-1|0;a=a+1|0;b=b+2|0;continue}else{e=h+16|0;break u}}a=P()|0;O()|0;break a}v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{f=w[a+3|0];switch(f-4|0){case 3:break D;case 12:case 13:break E;case 4:break F;case 5:break G;case 2:break H;case 0:case 1:break I;default:break C}}v[22440]=0;b=da(207,i+1488|0,c|0,b|0,(f|0)==5|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break f}sb(b);e=v[c+8>>2]-K|0;break u}if(w[a+1|0]!=1){break C}v[22440]=0;Q(190,c|0,4)|0;a=v[22440];v[22440]=0;if((a|0)==1){break f}v[22440]=0;g=T(159,c|0)|0;a=v[22440];v[22440]=0;J:{K:{L:{if((a|0)!=1){v[22440]=0;v[i+392>>2]=g;h=T(208,c|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break L}v[22440]=0;U(209,i+416|0,c|0,g|0);a=v[22440];v[22440]=0;if((a|0)==1){break K}qc(i+392|0,v[i+416>>2]);f=v[i+392>>2];e=ce(i+416|0);d=x[b+34>>1];g=v[b+20>>2];b=v[b>>2];a=v[i+416>>2];v[22440]=0;ga(210,e|0,a|0,g|0,Fj(b,d)|0,h<<24>>24);a=v[22440];v[22440]=0;if((a|0)==1){break J}e=f+9|0;vc(i+416|0);break u}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vc(i+416|0);break a}if(w[a+1|0]!=1|w[a|0]!=16){break C}a=v[i+2580>>2];h=x[wk(i+1480|0)>>1];f=cb-16|0;cb=f;v[f+12>>2]=a>>>1;v[f+8>>2]=v[b>>2];b=v[b+20>>2];d=v[Bb(f+12|0,f+8|0)>>2];e=d;while(1){if(e){a=w[g|0]+h|0;h=a+w[g+1|0]|0;u[b>>1]=h<<8|a&255;b=b+2|0;g=g+2|0;e=e-1|0;continue}break}cb=f+16|0;e=d<<1;break u}if(w[a+1|0]!=1|w[a|0]>16){break C}e=0;v[22440]=0;d=Q(158,c|0,8)|0;g=v[22440];v[22440]=0;if((g|0)==1){break f}if(!d){break u}v[22440]=0;d=T(159,c|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break f}v[i+2580>>2]=d;if(d>>>0<4){break u}v[22440]=0;U(192,i+392|0,c|0,d|0);g=v[22440];v[22440]=0;if((g|0)==1){break c}g=i+392|0;s=Vq(i+416|0,g);sb(g);v[22440]=0;d=T(211,s|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break e}e=d+4|0;p=w[a|0];r=(p|0)!=16;d=0;g=0;while(1){if(y[b>>2]<=g>>>0){break w}M:{if(r){break M}v[22440]=0;E=Q(166,s|0,8)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break M}a=V(30592)|0;break x}v[22440]=0;j=Q(166,s|0,1)|0;a=v[22440];v[22440]=0;if((a|0)==1){break y}v[22440]=0;f=Q(166,s|0,1)|0;a=v[22440];v[22440]=0;if((a|0)==1){break y}N:{O:{P:{if(!f){h=8;while(1){v[22440]=0;f=Q(166,s|0,1)|0;a=v[22440];v[22440]=0;if((a|0)==1){break N}if(f){break P}h=h+16|0;continue}}v[22440]=0;a=Q(166,s|0,3)|0;f=v[22440];v[22440]=0;if((f|0)!=1){break O}break y}v[22440]=0;f=Q(166,s|0,4)|0;a=v[22440];v[22440]=0;if((a|0)==1){break y}a=f+h|0}d=(d&255)+(((j?-1:0)^a)&255)|0;Q:{if((p|0)!=16){t[v[b+20>>2]+g|0]=d;break Q}u[v[b+20>>2]+(g<<1)>>1]=E&255|d<<8}g=g+1|0;continue}break}a=V(30592)|0;break x}o=w[a|0];if((o|0)!=16){break B}e=w[a+1|0];if((e-1&255)>>>0>1){break A}M=i,N=B(v[b>>2],Zp(e)),v[M+416>>2]=N;qc(i+416|0,v[i+2580>>2]);b=v[b+20>>2];e=v[i+416>>2];if(w[a+3|0]==16){a=e;while(1){if(!a){break u}M=b,N=x[Xb(30624,w[g|0])>>1],u[M>>1]=N;b=b+2|0;g=g+1|0;a=a-1|0;continue}}a=e;while(1){if(!a){break u}M=b,N=x[Xb(31136,w[g|0])>>1],u[M>>1]=N;b=b+2|0;g=g+1|0;a=a-1|0;continue}}if(w[a+1|0]!=1|w[a|0]>16){break C}e=0;if(y[i+2580>>2]<5){break u}d=x[b+34>>1];g=v[b+20>>2];a=v[b>>2];v[22440]=0;e=Y(212,c|0,g|0,Fj(a,d)|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break u}break f}o=w[a|0]}if((o|0)==8){if(w[a+1|0]==1){R:{switch(f|0){case 0:a=v[b>>2];b=v[b+20>>2];d=cb-16|0;cb=d;v[d+12>>2]=v[i+2580>>2];v[d+8>>2]=a;a=v[Bb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[g|0];b=b+1|0;g=g+1|0;e=e-1|0;continue}break};cb=d+16|0;e=a;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=cb-16|0;cb=d;v[d+12>>2]=v[i+2580>>2];v[d+8>>2]=a;a=v[Bb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[g|0]^128;b=b+1|0;g=g+1|0;e=e-1|0;continue}break};cb=d+16|0;e=a;break u;default:e=0;if((f|0)!=11){break u}break;case 2:break R}}e=v[i+2580>>2];d=hr(i+384|0);a=v[b>>2];b=v[b+20>>2];h=w[d|0];d=cb-16|0;cb=d;v[d+12>>2]=e;v[d+8>>2]=a;a=v[Bb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){h=w[g|0]+h|0;t[b|0]=h;b=b+1|0;g=g+1|0;e=e-1|0;continue}break}cb=d+16|0;e=a;break u}if(w[a+1|0]==3){S:{switch(f|0){case 0:h=cb-16|0;cb=h;f=v[i+2580>>2];v[h+12>>2]=f;d=v[b>>2];v[h+8>>2]=d;a=h+8|0;e=v[Bb(a,h+12|0)>>2];v[h+8>>2]=d;v[h+4>>2]=f-e;d=v[Bb(a,h+4|0)>>2];o=v[b+20>>2];a=e;f=g;while(1){if(a){t[o|0]=w[f|0];o=o+2|0;f=f+1|0;a=a-1|0;continue}break};o=v[b+20>>2]+1|0;f=v[b>>2]+g|0;a=d;while(1){if(a){t[o|0]=w[f|0];o=o+2|0;f=f+1|0;a=a-1|0;continue}break};cb=h+16|0;e=e+d|0;break u;case 1:h=cb-16|0;cb=h;f=v[i+2580>>2];v[h+12>>2]=f;d=v[b>>2];v[h+8>>2]=d;a=h+8|0;e=v[Bb(a,h+12|0)>>2];v[h+8>>2]=d;v[h+4>>2]=f-e;d=v[Bb(a,h+4|0)>>2];o=v[b+20>>2];a=e;f=g;while(1){if(a){t[o|0]=w[f|0]^128;o=o+2|0;f=f+1|0;a=a-1|0;continue}break};o=v[b+20>>2]+1|0;f=v[b>>2]+g|0;a=d;while(1){if(a){t[o|0]=w[f|0]^128;o=o+2|0;f=f+1|0;a=a-1|0;continue}break};cb=h+16|0;e=e+d|0;break u;default:e=0;if((f|0)!=11){break u}break;case 2:break S}}h=v[i+2580>>2];e=w[hr(i+376|0)|0];p=cb-16|0;cb=p;v[p+12>>2]=h;f=v[b>>2];v[p+8>>2]=f;d=p+8|0;j=v[Bb(d,p+12|0)>>2];v[p+8>>2]=f;v[p+4>>2]=h-j;h=v[Bb(d,p+4|0)>>2];r=b;E=v[b+20>>2];f=e;b=j;d=g;while(1){if(b){f=w[d|0]+f|0;t[E|0]=f;E=E+2|0;d=d+1|0;b=b-1|0;continue}break}E=v[r+20>>2]+1|0;d=v[r>>2]+g|0;b=h;while(1){if(b){e=w[d|0]+e|0;t[E|0]=e;E=E+2|0;d=d+1|0;b=b-1|0;continue}break}cb=p+16|0;e=h+j|0;if(w[a+3|0]!=11){break u}a=v[r+20>>2];b=a+(v[r>>2]<<1)|0;while(1){if(a>>>0>=b>>>0){break u}t[a+1|0]=w[a+1|0]+w[a|0];a=a+2|0;continue}}e=0;if(w[a+1|0]!=2){break u}T:{switch(f|0){case 0:a=v[b>>2];b=v[b+20>>2];d=cb-16|0;cb=d;v[d+12>>2]=v[i+2580>>2]>>>1;v[d+8>>2]=a;a=v[Bb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[g|0];t[b+1|0]=w[g+1|0];b=b+2|0;g=g+2|0;e=e-1|0;continue}break};cb=d+16|0;e=a<<1;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=cb-16|0;cb=d;v[d+12>>2]=v[i+2580>>2]>>>1;v[d+8>>2]=a;a=v[Bb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[g|0]^128;t[b+1|0]=w[g+1|0]^128;b=b+2|0;g=g+2|0;e=e-1|0;continue}break};cb=d+16|0;e=a<<1;break u;case 2:break T;default:break u}}e=v[i+2580>>2];a=hr(i+368|0);d=v[b>>2];h=v[b+20>>2];a=w[a|0];f=cb-16|0;cb=f;v[f+12>>2]=e>>>1;v[f+8>>2]=d;b=a;e=v[Bb(f+12|0,f+8|0)>>2];d=e;while(1){if(d){a=w[g|0]+a|0;t[h|0]=a;b=w[g+1|0]+b|0;t[h+1|0]=b;h=h+2|0;g=g+2|0;d=d-1|0;continue}break}cb=f+16|0;e=e<<1;break u}if((o|0)!=16){break z}e=w[a+1|0];if((e|0)!=1){break A}if(!w[a+2|0]){U:{switch(f|0){case 0:d=cb-16|0;cb=d;v[d+12>>2]=v[i+2580>>2]>>>1;v[d+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=w[g|0]|w[g+1|0]<<8;b=b+2|0;g=g+2|0;e=e-1|0;continue}break};cb=d+16|0;e=a<<1;break u;case 1:d=cb-16|0;cb=d;v[d+12>>2]=v[i+2580>>2]>>>1;v[d+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=(w[g|0]|w[g+1|0]<<8)^32768;b=b+2|0;g=g+2|0;e=e-1|0;continue}break};cb=d+16|0;e=a<<1;break u;default:e=0;if((f|0)!=11){break u}break;case 2:break U}}a=v[i+2580>>2];h=x[wk(i+360|0)>>1];d=cb-16|0;cb=d;v[d+12>>2]=a>>>1;v[d+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){h=(w[g|0]+h|0)+(w[g+1|0]<<8)|0;u[b>>1]=h;b=b+2|0;g=g+2|0;e=e-1|0;continue}break}cb=d+16|0;e=a<<1;break u}e=w[a+1|0];if((e|0)!=1){break A}if(w[a+2|0]==1){e=0;V:{switch(f|0){case 0:f=cb-16|0;cb=f;v[f+12>>2]=v[i+2580>>2]>>>1;v[f+8>>2]=v[b>>2];b=v[b+20>>2];d=v[Bb(f+12|0,f+8|0)>>2];e=d;while(1){if(e){a=w[g|0]|w[g+1|0]<<8;u[b>>1]=a<<8|a>>>8;b=b+2|0;g=g+2|0;e=e-1|0;continue}break};cb=f+16|0;e=d<<1;break u;case 1:f=cb-16|0;cb=f;v[f+12>>2]=v[i+2580>>2]>>>1;v[f+8>>2]=v[b>>2];b=v[b+20>>2];d=v[Bb(f+12|0,f+8|0)>>2];e=d;while(1){if(e){a=w[g|0]|w[g+1|0]<<8;u[b>>1]=(a<<8|a>>>8)^32768;b=b+2|0;g=g+2|0;e=e-1|0;continue}break};cb=f+16|0;e=d<<1;break u;case 2:break V;default:break u}}a=v[i+2580>>2];h=x[wk(i+352|0)>>1];d=cb-16|0;cb=d;v[d+12>>2]=a>>>1;v[d+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){h=(w[g+1|0]+h|0)+(w[g|0]<<8)|0;u[b>>1]=h;b=b+2|0;g=g+2|0;e=e-1|0;continue}break}cb=d+16|0;e=a<<1;break u}e=w[a+1|0]}if(!(w[a+2|0]|(e&255)!=3)){W:{switch(f|0){case 0:r=cb-16|0;cb=r;d=v[i+2580>>2];v[r+12>>2]=d;j=v[b>>2]<<1;v[r+8>>2]=j;a=r+8|0;f=v[Bb(a,r+12|0)>>2];v[r+8>>2]=j;v[r+4>>2]=d-f;a=v[Bb(a,r+4|0)>>2];e=v[b+20>>2];f=f>>>1|0;h=f;d=g;while(1){if(h){u[e>>1]=w[d|0]|w[d+1|0]<<8;e=e+4|0;d=d+2|0;h=h-1|0;continue}break};e=g+j|0;d=v[b+20>>2]+2|0;a=a>>>1|0;h=a;while(1){if(h){u[d>>1]=w[e|0]|w[e+1|0]<<8;d=d+4|0;e=e+2|0;h=h-1|0;continue}break};cb=r+16|0;e=a+f<<1;break u;case 1:r=cb-16|0;cb=r;d=v[i+2580>>2];v[r+12>>2]=d;j=v[b>>2]<<1;v[r+8>>2]=j;a=r+8|0;f=v[Bb(a,r+12|0)>>2];v[r+8>>2]=j;v[r+4>>2]=d-f;a=v[Bb(a,r+4|0)>>2];e=v[b+20>>2];f=f>>>1|0;h=f;d=g;while(1){if(h){u[e>>1]=(w[d|0]|w[d+1|0]<<8)^32768;e=e+4|0;d=d+2|0;h=h-1|0;continue}break};e=g+j|0;d=v[b+20>>2]+2|0;a=a>>>1|0;h=a;while(1){if(h){u[d>>1]=(w[e|0]|w[e+1|0]<<8)^32768;d=d+4|0;e=e+2|0;h=h-1|0;continue}break};cb=r+16|0;e=a+f<<1;break u;default:e=0;if((f|0)!=11){break u}break;case 2:break W}}f=v[i+2580>>2];e=x[wk(i+344|0)>>1];s=cb-16|0;cb=s;v[s+12>>2]=f;p=v[b>>2]<<1;v[s+8>>2]=p;d=s+8|0;j=v[Bb(d,s+12|0)>>2];v[s+8>>2]=p;v[s+4>>2]=f-j;r=v[Bb(d,s+4|0)>>2];h=b;f=v[b+20>>2];b=e;j=j>>>1|0;E=j;d=g;while(1){if(E){b=(w[d|0]+b|0)+(w[d+1|0]<<8)|0;u[f>>1]=b;f=f+4|0;d=d+2|0;E=E-1|0;continue}break}d=g+p|0;f=v[h+20>>2]+2|0;b=r>>>1|0;E=b;while(1){if(E){e=(w[d|0]+e|0)+(w[d+1|0]<<8)|0;u[f>>1]=e;f=f+4|0;d=d+2|0;E=E-1|0;continue}break}cb=s+16|0;e=b+j<<1;if(w[a+3|0]!=11){break u}a=v[h+20>>2];b=a+(v[h>>2]<<2)|0;while(1){if(a>>>0>=b>>>0){break u}u[a+2>>1]=x[a+2>>1]+x[a>>1];a=a+4|0;continue}}d=w[a+1|0];if((d|0)==3){if(w[a+2|0]==1){e=0;X:{switch(f|0){case 0:p=cb-16|0;cb=p;d=v[i+2580>>2];v[p+12>>2]=d;r=v[b>>2]<<1;v[p+8>>2]=r;a=p+8|0;f=v[Bb(a,p+12|0)>>2];v[p+8>>2]=r;v[p+4>>2]=d-f;j=v[Bb(a,p+4|0)>>2];e=v[b+20>>2];f=f>>>1|0;h=f;d=g;while(1){if(h){a=w[d|0]|w[d+1|0]<<8;u[e>>1]=a<<8|a>>>8;e=e+4|0;d=d+2|0;h=h-1|0;continue}break};e=g+r|0;d=v[b+20>>2]+2|0;b=j>>>1|0;h=b;while(1){if(h){a=w[e|0]|w[e+1|0]<<8;u[d>>1]=a<<8|a>>>8;d=d+4|0;e=e+2|0;h=h-1|0;continue}break};cb=p+16|0;e=b+f<<1;break u;case 1:p=cb-16|0;cb=p;d=v[i+2580>>2];v[p+12>>2]=d;r=v[b>>2]<<1;v[p+8>>2]=r;a=p+8|0;f=v[Bb(a,p+12|0)>>2];v[p+8>>2]=r;v[p+4>>2]=d-f;j=v[Bb(a,p+4|0)>>2];e=v[b+20>>2];f=f>>>1|0;h=f;d=g;while(1){if(h){a=w[d|0]|w[d+1|0]<<8;u[e>>1]=(a<<8|a>>>8)^32768;e=e+4|0;d=d+2|0;h=h-1|0;continue}break};e=g+r|0;d=v[b+20>>2]+2|0;b=j>>>1|0;h=b;while(1){if(h){a=w[e|0]|w[e+1|0]<<8;u[d>>1]=(a<<8|a>>>8)^32768;d=d+4|0;e=e+2|0;h=h-1|0;continue}break};cb=p+16|0;e=b+f<<1;break u;case 2:break X;default:break u}}f=v[i+2580>>2];a=x[wk(i+336|0)>>1];p=cb-16|0;cb=p;v[p+12>>2]=f;r=v[b>>2]<<1;v[p+8>>2]=r;d=p+8|0;e=v[Bb(d,p+12|0)>>2];v[p+8>>2]=r;v[p+4>>2]=f-e;j=v[Bb(d,p+4|0)>>2];d=b;o=v[d+20>>2];b=a;e=e>>>1|0;f=e;h=g;while(1){if(f){b=(w[h+1|0]+b|0)+(w[h|0]<<8)|0;u[o>>1]=b;o=o+4|0;h=h+2|0;f=f-1|0;continue}break}h=g+r|0;o=v[d+20>>2]+2|0;b=j>>>1|0;f=b;while(1){if(f){a=(w[h+1|0]+a|0)+(w[h|0]<<8)|0;u[o>>1]=a;o=o+4|0;h=h+2|0;f=f-1|0;continue}break}cb=p+16|0;e=b+e<<1;break u}d=w[a+1|0]}if(!(w[a+2|0]|(d&255)!=2)){e=0;Y:{switch(f|0){case 0:d=cb-16|0;cb=d;v[d+12>>2]=v[i+2580>>2]>>>2;v[d+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=w[g|0]|w[g+1|0]<<8;u[b+2>>1]=w[g+2|0]|w[g+3|0]<<8;b=b+4|0;g=g+4|0;e=e-1|0;continue}break};cb=d+16|0;e=a<<2;break u;case 1:d=cb-16|0;cb=d;v[d+12>>2]=v[i+2580>>2]>>>2;v[d+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=(w[g|0]|w[g+1|0]<<8)^32768;u[b+2>>1]=(w[g+2|0]|w[g+3|0]<<8)^32768;b=b+4|0;g=g+4|0;e=e-1|0;continue}break};cb=d+16|0;e=a<<2;break u;case 2:break Y;default:break u}}d=v[i+2580>>2];a=x[wk(i+328|0)>>1];f=cb-16|0;cb=f;v[f+12>>2]=d>>>2;v[f+8>>2]=v[b>>2];h=v[b+20>>2];b=a;e=v[Bb(f+12|0,f+8|0)>>2];d=e;while(1){if(d){a=(w[g|0]+a|0)+(w[g+1|0]<<8)|0;u[h>>1]=a;b=(w[g+2|0]+b|0)+(w[g+3|0]<<8)|0;u[h+2>>1]=b;h=h+4|0;g=g+4|0;d=d-1|0;continue}break}cb=f+16|0;e=e<<2;break u}e=0;if(w[a+1|0]!=2|w[a+2|0]!=1){break u}Z:{switch(f|0){case 0:f=cb-16|0;cb=f;v[f+12>>2]=v[i+2580>>2]>>>2;v[f+8>>2]=v[b>>2];b=v[b+20>>2];d=v[Bb(f+12|0,f+8|0)>>2];e=d;while(1){if(e){a=w[g|0]|w[g+1|0]<<8;u[b>>1]=a<<8|a>>>8;a=w[g+2|0]|w[g+3|0]<<8;u[b+2>>1]=a<<8|a>>>8;b=b+4|0;g=g+4|0;e=e-1|0;continue}break};cb=f+16|0;e=d<<2;break u;case 1:f=cb-16|0;cb=f;v[f+12>>2]=v[i+2580>>2]>>>2;v[f+8>>2]=v[b>>2];b=v[b+20>>2];d=v[Bb(f+12|0,f+8|0)>>2];e=d;while(1){if(e){a=w[g|0]|w[g+1|0]<<8;u[b>>1]=(a<<8|a>>>8)^32768;a=w[g+2|0]|w[g+3|0]<<8;u[b+2>>1]=(a<<8|a>>>8)^32768;b=b+4|0;g=g+4|0;e=e-1|0;continue}break};cb=f+16|0;e=d<<2;break u;case 2:break Z;default:break u}}d=v[i+2580>>2];a=x[wk(i+320|0)>>1];f=cb-16|0;cb=f;v[f+12>>2]=d>>>2;v[f+8>>2]=v[b>>2];h=v[b+20>>2];b=a;e=v[Bb(f+12|0,f+8|0)>>2];d=e;while(1){if(d){a=(w[g+1|0]+a|0)+(w[g|0]<<8)|0;u[h>>1]=a;b=(w[g+3|0]+b|0)+(w[g+2|0]<<8)|0;u[h+2>>1]=b;h=h+4|0;g=g+4|0;d=d-1|0;continue}break}cb=f+16|0;e=e<<2;break u}_:{$:{aa:{ba:{if((o|0)==24){if(!(f|w[a+1|0]!=1)){d=v[i+2580>>2];if(!w[a+2|0]){f=cb-16|0;cb=f;v[f+12>>2]=(d>>>0)/3;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){M=b,N=bd(w[g+1|0]<<16|w[g|0]<<8|w[g+2|0]<<24,16),u[M>>1]=N;b=b+2|0;g=g+3|0;e=e-1|0;continue}break}cb=f+16|0;e=B(a,3);break u}f=cb-16|0;cb=f;v[f+12>>2]=(d>>>0)/3;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){M=b,N=bd(w[g+1|0]<<16|w[g+2|0]<<8|w[g|0]<<24,16),u[M>>1]=N;b=b+2|0;g=g+3|0;e=e-1|0;continue}break}cb=f+16|0;e=B(a,3);break u}d=0;if(w[a+1|0]!=2){e=0;break ba}e=0;if(f){break ba}d=v[i+2580>>2];if(!w[a+2|0]){f=cb-16|0;cb=f;v[f+12>>2]=(d>>>0)/6;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){M=b,N=bd(w[g+1|0]<<16|w[g|0]<<8|w[g+2|0]<<24,16),u[M>>1]=N;M=b,N=bd(w[g+4|0]<<16|w[g+3|0]<<8|w[g+5|0]<<24,16),u[M+2>>1]=N;b=b+4|0;g=g+6|0;e=e-1|0;continue}break}cb=f+16|0;e=B(a,6);break u}f=cb-16|0;cb=f;v[f+12>>2]=(d>>>0)/6;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){M=b,N=bd(w[g+1|0]<<16|w[g+2|0]<<8|w[g|0]<<24,16),u[M>>1]=N;M=b,N=bd(w[g+4|0]<<16|w[g+5|0]<<8|w[g+3|0]<<24,16),u[M+2>>1]=N;b=b+4|0;g=g+6|0;e=e-1|0;continue}break}cb=f+16|0;e=B(a,6);break u}ca:{da:{d=(o|0)==32;if(d){if(!(f|w[a+1|0]!=1)){d=v[i+2580>>2];if(!w[a+2|0]){f=cb-16|0;cb=f;v[f+12>>2]=d>>>2;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){M=b,N=bd(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24),16),u[M>>1]=N;b=b+2|0;g=g+4|0;e=e-1|0;continue}break}cb=f+16|0;e=a<<2;break u}f=cb-16|0;cb=f;v[f+12>>2]=d>>>2;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){d=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);M=b,N=bd(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[M>>1]=N;b=b+2|0;g=g+4|0;e=e-1|0;continue}break}cb=f+16|0;e=a<<2;break u}if(f|w[a+1|0]!=2){break da}d=v[i+2580>>2];if(!w[a+2|0]){f=cb-16|0;cb=f;v[f+12>>2]=d>>>3;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){M=b,N=bd(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24),16),u[M>>1]=N;M=b,N=bd(w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24),16),u[M+2>>1]=N;b=b+4|0;g=g+8|0;e=e-1|0;continue}break}cb=f+16|0;e=a<<3;break u}f=cb-16|0;cb=f;v[f+12>>2]=d>>>3;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){d=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);M=b,N=bd(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[M>>1]=N;d=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);M=b,N=bd(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[M+2>>1]=N;b=b+4|0;g=g+8|0;e=e-1|0;continue}break}cb=f+16|0;e=a<<3;break u}e=0;if((o|0)!=64){break u}if(!(f|w[a+1|0]!=1)){d=v[i+2580>>2];if(!w[a+2|0]){f=cb-16|0;cb=f;v[f+12>>2]=d>>>3;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){M=b,N=Mc(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24),w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24),48),u[M>>1]=N;b=b+2|0;g=g+8|0;e=e-1|0;continue}break}cb=f+16|0;e=a<<3;break u}j=cb-16|0;cb=j;v[j+12>>2]=d>>>3;v[j+8>>2]=v[b>>2];b=v[b+20>>2];d=v[Bb(j+12|0,j+8|0)>>2];e=d;while(1){if(e){h=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);a=h<<24|h<<8&16711680;o=h>>>8|0;f=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);h=h>>>24|0;a=a|((o|f<<24)&65280|(h|f<<8)&255);M=b,N=Mc((o|(f&255)<<24)&-16777216|(h|(f&16777215)<<8)&16711680|(f>>>8&65280|f>>>24),a,48),u[M>>1]=N;b=b+2|0;g=g+8|0;e=e-1|0;continue}break}cb=j+16|0;e=d<<3;break u}e=(o|0)==64;if(f|w[a+1|0]!=2){break ca}d=v[i+2580>>2];if(!w[a+2|0]){f=cb-16|0;cb=f;v[f+12>>2]=d>>>4;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){M=b,N=Mc(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24),w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24),48),u[M>>1]=N;M=b,N=Mc(w[g+8|0]|w[g+9|0]<<8|(w[g+10|0]<<16|w[g+11|0]<<24),w[g+12|0]|w[g+13|0]<<8|(w[g+14|0]<<16|w[g+15|0]<<24),48),u[M+2>>1]=N;b=b+4|0;g=g+16|0;e=e-1|0;continue}break}cb=f+16|0;e=a<<4;break u}j=cb-16|0;cb=j;v[j+12>>2]=d>>>4;v[j+8>>2]=v[b>>2];b=v[b+20>>2];d=v[Bb(j+12|0,j+8|0)>>2];e=d;while(1){if(e){h=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);a=h<<24|h<<8&16711680;o=h>>>8|0;f=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);h=h>>>24|0;a=a|((o|f<<24)&65280|(h|f<<8)&255);M=b,N=Mc((o|(f&255)<<24)&-16777216|(h|(f&16777215)<<8)&16711680|(f>>>8&65280|f>>>24),a,48),u[M>>1]=N;h=w[g+8|0]|w[g+9|0]<<8|(w[g+10|0]<<16|w[g+11|0]<<24);f=w[g+12|0]|w[g+13|0]<<8|(w[g+14|0]<<16|w[g+15|0]<<24);a=h<<24|h<<8&16711680|((f<<24|h>>>8)&65280|(f<<8|h>>>24)&255);M=b,N=Mc(((f&255)<<24|h>>>8)&-16777216|((f&16777215)<<8|h>>>24)&16711680|(f>>>8&65280|f>>>24),a,48),u[M+2>>1]=N;b=b+4|0;g=g+16|0;e=e-1|0;continue}break}cb=j+16|0;e=d<<4;break u}if(!(w[a+1|0]!=1|(f|0)!=3)){d=v[i+2580>>2];if(!w[a+2|0]){f=cb-16|0;cb=f;v[f+12>>2]=d>>>2;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){k=Qf((l(2,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24)),q()));k=zf(C(Pd(ng(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));ea:{if(C(D(k))<C(2147483648)){d=~~k;break ea}d=-2147483648}M=b,N=Wc(d),u[M>>1]=N;b=b+2|0;g=g+4|0;e=e-1|0;continue}break}cb=f+16|0;e=a<<2;break u}f=cb-16|0;cb=f;v[f+12>>2]=d>>>2;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){d=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);k=Qf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));k=zf(C(Pd(ng(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));fa:{if(C(D(k))<C(2147483648)){d=~~k;break fa}d=-2147483648}M=b,N=Wc(d),u[M>>1]=N;b=b+2|0;g=g+4|0;e=e-1|0;continue}break}cb=f+16|0;e=a<<2;break u}if(!(w[a+1|0]!=2|(f|0)!=3)){d=v[i+2580>>2];if(!w[a+2|0]){f=cb-16|0;cb=f;v[f+12>>2]=d>>>3;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){k=Qf((l(2,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24)),q()));k=zf(C(Pd(ng(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));ga:{if(C(D(k))<C(2147483648)){d=~~k;break ga}d=-2147483648}M=b,N=Wc(d),u[M>>1]=N;k=Qf((l(2,w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24)),q()));k=zf(C(Pd(ng(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));ha:{if(C(D(k))<C(2147483648)){d=~~k;break ha}d=-2147483648}M=b,N=Wc(d),u[M+2>>1]=N;b=b+4|0;g=g+8|0;e=e-1|0;continue}break}cb=f+16|0;e=a<<3;break u}f=cb-16|0;cb=f;v[f+12>>2]=d>>>3;v[f+8>>2]=v[b>>2];b=v[b+20>>2];a=v[Bb(f+12|0,f+8|0)>>2];e=a;while(1){if(e){d=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);k=Qf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));k=zf(C(Pd(ng(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));ia:{if(C(D(k))<C(2147483648)){d=~~k;break ia}d=-2147483648}M=b,N=Wc(d),u[M>>1]=N;d=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);k=Qf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));k=zf(C(Pd(ng(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));ja:{if(C(D(k))<C(2147483648)){d=~~k;break ja}d=-2147483648}M=b,N=Wc(d),u[M+2>>1]=N;b=b+4|0;g=g+8|0;e=e-1|0;continue}break}cb=f+16|0;e=a<<3;break u}e=(o|0)==64;if((o|0)!=64){break $}}if(!(w[a+1|0]!=1|(f|0)!=3)){d=v[i+2580>>2];if(!w[a+2|0]){f=cb-32|0;cb=f;v[f+24>>2]=d>>>3;v[f+16>>2]=v[b>>2];b=v[b+20>>2];d=v[Bb(f+24|0,f+16|0)>>2];e=d;while(1){if(e){a=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);l(0,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));l(1,a|0);m=mg(+n());M=f,R=kf(m)?m>=0?1:-1:m,A[M+24>>3]=R;v[f+16>>2]=0;v[f+20>>2]=-1074790400;v[f+8>>2]=0;v[f+12>>2]=1072693248;m=ne(A[Fg(f+24|0,f+16|0,f+8|0)>>3]*32768);ka:{if(D(m)<2147483648){a=~~m;break ka}a=-2147483648}M=b,N=Wc(a),u[M>>1]=N;b=b+2|0;g=g+8|0;e=e-1|0;continue}break}cb=f+32|0;e=d<<3;break u}j=cb-32|0;cb=j;v[j+24>>2]=d>>>3;v[j+16>>2]=v[b>>2];b=v[b+20>>2];f=v[Bb(j+24|0,j+16|0)>>2];e=f;while(1){if(e){a=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);d=a<<24;d=d|a<<8&16711680;o=a>>>8|0;h=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);a=a>>>24|0;d=d|((o|h<<24)&65280|(a|h<<8)&255);l(0,(o|(h&255)<<24)&-16777216|(a|(h&16777215)<<8)&16711680|(h>>>8&65280|h>>>24));l(1,d|0);m=mg(+n());M=j,R=kf(m)?m>=0?1:-1:m,A[M+24>>3]=R;v[j+16>>2]=0;v[j+20>>2]=-1074790400;v[j+8>>2]=0;v[j+12>>2]=1072693248;m=ne(A[Fg(j+24|0,j+16|0,j+8|0)>>3]*32768);la:{if(D(m)<2147483648){a=~~m;break la}a=-2147483648}M=b,N=Wc(a),u[M>>1]=N;b=b+2|0;g=g+8|0;e=e-1|0;continue}break}cb=j+32|0;e=f<<3;break u}if(!(w[a+1|0]!=2|(f|0)!=3)){d=v[i+2580>>2];if(!w[a+2|0]){f=cb-32|0;cb=f;v[f+24>>2]=d>>>4;v[f+16>>2]=v[b>>2];b=v[b+20>>2];d=v[Bb(f+24|0,f+16|0)>>2];e=d;while(1){if(e){a=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);l(0,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));l(1,a|0);m=mg(+n());M=f,R=kf(m)?m>=0?1:-1:m,A[M+24>>3]=R;v[f+16>>2]=0;v[f+20>>2]=-1074790400;v[f+8>>2]=0;v[f+12>>2]=1072693248;m=ne(A[Fg(f+24|0,f+16|0,f+8|0)>>3]*32768);ma:{if(D(m)<2147483648){a=~~m;break ma}a=-2147483648}M=b,N=Wc(a),u[M>>1]=N;a=w[g+12|0]|w[g+13|0]<<8|(w[g+14|0]<<16|w[g+15|0]<<24);l(0,w[g+8|0]|w[g+9|0]<<8|(w[g+10|0]<<16|w[g+11|0]<<24));l(1,a|0);m=mg(+n());M=f,R=kf(m)?m>=0?1:-1:m,A[M+24>>3]=R;v[f+16>>2]=0;v[f+20>>2]=-1074790400;v[f+8>>2]=0;v[f+12>>2]=1072693248;m=ne(A[Fg(f+24|0,f+16|0,f+8|0)>>3]*32768);na:{if(D(m)<2147483648){a=~~m;break na}a=-2147483648}M=b,N=Wc(a),u[M+2>>1]=N;b=b+4|0;g=g+16|0;e=e-1|0;continue}break}cb=f+32|0;e=d<<4;break u}j=cb-32|0;cb=j;v[j+24>>2]=d>>>4;v[j+16>>2]=v[b>>2];b=v[b+20>>2];f=v[Bb(j+24|0,j+16|0)>>2];e=f;while(1){if(e){a=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);d=a<<24;d=d|a<<8&16711680;o=a>>>8|0;h=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);a=a>>>24|0;d=d|((o|h<<24)&65280|(a|h<<8)&255);l(0,(o|(h&255)<<24)&-16777216|(a|(h&16777215)<<8)&16711680|(h>>>8&65280|h>>>24));l(1,d|0);m=mg(+n());M=j,R=kf(m)?m>=0?1:-1:m,A[M+24>>3]=R;v[j+16>>2]=0;v[j+20>>2]=-1074790400;v[j+8>>2]=0;v[j+12>>2]=1072693248;m=ne(A[Fg(j+24|0,j+16|0,j+8|0)>>3]*32768);oa:{if(D(m)<2147483648){a=~~m;break oa}a=-2147483648}M=b,N=Wc(a),u[M>>1]=N;a=w[g+8|0]|w[g+9|0]<<8|(w[g+10|0]<<16|w[g+11|0]<<24);d=a<<24;d=d|a<<8&16711680;o=a>>>8|0;h=w[g+12|0]|w[g+13|0]<<8|(w[g+14|0]<<16|w[g+15|0]<<24);a=a>>>24|0;d=d|((o|h<<24)&65280|(a|h<<8)&255);l(0,(o|(h&255)<<24)&-16777216|(a|(h&16777215)<<8)&16711680|(h>>>8&65280|h>>>24));l(1,d|0);m=mg(+n());M=j,R=kf(m)?m>=0?1:-1:m,A[M+24>>3]=R;v[j+16>>2]=0;v[j+20>>2]=-1074790400;v[j+8>>2]=0;v[j+12>>2]=1072693248;m=ne(A[Fg(j+24|0,j+16|0,j+8|0)>>3]*32768);pa:{if(D(m)<2147483648){a=~~m;break pa}a=-2147483648}M=b,N=Wc(a),u[M+2>>1]=N;b=b+4|0;g=g+16|0;e=e-1|0;continue}break}cb=j+32|0;e=f<<4;break u}if((o|0)!=24){break aa}}if((f|0)!=15|(w[a+1|0]-1&255)>>>0>1){break aa}v[i+416>>2]=-2147483648;d=v[i+2580>>2];qa:{if(!w[a+2|0]){v[i+8>>2]=v[i+312>>2];v[i+308>>2]=0;a=v[i+308>>2];v[i>>2]=v[i+304>>2];v[i+4>>2]=a;E=i+416|0;s=cb-16|0;cb=s;M=s,N=B(v[b>>2],zd(x[b+34>>1])),v[M+12>>2]=N;qc(s+12|0,(d>>>0)/3|0);d=v[i+4>>2];a=g;j=v[s+12>>2];f=j;while(1){if(f){h=w[a+1|0]<<16|w[a|0]<<8|w[a+2|0]<<24;ra:{if((h|0)<0){e=-2147483648;if((h|0)==-2147483648){break ra}h=0-h|0}e=d>>>0<h>>>0?h:d}d=e;f=f-1|0;a=a+3|0;continue}else{sa:{if(!d){break sa}p=d-1|0;r=d>>>1|0;h=v[b+20>>2];a=j;while(1){if(!a){break sa}e=w[g+1|0]<<16|w[g|0]<<8|w[g+2|0]<<24;f=e>>31<<31|e>>>1;e=r|e<<31;ta:{if((f|0)>0|(f|0)>=0){e=nka(e,f,d,0);f=fb;break ta}f=nka(p-e|0,0-((e>>>0>p>>>0)+f|0)|0,d,0);e=0-f|0;f=0-(fb+((f|0)!=0)|0)|0}M=h,N=bd(yc(e,f),16),u[M>>1]=N;a=a-1|0;g=g+3|0;h=h+2|0;continue}}}break}if(E){v[E>>2]=d}cb=s+16|0;e=B(j,3);break qa}v[i+24>>2]=v[i+296>>2];v[i+292>>2]=0;a=v[i+292>>2];v[i+16>>2]=v[i+288>>2];v[i+20>>2]=a;E=i+416|0;s=cb-16|0;cb=s;M=s,N=B(v[b>>2],zd(x[b+34>>1])),v[M+12>>2]=N;qc(s+12|0,(d>>>0)/3|0);d=v[i+20>>2];a=g;j=v[s+12>>2];f=j;while(1){if(f){h=w[a+1|0]<<16|w[a+2|0]<<8|w[a|0]<<24;ua:{if((h|0)<0){e=-2147483648;if((h|0)==-2147483648){break ua}h=0-h|0}e=d>>>0<h>>>0?h:d}d=e;f=f-1|0;a=a+3|0;continue}else{va:{if(!d){break va}p=d-1|0;r=d>>>1|0;h=v[b+20>>2];a=j;while(1){if(!a){break va}e=w[g+1|0]<<16|w[g+2|0]<<8|w[g|0]<<24;f=e>>31<<31|e>>>1;e=r|e<<31;wa:{if((f|0)>0|(f|0)>=0){e=nka(e,f,d,0);f=fb;break wa}f=nka(p-e|0,0-((e>>>0>p>>>0)+f|0)|0,d,0);e=0-f|0;f=0-(fb+((f|0)!=0)|0)|0}M=h,N=bd(yc(e,f),16),u[M>>1]=N;a=a-1|0;g=g+3|0;h=h+2|0;continue}}}break}if(E){v[E>>2]=d}cb=s+16|0;e=B(j,3)}if(!e){break u}a=v[i+416>>2];if((a|0)==-2147483648){break u}g=kka(x[b+32>>1],0,a,0)+1073741824|0;a=fb;a=g>>>0<1073741824?a+1|0:a;M=b,N=wd(wc((a&2147483647)<<1|g>>>31,a>>>31|0),1,64),u[M+32>>1]=N;u[b+34>>1]=x[b+34>>1]|8192;break u}if(!d){break _}}if(!((f|0)!=15|(w[a+1|0]-1&255)>>>0>1)){v[i+416>>2]=-2147483648;d=v[i+2580>>2];xa:{if(!w[a+2|0]){v[i+40>>2]=v[i+280>>2];v[i+276>>2]=0;a=v[i+276>>2];v[i+32>>2]=v[i+272>>2];v[i+36>>2]=a;E=i+416|0;s=cb-16|0;cb=s;M=s,N=B(v[b>>2],zd(x[b+34>>1])),v[M+12>>2]=N;qc(s+12|0,d>>>2|0);h=v[i+36>>2];f=g;j=v[s+12>>2];d=j;while(1){if(d){a=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);ya:{if((a|0)<0){e=-2147483648;if((a|0)==-2147483648){break ya}a=0-a|0}e=a>>>0>h>>>0?a:h}h=e;d=d-1|0;f=f+4|0;continue}else{za:{if(!h){break za}p=h-1|0;r=h>>>1|0;d=v[b+20>>2];a=j;while(1){if(!a){break za}e=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);f=e>>31<<31|e>>>1;e=r|e<<31;Aa:{if((f|0)>0|(f|0)>=0){e=nka(e,f,h,0);f=fb;break Aa}f=nka(p-e|0,0-((e>>>0>p>>>0)+f|0)|0,h,0);e=0-f|0;f=0-(fb+((f|0)!=0)|0)|0}M=d,N=bd(yc(e,f),16),u[M>>1]=N;a=a-1|0;g=g+4|0;d=d+2|0;continue}}}break}if(E){v[E>>2]=h}cb=s+16|0;e=j<<2;break xa}v[i+56>>2]=v[i+264>>2];v[i+260>>2]=0;a=v[i+260>>2];v[i+48>>2]=v[i+256>>2];v[i+52>>2]=a;E=i+416|0;s=cb-16|0;cb=s;M=s,N=B(v[b>>2],zd(x[b+34>>1])),v[M+12>>2]=N;qc(s+12|0,d>>>2|0);h=v[i+52>>2];d=g;f=v[s+12>>2];a=f;while(1){if(a){e=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);o=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);Ba:{if((o|0)<0){e=-2147483648;if((o|0)==-2147483648){break Ba}o=0-o|0}e=h>>>0<o>>>0?o:h}h=e;a=a-1|0;d=d+4|0;continue}else{Ca:{if(!h){break Ca}p=h-1|0;r=h>>>1|0;d=v[b+20>>2];a=f;while(1){if(!a){break Ca}e=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);j=e>>31<<31|e>>>1;e=r|e<<31;Da:{if((j|0)>0|(j|0)>=0){e=nka(e,j,h,0);j=fb;break Da}j=nka(p-e|0,0-((e>>>0>p>>>0)+j|0)|0,h,0);e=0-j|0;j=0-(fb+((j|0)!=0)|0)|0}M=d,N=bd(yc(e,j),16),u[M>>1]=N;a=a-1|0;g=g+4|0;d=d+2|0;continue}}}break}if(E){v[E>>2]=h}cb=s+16|0;e=f<<2}if(!e){break u}a=v[i+416>>2];if((a|0)==-2147483648){break u}g=kka(x[b+32>>1],0,a,0)+1073741824|0;a=fb;a=g>>>0<1073741824?a+1|0:a;M=b,N=wd(wc((a&2147483647)<<1|g>>>31,a>>>31|0),1,64),u[M+32>>1]=N;u[b+34>>1]=x[b+34>>1]|8192;break u}if((f|0)!=14|(w[a+1|0]-1&255)>>>0>1){break _}v[i+416>>2]=1065353216;d=v[i+2580>>2];Ea:{if(!w[a+2|0]){v[i+244>>2]=0;v[i+248>>2]=1065353216;a=v[i+252>>2];v[i+72>>2]=v[i+248>>2];v[i+76>>2]=a;a=v[i+244>>2];v[i+64>>2]=v[i+240>>2];v[i+68>>2]=a;e=i+416|0;f=cb-16|0;cb=f;M=f,N=B(v[b>>2],zd(x[b+34>>1])),v[M+12>>2]=N;qc(f+12|0,d>>>2|0);F=z[(i- -64|0)+4>>2];h=g;d=v[f+12>>2];a=d;while(1){if(a){k=Qf((l(2,w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24)),q()));k=C(D(ng(k)?k>=C(0)?C(1):C(-1):k));F=k>F?k:F;a=a-1|0;h=h+4|0;continue}else{Fa:{a=F==C(0);if(a){break Fa}I=a?C(1):C(C(1)/F);h=v[b+20>>2];a=d;while(1){if(!a){break Fa}k=Qf((l(2,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24)),q()));k=zf(C(Pd(C(I*(ng(k)?k>=C(0)?C(1):C(-1):k)),C(-1))*C(32768)));Ga:{if(C(D(k))<C(2147483648)){j=~~k;break Ga}j=-2147483648}M=h,N=Wc(j),u[M>>1]=N;a=a-1|0;g=g+4|0;h=h+2|0;continue}}if(e){z[e>>2]=F}cb=f+16|0;e=d<<2}break}break Ea}v[i+228>>2]=0;v[i+232>>2]=1065353216;a=v[i+236>>2];v[i+88>>2]=v[i+232>>2];v[i+92>>2]=a;a=v[i+228>>2];v[i+80>>2]=v[i+224>>2];v[i+84>>2]=a;e=i+416|0;j=cb-16|0;cb=j;M=j,N=B(v[b>>2],zd(x[b+34>>1])),v[M+12>>2]=N;qc(j+12|0,d>>>2|0);F=z[i+84>>2];h=g;d=v[j+12>>2];a=d;while(1){if(a){f=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);k=Qf((l(2,f<<24|f<<8&16711680|(f>>>8&65280|f>>>24)),q()));k=C(D(ng(k)?k>=C(0)?C(1):C(-1):k));F=k>F?k:F;a=a-1|0;h=h+4|0;continue}else{Ha:{a=F==C(0);if(a){break Ha}I=a?C(1):C(C(1)/F);h=v[b+20>>2];a=d;while(1){if(!a){break Ha}f=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);k=Qf((l(2,f<<24|f<<8&16711680|(f>>>8&65280|f>>>24)),q()));k=zf(C(Pd(C(I*(ng(k)?k>=C(0)?C(1):C(-1):k)),C(-1))*C(32768)));Ia:{if(C(D(k))<C(2147483648)){f=~~k;break Ia}f=-2147483648}M=h,N=Wc(f),u[M>>1]=N;a=a-1|0;g=g+4|0;h=h+2|0;continue}}if(e){z[e>>2]=F}cb=j+16|0;e=d<<2}break}}if(!e){break u}k=z[i+416>>2];if(k==C(1)){break u}k=zf(Ny(C(k*C(x[b+32>>1])),C(1),C(64)));a=65535;Ja:{if(k>=C(65535)){break Ja}a=0;if(k<=C(0)){break Ja}a=~~k>>>0;if(k<C(4294967296)&k>=C(0)){break Ja}a=0}u[b+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break u}if(!(!e|((f|0)!=14|(w[a+1|0]-1&255)>>>0>1))){v[i+416>>2]=0;v[i+420>>2]=1072693248;d=v[i+2580>>2];Ka:{if(!w[a+2|0]){v[i+208>>2]=0;v[i+212>>2]=1072693248;v[i+200>>2]=0;v[i+204>>2]=0;v[i+104>>2]=0;v[i+108>>2]=0;v[i+112>>2]=0;v[i+116>>2]=1072693248;a=v[i+220>>2];v[i+120>>2]=v[i+216>>2];v[i+124>>2]=a;a=v[i+196>>2];v[i+96>>2]=v[i+192>>2];v[i+100>>2]=a;h=i+416|0;j=cb-32|0;cb=j;M=j,N=B(v[b>>2],zd(x[b+34>>1])),v[M+4>>2]=N;qc(j+4|0,d>>>3|0);G=A[i+104>>3];d=g;e=v[j+4>>2];a=e;while(1){if(a){f=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);l(0,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));l(1,f|0);m=mg(+n());m=D(kf(m)?m>=0?1:-1:m);G=m>G?m:G;a=a-1|0;d=d+8|0;continue}else{La:{a=G==0;if(a){break La}J=a?1:1/G;d=v[b+20>>2];a=e;while(1){if(!a){break La}f=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);l(0,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));l(1,f|0);m=mg(+n());M=j,R=J*(kf(m)?m>=0?1:-1:m),A[M+24>>3]=R;v[j+16>>2]=0;v[j+20>>2]=-1074790400;v[j+8>>2]=0;v[j+12>>2]=1072693248;m=ne(A[Fg(j+24|0,j+16|0,j+8|0)>>3]*32768);Ma:{if(D(m)<2147483648){f=~~m;break Ma}f=-2147483648}M=d,N=Wc(f),u[M>>1]=N;a=a-1|0;g=g+8|0;d=d+2|0;continue}}if(h){A[h>>3]=G}cb=j+32|0;e=e<<3}break}break Ka}v[i+176>>2]=0;v[i+180>>2]=1072693248;v[i+168>>2]=0;v[i+172>>2]=0;v[i+136>>2]=0;v[i+140>>2]=0;v[i+144>>2]=0;v[i+148>>2]=1072693248;a=v[i+188>>2];v[i+152>>2]=v[i+184>>2];v[i+156>>2]=a;a=v[i+164>>2];v[i+128>>2]=v[i+160>>2];v[i+132>>2]=a;j=i+416|0;E=cb-32|0;cb=E;M=E,N=B(v[b>>2],zd(x[b+34>>1])),v[M+4>>2]=N;qc(E+4|0,d>>>3|0);G=A[i+136>>3];d=g;f=v[E+4>>2];a=f;while(1){if(a){e=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);h=e<<24|e<<8&16711680;o=e>>>8|0;r=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);e=e>>>24|0;h=h|((o|r<<24)&65280|(e|r<<8)&255);l(0,(o|(r&255)<<24)&-16777216|(e|(r&16777215)<<8)&16711680|(r>>>8&65280|r>>>24));l(1,h|0);m=mg(+n());m=D(kf(m)?m>=0?1:-1:m);G=m>G?m:G;a=a-1|0;d=d+8|0;continue}else{Na:{a=G==0;if(a){break Na}J=a?1:1/G;d=v[b+20>>2];a=f;while(1){if(!a){break Na}p=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);h=p<<24|p<<8&16711680;o=p>>>8|0;r=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);e=o|r<<24;s=(o|(r&255)<<24)&-16777216;o=p>>>24|0;l(0,s|(o|(r&16777215)<<8)&16711680|(r>>>8&65280|r>>>24));l(1,h|(e&65280|(o|r<<8)&255));m=mg(+n());M=E,R=J*(kf(m)?m>=0?1:-1:m),A[M+24>>3]=R;v[E+16>>2]=0;v[E+20>>2]=-1074790400;v[E+8>>2]=0;v[E+12>>2]=1072693248;m=ne(A[Fg(E+24|0,E+16|0,E+8|0)>>3]*32768);Oa:{if(D(m)<2147483648){e=~~m;break Oa}e=-2147483648}M=d,N=Wc(e),u[M>>1]=N;a=a-1|0;g=g+8|0;d=d+2|0;continue}}if(j){A[j>>3]=G}cb=E+32|0;e=f<<3}break}}if(!e){break u}m=A[i+416>>3];if(m==1){break u}M=b,N=nT(Wt(m*+x[b+32>>1],1,64)),u[M+32>>1]=N;u[b+34>>1]=x[b+34>>1]|8192;break u}e=0;if(!d){break u}if(!(w[a+1|0]!=1|(f|0)!=12)){d=v[i+2580>>2];if(!w[a+2|0]){e=hN(b,g,d,C(30517578125e-15));break u}e=gN(b,g,d,C(30517578125e-15));break u}if(!(w[a+1|0]!=2|(f|0)!=12)){d=v[i+2580>>2];if(!w[a+2|0]){e=fN(b,g,d,C(30517578125e-15));break u}e=eN(b,g,d,C(30517578125e-15));break u}if(!(w[a+1|0]!=1|(f|0)!=13)){d=v[i+2580>>2];if(!w[a+2|0]){e=hN(b,g,d,C(1.1920928955078125e-7));break u}e=gN(b,g,d,C(1.1920928955078125e-7));break u}if(w[a+1|0]!=2|(f|0)!=13){break u}d=v[i+2580>>2];if(!w[a+2|0]){e=fN(b,g,d,C(1.1920928955078125e-7));break u}e=eN(b,g,d,C(1.1920928955078125e-7));break u}a=V(30592)|0}if((O()|0)!=(fa(30592)|0)){break d}_(a|0)|0;v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)==1){break v}}sb(s);break u}a=P()|0;O()|0;break d}v[22440]=0;Q(157,c|0,e+K|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break f}}vc(H)}cb=i+2608|0;return e|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}sb(s);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}vc(H);S(a|0);L()}function lia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;d=cb-496|0;cb=d;sc(b);j=cb-16|0;cb=j;i=d+304|0;rq(j+8|0,i);h=b;b=v[j+12>>2];Yb(j,h,v[j+8>>2],b);l=v[j+4>>2];if((l|0)==(b|0)){Ob(h,v[j+12>>2])}cb=j+16|0;b=(b|0)==(l|0);if(!b){KS(i)}a:{b:{c:{if(!b){break c}if(!MS(d+304|0)){break c}if(!Kb(h,wc(LS(d+304|0),fb))){break c}if(!c){f=1;break c}ud(a,32);t[d+303|0]=0;j=Db(d+288|0);d:{e:{f:{g:{h:{i:{j:{if(!Mb(d+304|0,16311,4)){v[22440]=0;R(418,a|0,16777216);b=v[22440];v[22440]=0;if((b|0)==1){break b}v[22440]=0;b=T(162,h|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break b}v[22440]=0;Q(157,h|0,b-4|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break b}v[22440]=0;z=T(159,h|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break j}break b}k:{l:{m:{n:{o:{p:{if(((w[d+344|0]|w[d+345|0]<<8)-2185&65535)>>>0>1910){break p}v[22440]=0;b=T(162,h|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break b}v[22440]=0;Q(157,h|0,b-4|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break b}v[22440]=0;z=T(159,h|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break b}if(z>>>0<256){break p}v[22440]=0;b=T(162,h|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break b}if(b>>>0<=z>>>0){break p}v[22440]=0;b=Q(157,h|0,z|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break b}if(!b){break p}v[22440]=0;b=T(419,h|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break b}if(!b){break p}v[22440]=0;R(418,a|0,16777216);b=v[22440];v[22440]=0;if((b|0)==1){break b}b=w[d+344|0]|w[d+345|0]<<8;if(b>>>0>=4096){v[22440]=0;c=Q(1,d+104|0,16526)|0;b=v[22440];v[22440]=0;if((b|0)==1){break i}a=v[a+1298464>>2];v[22440]=0;U(388,a|0,1,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(c);break d}b=P()|0;O()|0;rb(c);break a}if(b>>>0<2194){break p}v[22440]=0;f=Q(1,d+104|0,16050)|0;b=v[22440];v[22440]=0;if((b|0)==1){break o}b=v[a+1298464>>2];v[22440]=0;U(388,b|0,4,f|0);b=v[22440];v[22440]=0;if((b|0)==1){break n}rb(f)}if(v[a+480180>>2]!=32){break j}b=w[d+344|0]|w[d+345|0]<<8;if((b&61440)!=20480){break k}b=b&4095;f=b<<16;if(Mb(d+364|0,13700,4)){break m}t[d+303|0]=1;break l}b=P()|0;O()|0;break a}b=P()|0;O()|0;rb(f);break a}if(b>>>0<297){break l}f=w[d+364|0]|w[d+365|0]<<8|f}v[a+1074308>>2]=f;break j}f=w[d+346|0]|w[d+347|0]<<8;if(!((f|0)!=2184&(b|0)!=2184)){t[d+303|0]=1;v[a+1074308>>2]=18284544;break j}if(!((b|0)!=535|(f|0)!=512)){if(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)){break j}q:{if(HA(d+368|0,255,64)){v[a+1074308>>2]=18219008;v[22440]=0;b=Q(1,d+104|0,14917)|0;f=v[22440];v[22440]=0;if((f|0)!=1){break q}b=P()|0;O()|0;break a}v[a+1074308>>2]=18284544;v[22440]=0;b=Q(1,d+104|0,16900)|0;f=v[22440];v[22440]=0;if((f|0)==1){break h}}Cb(j,b);rb(b);t[d+303|0]=1;break j}if(!((b|0)!=532|(f|0)!=514)){if(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)){break j}v[a+1074308>>2]=17367040;v[22440]=0;b=Q(1,d+104|0,14803)|0;f=v[22440];v[22440]=0;if((f|0)!=1){Cb(j,b);rb(b);t[d+303|0]=1;break j}b=P()|0;O()|0;break a}if((b|0)!=768|(f|0)!=768|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24))|((w[d+336|0]|w[d+337|0]<<8)!=256|w[d+356|0]!=128)){break j}if(w[d+357|0]){break j}v[a+1074308>>2]=18285088;t[d+303|0]=1}b=v[a+480208>>2]&-17|(w[d+348|0]|w[d+349|0]<<8)<<1&16;v[a+480208>>2]=b;b=b&-5|(w[d+348|0]|w[d+349|0]<<8)>>>2&4;v[a+480208>>2]=b;b=b&-9|(w[d+348|0]|w[d+349|0]<<8)>>>2&8;v[a+480208>>2]=b;v[a+480208>>2]=b&-32769|(w[d+348|0]|w[d+349|0]<<8)<<3&32768;Hq(d+216|0,d+304|4);v[22440]=0;W(225,d+104|0,v[d+216>>2],v[d+220>>2],w[d+224|0]);b=v[22440];v[22440]=0;if((b|0)==1){break g}b=d+104|0;tc(a+1298308|0,b);rb(b);if(!(!(w[d+350|0]&4)|v[a+1074308>>2]-18285314>>>0>4276681982)){v[a+480216>>2]=w[d+334|0];v[a+480220>>2]=w[d+335|0]}b=w[d+352|0];v[a+480200>>2]=b>>>0>128?256:b<<1;b=w[d+354|0];if(b){v[a+480196>>2]=b}t[d+104|0]=31;t[d+216|0]=w[d+355|0];b=d+104|0;f=d+216|0;I=a,J=B(w[ff(b,f)|0],1e4),v[I+480204>>2]=J;t[d+104|0]=w[d+353|0];t[d+216|0]=128;I=a,J=w[Tb(b,f)|0],v[I+480228>>2]=J;f=0;while(1){if((f|0)==64){r:{v[22440]=0;Q(157,h|0,192)|0;b=v[22440];v[22440]=0;if((b|0)==1){break b}if(v[a+480180>>2]==16777216&((w[d+344|0]|w[d+345|0]<<8)-2187&65535)>>>0<=2){break r}b=Nb(a+484360|0);f=w[d+336|0]|w[d+337|0]<<8;v[22440]=0;ea(351,b|0,h|0,f|0,255,254)|0;b=v[22440];v[22440]=0;if((b|0)==1){break b}break e}}else{b=(d+304|0)+f|0;l=b- -64|0;s:{if(w[l|0]==255){break s}m=(f<<5)+a|0;i=m+480280|0;$e(i);I=m+480286|0,J=wd(w[b+128|0],0,64),u[I>>1]=J;b=t[l|0];if((b|0)<0){v[i>>2]=v[i>>2]|1024;b=w[l|0]}b=b&127;if(b>>>0<=64){u[m+480284>>1]=b<<2;break s}if((b|0)!=100){break s}v[i>>2]=v[i>>2]|256}f=f+1|0;continue}break}f=0;v[22440]=0;b=T(196,h|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break f}if(b){break d}v[22440]=0;b=T(159,h|0)|0;i=v[22440];v[22440]=0;t:{if((i|0)==1){break t}if(b>>>0>4e3){break d}i=Nb(a+484360|0);v[22440]=0;b=Y(420,i|0,h|0,b|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break t}if(!b){break d}break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}s=Rb(d+272|0);m=Rb(d+256|0);l=Rb(d+240|0);b=w[d+338|0]|w[d+339|0]<<8;f=0;v[22440]=0;b=Y(421,h|0,s|0,b|0)|0;i=v[22440];v[22440]=0;u:{v:{w:{if((i|0)==1){break w}if(!b){break u}b=w[d+340|0]|w[d+341|0]<<8;v[22440]=0;b=Y(421,h|0,m|0,b|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break w}if(!b){break u}b=w[d+342|0]|w[d+343|0]<<8;v[22440]=0;b=Y(421,h|0,l|0,b|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break w}if(!b){break u}v[d+236>>2]=-1;I=d,J=yb(v[s>>2]),v[I+104>>2]=J;i=yb(v[s+4>>2]);while(1){b=v[d+104>>2];if(Qb(b,i)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(!b|b>>>0>=y[d+236>>2])){v[d+236>>2]=b}Ge(d+104|0);continue}else{I=d,J=yb(v[m>>2]),v[I+104>>2]=J;i=yb(v[m+4>>2]);while(1){b=v[d+104>>2];if(Qb(b,i)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(!b|b>>>0>=y[d+236>>2])){v[d+236>>2]=b}Ge(d+104|0);continue}else{I=d,J=yb(v[l>>2]),v[I+104>>2]=J;i=yb(v[l+4>>2]);x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{while(1){b=v[d+104>>2];if(Qb(b,i)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(!b|b>>>0>=y[d+236>>2])){v[d+236>>2]=b}Ge(d+104|0);continue}else{if(t[d+350|0]&1){v[d+104>>2]=w[d+360|0]|w[d+361|0]<<8|(w[d+362|0]<<16|w[d+363|0]<<24);I=d,J=v[Bb(d+236|0,d+104|0)>>2],v[I+236>>2]=J}if((w[d+346|0]|w[d+347|0]<<8)!=532){break F}b=w[d+344|0]|w[d+345|0]<<8;if(w[d+335|0]|(b?(b|0)!=532:0)|(w[d+334|0]|w[d+357|0])){break F}if(w[d+348|0]&192|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24))){break F}if(w[d+338|0]|w[d+339|0]<<8){break G}b=w[d+340|0]|w[d+341|0]<<8;if(!b){break G}if((v[h+8>>2]+(pc(v[m>>2],v[m+4>>2])<<2)|0)+2>>>0>y[d+236>>2]){break G}}break}while(1){if((f&65535)>>>0<(b&65535)>>>0){v[22440]=0;b=T(159,h|0)|0;e=v[22440];v[22440]=0;H:{if((e|0)!=1){if(!b){break H}xg(h,((f&65535)<<2)+4|0);break G}b=P()|0;O()|0;break v}f=f+1|0;b=w[d+340|0]|w[d+341|0]<<8;continue}break}v[22440]=0;b=Q(1,d+104|0,15061)|0;e=v[22440];v[22440]=0;if((e|0)==1){break E}Cb(j,b);rb(b)}e=1;if(w[d+344|0]|w[d+345|0]<<8){break F}v[22440]=0;b=Q(1,d+104|0,15459)|0;f=v[22440];v[22440]=0;if((f|0)==1){break D}Cb(j,b);rb(b)}b=w[d+350|0]|w[d+351|0]<<8;I:{if(b&2){v[22440]=0;f=T(196,h|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break y}v[22440]=0;b=f<<3;i=Q(158,h|0,b|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break y}if(!(!i|y[d+236>>2]<b+v[h+8>>2]>>>0)){v[22440]=0;b=a+1298408|0;R(422,b|0,f|0);i=v[22440];v[22440]=0;if((i|0)==1){break y}I=d,J=yb(v[b>>2]),v[I+216>>2]=J;i=yb(v[a+1298412>>2]);J:{K:{while(1){b=v[d+216>>2];if(!Qb(b,i)){if(!(!f&e)){break I}if(!(w[d+350|0]&4)){break J}v[22440]=0;b=Q(1,d+104|0,15492)|0;e=v[22440];v[22440]=0;if((e|0)==1){break K}Cb(j,b);rb(b);break I}v[22440]=0;R(423,h|0,d+104|0);k=v[22440];v[22440]=0;if((k|0)!=1){Hb(b,0,44);k=w[d+104|0]|w[d+105|0]<<8;if(w[d+106|0]|w[d+107|0]<<8?1:k){v[b+20>>2]=(k>>>9|0)+80;I=b,J=Vb((w[d+104|0]|w[d+105|0]<<8)>>>5&15,1,12)-1|0,v[I+16>>2]=J;I=b,J=Vb((w[d+104|0]|w[d+105|0]<<8)&31,1,31),v[I+12>>2]=J;I=b,J=Vb((w[d+106|0]|w[d+107|0]<<8)>>>11|0,0,23),v[I+8>>2]=J;I=b,J=Vb((w[d+106|0]|w[d+107|0]<<8)>>>5&63,0,59),v[I+4>>2]=J;I=b,J=Vb((w[d+106|0]|w[d+107|0]<<8)<<1&62,0,59),v[I>>2]=J}v[b+44>>2]=w[d+108|0]|w[d+109|0]<<8|(w[d+110|0]<<16|w[d+111|0]<<24);v[d+216>>2]=v[d+216>>2]+48;continue}break}b=P()|0;O()|0;break v}b=P()|0;O()|0;break v}v[22440]=0;b=Q(1,d+104|0,15088)|0;e=v[22440];v[22440]=0;if((e|0)!=1){Cb(j,b);rb(b);break I}b=P()|0;O()|0;break v}xg(h,2);break I}if(!(b>>>0<2&e)){break I}v[22440]=0;b=T(196,h|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break x}if(!b){v[22440]=0;b=Q(1,d+104|0,15061)|0;e=v[22440];v[22440]=0;if((e|0)!=1){Cb(j,b);rb(b);break I}b=P()|0;O()|0;break v}xg(h,2)}L:{if(!(w[d+350|0]&8?1:w[d+348|0]&128)){break L}v[22440]=0;b=a+901404|0;e=Q(424,h|0,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break C}if(!e){break L}GA(b)}if((w[d+344|0]|w[d+345|0]<<8)>>>0<=531){_p(a+901404|0)}v[22440]=0;A=T(176,d+216|0)|0;b=v[22440];v[22440]=0;M:{N:{O:{if((b|0)!=1){v[22440]=0;b=Q(414,h|0,13937)|0;e=v[22440];v[22440]=0;if((e|0)==1){break O}if(b){v[22440]=0;b=T(159,h|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break N}v[22440]=0;U(192,d+192|0,h|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break N}b=d+192|0;e=cc(d+104|0,b);Sc(A,e);sb(e);sb(b)}u[a+480188>>1]=1;v[22440]=0;b=Q(414,h|0,13942)|0;e=v[22440];v[22440]=0;if((e|0)==1){break O}if(!b){break A}v[22440]=0;b=T(159,h|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){v[22440]=0;U(192,d+192|0,h|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break M}}b=P()|0;O()|0;break z}b=P()|0;O()|0;break v}b=P()|0;O()|0;break z}b=P()|0;O()|0;break z}b=d+192|0;e=cc(d+104|0,b);sb(b);v[22440]=0;b=T(162,e|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break B}u[d+192>>1]=(b>>>0)/20;b=x[Kc(26756,d+192|0)>>1];u[a+480188>>1]=b;f=0;while(1){if((b|0)==(f|0)){sb(e);break A}v[22440]=0;U(425,e|0,((f<<5)+a|0)+480289|0,20);i=v[22440];v[22440]=0;if((i|0)!=1){f=f+1|0;continue}break}break B}b=P()|0;O()|0;break v}b=P()|0;O()|0;break v}b=P()|0;O()|0;break v}b=P()|0;O()|0;sb(e);break z}P:{b=v[d+236>>2];e=v[h+8>>2];Q:{if(b>>>0>=e>>>0){f=b-e|0;break Q}v[22440]=0;f=T(204,h|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break P}}v[22440]=0;U(192,d+104|0,h|0,f|0);b=v[22440];v[22440]=0;if((b|0)==1){break P}b=d+104|0;D=cc(d+192|0,b);sb(b);v[22440]=0;E=Q(426,a|0,D|0)|0;b=v[22440];v[22440]=0;R:{S:{T:{if((b|0)==1){break T}if(!(t[d+350|0]&1)|!(w[d+358|0]|w[d+359|0]<<8)){break S}b=w[d+360|0]|w[d+361|0]<<8|(w[d+362|0]<<16|w[d+363|0]<<24);v[22440]=0;b=Q(157,h|0,b|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break T}if(!b){break S}b=w[d+358|0]|w[d+359|0]<<8;v[22440]=0;W(340,a+1298332|0,h|0,b|0,4);b=v[22440];v[22440]=0;if((b|0)!=1){break S}}b=P()|0;O()|0;break R}e=a+480192|0;u[e>>1]=0;if(w[d+348|0]&4){u[d+104>>1]=w[d+338|0]|w[d+339|0]<<8;u[d+32>>1]=255;g=x[Kc(d+104|0,d+32|0)>>1];u[e>>1]=g}f=0;U:{while(1){if((g&65535)>>>0<=f>>>0){v[d+188>>2]=0;f=0;b=w[d+340|0]|w[d+341|0]<<8;if(b){b=Ib(v[m>>2],b-1|0);v[d+188>>2]=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+80;b=w[d+340|0]|w[d+341|0]<<8}else{b=0}u[d+104>>1]=b;u[d+32>>1]=3999;n=a+480190|0;g=x[Kc(d+104|0,d+32|0)>>1];u[n>>1]=g;k=c&2;p=d+124|0;r=a+1298464|0;while(1){V:{W:{X:{Y:{Z:{_:{$:{aa:{if((g&65535)>>>0>f>>>0){b=Ib(v[m>>2],f);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!b){break W}v[22440]=0;b=Q(157,h|0,b|0)|0;e=v[22440];v[22440]=0;ba:{ca:{da:{ea:{fa:{if((e|0)==1){break fa}if(!b){break W}v[22440]=0;b=Q(427,h|0,d+104|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break fa}if(!b){break W}v[22440]=0;g=f+1|0;e=B(g,104)+a|0;b=e+484380|0;i=Q(428,d+104|0,b|0)|0;o=v[22440];v[22440]=0;if((o|0)==1){break ea}Hq(d+88|0,p);v[22440]=0;W(225,d+32|0,v[d+88>>2],v[d+92>>2],w[d+96|0]);o=v[22440];v[22440]=0;if((o|0)==1){break da}o=d+32|0;uc(((g<<5)+a|0)+946304|0,o);rb(o);v[22440]=0;i=Q(157,h|0,i|0)|0;o=v[22440];v[22440]=0;if((o|0)==1){break ea}if(!i){break W}e=x[e+484414>>1];if(!(e&512)){break ca}v[22440]=0;e=Q(429,h|0,d+32|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break aa}if(!e){break ba}v[d+16>>2]=v[d+40>>2];e=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=e;zl(b,1,d+8|0);break ba}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}if(!(e&16384)){e=w[d+344|0]|w[d+345|0]<<8;i=Nc(d+32|0,w[d+122|0]&2?16:8,1,0,(w[d+150|0]^-1)&1);g=w[d+122|0];if(!(!(g&4)|e>>>0<532)){so(i,3);g=w[d+122|0]}ga:{ha:{if(g&8){g=w[d+150|0]&4?5:4;break ha}e=w[d+150|0];if(!(g&2)){g=10;if((e|0)==255){break ha}}if(e&2){t[i+2|0]=1;e=w[d+150|0]}if(e&4){Hf(i,2);e=w[d+150|0]}if(!(e&8)){break ga}g=9;if(!(w[d+122|0]&2)){break ga}}Hf(i,g)}if(k){g=0;v[22440]=0;Y(222,d+32|0,b|0,h|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){break Y}break V}g=1;e=w[d+35|0];if(e>>>0>17){break X}e=1<<e;if(!(e&63503)){if(!(e&198144)){break X}break Z}if(w[d+32|0]){break Z}break Y}v[22440]=0;R(430,h|0,d+84|0);b=v[22440];v[22440]=0;if((b|0)==1){break _}b=v[d+84>>2];if(!(!k|!b)){e=Db(d+32|0);v[22440]=0;U(275,h|0,e|0,b|0);b=v[22440];v[22440]=0;ia:{ja:{ka:{la:{ma:{na:{oa:{if((b|0)!=1){v[22440]=0;R(386,d+72|0,16448);b=v[22440];v[22440]=0;if((b|0)==1){break oa}v[d+68>>2]=g;v[22440]=0;U(11,d+56|0,0,e|0);b=v[22440];v[22440]=0;if((b|0)==1){break na}v[22440]=0;W(431,d+88|0,d+72|0,d+68|0,d+56|0);b=v[22440];v[22440]=0;if((b|0)==1){break ma}b=v[r>>2];v[22440]=0;U(388,b|0,2,d+88|0);b=v[22440];v[22440]=0;if((b|0)==1){break la}rb(d+88|0);rb(d+56|0);Ab(d+72|0);rb(e);break ba}b=P()|0;O()|0;break ia}b=P()|0;O()|0;break ia}b=P()|0;O()|0;break ja}b=P()|0;O()|0;break ka}b=P()|0;O()|0;rb(d+88|0)}rb(d+56|0)}Ab(d+72|0)}rb(e);break R}v[22440]=0;Q(190,h|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break _}}g=0;break X}u[d+104>>1]=1;u[d+32>>1]=g;I=a+480190|0,J=x[ie(d+104|0,d+32|0)>>1],u[I>>1]=J;if(!(q&1)|(w[d+344|0]|w[d+345|0]<<8)!=516|(w[d+350|0]|w[d+351|0]<<8|(w[d+346|0]|w[d+347|0]<<8)!=512)){break $}if(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)|((w[d+348|0]|w[d+349|0]<<8)&65527)!=21|(w[d+352|0]!=128|w[d+353|0]!=48)){break $}if(w[d+357|0]|w[d+356|0]!=128|(w[d+358|0]|w[d+359|0]<<8)){break $}b=d+432|0;g=d+368|0;f=1;while(1)if((b|0)==(g|0)){b=d+496|0;g=d+432|0;while(1)if((b|0)==(g|0)){g=20;while(1){if((g|0)==26){pa:{if(!(f&1)){break $}v[22440]=0;b=Q(1,d+104|0,9898)|0;e=v[22440];v[22440]=0;if((e|0)==1){break pa}Cb(j,b);rb(b);break $}}else{f=!w[(d+g|0)+308|0]&f;g=g+1|0;continue}break}b=P()|0;O()|0;break R}else{f=w[g|0]==64&f;g=g+1|0;continue}}else{f=(w[g|0]&127)==32&f;g=g+1|0;continue}}b=P()|0;O()|0;break R}v[a+480260>>2]=0;v[a+480264>>2]=2147483647;b=pc(v[l>>2],v[l+4>>2]);u[d+104>>1]=b;q=x[Kc(d+104|0,v[a+8>>2]+10|0)>>1];u[d+84>>1]=q;qa:{ra:{sa:{ta:{if((b|0)!=(q|0)){v[22440]=0;Z(432,d+32|0);b=v[22440];v[22440]=0;if((b|0)==1){break qa}b=v[l+4>>2];e=v[l>>2];v[22440]=0;I=d,J=pc(e,b),v[I+88>>2]=J;W(433,d+104|0,d+32|0,d+88|0,d+84|0);b=v[22440];v[22440]=0;if((b|0)==1){break sa}b=v[a+1298464>>2];v[22440]=0;U(388,b|0,2,d+104|0);b=v[22440];v[22440]=0;if((b|0)==1){break ta}rb(d+104|0);Ab(d+32|0)}if(!(c&1)){u[d+84>>1]=0;q=0}g=a+480188|0;b=0;ua:{va:{wa:{xa:{ya:{za:{while(1){Aa:{if((b|0)==(q|0)){Ba:{Ca:{b=v[d+188>>2];if(!b){break Ca}v[22440]=0;Q(157,h|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Ba}if(!C){break Ca}while(1){Da:{v[22440]=0;b=Q(158,h|0,4)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Da}if(!b){break Ca}v[22440]=0;b=Q(414,h|0,13911)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Da}Ea:{if(!b){v[22440]=0;b=Q(414,h|0,13916)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Da}if(!b){break Ea}}v[22440]=0;b=T(159,h|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){xg(h,8);if(!(b&1616928864)|b&-2139062144){break Ea}break Ca}b=P()|0;O()|0;break R}v[22440]=0;b=T(196,h|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Da}v[22440]=0;Q(190,h|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){continue}}break}b=P()|0;O()|0;break R}v[22440]=0;b=Q(434,a|0,h|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Ba}b=b|w[d+303|0];t[d+303|0]=b;if(!(!b|E)){Rt(a+1074312|0);t[a+1074368|0]=0}v[22440]=0;W(435,a|0,h|0,0,d+303|0);b=v[22440];v[22440]=0;if((b|0)==1){break Ba}v[22440]=0;n=a+484344|0;R(228,n|0,q|0);b=v[22440];v[22440]=0;if((b|0)==1){break Ba}p=a+480188|0;H=a+480183|0;f=0;Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{while(1){Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{if((f|0)!=(q|0)){b=Ib(v[l>>2],f);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(b){v[22440]=0;b=Q(157,h|0,b|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Va}if(b){break Ua}}v[22440]=0;b=Y(229,n|0,f&65535,64)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Va}if(b){break Wa}u[d+68>>1]=f;v[22440]=0;Z(436,d+32|0);b=v[22440];v[22440]=0;if((b|0)==1){break _a}v[22440]=0;U(437,d+104|0,d+32|0,d+68|0);b=v[22440];v[22440]=0;if((b|0)==1){break Za}b=v[a+1298464>>2];v[22440]=0;U(388,b|0,2,d+104|0);b=v[22440];v[22440]=0;if((b|0)==1){break Ya}rb(d+104|0);Ab(d+32|0)}$a:{if(!v[a+1074308>>2]){f=w[d+344|0]|w[d+345|0]<<8;if((f|0)!=2184){break $a}v[a+1074308>>2]=18284544}if(xd(j)){break Sa}f=w[d+344|0]|w[d+345|0]<<8}b=f&65535;if((b|0)!=8191){break Ta}g=w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24);break Ha}b=P()|0;O()|0;break R}b=P()|0;O()|0;break Xa}b=P()|0;O()|0;rb(d+104|0)}Ab(d+32|0);break R}b=Sb(n,f);v[22440]=0;R(438,b|0,A|0);b=v[22440];v[22440]=0;if((b|0)!=1){break Qa}}b=P()|0;O()|0;break R}v[22440]=0;b=T(196,h|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Ia}v[22440]=0;F=T(196,h|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Ja}v[22440]=0;c=Q(190,h|0,4)|0;e=v[22440];v[22440]=0;if((e|0)==1){break Ja}if(!c){break Qa}v[22440]=0;c=Y(229,n|0,f&65535,F|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break Ja}if(!c){break Qa}v[22440]=0;U(192,d+32|0,h|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break Ka}b=d+32|0;k=cc(d+104|0,b);sb(b);b=Sb(n,f);v[22440]=0;R(438,b|0,A|0);b=v[22440];v[22440]=0;if((b|0)==1){break Ma}b=x[p>>1];v[22440]=0;r=Q(439,d+32|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Na}b=x[p>>1];c=d+72|0;Ej(c);v[22440]=0;o=Y(440,d+88|0,b|0,c|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Pa}I=d,J=Pg(Sb(n,f)),v[I+56>>2]=J;C=0;while(1){ab:{bb:{cb:{db:{if(C>>>0>=F>>>0){break db}v[22440]=0;b=Q(158,d+104|0,1)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Ra}if(!b){break db}v[22440]=0;b=T(208,k|0)|0;c=v[22440];v[22440]=0;eb:{if((c|0)!=1){b=b<<24>>24;if(b){break eb}xT(d+56|0,x[p>>1]);C=C+1|0;continue}break Ra}fb:{c=b&127;i=c?c-1&65535:0;if(Uc(v[d+32>>2],v[d+36>>2])>>>0>i>>>0){break fb}v[22440]=0;t[d+72|0]=0;c=i+1|0;U(441,r|0,c|0,d+72|0);e=v[22440];v[22440]=0;if((e|0)==1){break Ra}e=d+72|0;Ej(e);v[22440]=0;U(442,o|0,c|0,e|0);c=v[22440];v[22440]=0;if((c|0)!=1){break fb}break Ra}if((b|0)<0){v[22440]=0;b=T(208,k|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Ra}I=Eb(v[d+32>>2],i),J=b,t[I|0]=J}g=d+72|0;Ej(g);if(i>>>0<x[p>>1]){g=Cd(v[d+56>>2],i)}b=Eb(v[d+32>>2],i);e=w[b|0];if(e&16){I=g,J=w[Cd(v[d+88>>2],i)|0],t[I|0]=J;e=w[b|0]}if(e&32){I=g,J=w[Cd(v[d+88>>2],i)+1|0],t[I+1|0]=J;e=w[b|0]}if(e&64){c=Cd(v[d+88>>2],i);t[g+2|0]=w[c+2|0];t[g+4|0]=w[c+4|0];e=w[b|0]}if(e<<24>>24<0){c=Cd(v[d+88>>2],i);t[g+3|0]=w[c+3|0];t[g+5|0]=w[c+5|0];e=w[b|0]}if(e&1){v[22440]=0;b=T(208,k|0)|0;c=v[22440];v[22440]=0;gb:{hb:{if((c|0)!=1){b=b+(((b^-1)&128)>>>7|0)|0;if(!(t[H|0]&1)){break hb}c=b;break gb}break Ra}c=253;if((b-121&255)>>>0<132){break gb}c=(b&255)==253?0:b}t[g|0]=c;I=Cd(v[d+88>>2],i),J=c,t[I|0]=J;b=Eb(v[d+32>>2],i)}if(w[b|0]&2){v[22440]=0;b=T(208,k|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Ra}t[g+1|0]=b;I=Cd(v[d+88>>2],i),J=b,t[I+1|0]=J;b=Eb(v[d+32>>2],i)}if(!(w[b|0]&4)){break ab}v[22440]=0;b=T(208,k|0)|0;c=v[22440];v[22440]=0;ib:{jb:{if((c|0)!=1){if(b>>>0>64){break jb}t[g+4|0]=b;e=1;break ib}break Ra}if(b<<24>>24<=-64){e=2;t[g+2|0]=2;b=b^-128;t[g+4|0]=b;break bb}if(b>>>0<=74){e=5;t[g+2|0]=5;b=b-65|0;t[g+4|0]=b;break bb}if(b>>>0<=84){e=6;t[g+2|0]=6;b=b-75|0;t[g+4|0]=b;break bb}if(b>>>0<=94){e=3;t[g+2|0]=3;b=b-85|0;t[g+4|0]=b;break bb}if(b>>>0<=104){e=4;t[g+2|0]=4;b=b-95|0;t[g+4|0]=b;break bb}if(b>>>0<=114){e=13;t[g+2|0]=13;b=b-105|0;t[g+4|0]=b;break bb}if(b>>>0<=124){e=12;t[g+2|0]=12;b=b-115|0;t[g+4|0]=b;break bb}c=b+63|0;if((c&255)>>>0<=9){t[g+4|0]=c;e=11;t[g+2|0]=11;b=c;break bb}c=b+53|0;G=c&255;if(G>>>0<=9){t[g+4|0]=c;e=8;t[g+2|0]=8;if(!G){b=0;break bb}if(v[a+1074308>>2]-1>>>0>18285139){break cb}e=7;t[g+2|0]=7;break cb}b=b+33|0;if((b&255)>>>0>=10){b=w[g+4|0];e=w[g+2|0];break bb}t[g+4|0]=b;e=15}t[g+2|0]=e;break bb}Th(o);_b(r);sb(d+104|0);break Qa}b=c}c=Cd(v[d+88>>2],i);t[c+4|0]=b;t[c+2|0]=e;b=Eb(v[d+32>>2],i)}if(!(w[b|0]&8)){continue}v[22440]=0;R(267,d+24|0,k|0);b=v[22440];v[22440]=0;if((b|0)!=1){b=d+24|0;EA(g,w[b|0],w[Ec(b)|0],1);b=Cd(v[d+88>>2],i);t[b+3|0]=w[g+3|0];t[b+5|0]=w[g+5|0];continue}break}break Ra}g=b-4176|0;kb:{switch(b>>>12|0){case 0:if(E){v[22440]=0;b=Q(1,d+104|0,8369)|0;c=v[22440];v[22440]=0;if((c|0)!=1){Cb(j,b);rb(b);break Ga}b=P()|0;O()|0;break R}lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{yb:{if((f&65535)==532){g=w[d+346|0]|w[d+347|0]<<8;zb:{if((g|0)!=512){break zb}if((w[d+348|0]|w[d+349|0]<<8)==9){Ab:{if(w[d+335|0]|(w[d+350|0]|w[d+351|0]<<8)|(w[d+334|0]|(w[d+338|0]|w[d+339|0]<<8))){break Ab}if(((w[d+342|0]|w[d+343|0]<<8)+1|0)!=(w[d+336|0]|w[d+337|0]<<8)|w[d+352|0]!=128|(w[d+353|0]!=100|w[d+354|0]!=1)){break Ab}if(w[d+357|0]|w[d+356|0]!=128|(w[d+358|0]|w[d+359|0]<<8|(w[d+360|0]|w[d+361|0]<<8|(w[d+362|0]<<16|w[d+363|0]<<24)))){break Ab}if(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)){break Ab}v[22440]=0;b=Q(1,d+104|0,9879)|0;c=v[22440];v[22440]=0;if((c|0)!=1){Cb(j,b);rb(b);break Ga}b=P()|0;O()|0;break R}g=w[d+346|0]|w[d+347|0]<<8;if((g|0)!=512){break zb}}if(!(w[d+335|0]|w[d+334|0]|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)))){v[a+1074308>>2]=16777381;v[22440]=0;b=Q(1,d+104|0,14998)|0;c=v[22440];v[22440]=0;if((c|0)!=1){Cb(j,b);rb(b);t[d+303|0]=1;break Ga}b=P()|0;O()|0;break R}g=w[d+346|0]|w[d+347|0]<<8}f=532;Bb:{if((g&65535)!=532){break Bb}if(Mb(d+364|0,14180,4)){break Bb}v[22440]=0;b=Q(1,d+104|0,8407)|0;c=v[22440];v[22440]=0;if((c|0)!=1){Cb(j,b);rb(b);v[22440]=0;Q(272,a+1074312|0,38)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break Ga}break Fa}b=P()|0;O()|0;break R}g=w[d+346|0]|w[d+347|0]<<8;if((g|0)!=532){break xb}if((w[d+350|0]|w[d+351|0]<<8)>>>0>1){break wb}if(w[d+357|0]|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24))|(!x[a+480190>>1]|((w[d+348|0]|w[d+349|0]<<8)&4294)!=4)){break yb}v[22440]=0;e=Q(56,d+104|0,13513)|0;b=v[22440];v[22440]=0;if((b|0)==1){break ub}b=cb-16|0;cb=b;c=cb-16|0;cb=c;Xu(c+8|0,a+484527|0);vS(b+8|0,v[c+8>>2],v[c+12>>2]);cb=c+16|0;se(b,e);c=Hc(v[b+8>>2],v[b+12>>2],v[b>>2],v[b+4>>2]);cb=b+16|0;rb(e);if(c){break vb}f=w[d+344|0]|w[d+345|0]<<8}if(f&65535){break yb}if(xd(j)){break sb}}g=w[d+346|0]|w[d+347|0]<<8}if((g&65535)>>>0>767){break Ga}}if(!xd(j)){break Ga}if((g&65535)>>>0<533){break qb}v[22440]=0;b=Q(1,d+104|0,15031)|0;c=v[22440];v[22440]=0;if((c|0)==1){break rb}Cb(j,b);rb(b);break pb}v[22440]=0;b=Q(1,d+104|0,8433)|0;c=v[22440];v[22440]=0;if((c|0)==1){break tb}Cb(j,b);rb(b);break Ga}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}v[22440]=0;b=Q(1,d+104|0,9769)|0;c=v[22440];v[22440]=0;if((c|0)!=1){Cb(j,b);rb(b);break Ga}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}if((f&65535)>>>0>=533){v[22440]=0;R(443,d+32|0,4018);b=v[22440];v[22440]=0;Cb:{if((b|0)!=1){b=w[d+344|0]|w[d+345|0]<<8;v[22440]=0;v[d+88>>2]=b-532;U(444,d+104|0,d+32|0,d+88|0);b=v[22440];v[22440]=0;if((b|0)==1){break Cb}b=d+104|0;Cb(j,b);rb(b);Ab(d+32|0);break pb}b=P()|0;O()|0;break R}b=P()|0;O()|0;Ab(d+32|0);break R}v[22440]=0;R(273,d+32|0,4317);b=v[22440];v[22440]=0;if((b|0)==1){break ob}b=w[d+344|0]|w[d+345|0]<<8;v[d+72>>2]=b>>>8&15;v[22440]=0;v[d+56>>2]=b&255;R(445,d+88|0,d+56|0);b=v[22440];v[22440]=0;if((b|0)==1){break nb}v[22440]=0;W(431,d+104|0,d+32|0,d+72|0,d+88|0);b=v[22440];v[22440]=0;if((b|0)==1){break mb}b=d+104|0;Cb(j,b);rb(b);rb(d+88|0);Ab(d+32|0)}b=a+1298408|0;if(!hc(v[b>>2],v[a+1298412>>2])){break Ga}c=w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24);if(!c){break Ga}c=NC(w[d+344|0]|w[d+345|0]<<8,c);e=eo(d+104|0);v[e+44>>2]=c;v[22440]=0;R(446,b|0,e|0);b=v[22440];v[22440]=0;if((b|0)!=1){break Ga}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;break lb}b=P()|0;O()|0;rb(d+88|0)}Ab(d+32|0);break R;case 4:v[22440]=0;Z(447,d+32|0);b=v[22440];v[22440]=0;Db:{Eb:{Fb:{if((b|0)!=1){b=w[d+344|0]|w[d+345|0]<<8;v[d+72>>2]=b>>>8&15;v[22440]=0;v[d+56>>2]=b&255;R(445,d+88|0,d+56|0);b=v[22440];v[22440]=0;if((b|0)==1){break Fb}v[22440]=0;W(431,d+104|0,d+32|0,d+72|0,d+88|0);b=v[22440];v[22440]=0;if((b|0)==1){break Eb}b=d+104|0;Cb(j,b);rb(b);rb(d+88|0);Ab(d+32|0);break Ga}b=P()|0;O()|0;break R}b=P()|0;O()|0;break Db}b=P()|0;O()|0;rb(d+88|0)}Ab(d+32|0);break R;case 6:v[22440]=0;b=Q(1,d+104|0,8369)|0;c=v[22440];v[22440]=0;if((c|0)!=1){Cb(j,b);rb(b);break Ga}b=P()|0;O()|0;break R;case 7:if(!((f&65535)!=32767|(w[d+346|0]|w[d+347|0]<<8)!=533)){v[22440]=0;b=Q(1,d+104|0,5045)|0;c=v[22440];v[22440]=0;if((c|0)!=1){Cb(j,b);rb(b);break Ga}b=P()|0;O()|0;break R}v[22440]=0;R(139,d+32|0,4153);b=v[22440];v[22440]=0;Gb:{if((b|0)!=1){b=w[d+344|0]|w[d+345|0]<<8;v[d+88>>2]=b>>>8&15;v[d+72>>2]=b>>>4&15;v[22440]=0;v[d+56>>2]=b&15;ga(140,d+104|0,d+32|0,d+88|0,d+72|0,d+56|0);b=v[22440];v[22440]=0;if((b|0)==1){break Gb}b=d+104|0;Cb(j,b);rb(b);Ab(d+32|0);break Ga}b=P()|0;O()|0;break R}b=P()|0;O()|0;Ab(d+32|0);break R;case 1:break Ha;case 13:break kb;default:break Ga}}v[22440]=0;b=Q(1,d+104|0,6126)|0;c=v[22440];v[22440]=0;if((c|0)!=1){Cb(j,b);rb(b);break Ga}b=P()|0;O()|0;break R}v[22440]=0;c=Q(1,d+32|0,17645)|0;b=v[22440];v[22440]=0;Hb:{Ib:{Jb:{Kb:{Lb:{Mb:{if((b|0)!=1){b=v[a+1074308>>2];v[22440]=0;R(142,d+88|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break Mb}v[22440]=0;U(2,d+104|0,c|0,d+88|0);b=v[22440];v[22440]=0;if((b|0)==1){break Lb}e=d+104|0;b=Cb(j,e);rb(e);rb(d+88|0);rb(c);if(!Mb(d+364|0,13700,4)|((w[d+344|0]|w[d+345|0]<<8)&61440)!=20480){break Hb}v[22440]=0;c=Q(1,d+104|0,16912)|0;e=v[22440];v[22440]=0;if((e|0)==1){break Jb}v[22440]=0;Q(100,b|0,c|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Ib}rb(c);break Ga}b=P()|0;O()|0;break R}b=P()|0;O()|0;break Kb}b=P()|0;O()|0;rb(d+88|0)}rb(c);break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;rb(c);break R}if(!$D(v[a+1074308>>2])){break Ga}v[22440]=0;c=Q(1,d+104|0,17148)|0;e=v[22440];v[22440]=0;Nb:{if((e|0)!=1){v[22440]=0;Q(100,b|0,c|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Nb}rb(c);break Ga}b=P()|0;O()|0;break R}b=P()|0;O()|0;rb(c);break R}b=P()|0;O()|0;u[d+68>>1]=f;Th(o);break Oa}f=f+1|0;continue}break}b=P()|0;O()|0;u[d+68>>1]=f}_b(r);break La}b=P()|0;O()|0;u[d+68>>1]=f;break La}b=P()|0;O()|0;u[d+68>>1]=f}sb(d+104|0);break R}b=P()|0;O()|0;u[d+68>>1]=f;break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}b=w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24);v[22440]=0;U(448,d+104|0,f&65535,b|0);b=v[22440];v[22440]=0;Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{if((b|0)!=1){b=d+104|0;Cb(j,b);rb(b);if((g|0)>1915){break Tb}f=v[a+480208>>2];if(!(f&16)){break Sb}v[22440]=0;Q(272,a+1074312|0,7)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Fa}break Rb}b=P()|0;O()|0;break R}if(g>>>0>4200){break Pb}f=v[a+480208>>2]}if(!(f&16)){v[22440]=0;Q(272,a+1074312|0,7)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Fa}}if((g|0)>2385){break Qb}}v[22440]=0;Q(272,a+1074312|0,38)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Fa}}v[22440]=0;b=Q(272,a+1074312|0,102)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Fa}v[22440]=0;Q(272,b|0,48)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Fa}break Ob}if(g>>>0>4383){break Ga}}v[22440]=0;b=Y(271,a+1074312|0,116,1)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Fa}v[22440]=0;Q(272,b|0,115)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Fa}}Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{_b:{b=v[a+480180>>2];f=(b|0)==16777216;if(!f){break _b}$b:{if((w[d+344|0]|w[d+345|0]<<8)>>>0<=2185){f=(b|0)==16777216;break $b}v[22440]=0;b=Q(157,h|0,z|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Ba}if(b){b=w[d+344|0]|w[d+345|0]<<8;v[22440]=0;U(449,a|0,h|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break Ba}}b=v[a+480180>>2];f=(b|0)==16777216;if((b|0)!=16777216){break _b}}v[22440]=0;Q(1,d+104|0,13884)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break Zb}b=P()|0;O()|0;break R}v[22440]=0;R(273,d+32|0,4317);b=v[22440];v[22440]=0;if((b|0)==1){break Yb}b=w[d+346|0]|w[d+347|0]<<8;v[d+72>>2]=b>>>8;v[22440]=0;v[d+56>>2]=b&255;R(445,d+88|0,d+56|0);b=v[22440];v[22440]=0;if((b|0)==1){break Xb}v[22440]=0;W(431,d+104|0,d+32|0,d+72|0,d+88|0);b=v[22440];v[22440]=0;if((b|0)==1){break Wb}}b=d+104|0;Cb(a+1298344|0,b);rb(b);if(!f){rb(d+88|0);Ab(d+32|0)}ac:{if(v[a+480180>>2]==16777216){v[22440]=0;Q(1,d+104|0,10143)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break ac}break Ub}v[22440]=0;Q(1,d+104|0,6130)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Ub}}b=d+104|0;Cb(a+1298356|0,b);rb(b);Cb(a+1298368|0,j);v[a+1298404>>2]=v[a+1074308>>2]?8:5;sb(D);sb(A);f=1;break u}b=P()|0;O()|0;break R}b=P()|0;O()|0;break Vb}b=P()|0;O()|0;rb(d+88|0)}Ab(d+32|0);break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}bc:{c=Ib(v[l>>2],b);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);cc:{if(!c){break cc}v[22440]=0;c=Q(157,h|0,c|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break za}if(!c){break cc}v[22440]=0;c=T(196,h|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break ua}v[22440]=0;n=T(196,h|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break va}if((n-1025&65535)>>>0<64512){break cc}v[22440]=0;e=Q(190,h|0,4)|0;f=v[22440];v[22440]=0;if((f|0)==1){break va}if(!e){break cc}v[22440]=0;U(192,d+32|0,h|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break wa}c=d+32|0;p=cc(d+104|0,c);sb(c);e=x[g>>1];i=0;v[22440]=0;k=Q(439,c|0,e|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break ya}dc:{while(1){if(i>>>0>=n>>>0){break dc}v[22440]=0;c=Q(158,d+104|0,1)|0;e=v[22440];v[22440]=0;if((e|0)==1){break bc}if(!c){break dc}v[22440]=0;c=T(208,p|0)|0;e=v[22440];v[22440]=0;ec:{if((e|0)!=1){e=c<<24>>24;if(e){break ec}i=i+1|0;continue}break Aa}fc:{c=e&127;r=c?c-1|0:0;c=r&65535;if(Uc(v[d+32>>2],v[d+36>>2])>>>0>c>>>0){break fc}v[22440]=0;t[d+88|0]=0;U(441,k|0,c+1|0,d+88|0);f=v[22440];v[22440]=0;if((f|0)!=1){break fc}break Aa}gc:{if((e|0)<0){v[22440]=0;e=T(208,p|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break gc}I=Eb(v[d+32>>2],c),J=e,t[I|0]=J}f=Eb(v[d+32>>2],c);e=w[f|0];if(!(!(e&15)|c>>>0<x[g>>1])){u[g>>1]=r+1;e=w[f|0]}if(e&1){v[22440]=0;Q(190,d+104|0,1)|0;e=v[22440];v[22440]=0;if((e|0)==1){break gc}f=Eb(v[d+32>>2],c)}if(w[f|0]&2){v[22440]=0;Q(190,d+104|0,1)|0;e=v[22440];v[22440]=0;if((e|0)==1){break gc}f=Eb(v[d+32>>2],c)}if(w[f|0]&4){v[22440]=0;Q(190,d+104|0,1)|0;e=v[22440];v[22440]=0;if((e|0)==1){break gc}f=Eb(v[d+32>>2],c)}if(!(w[f|0]&8)){continue}v[22440]=0;Q(190,d+104|0,2)|0;c=v[22440];v[22440]=0;if((c|0)!=1){continue}}break}break Aa}v[d+88>>2]=v[h+8>>2];I=d,J=v[Pc(d+188|0,d+88|0)>>2],v[I+188>>2]=J;_b(k);sb(d+104|0)}b=b+1|0;continue}}break}b=P()|0;O()|0;_b(k);break xa}b=P()|0;O()|0;break R}b=P()|0;O()|0}sb(d+104|0);break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;rb(d+104|0);break ra}b=P()|0;O()|0}Ab(d+32|0);break R}b=P()|0;O()|0;break R}b=P()|0;O()|0;break R}g=0;e=DA(d+32|0,v[b>>2]);v[22440]=0;Q(190,h|0,e|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break V}}if(w[d+35|0]!=1){break X}q=v[b>>2]!=0|q}v[d+32>>2]=v[h+8>>2];I=d,J=v[Pc(d+188|0,d+32|0)>>2],v[I+188>>2]=J;C=(g|0)!=0}f=f+1|0;g=x[n>>1];continue}break}b=P()|0;O()|0;break R}hc:{b=Ib(v[s>>2],f);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);ic:{if(!b){break ic}v[22440]=0;b=Q(157,h|0,b|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break hc}if(!b){break ic}v[22440]=0;b=Q(158,h|0,554)|0;g=v[22440];v[22440]=0;if((g|0)==1){break hc}if(!b){break ic}v[22440]=0;b=Y(257,a|0,f+1&65535,0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break U}if(!b){break ic}g=w[d+346|0]|w[d+347|0]<<8;v[22440]=0;W(450,a|0,h|0,b|0,g|0);g=v[22440];v[22440]=0;if((g|0)==1){break U}t[b+33|0]=w[d+357|0]}f=f+1|0;g=x[e>>1];continue}break}b=P()|0;O()|0;break R}b=P()|0;O()|0}sb(D);break z}b=P()|0;O()|0}sb(A);break v}b=P()|0;O()|0;break v}b=P()|0;O()|0;break v}}}}}b=P()|0;O()|0}fc(l);fc(m);fc(s);break a}fc(l);fc(m);fc(s)}rb(j)}cb=d+496|0;return f|0}b=P()|0;O()|0}rb(j);S(b|0);L()}function Kga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,_=0;d=cb-1664|0;cb=d;sc(b);a:{if(!$h(b,d+1656|0)){break a}if(!IR(d+1656|0)){break a}if(!c){f=1;break a}p=w[d+1656|3];t[d+1655|0]=p;v[d+1648>>2]=-1;v[d+1644>>2]=1048576;if(p>>>0>=5){g=Ag(b);v[d+1648>>2]=g;if(!Kb(b,g)){break a}v[d+224>>2]=134217727;X=d,_=v[Bb(d+224|0,d+1648|0)>>2]<<5,v[X+1644>>2]=_}A=Rb(d+1632|0);g=d+1656|4;v[d+224>>2]=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);e=v[Bb(d+1644|0,d+224|0)>>2];v[22440]=0;R(551,A|0,e|0);e=v[22440];v[22440]=0;b:{c:{d:{e:{f:{if((e|0)!=1){g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);v[22440]=0;g=Y(552,b|0,A|0,g|0)|0;e=v[22440];v[22440]=0;g:{if((e|0)==1){break g}if(!g){break b}if(p>>>0>=5){v[22440]=0;Q(157,b|0,v[d+1648>>2]+12|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break g}}v[22440]=0;R(252,a|0,0);g=v[22440];v[22440]=0;if((g|0)==1){break g}eg(a);qe(d+1600|0,v[A>>2],v[A+4>>2]);g=ee(d+1592|0);e=v[g+4>>2];g=v[g>>2];v[22440]=0;n=ea(553,d+1608|0,v[d+1600>>2],v[d+1604>>2],g|0,e|0)|0;g=v[22440];v[22440]=0;h:{i:{if((g|0)!=1){v[22440]=0;U(361,n|0,a+1298308|0,-1);g=v[22440];v[22440]=0;if((g|0)==1){break i}v[22440]=0;U(361,n|0,a+1298332|0,-1);g=v[22440];v[22440]=0;if((g|0)==1){break i}v[22440]=0;g=Q(554,n|0,d+1168|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break f}if(!g){break c}o=d+1168|0;h=t[o|0];if((h|0)<=0){break c}g=d+1177|0;if((w[g|0]|w[g+1|0]<<8)>>>0>255){break c}e=d+1179|0;if((w[e|0]|w[e+1|0]<<8)>>>0<=3999){break h}break c}h=P()|0;O()|0;break d}h=P()|0;O()|0;break e}D=a+480188|0;u[D>>1]=h&255;l=a+484360|0;f=d+1168|3;Qe(Nb(l),w[f|0]|w[f+1|0]<<8);u[a+480192>>1]=w[g|0]|w[g+1|0]<<8;u[a+480190>>1]=w[e|0]|w[e+1|0]<<8;g=w[d+1181|0];v[a+480196>>2]=g?g:6;g=w[d+1182|0];v[a+480204>>2]=B(g?g:125,1e4);k=d+1183|0;g=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);j:{if(g&256){v[22440]=0;R(418,a|0,32);g=v[22440];v[22440]=0;if((g|0)!=1){break j}break f}if(g&2){v[22440]=0;R(418,a|0,2);g=v[22440];v[22440]=0;if((g|0)==1){break f}break j}if(g&128){v[22440]=0;R(418,a|0,1);g=v[22440];v[22440]=0;if((g|0)==1){break f}break j}if(g&8){v[22440]=0;R(418,a|0,16);g=v[22440];v[22440]=0;if((g|0)==1){break f}break j}v[22440]=0;R(418,a|0,4);g=v[22440];v[22440]=0;if((g|0)==1){break f}}g=v[a+480208>>2];e=g|16777216;v[a+480208>>2]=e;f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);if(f&1){e=g|16777232;v[a+480208>>2]=e;f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24)}if(!(!(f&16)|v[a+480180>>2]!=2)){e=e|65536;v[a+480208>>2]=e;f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24)}if(!(!(f&4)|v[a+480180>>2]!=2)){e=e|2;v[a+480208>>2]=e;f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24)}if(!(f&2048|v[a+480180>>2]!=32)){e=e|4;v[a+480208>>2]=e;f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24)}if(!(f&1024|v[a+480180>>2]!=32)){e=e|8;v[a+480208>>2]=e;f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24)}if(f&2097152){v[a+480208>>2]=e|32768;f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24)}if(f&524288){v[22440]=0;Y(271,a+1074312|0,5,1)|0;g=v[22440];v[22440]=0;if((g|0)==1){break f}}g=v[a+480180>>2];k:{if((g|0)!=2){if((g|0)!=32){break k}t[d+224|0]=w[d+1187|0];t[d+144|0]=128;X=a,_=w[Tb(d+224|0,d+144|0)|0]<<1,v[X+480200>>2]=_;break k}t[d+224|0]=w[d+1187|0];t[d+144|0]=64;X=a,_=w[Tb(d+224|0,d+144|0)|0]<<2,v[X+480200>>2]=_}e=t[d+1189|0];l:{if((e|0)<0){e=e+52|0;break l}I=qx(+(e|0)*3.1/20);m:{if(I<4294967296&I>=0){e=~~I>>>0;break m}e=0}e=e+51|0}v[a+480228>>2]=e;u[d+224>>1]=64;h=x[Kc(D,d+224|0)>>1];e=0;j=(g|0)==4;i=(g|0)!=32;f=0;while(1)if((f|0)==(h|0)){f=0;h=0;while(1){if((e|0)!=16){h=w[(d+e|0)+1318|0]!=0|h;e=e+1|0;continue}break}while(1){if((f|0)!=128){h=w[((f<<1)+d|0)+1335|0]!=0|h;f=f+1|0;continue}break}n:{if(!(h&1)){break n}g=a+901692|0;f=0;while(1){if((f|0)==16){g=a+902204|0;f=0;while(1){if((f|0)==128){break n}e=(d+1168|0)+(f<<1)|0;o:{if(w[e+167|0]){v[22440]=0;Z(555,d+144|0);h=v[22440];v[22440]=0;p:{q:{r:{s:{t:{if((h|0)!=1){h=w[e+167|0];v[22440]=0;v[d+168>>2]=h-1;R(556,d+1112|0,d+168|0);h=v[22440];v[22440]=0;if((h|0)==1){break t}e=w[e+166|0];v[22440]=0;t[d+112|0]=e;R(557,d+1088|0,d+112|0);e=v[22440];v[22440]=0;if((e|0)==1){break s}v[22440]=0;W(558,d+224|0,d+144|0,d+1112|0,d+1088|0);e=v[22440];v[22440]=0;if((e|0)==1){break r}e=d+224|0;se(d+1144|0,e);df(we(g,f),v[d+1144>>2],v[d+1148>>2]);rb(e);rb(d+1088|0);rb(d+1112|0);Ab(d+144|0);break o}h=P()|0;O()|0;break e}h=P()|0;O()|0;break p}h=P()|0;O()|0;break q}h=P()|0;O()|0;rb(d+1088|0)}rb(d+1112|0)}Ab(d+144|0);break e}nc(d+1136|0,21685);df(we(g,f),v[d+1136>>2],v[d+1140>>2])}f=f+1|0;continue}}u:{e=(d+f|0)+1318|0;v:{if(w[e|0]){v[22440]=0;Z(559,d+144|0);h=v[22440];v[22440]=0;if((h|0)==1){break u}e=w[e|0];v[22440]=0;v[d+1088>>2]=e-1;R(556,d+1112|0,d+1088|0);e=v[22440];v[22440]=0;w:{x:{if((e|0)!=1){v[22440]=0;U(295,d+224|0,d+144|0,d+1112|0);e=v[22440];v[22440]=0;if((e|0)==1){break x}e=d+224|0;se(d+1160|0,e);df(we(g,f),v[d+1160>>2],v[d+1164>>2]);rb(e);rb(d+1112|0);Ab(d+144|0);break v}h=P()|0;O()|0;break w}h=P()|0;O()|0;rb(d+1112|0)}Ab(d+144|0);break e}nc(d+1152|0,21685);df(we(g,f),v[d+1152>>2],v[d+1156>>2])}f=f+1|0;continue}break}h=P()|0;O()|0;break e}g=Nb(l);e=d+1168|1;e=w[e|0]|w[e+1|0]<<8;v[22440]=0;ea(351,g|0,n|0,e|0,255,254)|0;g=v[22440];v[22440]=0;if((g|0)!=1){g=w[o|0];i=d+1168|5;e=w[i|0]|w[i+1|0]<<8;v[22440]=0;U(192,d+224|0,n|0,B(e,g)<<1);g=v[22440];v[22440]=0;if((g|0)!=1){g=d+224|0;J=cc(d+1112|0,g);sb(g);e=w[i|0]|w[i+1|0]<<8;v[22440]=0;U(192,g|0,n|0,e<<1);g=v[22440];v[22440]=0;y:{if((g|0)!=1){g=d+224|0;K=cc(d+1088|0,g);sb(g);g=d+1168|7;g=w[g|0]|w[g+1|0]<<8;v[22440]=0;C=Q(221,d+1072|0,g|0)|0;g=v[22440];v[22440]=0;z:{if((g|0)!=1){X=d,_=yb(v[C>>2]),v[X+168>>2]=_;g=yb(v[C+4>>2]);A:{B:{C:{while(1){e=v[d+168>>2];if(!Qb(e,g)){q=a+480180|0;g=v[q>>2];s=c&1;if(!s){break B}e=w[i|0]|w[i+1|0]<<8;v[22440]=0;R(228,a+484344|0,e|0);e=v[22440];v[22440]=0;if((e|0)!=1){break B}h=P()|0;O()|0;break A}v[22440]=0;f=T(159,n|0)|0;h=v[22440];v[22440]=0;if((h|0)!=1){v[22440]=0;U(192,d+144|0,n|0,f|0);f=v[22440];v[22440]=0;if((f|0)==1){break C}h=e;e=d+224|0;f=d+144|0;Sc(h,cc(e,f));sb(e);sb(f);Uf(d+168|0);continue}break}h=P()|0;O()|0;break A}h=P()|0;O()|0;break A}E=(g|0)==16?14:(g|0)==32?1:13;F=a+484344|0;l=1;while(1){D:{E:{F:{G:{H:{I:{if((w[i|0]|w[i+1|0]<<8)>>>0<=m>>>0){switch(v[a+480180>>2]-1|0){case 0:break G;case 3:break I;default:break F}}v[22440]=0;g=T(196,K|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break H}v[d+144>>2]=g;if(!s){break D}v[22440]=0;g=Y(229,F|0,m&65535,g|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break H}r=0;if(!g){break D}while(1){f=r&65535;if(f>>>0>=w[o|0]){break D}v[22440]=0;g=T(196,J|0)|0;e=v[22440];v[22440]=0;J:{if((e|0)!=1){e=v[C>>2];if(Df(e,v[C+4>>2])>>>0<=g>>>0){break J}z=Ng(e,g);sc(z);e=0;f=Zc(Sb(F,m),0,f);K:while(1){if(y[d+144>>2]<=e>>>0){break J}v[22440]=0;g=T(208,z|0)|0;h=v[22440];v[22440]=0;if((h|0)!=1){if(!g){break J}G=g>>>4|0;M=g&15;tg(d+224|0);h=0;while(1){L:{M:{N:{if(M>>>0>(h&255)>>>0){v[22440]=0;R(267,d+168|0,z|0);g=v[22440];v[22440]=0;if((g|0)==1){break N}O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{g=w[Eb(d+168|0,0)|0];switch(g-1|0){case 14:break _;case 10:break $;case 6:break aa;case 5:break ba;case 1:break ca;case 0:break da;case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break O;case 33:break S;case 30:case 31:break T;case 29:break U;case 28:break V;case 26:break W;case 19:case 20:break X;case 17:break Y;case 15:break Z;default:break ea}}switch(g-48|0){case 4:break P;case 1:case 2:break Q;case 0:break R;default:break O}}g=w[Eb(d+168|0,1)|0];fa:{if(g>>>0<=119){g=g+E|0;break fa}ga:{switch(g-254|0){case 1:g=255;break fa;case 0:g=254;break fa;default:break ga}}g=253}t[d+224|0]=g;l=UA(g)&l;break L}X=d,_=w[Eb(d+168|0,1)|0]+1|0,t[X+225|0]=_;break L}ha:{if(w[d+226|0]){break ha}g=v[q>>2];if((g|0)!=32){if((g|0)!=4){break ha}g=w[Eb(d+168|0,1)|0];if(g&15){break ha}t[d+226|0]=11;t[d+228|0]=g>>>4;break L}g=w[Eb(d+168|0,1)|0];j=0;while(1){if((j|0)==10){break ha}if((g|0)==w[j+43856|0]){t[d+228|0]=j;t[d+226|0]=11;break L}else{j=j+1|0;continue}}}X=d,_=w[Eb(d+168|0,1)|0],t[X+229|0]=_;t[d+227|0]=4;break L}g=Eb(d+168|0,1);ia:{if(w[d+226|0]){break ia}j=w[g|0];if(v[q>>2]!=32|j>>>0>9){break ia}t[d+228|0]=j;t[d+226|0]=8;break L}t[d+229|0]=w[g|0];t[d+227|0]=5;break L}ja:{if(w[d+226|0]){break ja}ka:{g=v[q>>2];if((g|0)!=4){if((g|0)!=32){break ja}j=Eb(d+168|0,1);g=w[j|0];if((g|0)!=255){break ka}t[d+228|0]=64;t[d+226|0]=2;break L}j=Eb(d+168|0,1);if(w[j|0]&15){break ja}break M}if(!(g&3)){break M}}X=d,_=w[Eb(d+168|0,1)|0],t[X+229|0]=_;t[d+227|0]=9;break L}j=w[d+226|0];g=Eb(d+168|0,1);la:{if(j|v[q>>2]==1){break la}j=w[g|0];if(j>>>0>64){break la}t[d+228|0]=j;t[d+226|0]=1;break L}t[d+229|0]=w[g|0];t[d+227|0]=13;break L}g=w[Eb(d+168|0,1)|0];t[d+229|0]=g;t[d+227|0]=14;if(v[q>>2]==32){break L}t[d+229|0]=B((g&240)>>>4|0,10)+(g&15);break L}g=w[Eb(d+168|0,1)|0];t[d+229|0]=g;t[d+227|0]=g>>>0<32?16:17;break L}j=w[Eb(d+168|0,1)|0];if(j>>>0>=16){t[d+228|0]=j>>>4;t[d+226|0]=(g|0)==20?3:5;break L}t[d+228|0]=j&15;t[d+226|0]=(g|0)==20?4:6;break L}g=w[Eb(d+168|0,1)|0];if(g>>>0>=16){t[d+226|0]=10;t[d+228|0]=g>>>4;break L}t[d+226|0]=9;t[d+228|0]=g&15;break L}g=w[Eb(d+168|0,1)|0];t[d+227|0]=28;t[d+229|0]=g|16;break L}g=w[Eb(d+168|0,1)|0];t[d+227|0]=28;t[d+229|0]=g|32;break L}X=d,_=w[Eb(d+168|0,1)|0],t[X+228|0]=_;t[d+226|0]=(g|0)==31?7:8;break L}g=w[d+227|0];t[d+227|0]=(g|0)==4?6:(g|0)==5?7:11;X=d,_=w[Eb(d+168|0,1)|0],t[X+229|0]=_;break L}g=Eb(d+168|0,1);t[d+228|0]=w[g|0]%10;g=w[g|0];if(g>>>0<=9){t[d+226|0]=5;break L}if(g>>>0<=19){t[d+226|0]=6;break L}if(g>>>0<=29){t[d+226|0]=3;break L}if(g>>>0>39){break L}t[d+226|0]=4;break L}X=d,_=w[Eb(d+168|0,1)|0],t[X+228|0]=_;t[d+226|0]=(g|0)==49?13:12;break L}g=w[Eb(d+168|0,1)|0]+33|0;if((g&255)>>>0>9){break L}t[d+226|0]=15;t[d+228|0]=g;break L}if(g>>>0>57){break L}X=d,_=w[Eb(d+168|0,1)|0],t[X+229|0]=_;t[d+227|0]=w[g+26928|0];break L}v[d+168>>2]=e+G;g=v[Bb(d+168|0,d+144|0)>>2];g=e>>>0>g>>>0?e:g;while(1){if((e|0)!=(g|0)){h=v[d+224>>2];t[f|0]=h;t[f+1|0]=h>>>8;t[f+2|0]=h>>>16;t[f+3|0]=h>>>24;h=x[d+228>>1];t[f+4|0]=h;t[f+5|0]=h>>>8;e=e+1|0;f=B(w[o|0],6)+f|0;continue}break}e=g;continue K}h=P()|0;O()|0;break A}g=w[j|0];t[d+226|0]=2;t[d+228|0]=g>>>2}h=h+1|0;continue}}break}h=P()|0;O()|0;break A}h=P()|0;O()|0;break A}r=r+1|0;continue}}f=x[a+480192>>1];g=0;break E}h=P()|0;O()|0;break A}if((l^1)&1|x[D>>1]!=4){break F}v[a+480208>>2]=v[a+480208>>2]|8454144}f=0;g=!((w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24))&512)}v[22440]=0;z=Q(560,d+1056|0,f|0)|0;e=v[22440];v[22440]=0;ma:{na:{oa:{pa:{qa:{if((e|0)!=1){q=a+480192|0;j=p>>>0<5;i=a+480180|0;h=1;ra:{while(1){l=h&65535;if(l>>>0>x[q>>1]){break ra}sa:{ta:{ua:{va:{if(!g){v[22440]=0;f=Y(257,a|0,l|0,0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break va}if(f){break ua}}while(1){v[22440]=0;e=T(208,n|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break na}if(e){continue}break}if(!j){while(1){v[22440]=0;e=T(208,n|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){h=P()|0;O()|0;break ma}if(e){continue}break}}v[22440]=0;Q(190,n|0,826)|0;e=v[22440];v[22440]=0;if((e|0)!=1){break ta}}h=P()|0;O()|0;break ma}e=Db(d+144|0);v[22440]=0;U(361,n|0,e|0,-1);m=v[22440];v[22440]=0;if((m|0)==1){break sa}uc(f+492|0,e);if(!j){v[22440]=0;U(361,n|0,e|0,-1);m=v[22440];v[22440]=0;if((m|0)==1){break sa}uc(f+524|0,e)}v[22440]=0;m=Q(561,n|0,d+224|0)|0;o=v[22440];v[22440]=0;if((o|0)==1){break oa}if(!m){break qa}m=v[i>>2];v[22440]=0;U(562,d+224|0,f|0,m|0);f=v[22440];v[22440]=0;if((f|0)==1){break oa}if(v[i>>2]==4){f=Ib(v[z>>2],l-1|0);l=x[d+1026>>1]|x[d+1028>>1]<<16;t[f|0]=l;t[f+1|0]=l>>>8;t[f+2|0]=l>>>16;t[f+3|0]=l>>>24}rb(e)}h=h+1|0;continue}break}break oa}if(!g){break pa}u[a+480192>>1]=0;break pa}h=P()|0;O()|0;break A}rb(e)}g=x[a+480190>>1];v[22440]=0;q=Q(563,d+208|0,g|0)|0;g=v[22440];v[22440]=0;l=1;if((g|0)!=1){l=p>>>0<=4?!(t[k|0]&1):l;s=c&2;M=a+480180|0;h=1;c=0;while(1){g=c;wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{m=h&65535;if(m>>>0<=x[a+480190>>1]){i=Db(d+192|0);v[22440]=0;U(361,n|0,i|0,-1);c=v[22440];v[22440]=0;if((c|0)==1){break Ra}j=B(m,104)+a|0;uc(((m<<5)+a|0)+946304|0,i);c=p>>>0<5;if(!c){v[22440]=0;U(361,n|0,i|0,-1);e=v[22440];v[22440]=0;if((e|0)==1){break Ra}pe(j+484423|0,i)}v[22440]=0;e=Q(564,n|0,d+224|0)|0;f=v[22440];v[22440]=0;Sa:{Ta:{if((f|0)==1){break Ta}if(!e){break Sa}e=v[M>>2];v[22440]=0;f=j+484380|0;W(565,d+224|0,f|0,e|0,l|0);e=v[22440];v[22440]=0;if((e|0)==1){break Ta}E=0;Ua:{if(((w[d+244|0]|w[d+245|0]<<8)&61440)!=28672|c){break Ua}v[22440]=0;E=T(566,n|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break Ua}h=P()|0;O()|0;break za}if(!s){break xa}e=w[d+259|0]|w[d+260|0]<<8|(w[d+261|0]<<16|w[d+262|0]<<24);c=w[d+244|0]|w[d+245|0]<<8;o=c&61440;if(!(e|o)){c=Nc(d+144|0,c&1?16:8,c&1024?3:1,0,0);v[22440]=0;Y(222,c|0,f|0,b|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break xa}h=P()|0;O()|0;break za}if((e|0)<0){c=e+m|0;if((c|0)<=0){break xa}HR(f,(B(c,104)+a|0)+484380|0);break xa}if((e|0)<=0){break xa}if(c&1){e=j+484414|0;u[e>>1]=x[e>>1]|1;e=w[d+244|0]|w[d+245|0]<<8}else{e=c}if(e&1024){e=j+484414|0;u[e>>1]=x[e>>1]|64}e=w[d+259|0]|w[d+260|0]<<8|(w[d+261|0]<<16|w[d+262|0]<<24);v[22440]=0;U(192,d+144|0,b|0,e|0);e=v[22440];v[22440]=0;Va:{Wa:{Xa:{Ya:{Za:{_a:{if((e|0)!=1){r=d+144|0;e=cc(d+168|0,r);sb(r);N=j+484414|0;r=zd(x[N>>1]);V=(o|0)==16384;if(!V&(o|0)!=8192){break Ya}v[22440]=0;G=T(162,d+168|0)|0;H=v[22440];v[22440]=0;if((H|0)==1){break Va}H=4/(r>>>0)|0;kka(H,0,G,0);qc(f,fb?-1:B(H,G));if((o|0)==8192){break _a}if(!V){break Ya}if(!Lg(f)){break Xa}if(!(t[d+244|0]&1)){break Za}c=v[j+484400>>2];f=v[f>>2];v[22440]=0;W(567,e|0,c|0,f|0,r|0);e=v[22440];v[22440]=0;c=g;if((e|0)==1){break Ba}break Wa}h=P()|0;O()|0;break za}if(!Lg(f)){break Xa}if(t[d+244|0]&1){c=v[j+484400>>2];f=v[f>>2];v[22440]=0;W(568,e|0,c|0,f|0,r|0);e=v[22440];v[22440]=0;c=g;if((e|0)!=1){break Wa}break Ba}c=v[j+484400>>2];f=v[f>>2];v[22440]=0;W(569,e|0,c|0,f|0,r|0);e=v[22440];v[22440]=0;c=g;if((e|0)==1){break Ba}break Wa}c=v[j+484400>>2];f=v[f>>2];v[22440]=0;W(570,e|0,c|0,f|0,r|0);e=v[22440];v[22440]=0;c=g;if((e|0)==1){break Ba}break Wa}if((c&45056)==12288){c=GR(d+144|0,e,w[d+263|0]|w[d+264|0]<<8,E);e=jf(v[q>>2],m-1|0);Sc(e,c);v[e+20>>2]=v[c+20>>2];sb(c);break Xa}if((o|0)!=32768){c=1;if((o|0)!=4096){break Wa}c=be(d+144|0,e);v[22440]=0;Q(571,d+136|0,e|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){$a:{ab:{if(!w[d+141|0]){break ab}o=w[d+263|0]|w[d+264|0]<<8;e=x[d+138>>1]<<1;if(o>>>0<(e&65535)>>>0){break ab}e=o-e|0;t[d+263|0]=e;t[d+264|0]=e>>>8;v[22440]=0;Q(157,d+168|0,x[d+136>>1])|0;e=v[22440];v[22440]=0;if((e|0)==1){break $a}v[22440]=0;e=T(204,d+168|0)|0;o=v[22440];v[22440]=0;if((o|0)==1){break $a}v[22440]=0;U(192,d+88|0,d+168|0,e|0);e=v[22440];v[22440]=0;if((e|0)==1){break $a}e=d+112|0;o=d+88|0;Sc(c,cc(e,o));sb(e);sb(o)}v[22440]=0;e=ea(572,a|0,m|0,c|0,1,1)|0;c=v[22440];v[22440]=0;if((c|0)==1){break $a}c=1;if(e){c=w[d+263|0]|w[d+264|0]<<8;bb:{if(!c){break bb}e=x[N>>1];m=Fj(v[f>>2],e);if(m>>>0<=c>>>0){break bb}e=Ak(e);j=v[j+484400>>2];gj(j,c+j|0,m-c|0);v[f>>2]=v[f>>2]-((c>>>0)/(e>>>0)|0)}c=v[d+232>>2];v[d+84>>2]=c;v[d+4>>2]=c;c=d+4|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);if(c>>>0<y[f>>2]){v[f>>2]=c}c=g}sb(d+144|0);break Wa}}h=P()|0;O()|0;sb(d+144|0);break Aa}v[22440]=0;c=Q(429,e|0,d+144|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break Qa}if(!c){break Xa}v[d+16>>2]=v[d+152>>2];c=v[d+148>>2];v[d+8>>2]=v[d+144>>2];v[d+12>>2]=c;zl(f,1,d+8|0)}c=g}sb(d+168|0);break wa}h=P()|0;O()|0;break Aa}h=P()|0;O()|0;break za}rb(i)}cb:{if(!s){break cb}i=1;while(1){f=i&65535;if(f>>>0>x[a+480190>>1]){break cb}b=v[q>>2];v[22440]=0;b=jf(b,f-1|0);c=T(180,b|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break Pa}db:{eb:{if(!c){break eb}fb:{gb:{c=x[b+22>>1];if(!c){break gb}e=c+i&65535;if(!e|e>>>0>x[a+480190>>1]){break gb}j=x[b+20>>1];if(!j){break gb}c=1;e=jf(v[q>>2],e-1|0);break fb}c=0;v[22440]=0;j=T(162,b|0)|0;h=v[22440];v[22440]=0;e=b;if((h|0)==1){break Oa}}sc(e);hb:{if(c){h=x[b+20>>1];v[22440]=0;h=Q(158,e|0,h|0)|0;l=v[22440];v[22440]=0;if((l|0)==1){break Oa}if(!h){break eb}v[d+144>>2]=0;v[d+168>>2]=0;v[22440]=0;U(205,d+224|0,e|0,j|0);h=v[22440];v[22440]=0;ib:{if((h|0)!=1){l=$z(ce(d+224|0),Ei(v[d+224>>2]),d+144|0,d+168|0);v[22440]=0;Q(190,e|0,v[d+144>>2])|0;e=v[22440];v[22440]=0;if((e|0)==1){break ib}vc(d+224|0);break hb}h=P()|0;O()|0;break ya}h=P()|0;O()|0;vc(d+224|0);break ya}l=0;v[d+144>>2]=0;v[d+168>>2]=0}v[22440]=0;R(573,d+224|0,b|0);e=v[22440];v[22440]=0;jb:{kb:{if((e|0)!=1){j=ce(d+224|0);h=v[d+224>>2];if(!c){l=$z(j,Ei(h),d+144|0,d+168|0);v[22440]=0;c=v[d+144>>2];Q(190,b|0,c|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break db}j=c+j|0;h=h-c|0}if(l){break kb}g=1;break jb}h=P()|0;O()|0;break ya}c=B(f,104)+a|0;m=c+484380|0;Lg(m);o=c+484400|0;r=c+484414|0;e=0;f=v[d+168>>2];while(1){lb:{if(y[m>>2]<=e>>>0|(!h|(f|0)!=1?f:0)){break lb}if(!Sd(m)){break lb}v[d+112>>2]=0;v[d+88>>2]=0;p=FR(l,j,Ei(h),d+112|0,d+192|0,d+88|0);v[22440]=0;v[d+144>>2]=p;Q(190,b|0,p|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Ca}Zh(d+88|0,Ei(v[m>>2]-e|0));c=v[d+88>>2];mb:{if((c|0)<=0){break mb}f=v[d+112>>2];s=x[r>>1];if((zd(s)|0)!=(f|0)){break mb}if(s&1){pg(d+72|0,v[o>>2]+(B(e,f)<<1)|0,f,c);pg(d+56|0,v[d+192>>2],v[d+112>>2],c);v[22440]=0;ka(574,v[d+72>>2],v[d+76>>2],v[d+80>>2],v[d+56>>2],v[d+60>>2],v[d+64>>2]);f=v[22440];v[22440]=0;if((f|0)!=1){break mb}break Ca}pg(d+40|0,v[o>>2]+B(e,f)|0,f,c);pg(d+24|0,v[d+192>>2],v[d+112>>2],c);v[22440]=0;ka(575,v[d+40>>2],v[d+44>>2],v[d+48>>2],v[d+24>>2],v[d+28>>2],v[d+32>>2]);f=v[22440];v[22440]=0;if((f|0)==1){break Ca}}h=h-p|0;j=j+p|0;f=ER(l);v[d+168>>2]=f;e=c+e|0;continue}break}CR(l)}vc(d+224|0)}i=i+1|0;continue}break}break Ca}nb:{if(v[a+480180>>2]!=4){break nb}f=0;c=a+480192|0;while(1){if(x[c>>1]<=f>>>0){break nb}b=Ib(v[z>>2],f);e=w[b|0];h=w[b+1|0];l=w[b+2|0];b=w[b+3|0];v[22440]=0;f=f+1|0;ka(403,a|0,f&65535,e|0,h|0,l|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){continue}break}h=P()|0;O()|0;break ya}if(!(w[k+2|0]&16)){break Ka}v[22440]=0;b=Q(158,n|0,1)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Ma}if(!b){break Ka}f=0;v[22440]=0;b=T(208,n|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Na}if(!(b&1)){break La}while(1){if(x[D>>1]<=f>>>0){break La}v[22440]=0;b=T(159,n|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){t[((f<<5)+a|0)+480288|0]=b;f=f+1|0;continue}break}h=P()|0;O()|0;break ya}h=P()|0;O()|0;break za}h=P()|0;O()|0;break Aa}h=P()|0;O()|0;break ya}h=P()|0;O()|0;break ya}h=P()|0;O()|0;break ya}h=P()|0;O()|0;break ya}while(1){v[22440]=0;b=Q(158,n|0,1)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Da}if(!b){break Ka}v[22440]=0;b=T(208,n|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Ia}if(!b){break Ka}v[22440]=0;c=T(159,n|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break Ja}v[22440]=0;U(192,d+144|0,n|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break Ja}c=d+144|0;e=cc(d+224|0,c);sb(c);ob:{if(b>>>0<=250){v[22440]=0;R(451,e|0,(B(b,160)+a|0)+906140|0);b=v[22440];v[22440]=0;if((b|0)==1){break ob}}sb(d+224|0);continue}break}h=P()|0;O()|0;sb(d+224|0);break ya}h=a+901404|0;c=Db(d+112|0);j=a+480180|0;e=0;l=0;while(1){v[22440]=0;b=Q(158,n|0,8)|0;f=v[22440];v[22440]=0;pb:{qb:{rb:{sb:{tb:{if((f|0)!=1){if(b){v[22440]=0;f=T(159,n|0)|0;b=v[22440];v[22440]=0;ub:{vb:{wb:{xb:{yb:{zb:{Ab:{Bb:{if((b|0)!=1){v[22440]=0;b=T(159,n|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break Bb}v[22440]=0;U(192,d+224|0,n|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break Ab}i=d+224|0;b=cc(d+144|0,i);sb(i);if((f|0)==1229211981){break xb}if((f|0)==1229476432){break yb}if((f|0)==1397900630){break zb}if((f|0)!=1414548815){break pb}v[22440]=0;f=Q(414,b|0,13937)|0;i=v[22440];v[22440]=0;if((i|0)==1){break Ha}if(!f){break qb}v[22440]=0;f=T(159,b|0)|0;i=v[22440];v[22440]=0;if((i|0)!=1){v[22440]=0;U(192,d+224|0,d+144|0,f|0);f=v[22440];v[22440]=0;if((f|0)!=1){break wb}}h=P()|0;O()|0;break Ga}h=P()|0;O()|0;break Ea}h=P()|0;O()|0;break Ea}h=P()|0;O()|0;break Ea}Cb:{Db:{Eb:{f=v[j>>2];switch(f-2|0){case 1:break pb;case 0:break vb;case 2:break Db;default:break Eb}}if((f|0)==16){break Cb}if((f|0)!=32){break pb}v[22440]=0;e=T(196,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break Ha}v[22440]=0;l=T(196,b|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break pb}break Ha}v[d+224>>2]=32;v[22440]=0;f=T(162,d+144|0)|0;i=v[22440];v[22440]=0;if((i|0)!=1){v[d+168>>2]=f;f=v[Bb(d+224|0,d+168|0)>>2];v[22440]=0;U(576,b|0,c|0,f|0);b=v[22440];v[22440]=0;if((b|0)!=1){break pb}}h=P()|0;O()|0;break Ga}v[22440]=0;b=T(208,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break ub}v[22440]=0;R(577,d+168|0,4214);f=v[22440];v[22440]=0;Fb:{if((f|0)!=1){v[d+88>>2]=b>>>4;v[22440]=0;v[d+192>>2]=b&15;W(309,d+224|0,d+168|0,d+88|0,d+192|0);b=v[22440];v[22440]=0;if((b|0)==1){break Fb}b=d+224|0;Cb(c,b);rb(b);Ab(d+168|0);break pb}h=P()|0;O()|0;break Ga}h=P()|0;O()|0;Ab(d+168|0);break Ga}v[22440]=0;f=T(208,b|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break Ha}v[a+480216>>2]=f;v[22440]=0;b=T(208,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break Ha}v[a+480220>>2]=b;break pb}v[22440]=0;Q(424,b|0,h|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Ha}GA(h);break pb}f=d+168|0;i=d+224|0;p=cc(f,i);sb(i);v[22440]=0;f=T(162,f|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break rb}u[d+224>>1]=f>>>5;X=d,_=Cf(F),u[X+88>>1]=_;i=x[Kc(d+224|0,d+88|0)>>1];f=0;while(1){if((f|0)==(i|0)){sb(d+168|0);break qb}v[22440]=0;R(578,p|0,d+224|0);m=v[22440];v[22440]=0;Gb:{if((m|0)==1){break Gb}m=Sb(F,f);v[22440]=0;Q(579,m|0,d+224|0)|0;m=v[22440];v[22440]=0;if((m|0)==1){break Gb}f=f+1|0;continue}break}break rb}v[22440]=0;e=T(196,b|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Ha}break pb}h=P()|0;O()|0;break Ga}b=v[a+480180>>2];Hb:{Ib:{Jb:{if((b|0)!=32){break Jb}f=e&65535;if(f>>>0<256){break Jb}if(f>>>0<532){break Ib}}b=(b|0)!=2;Kb:{if(b){break Kb}f=e&65535;if(f>>>0<12544){break Kb}if(f>>>0<12820){break Ib}}if(b){break Hb}b=e&65535;if(b>>>0<4864|b>>>0>4895){break Hb}}_p(h)}f=1;Lb:{if(!(t[k+2|0]&1)){break Lb}e=v[a+1074308>>2];if(!e){e=a+480192|0;h=a+480180|0;while(1){b=f&65535;if(b>>>0<=x[e>>1]){b=v[((b<<2)+a|0)+900380>>2];if(b){k=v[h>>2];v[22440]=0;R(580,Bh(b,2)|0,k|0);k=v[22440];v[22440]=0;if((k|0)==1){break tb}t[b+19|0]=w[b+19|0]+3>>>2}f=f+1|0;continue}break}e=v[a+1074308>>2]}if(e>>>0<=18350079){v[22440]=0;b=Q(272,a+1074312|0,27)|0;e=v[22440];v[22440]=0;if((e|0)==1){break Fa}v[22440]=0;Q(272,b|0,57)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Fa}e=v[a+1074308>>2]}if(e>>>0<=19070975){v[22440]=0;Q(272,a+1074312|0,73)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Fa}e=v[a+1074308>>2]}if(e>>>0>19267583){break Lb}v[22440]=0;Q(272,a+1074312|0,50)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Fa}}Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{if(xd(c)){v[22440]=0;Z(581,d+144|0);b=v[22440];v[22440]=0;_b:{if((b|0)!=1){v[22440]=0;U(549,d+224|0,d+144|0,d+1655|0);b=v[22440];v[22440]=0;if((b|0)==1){break _b}break Zb}h=P()|0;O()|0;break Ea}h=P()|0;O()|0;Ab(d+144|0);break Ea}v[22440]=0;Z(582,d+144|0);b=v[22440];v[22440]=0;if((b|0)==1){break Yb}v[22440]=0;W(583,d+224|0,d+144|0,d+1655|0,c|0);b=v[22440];v[22440]=0;if((b|0)==1){break Xb}}b=d+224|0;Cb(c,b);rb(b);b=d+144|0;Ab(b);v[22440]=0;R(548,b|0,3980);b=v[22440];v[22440]=0;if((b|0)==1){break Vb}v[22440]=0;U(549,d+224|0,d+144|0,d+1655|0);b=v[22440];v[22440]=0;if((b|0)==1){break Ub}b=d+224|0;Cb(a+1298344|0,b);rb(b);Ab(d+144|0);v[22440]=0;b=Q(1,b|0,15079)|0;e=v[22440];v[22440]=0;if((e|0)==1){break Tb}Cb(a+1298356|0,b);rb(b);b=v[a+480180>>2];switch(b-1|0){case 2:break sb;case 1:break Pb;case 3:break Qb;case 0:break Rb;default:break Wb}}h=P()|0;O()|0;break Ea}h=P()|0;O()|0;Ab(d+144|0);break Ea}if((b|0)==16){break Sb}if((b|0)==32){break Ob}if((b|0)!=16777216){break sb}v[22440]=0;b=Q(1,d+224|0,10143)|0;e=v[22440];v[22440]=0;if((e|0)==1){break Nb}Cb(a+1298392|0,b);rb(b);v[22440]=0;b=Q(1,d+224|0,13884)|0;e=v[22440];v[22440]=0;if((e|0)==1){break Mb}Cb(a+1298380|0,b);rb(b);break sb}h=P()|0;O()|0;break Ea}h=P()|0;O()|0;Ab(d+144|0);break Ea}h=P()|0;O()|0;break Ea}v[22440]=0;b=Q(1,d+224|0,10148)|0;e=v[22440];v[22440]=0;$b:{if((e|0)!=1){Cb(a+1298392|0,b);rb(b);v[22440]=0;b=Q(1,d+224|0,8394)|0;e=v[22440];v[22440]=0;if((e|0)==1){break $b}Cb(a+1298380|0,b);rb(b);break sb}h=P()|0;O()|0;break Ea}h=P()|0;O()|0;break Ea}v[22440]=0;b=Q(1,d+224|0,12354)|0;e=v[22440];v[22440]=0;ac:{if((e|0)!=1){Cb(a+1298392|0,b);rb(b);v[22440]=0;b=Q(1,d+224|0,14351)|0;e=v[22440];v[22440]=0;if((e|0)==1){break ac}Cb(a+1298380|0,b);rb(b);break sb}h=P()|0;O()|0;break Ea}h=P()|0;O()|0;break Ea}v[22440]=0;b=Q(1,d+224|0,10121)|0;e=v[22440];v[22440]=0;bc:{if((e|0)!=1){Cb(a+1298392|0,b);rb(b);v[22440]=0;b=Q(1,d+224|0,15323)|0;e=v[22440];v[22440]=0;if((e|0)==1){break bc}Cb(a+1298380|0,b);rb(b);break sb}h=P()|0;O()|0;break Ea}h=P()|0;O()|0;break Ea}v[22440]=0;b=Q(1,d+224|0,10493)|0;e=v[22440];v[22440]=0;cc:{if((e|0)!=1){Cb(a+1298392|0,b);rb(b);v[22440]=0;b=Q(1,d+224|0,15126)|0;e=v[22440];v[22440]=0;if((e|0)==1){break cc}Cb(a+1298380|0,b);rb(b);break sb}h=P()|0;O()|0;break Ea}h=P()|0;O()|0;break Ea}v[22440]=0;b=Q(1,d+224|0,6130)|0;e=v[22440];v[22440]=0;dc:{ec:{fc:{gc:{hc:{if((e|0)!=1){Cb(a+1298392|0,b);rb(b);if(!(l&65535)){break dc}v[22440]=0;R(273,d+144|0,4317);b=v[22440];v[22440]=0;if((b|0)==1){break hc}v[d+88>>2]=(l&65280)>>>8;v[22440]=0;v[d+192>>2]=l&255;R(445,d+168|0,d+192|0);b=v[22440];v[22440]=0;if((b|0)==1){break gc}v[22440]=0;W(431,d+224|0,d+144|0,d+88|0,d+168|0);b=v[22440];v[22440]=0;if((b|0)==1){break fc}b=d+224|0;Cb(a+1298380|0,b);rb(b);rb(d+168|0);Ab(d+144|0);break sb}h=P()|0;O()|0;break Ea}h=P()|0;O()|0;break Ea}h=P()|0;O()|0;break ec}h=P()|0;O()|0;rb(d+168|0)}Ab(d+144|0);break Ea}v[22440]=0;b=Q(1,d+224|0,8586)|0;e=v[22440];v[22440]=0;if((e|0)!=1){Cb(a+1298380|0,b);rb(b);break sb}h=P()|0;O()|0;break Ea}h=P()|0;O()|0;break Ea}h=P()|0;O()|0;break Ea}h=P()|0;O()|0;break Ea}h=P()|0;O()|0;break Ea}Cb(a+1298368|0,c);ic:{if(v[a+1074308>>2]){v[a+1298404>>2]=8;break ic}if(v[a+480180>>2]==1){v[a+1298404>>2]=2;break ic}v[a+1298404>>2]=5}f=1;jc:{kc:{if(g&1){v[22440]=0;b=Q(1,d+224|0,16660)|0;g=v[22440];v[22440]=0;if((g|0)==1){break kc}a=v[a+1298464>>2];v[22440]=0;U(388,a|0,2,b|0);a=v[22440];v[22440]=0;if((a|0)==1){break jc}rb(b)}rb(c);Yz(q);fc(z);Ic(C);sb(K);sb(J);break c}h=P()|0;O()|0;break Ea}h=P()|0;O()|0;rb(b);break Ea}h=P()|0;O()|0;sb(d+168|0);break Ga}v[22440]=0;f=Q(414,b|0,13942)|0;i=v[22440];v[22440]=0;if((i|0)==1){break Ha}lc:{if(!f){break lc}v[22440]=0;f=T(159,b|0)|0;i=v[22440];v[22440]=0;mc:{if((i|0)!=1){v[22440]=0;U(192,d+168|0,d+144|0,f|0);f=v[22440];v[22440]=0;if((f|0)!=1){break mc}}h=P()|0;O()|0;break Ga}f=d+224|0;i=d+168|0;p=cc(f,i);sb(i);v[22440]=0;f=T(162,f|0)|0;i=v[22440];v[22440]=0;if((i|0)!=1){u[d+168>>1]=(f>>>0)/20;u[d+88>>1]=x[D>>1];i=x[Kc(d+168|0,d+88|0)>>1];f=0;while(1){if((f|0)==(i|0)){sb(d+224|0);break lc}v[22440]=0;U(425,p|0,((f<<5)+a|0)+480289|0,20);m=v[22440];v[22440]=0;if((m|0)!=1){f=f+1|0;continue}break}}h=P()|0;O()|0;sb(d+224|0);break Ga}v[22440]=0;Q(434,a|0,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break Ha}v[22440]=0;W(435,a|0,b|0,1,0);f=v[22440];v[22440]=0;if((f|0)==1){break Ha}if((e-2186&65535)>>>0<=117){v[j>>2]=16777216;v[22440]=0;U(449,a|0,b|0,e&65535);b=v[22440];v[22440]=0;if((b|0)==1){break Ha}}if(!v[a+1074308>>2]){break pb}v[22440]=0;b=Q(1,d+168|0,17645)|0;f=v[22440];v[22440]=0;nc:{oc:{pc:{if((f|0)!=1){f=v[a+1074308>>2];v[22440]=0;R(142,d+88|0,f|0);f=v[22440];v[22440]=0;if((f|0)==1){break pc}v[22440]=0;U(2,d+224|0,b|0,d+88|0);f=v[22440];v[22440]=0;if((f|0)==1){break oc}f=d+224|0;Cb(c,f);rb(f);rb(d+88|0);rb(b);break pb}h=P()|0;O()|0;break Ga}h=P()|0;O()|0;break nc}h=P()|0;O()|0;rb(d+88|0)}rb(b);break Ga}sb(d+144|0);continue}}h=P()|0;O()|0;break ya}h=P()|0;O()|0;break ya}h=P()|0;O()|0}sb(d+144|0);break Ea}h=P()|0;O()|0}rb(c);break ya}h=P()|0;O()|0;break ya}h=P()|0;O()|0;vc(d+224|0);break ya}h=P()|0;O()|0}sb(d+168|0)}rb(i)}Yz(q);break ma}c=g}rb(i);h=h+1|0;continue}}h=P()|0;O()|0;break ma}h=P()|0;O()|0;rb(e);break ma}h=P()|0;O()|0}fc(z);break A}m=m+1|0;continue}}Ic(C);break z}h=P()|0;O()|0}sb(K);break y}h=P()|0;O()|0}sb(J);break e}h=P()|0;O()|0;break e}h=P()|0;O()|0;break e}else{qc:{if(j){break qc}if(!i){t[d+224|0]=w[(d+f|0)+1190|0];t[d+144|0]=64;X=((f<<5)+a|0)+480286|0,_=w[Tb(d+224|0,d+144|0)|0],u[X>>1]=_}rc:{g=w[(d+f|0)+1254|0];if((g|0)!=255){if((g|0)!=127){break rc}v[((f<<5)+a|0)+480280>>2]=256;break qc}u[((f<<5)+a|0)+480284>>1]=256;break qc}u[((f<<5)+a|0)+480284>>1]=g}f=f+1|0;continue}}h=P()|0;O()|0;break d}h=P()|0;O()|0;break d}h=P()|0;O()|0}sb(n)}_b(A);S(h|0);L()}sb(n)}_b(A)}cb=d+1664|0;return f|0}function Vga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;e=cb-912|0;cb=e;sc(b);a:{if(!RR(b,e+856|0)){break a}if(!VR(e+856|0)){break a}if(!Kb(b,wc(UR(e+856|0),fb))){break a}if(!c){d=1;break a}ud(a,8);eg(a);j=w[e+856|3]-48|0;t[e+855|0]=j;Tc(b,Wb(w[e+864|0]|w[e+865|0]<<8|(w[e+866|0]<<16|w[e+867|0]<<24)));f=e+544|0;Td(f,b,504);ga=cc(e+832|0,f);sb(f);v[22440]=0;R(522,b|0,f|0);f=v[22440];v[22440]=0;b:{c:{d:{e:{f:{g:{if((f|0)!=1){if(w[e+827|0]>63){break b}if(wb(w[e+544|0]|w[e+545|0]<<8)<<16>>16<0){break b}Hb(e+464|0,0,80);h:{d=Wb(w[e+888|0]|w[e+889|0]<<8|(w[e+890|0]<<16|w[e+891|0]<<24));if(!d){break h}v[22440]=0;f=Q(157,b|0,d|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){if(!f){break h}v[22440]=0;R(523,b|0,e+464|0);d=v[22440];v[22440]=0;if((d|0)!=1){break h}}h=P()|0;O()|0;break e}v[22440]=0;U(524,e+456|0,b|0,j&255);d=v[22440];v[22440]=0;if((d|0)!=1){f=e+456|0;ha=Oe(f);d=0;f=x[f>>1];if((f-128&65535)>>>0<65409){break b}u[a+480188>>1]=f;ca=Rb(e+440|0);d=Wb(w[e+880|0]|w[e+881|0]<<8|(w[e+882|0]<<16|w[e+883|0]<<24));i:{if(d){v[22440]=0;Q(157,b|0,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break g}d=w[e+827|0];v[22440]=0;U(525,b|0,ca|0,d|0);d=v[22440];v[22440]=0;if((d|0)==1){break g}h=w[e+827|0];break i}h=w[e+827|0];d=0;if(h){break c}}h=h&255;u[a+480192>>1]=h;u[a+480190>>1]=h;da=1;C=c&2;da=(j&255)>>>0>=2?t[e+808|0]>=0:da;E=!da;d=e+56|0;M=d|2;H=d|7;I=d|6;X=d|5;o=d|4;r=e+16|4;F=1;D=1;while(1){j:{k:{l:{m:{n:{o:{j=D&65535;if(j>>>0<=(h&65535)>>>0){v[22440]=0;N=F&65535;f=Y(257,a|0,j|0,N|0)|0;d=v[22440];v[22440]=0;p:{if((d|0)!=1){if(f){break p}break d}h=P()|0;O()|0;break f}z=v[((j<<2)+a|0)+900380>>2];u[e+20>>1]=0;v[e+16>>2]=0;v[22440]=0;s=T(176,e+128|0)|0;d=v[22440];v[22440]=0;q:{if((d|0)!=1){d=Ib(v[ca>>2],j-1|0);d=Wb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));r:{if(!d){break r}v[22440]=0;f=Q(157,b|0,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break k}if(!f){break r}v[22440]=0;R(526,b|0,e+16|0);d=v[22440];v[22440]=0;if((d|0)==1){break k}d=w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24);v[22440]=0;U(192,e+416|0,b|0,Wb(d)|0);d=v[22440];v[22440]=0;if((d|0)==1){break k}f=e+56|0;d=e+416|0;Sc(s,cc(f,d));sb(f);sb(d)}J=Rd((w[r|0]|w[r+1|0]<<8)<<16>>16);d=J&15;if((J|0)>=0){break q}Kt(z,0);ia=1;break o}h=P()|0;O()|0;break f}if(d>>>0>6){break o}A=w[d+26806|0];if(!d){break m}u[a+480190>>1]=(x[a+480190>>1]+A|0)-1;y=z+108|0;k=z+236|0;p=A-2|0;g=4;s:while(1){d=1;if((g|0)==10){break n}m=B(g,12);d=(p<<3)+g|0;i=w[d+26812|0]+F|0;j=w[d+26860|0];d=0;while(1)if((d|0)==12){g=g+1|0;continue s}else{f=d+m|0;ja=Xb(k,f),ka=i,u[ja>>1]=ka;f=Eb(y,f);t[f|0]=j+w[f|0];d=d+1|0;continue}}}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=e+464|4;d=Wb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));if(!d){break D}if(!wb(w[e+472|0]|w[e+473|0]<<8)){break D}v[22440]=0;f=Q(157,b|0,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break C}if(!f){break D}ja=e,ka=wb(w[e+472|0]|w[e+473|0]<<8),u[ja+128>>1]=ka;u[e+56>>1]=w[e+827|0];d=e+128|0;f=e+56|0;X=x[Kc(d,f)>>1];H=d|5;o=d|3;I=d|1;d=e- -64|0;y=f|4;E=wb(w[e+474|0]|w[e+475|0]<<8);k=E>>>0<19;p=E>>>0<21;m=E>>>0<15;i=E>>>0<6;h=0;while(1){if((h|0)==(X|0)){break D}v[22440]=0;U(527,b|0,e+128|0,E|0);f=v[22440];v[22440]=0;E:{F:{G:{if((f|0)!=1){h=h+1|0;s=v[((h<<2)+a|0)+900380>>2];if(w[e+128|0]){g=ul(e+56|0,0,64);ul(y,w[e+128|0]-1&65535,64);j=w[e+128|0];f=w[I|0];if(f){f=64/(f>>>0)|0}else{f=0}ul(d,f+j|0,0);v[22440]=0;C=s+48|0;U(528,C|0,g|0,3);f=v[22440];v[22440]=0;if((f|0)==1){break G}if(w[e+128|0]==1){ac(e+408|0,yb(v[C>>2]));j=v[e+408>>2];f=yb(v[C>>2]);f=v[C>>2]+(It(j,f)<<2)|0;Nd(C,Qi(f+4|0,v[C+4>>2],f));yb(f)}f=w[I|0];v[s>>2]=f?f<<9:32767;t[s+60|0]=w[s+60|0]|1;Z=1}H:{if(k){break H}v[s+4>>2]=w[e+146|0]+1>>>1;if(p){break H}u[s+28>>1]=w[e+148|0]|w[e+149|0]<<8}g=B(x[Xb(s+236|0,61)>>1],104)+a|0;t[g+484417|0]=w[o|0]<<4;if(m){break F}ja=g+484384|0,ka=Wb(w[e+138|0]|w[e+139|0]<<8|(w[e+140|0]<<16|w[e+141|0]<<24)),v[ja>>2]=ka;ja=g+484388|0,ka=Wb(w[e+138|0]|w[e+139|0]<<8|(w[e+140|0]<<16|w[e+141|0]<<24))+Wb(w[e+142|0]|w[e+143|0]<<8|(w[e+144|0]<<16|w[e+145|0]<<24))|0,v[ja>>2]=ka;break E}h=P()|0;O()|0;break f}h=P()|0;O()|0;break f}if(i){continue}}j=g+484414|0;f=x[j>>1]&-3|w[H|0]<<1&2;u[j>>1]=f;u[j>>1]=f&65531|w[H|0]>>>1&4;if(!(w[H|0]&4)){continue}u[g+484412>>1]=0;continue}}I:{d=Wb(w[e+484|0]|w[e+485|0]<<8|(w[e+486|0]<<16|w[e+487|0]<<24));if(!d){break I}if(!wb(w[e+488|0]|w[e+489|0]<<8)){break I}v[22440]=0;f=Q(157,b|0,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break C}if(!f){break I}ja=e,ka=wb(w[e+488|0]|w[e+489|0]<<8),u[ja+128>>1]=ka;u[e+56>>1]=w[e+827|0];p=x[Kc(e+128|0,e+56|0)>>1];m=wb(w[e+490|0]|w[e+491|0]<<8);d=0;J:while(1){if((d|0)==(p|0)){break I}v[22440]=0;U(529,b|0,e+128|0,m|0);f=v[22440];v[22440]=0;if((f|0)==1){break t}ET(e+416|0,e+128|0);v[22440]=0;W(225,e+56|0,v[e+416>>2],v[e+420>>2],w[e+424|0]);f=v[22440];v[22440]=0;if((f|0)==1){break u}d=d+1|0;k=((d<<2)+a|0)+900380|0;j=e+56|0;uc(v[k>>2]+492|0,j);rb(j);f=v[k>>2];v[22440]=0;R(392,j|0,f|0);f=v[22440];v[22440]=0;if((f|0)==1){break v}f=e+56|0;ja=e,ka=qk(f),v[ja+416>>2]=ka;i=Af(f);while(1)if(Qb(v[e+416>>2],i)){g=e+416|0;y=(x[Xn(g)>>1]<<5)+a|0;j=y+946328|0;o=v[k>>2];f=v[o+520>>2];v[j>>2]=v[o+516>>2];v[j+4>>2]=f;f=v[o+512>>2];j=y+946320|0;v[j>>2]=v[o+508>>2];v[j+4>>2]=f;f=v[o+504>>2];j=y+946312|0;v[j>>2]=v[o+500>>2];v[j+4>>2]=f;f=v[o+496>>2];j=y+946304|0;v[j>>2]=v[o+492>>2];v[j+4>>2]=f;um(g);continue}else{Ut(e+56|0);continue J}}}_p(a+901404|0);d=nc(e+400|0,4943);df(we(a+901692|0,0),v[d>>2],v[d+4>>2]);sc(b);C=c&1;V=a+484344|0;_=a+1298332|0;J=a+1298308|0;z=a+484360|0;c=e+128|0;E=c|1;q=c|4;c=e+40|0;j=c|4;A=c|2;H=c|3;G=e+544|2;c=0;while(1){K:{f=c&255;if(f>>>0<w[ha|0]){v[22440]=0;W(530,b|0,e+856|0,e+464|0,e+544|0);d=v[22440];v[22440]=0;L:{M:{N:{O:{P:{if((d|0)==1){break P}Q:{if(!f){d=0;break Q}v[22440]=0;f=T(279,z|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break P}d=c;if((f|0)==255){break d}}n=xj(z,d&255);K=Jg(e+384|0);Ac(n);$=w[e+855|0];if($>>>0>1){break N}l=0;if(wb(w[G|0]|w[G+1|0]<<8)>>>0>256|x[a+480188>>1]>16){break L}f=e+128|0;OR(f,e+544|0);d=w[G|0]|w[G+1|0]<<8;v[22440]=0;U(531,n|0,f|0,wb(d)|0);d=v[22440];v[22440]=0;if((d|0)==1){break O}ja=e,ka=yb(v[n>>2]),v[ja+128>>2]=ka;d=yb(v[n+4>>2]);while(1){f=v[e+128>>2];if(Qb(f,d)){u[f>>1]=x[f>>1]+aa;Ne(e+128|0);continue}else{mh(a,1);f=x[a+480188>>1];d=0;while(1)if((d|0)==(f|0)){d=32;break M}else{t[e+128|0]=w[(d+e|0)+810|0];t[e+56|0]=64;ja=((d<<5)+a|0)+480286|0,ka=w[Tb(e+128|0,e+56|0)|0],u[ja>>1]=ka;d=d+1|0;continue}}}}h=P()|0;O()|0;break f}h=P()|0;O()|0;break w}OR(e+128|0,e+544|0);R:{S:{T:{U:{if(!((wb(w[e+140|0]|w[e+141|0]<<8)-65&65535)>>>0<65472|x[a+480188>>1]>64)){y=Wb(w[e+148|0]|w[e+149|0]<<8|(w[e+150|0]<<16|w[e+151|0]<<24));d=wb(w[e+152|0]|w[e+153|0]<<8);if(d){u[e+56>>1]=d;u[e+416>>1]=800;f=wc(((x[Kc(e+56|0,e+416|0)>>1]<<5)+50>>>0)/100|0,0)}else{f=32}d=w[e+136|0]|w[e+137|0]<<8|(w[e+138|0]<<16|w[e+139|0]<<24);v[22440]=0;g=Q(157,b|0,Wb(d)|0)|0;d=v[22440];v[22440]=0;V:{if((d|0)==1){break V}d=0;W:{if(!g){break W}while(1){if(x[a+480188>>1]<=d>>>0){break W}v[22440]=0;i=T(208,b|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){t[e+56|0]=i;t[e+416|0]=64;ja=((d<<5)+a|0)+480286|0,ka=w[Tb(e+56|0,e+416|0)|0],u[ja>>1]=ka;d=d+1|0;continue}break}h=P()|0;O()|0;break w}X:{Y:{d=Wb(w[e+144|0]|w[e+145|0]<<8|(w[e+146|0]<<16|w[e+147|0]<<24));if(!d){break Y}v[22440]=0;g=Q(157,b|0,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break V}d=0;if(!g){break Y}while(1){if(x[a+480188>>1]<=d>>>0){break X}v[22440]=0;i=T(532,b|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){ja=((d<<5)+a|0)+480284|0,ka=(Vb(i,-16,16)<<3)+128|0,u[ja>>1]=ka;d=d+1|0;continue}break}h=P()|0;O()|0;break w}mh(a,1)}o=Rb(e+112|0);d=w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24);v[22440]=0;g=Q(157,b|0,Wb(d)|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break U}l=1;d=0;if(!g){break R}g=w[G|0]|w[G+1|0]<<8;v[22440]=0;i=Q(158,b|0,wb(g)<<1)|0;g=v[22440];v[22440]=0;if((g|0)==1){break U}if(!i){break R}g=w[G|0]|w[G+1|0]<<8;v[22440]=0;i=Y(533,b|0,o|0,wb(g)|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break U}if(!i){break R}ja=e,ka=yb(v[e+112>>2]),v[ja+104>>2]=ka;k=yb(v[e+116>>2]);while(1){d=v[e+104>>2];if(!Qb(d,k)){l=0;d=1;break R}g=wb(w[d|0]|w[d+1|0]<<8);Z:{if(wb(w[e+142|0]|w[e+143|0]<<8)>>>0<g>>>0){break Z}d=w[e+128|0]|w[e+129|0]<<8|(w[e+130|0]<<16|w[e+131|0]<<24);v[22440]=0;Q(157,b|0,Wb(d)+(g<<2)|0)|0;d=v[22440];v[22440]=0;_:{$:{aa:{ba:{ca:{if((d|0)==1){break ca}v[22440]=0;g=T(286,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break ca}v[22440]=0;g=Q(157,b|0,g|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break ca}if(!g){break Z}v[22440]=0;g=Q(158,b|0,42)|0;d=v[22440];v[22440]=0;if((d|0)==1){break ca}if(!g){break Z}v[22440]=0;R(534,b|0,e+56|0);d=v[22440];v[22440]=0;da:{if((d|0)!=1){if(hc(v[n>>2],v[n+4>>2])){break da}v[22440]=0;R(535,n|0,65534);d=v[22440];v[22440]=0;if((d|0)!=1){break da}}h=P()|0;O()|0;break S}d=w[e+96|0]|w[e+97|0]<<8;v[22440]=0;d=wb(d);v[e+52>>2]=d;g=Q(158,b|0,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break ba}if(!g){v[22440]=0;g=T(204,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break ba}qc(e+52|0,g)}qc(e+52|0,65534);i=v[n+4>>2];g=v[n>>2];d=0;v[22440]=0;p=v[e+52>>2];m=Fc(g,i);R(536,n|0,p+m|0);g=v[22440];v[22440]=0;if((g|0)==1){break $}while(1){ea:{if((d|0)==(p|0)){if(w[e+56|0]){break ea}break aa}v[22440]=0;i=T(278,b|0)|0;g=v[22440];v[22440]=0;fa:{if((g|0)!=1){g=i<<16>>16;if((g|0)<0){break fa}v[22440]=0;R(535,n|0,g+aa&65535);g=v[22440];v[22440]=0;if((g|0)!=1){break fa}}h=P()|0;O()|0;break S}d=d+1|0;continue}break}Im(e+40|0,e+56|0);v[22440]=0;U(537,e+16|0,v[e+40>>2],v[e+44>>2]);d=v[22440];v[22440]=0;ga:{ha:{ia:{if((d|0)!=1){v[22440]=0;U(11,e+416|0,2,e+16|0);d=v[22440];v[22440]=0;if((d|0)==1){break ia}v[22440]=0;R(280,n|0,e+416|0);d=v[22440];v[22440]=0;if((d|0)==1){break ha}rb(e+416|0);rb(e+16|0);break aa}h=P()|0;O()|0;break S}h=P()|0;O()|0;break ga}h=P()|0;O()|0;rb(e+416|0)}rb(e+16|0);break S}h=P()|0;O()|0;break S}h=P()|0;O()|0;break S}d=Wb(w[e+88|0]|w[e+89|0]<<8|(w[e+90|0]<<16|w[e+91|0]<<24));if(!d){break Z}v[22440]=0;g=Q(157,b|0,d|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){break _}}h=P()|0;O()|0;break S}if(!g){break Z}ja:{while(1){ka:{v[22440]=0;g=Q(538,b|0,e+40|0)|0;d=v[22440];v[22440]=0;la:{ma:{na:{oa:{if((d|0)!=1){if(!g){break Z}d=w[H|0];v[22440]=0;U(192,e+16|0,b|0,d|0);d=v[22440];v[22440]=0;if((d|0)==1){break oa}d=e+16|0;g=cc(e+416|0,d);sb(d);d=xl(wb(w[e+40|0]|w[e+41|0]<<8)+m|0);u[e+16>>1]=d;if((wb(w[e+40|0]|w[e+41|0]<<8)|0)==65535){break ja}h=v[n>>2];if(Fc(h,v[n+4>>2])>>>0<=d>>>0){break ka}l=65535;switch(w[A|0]-1|0){case 0:break ma;case 1:break na;default:break la}}h=P()|0;O()|0;break S}h=P()|0;O()|0;break S}v[22440]=0;i=T(278,g|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break T}v[22440]=0;g=Q(539,K|0,e+16|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break T}u[g>>1]=i;h=v[n>>2];l=65534;d=x[e+16>>1]}ja=Xb(h,d),ka=l,u[ja>>1]=ka}sb(e+416|0);continue}break}sb(e+416|0);break Z}sb(e+416|0)}Ne(e+104|0);continue}}h=P()|0;O()|0;break w}l=0;break L}h=P()|0;O()|0;break S}h=P()|0;O()|0;sb(e+416|0)}_c(o);break w}_c(o);if(d){d=f>>>(y>>>1&1)|0;break M}Ht(K);if(!l){break d}break K}g=wb(w[e+804|0]|w[e+805|0]<<8);m=w[e+807|0];I=m&64;f=w[e+808|0];M=f&32;F=(f&31)+1|0;ja=a,ka=LR(g,I>>>6|0,M>>>5|0,F),v[ja+480204>>2]=ka;ja=a,ka=wd(w[e+809|0],1,32),v[ja+480196>>2]=ka;if(M){v[a+480216>>2]=F;v[a+480220>>2]=F<<2}f=w[e+826|0];if(f){t[e+128|0]=f;t[e+56|0]=64;ja=a,ka=w[Tb(e+128|0,e+56|0)|0]<<2,v[ja+480200>>2]=ka}v[a+480228>>2]=d;v[a+480232>>2]=d;v[a+480208>>2]=v[a+480208>>2]&-3|(w[e+807|0]>>>4^-1)&2;pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{d=Wb(w[e+508|0]|w[e+509|0]<<8|(w[e+510|0]<<16|w[e+511|0]<<24));if(!d){break za}v[22440]=0;f=Q(157,b|0,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break ya}if(!f){break za}d=w[e+512|0]|w[e+513|0]<<8|(w[e+514|0]<<16|w[e+515|0]<<24);v[22440]=0;U(275,b|0,J|0,Wb(d)|0);d=v[22440];v[22440]=0;if((d|0)==1){break ya}if(w[ha|0]<2){break za}v[22440]=0;U(11,e+128|0,2,J|0);d=v[22440];v[22440]=0;Aa:{if((d|0)!=1){v[22440]=0;R(280,n|0,e+128|0);d=v[22440];v[22440]=0;if((d|0)==1){break Aa}rb(e+128|0);break za}h=P()|0;O()|0;break w}h=P()|0;O()|0;rb(e+128|0);break w}Ba:{if(Wb(w[e+480|0]|w[e+481|0]<<8|(w[e+482|0]<<16|w[e+483|0]<<24))>>>0<2){break Ba}d=w[e+476|0]|w[e+477|0]<<8|(w[e+478|0]<<16|w[e+479|0]<<24);v[22440]=0;f=Q(157,b|0,Wb(d)|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break ya}if(!f){break Ba}d=w[e+480|0]|w[e+481|0]<<8|(w[e+482|0]<<16|w[e+483|0]<<24);v[22440]=0;W(340,_|0,b|0,Wb(d)-1|0,4);d=v[22440];v[22440]=0;if((d|0)==1){break ya}}d=Wb(w[e+520|0]|w[e+521|0]<<8|(w[e+522|0]<<16|w[e+523|0]<<24));if(!d){break pa}v[22440]=0;f=Q(157,b|0,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break ya}if(!f){break pa}v[22440]=0;f=Q(158,b|0,12)|0;d=v[22440];v[22440]=0;if((d|0)==1){break ya}if(!f){break pa}v[22440]=0;Q(190,b|0,6)|0;d=v[22440];v[22440]=0;if((d|0)==1){break ya}v[22440]=0;f=T(278,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break ya}if((f|0)!=1){break pa}v[22440]=0;g=T(286,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break wa}if(!g){break pa}v[22440]=0;f=Q(158,b|0,g|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break wa}if(f){break xa}break pa}h=P()|0;O()|0;break w}zc(e+128|0,_);v[22440]=0;W(340,_|0,b|0,g|0,4);d=v[22440];v[22440]=0;if((d|0)==1){break ra}if(!xd(e+128|0)){v[22440]=0;f=Y(540,e+416|0,2,13)|0;d=v[22440];v[22440]=0;if((d|0)==1){break va}v[22440]=0;U(541,e+56|0,e+128|0,f|0);d=v[22440];v[22440]=0;if((d|0)==1){break ua}v[22440]=0;U(542,e|0,e+56|0,_|0);d=v[22440];v[22440]=0;if((d|0)==1){break ta}tc(_,e);rb(e);rb(e+56|0);rb(f)}rb(e+128|0);break pa}h=P()|0;O()|0;break w}h=P()|0;O()|0;break qa}h=P()|0;O()|0;break sa}h=P()|0;O()|0;rb(e+56|0)}rb(f);break qa}h=P()|0;O()|0}rb(e+128|0);break w}Ca:{if($>>>0<2){break Ca}l=0;if(!Wb(w[e+532|0]|w[e+533|0]<<8|(w[e+534|0]<<16|w[e+535|0]<<24))){break Ca}while(1){if(x[a+480188>>1]<=l>>>0){break Ca}d=w[e+532|0]|w[e+533|0]<<8|(w[e+534|0]<<16|w[e+535|0]<<24);v[22440]=0;f=Q(157,b|0,Wb(d)+(l<<2)|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break x}Da:{if(!f){break Da}v[22440]=0;f=T(286,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break x}v[22440]=0;f=Q(157,b|0,f|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break x}g=0;d=0;if(!f){break Da}while(1){Ea:{v[22440]=0;i=Q(158,b|0,8)|0;f=v[22440];v[22440]=0;Fa:{Ga:{Ha:{if((f|0)!=1){if(!i){break Ea}v[22440]=0;R(543,b|0,e+128|0);f=v[22440];v[22440]=0;if((f|0)==1){break Ha}f=Wb(w[e+128|0]|w[e+129|0]<<8|(w[e+130|0]<<16|w[e+131|0]<<24));if(!f){break Ea}switch((f&536870911)-1|0){case 1:break Fa;case 0:break Ga;default:continue}}h=P()|0;O()|0;break w}h=P()|0;O()|0;break w}g=Wb(w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24));continue}d=Wb(w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24));continue}break}if(!g|!d){break Da}v[22440]=0;g=Q(157,b|0,g|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break y}if(!g){break Da}v[22440]=0;U(425,b|0,((l<<5)+a|0)+480289|0,d|0);d=v[22440];v[22440]=0;if((d|0)==1){break y}}l=l+1|0;continue}}d=w[e+544|0]|w[e+545|0]<<8;v[22440]=0;D=wb(d);R(228,V|0,aa+D&65535);d=v[22440];v[22440]=0;if((d|0)==1){break z}X=m&16;o=aa&65535;ba=0;Ia:{Ja:{while(1){if((D|0)==(ba|0)){ja=e,ka=qk(K),v[ja+56>>2]=ka;ja=e,ka=Af(K),v[ja+416>>2]=ka;while(1){if(!ih(e+56|0,e+416|0)){l=1;d=Wb(w[e+464|0]|w[e+465|0]<<8|(w[e+466|0]<<16|w[e+467|0]<<24));if(!d){break L}v[22440]=0;f=Q(157,b|0,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break z}if(!f){break L}aa=D+aa|0;Ht(K);break K}d=Xn(e+56|0);i=d;g=Oe(d);Ka:{La:{Ma:{Na:{d=x[d>>1];if(!d){d=0;break Na}v[22440]=0;f=Q(318,n|0,d-1&65535)|0;d=v[22440];v[22440]=0;if((d|0)==1){break Ka}d=x[i>>1];if(!f){break Na}v[22440]=0;d=Q(371,n|0,d-1&65535)|0;f=v[22440];v[22440]=0;if((f|0)==1){break Ka}break Ma}if(x[g>>1]==((d&65535)+1|0)){break La}v[22440]=0;d=Y(370,V|0,1,0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break Ka}if((d|0)==65535){break La}ja=Xb(v[n>>2],x[i>>1]),ka=d,u[ja>>1]=ka}xe(Sb(V,d),ym(Pe(Je(e+128|0,12,au(x[g>>1])),v[Sb(V,d)+12>>2]-1|0)));D=(D&65535)>>>0>d>>>0?D:d+1|0}mk(e+56|0);continue}break}h=P()|0;O()|0;break w}Oa:{Pa:{if(!C){break Pa}d=w[e+872|0]|w[e+873|0]<<8|(w[e+874|0]<<16|w[e+875|0]<<24);v[22440]=0;f=Q(157,b|0,Wb(d)+(ba<<2)|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break Ja}if(!f){break Pa}v[22440]=0;f=T(286,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break Ja}v[22440]=0;f=Q(157,b|0,f|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break Ja}if(!f){break Pa}ea=Db(e+112|0);v[22440]=0;N=T(176,e+56|0)|0;d=v[22440];v[22440]=0;Qa:{Ra:{if((d|0)!=1){if($){break Ra}v[22440]=0;R(544,b|0,e+128|0);d=v[22440];v[22440]=0;if((d|0)==1){break Oa}u[e+104>>1]=w[e+128|0];fa=w[E|0]+1|0;f=48;break Qa}h=P()|0;O()|0;break A}m=t[e+806|0];v[22440]=0;R(545,b|0,e+40|0);d=v[22440];v[22440]=0;Sa:{Ta:{if((d|0)!=1){i=wb(w[e+40|0]|w[e+41|0]<<8);u[e+104>>1]=i;fa=wb(w[A|0]|w[A+1|0]<<8)+1|0;d=Wb(w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24));if(!d){break Sa}g=v[b+8>>2];v[22440]=0;Q(157,b|0,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break B}v[22440]=0;R(546,b|0,e+128|0);d=v[22440];v[22440]=0;if((d|0)==1){break B}d=w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24);v[22440]=0;f=Q(157,b|0,Wb(d)|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break B}if(!f){break Ta}d=w[e+136|0]|w[e+137|0]<<8|(w[e+138|0]<<16|w[e+139|0]<<24);v[22440]=0;U(275,b|0,ea|0,Wb(d)|0);d=v[22440];v[22440]=0;if((d|0)!=1){break Ta}break B}break B}d=Wb(w[e+144|0]|w[e+145|0]<<8|(w[e+146|0]<<16|w[e+147|0]<<24));Ua:{if(!d){break Ua}v[22440]=0;f=Q(157,b|0,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break B}if(!f){break Ua}v[22440]=0;f=T(286,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break B}v[22440]=0;f=Q(157,b|0,f|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break B}if(!f){break Ua}v[22440]=0;U(192,e+16|0,b|0,B(i,fa)|0);d=v[22440];v[22440]=0;if((d|0)==1){break B}f=e+416|0;d=e+16|0;Sc(N,cc(f,d));sb(f);sb(d)}v[22440]=0;Q(157,b|0,g|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break B}}f=m+($>>>0<3?48:24)|0}v[22440]=0;i=o+ba|0;g=Y(229,V|0,i&65535,fa|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break B}Va:{if(!g){break Va}s=Sb(V,i);v[22440]=0;R(288,s|0,ea|0);d=v[22440];v[22440]=0;if((d|0)==1){break Ia}Kf(e+104|0,x[a+480188>>1]);r=0;y=x[e+104>>1];Wa:while(1){if((r|0)==(fa|0)){break Va}l=0;d=Zc(s,r,0);while(1){if((l&65535)>>>0>=y>>>0){r=r+1|0;continue Wa}Xa:{if(!$){v[22440]=0;R(547,e+128|0,b|0);g=v[22440];v[22440]=0;if((g|0)!=1){p=e+128|0;m=w[p|0];g=Ec(p);t[d+1|0]=m>>>3&16|w[g|0]>>>4|m>>>1&32;i=w[g|0];ja=d,ka=w[Oe(p)|0],t[ja+5|0]=ka;g=m&63;h=g?g+f|0:0;g=i&15;break Xa}break B}v[22440]=0;R(360,e+128|0,b|0);g=v[22440];v[22440]=0;Ya:{Za:{if((g|0)!=1){g=e+128|0;k=Ec(g);p=Oe(g);m=Li(g);v[22440]=0;i=T(208,N|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break B}t[d+4|0]=i;i=w[e+128|0];g=i&127;if(!g){break Za}h=f+g|0;break Ya}break B}h=0;if((i|0)!=128){break Ya}t[d|0]=254}t[d+1|0]=w[k|0]&63;g=w[p|0];t[d+5|0]=w[m|0]}if(h-1>>>0<=119){t[d|0]=h}Z=(h|0)>84&da|Z;p=(I|0)!=0;m=(M|0)!=0;i=(X|0)!=0;k=cb-16|0;cb=k;t[d+3|0]=0;_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{g=g&255;switch(g-4|0){case 4:case 10:break _a;case 42:break ab;case 37:break bb;case 28:break cb;case 27:break db;case 26:break eb;case 25:break fb;case 24:break gb;case 23:break hb;case 22:break ib;case 21:break jb;case 20:break kb;case 18:break lb;case 17:break mb;case 16:break nb;case 14:break ob;case 13:break pb;case 12:break qb;case 11:break rb;case 9:break sb;case 8:break tb;case 5:break ub;case 0:break vb;default:break $a}}t[d+3|0]=5;i=w[d+5|0];t[k+15|0]=i>>>3;t[k+14|0]=15;g=w[Tb(k+15|0,k+14|0)|0];t[k+13|0]=i<<1&30;t[k+12|0]=15;ja=d,ka=w[Tb(k+13|0,k+12|0)|0]|g<<4,t[ja+5|0]=ka;break _a}if((w[d+5|0]-1&255)>>>0>19){break _a}t[d+3|0]=16;break _a}t[d+3|0]=13;g=w[d+5|0];wb:{if(!i){if(g>>>0>152){break wb}t[d+5|0]=B((g&240)>>>4|0,10)+(g&15);break _a}t[d+5|0]=(g&127)+1>>>1;break _a}t[d+3|0]=0;break _a}t[d+3|0]=11;break _a}g=w[d+5|0];if(!g){t[d+3|0]=14;break _a}if(g>>>0>240){break _a}t[d+3|0]=17;if(g>>>0<=2){t[d+5|0]=112;break _a}ja=d,ka=rk(+(LR(g,p,m,F)>>>0)/1e4),t[ja+5|0]=ka;break _a}t[d+3|0]=31;t[d+5|0]=w[d+5|0]|128;break _a}t[d+3|0]=19;t[k+11|0]=15;ja=d,ka=w[Tb(d+5|0,k+11|0)|0]|16,t[ja+5|0]=ka;break _a}t[d+3|0]=19;t[k+10|0]=15;ja=d,ka=w[Tb(d+5|0,k+10|0)|0]|32,t[ja+5|0]=ka;break _a}t[d+3|0]=5;g=w[d+5|0];t[k+9|0]=(g>>>4|0)+1;t[k+8|0]=15;ja=d,ka=g&15|w[Tb(k+9|0,k+8|0)|0]<<4,t[ja+5|0]=ka;break _a}t[d+3|0]=19;t[d+5|0]=w[d+5|0]&15|80;break _a}t[d+3|0]=19;t[k+7|0]=15;ja=d,ka=w[Tb(d+5|0,k+7|0)|0]|96,t[ja+5|0]=ka;break _a}t[d+3|0]=19;t[k+6|0]=15;ja=d,ka=w[Tb(d+5|0,k+6|0)|0]|192,t[ja+5|0]=ka;break _a}t[d+3|0]=10;break _a}t[d+3|0]=19;t[k+5|0]=15;ja=d,ka=w[Tb(d+5|0,k+5|0)|0]|160,t[ja+5|0]=ka;break _a}t[d+3|0]=19;t[k+4|0]=15;ja=d,ka=w[Tb(d+5|0,k+4|0)|0]|176,t[ja+5|0]=ka;break _a}g=(w[d+5|0]<<24)-16777216>>24;if((g|0)<0){break _a}t[d+5|0]=g;t[d+3|0]=31;break _a}t[d+3|0]=14;break _a}t[d+3|0]=19;t[k+3|0]=15;ja=d,ka=w[Tb(d+5|0,k+3|0)|0]|224,t[ja+5|0]=ka;break _a}g=w[d+5|0];if(g&240){t[d+3|0]=19;t[d+5|0]=g>>>4|208;break _a}if(!(g&15)){break _a}t[d+3|0]=19;t[d+5|0]=g|144;break _a}if(w[d+5|0]|w[d+4|0]){break _a}t[d+5|0]=159;t[d+3|0]=20;break _a}g=w[d+4|0];if(!g){break _a}t[d+3|0]=44;ja=d,ka=El(wc(((w[d+5|0]<<8&65280)>>>0)/(g>>>0)|0,0)),t[ja+5|0]=ka;break _a}g=w[d+5|0];if((g+16&255)>>>0>32){break _a}t[d+3|0]=9;ja=d,ka=rg(((g^128)<<3)-896|0),t[ja+5|0]=ka;break _a}if(g>>>0>15){break _a}Ef(d,g,w[d+5|0])}cb=k+16|0;d=d+6|0;l=l+1|0;continue}}}sb(e+56|0);rb(ea)}ba=ba+1|0;continue}break}break B}h=P()|0;O()|0;break w}break B}Ht(K);d=0;if(!l){break c}}Hi(z,0);d=1;xb:{if(Z&1){break xb}while(1){b=d&65535;if(b>>>0>x[a+480192>>1]){u[a+480192>>1]=0;break xb}b=((b<<2)+a|0)+900380|0;c=v[b>>2];if(c){Jt(c)}zb(c);v[b>>2]=0;d=d+1|0;continue}}yb:{if(!ia){break yb}v[22440]=0;c=Q(1,e+128|0,16401)|0;b=v[22440];v[22440]=0;zb:{if((b|0)!=1){b=v[a+1298464>>2];v[22440]=0;U(388,b|0,2,c|0);b=v[22440];v[22440]=0;if((b|0)==1){break zb}rb(c);break yb}h=P()|0;O()|0;break f}h=P()|0;O()|0;rb(c);break f}h=21685;Ab:{Bb:{switch(w[e+855|0]){case 0:h=x[a+480188>>1]>4?17296:17282;break Ab;case 1:h=17264;break Ab;case 2:h=17246;break Ab;case 3:break Bb;default:break Ab}}h=17219}v[22440]=0;R(548,e+56|0,16834);b=v[22440];v[22440]=0;Cb:{Db:{Eb:{if((b|0)!=1){v[22440]=0;U(549,e+128|0,e+56|0,e+855|0);b=v[22440];v[22440]=0;if((b|0)==1){break Eb}b=e+128|0;Cb(a+1298344|0,b);rb(b);Ab(e+56|0);v[22440]=0;c=Q(1,b|0,12674)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Db}Cb(a+1298356|0,c);rb(c);v[22440]=0;Q(138,a+1298368|0,h|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Cb}v[a+1298404>>2]=2;d=1;break c}h=P()|0;O()|0;break f}h=P()|0;O()|0;Ab(e+56|0);break f}h=P()|0;O()|0;break f}h=P()|0;O()|0;break f}c=c+1|0;continue}}h=P()|0;O()|0;break f}h=P()|0;O()|0;sb(e+56|0)}rb(ea);break w}h=P()|0;O()|0;break w}h=P()|0;O()|0;break w}h=P()|0;O()|0}Ht(K);break f}h=P()|0;O()|0;break f}h=P()|0;O()|0;break f}h=P()|0;O()|0;break f}A=1;if((d|0)!=7){break m}d=z+108|0;f=d+128|0;while(1){if((d|0)!=(f|0)){ja=d,ka=wl(w[d|0]-24|0),t[ja|0]=ka;d=d+1|0;continue}break}d=0}g=d;Z=1;break l}g=0;Fb:{if(E|(J|0)<0){break Fb}m=z+108|0;l=7;Gb:while(1){if((l|0)==10){break Fb}i=B(l,12);j=B(l,-12)+72|0;d=0;while(1)if((d|0)==12){l=l+1|0;continue Gb}else{f=Eb(m,d+i|0);t[f|0]=j+w[f|0];d=d+1|0;continue}}}}v[22440]=0;R(550,ga|0,e+56|0);d=v[22440];v[22440]=0;if((d|0)!=1){Hb:{d=w[o|0];if((d-1&255)>>>0<=15){t[z+31|0]=d;Z=1}d=w[X|0];if((d<<24)-16777216>>24>=0){t[z+30|0]=d}d=0;Ib:{while(1){if((d|0)==(A|0)){if(!C){break j}if((J|0)>=0){break Ib}break j}v[22440]=0;j=B(d+N|0,104)+a|0;R(284,j+484380|0,8);f=v[22440];v[22440]=0;if((f|0)!=1){t[e+416|0]=w[I|0];t[e+384|0]=64;ja=j+484410|0,ka=w[Tb(e+416|0,e+384|0)|0]<<2,u[ja>>1]=ka;t[j+484416|0]=w[H|0];d=d+1|0;continue}break}break k}m=Nc(e+416|0,8,1,1,0);j=wb(w[M|0]|w[M+1|0]<<8);l=wb(w[e+56|0]|w[e+57|0]<<8);v[22440]=0;h=T(162,e+128|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){d=Rd((w[r|0]|w[r+1|0]<<8)<<16>>16);if(d&16){kd(m,16);h=h>>>1|0;d=Rd((w[r|0]|w[r+1|0]<<8)<<16>>16)}if(d&32){so(m,3);h=h>>>1|0;d=Rd((w[r|0]|w[r+1|0]<<8)<<16>>16)}if(d&64){Hf(m,2)}h=g?(h>>>0)/((-1<<A^-1)>>>0)|0:h;g=j+l|0;d=0;while(1){if((d|0)==(A|0)){break j}i=B(d+N|0,104)+a|0;f=i+484380|0;v[f>>2]=h;v[22440]=0;Y(222,m|0,f|0,s|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break Hb}l=l<<1;g=g<<1;if(j>>>0>=2){v[i+484388>>2]=g;v[i+484384>>2]=l;f=i+484414|0;u[f>>1]=x[f>>1]|2}d=d+1|0;h=h<<1;continue}}}}}h=P()|0;O()|0;sb(e+128|0);break f}D=D+1|0;F=A+F|0;sb(e+128|0);h=x[a+480192>>1];continue}}h=P()|0;O()|0;break e}h=P()|0;O()|0;break e}h=P()|0;O()|0}fc(ca)}sb(ga);S(h|0);L()}d=0}fc(ca)}sb(ga)}cb=e+912|0;return d|0}function Bea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=C(0),D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,_=0,$=0,aa=0,ba=0,ca=0,fa=C(0),ga=0,ha=0,ia=0,ja=0,ka=0;e=cb-432|0;cb=e;sc(b);a:{b:{c:{if(!$h(b,e+424|0)){break c}if(!LP(e+424|0)){break c}if((Am(b)|0)>=0){break c}if(!c){j=1;break c}ud(a,16777216);v[a+480208>>2]=v[a+480208>>2]|1681e4;eq(e+160|0,32);h=v[e+172>>2];d=a+1074320|0;v[d>>2]=v[e+168>>2];v[d+4>>2]=h;d=v[e+164>>2];v[a+1074312>>2]=v[e+160>>2];v[a+1074316>>2]=d;Vf(a+1074312|0,38);p=Rb(e+408|0);q=Rb(e+392|0);s=Rb(e+376|0);m=Rb(e+360|0);xg(b,4);k=a+480190|0;J=c&1;I=a+1298332|0;o=2500;G=!(c&2);E=a+1298464|0;d:{e:{f:{while(1){v[22440]=0;c=Q(158,b|0,4)|0;d=v[22440];v[22440]=0;g:{h:{i:{j:{k:{l:{m:{n:{if((d|0)!=1){o:{if(c){v[22440]=0;d=T(701,b|0)|0;c=v[22440];v[22440]=0;p:{if((c|0)==1){break p}j=0;q:{switch(d+21|0){case 20:v[22440]=0;c=T(286,b|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){d=c&65535;if(x[a+480188>>1]|d-1>>>0>126){continue}u[a+480188>>1]=c;ja=a,ka=Vb(512/(d>>>0)|0,16,128),v[ja+480228>>2]=ka;continue}i=P()|0;O()|0;break a;case 19:v[22440]=0;K=T(286,b|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break p}if(K>>>0<=1024){continue}break m;case 16:v[22440]=0;c=T(286,b|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){if((c&65535)==4){continue}break m}i=P()|0;O()|0;break a;case 15:v[22440]=0;c=T(286,b|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){v[e+160>>2]=c;v[e+56>>2]=800;ja=a,ka=Le(+y[Bb(e+160|0,e+56|0)>>2]*1.24*1e4),v[ja+480204>>2]=ka;continue}i=P()|0;O()|0;break a;case 17:case 18:v[22440]=0;Q(190,b|0,4)|0;c=v[22440];v[22440]=0;if((c|0)!=1){continue}break p;case 31:v[22440]=0;c=T(286,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break p}_=1;o=wd(c,0,1e4);continue;case 32:case 33:v[22440]=0;c=T(286,b|0)|0;d=v[22440];v[22440]=0;r:{s:{if((d|0)!=1){_=1;if(!c){continue}v[22440]=0;c=Q(1,e+160|0,12583)|0;d=v[22440];v[22440]=0;if((d|0)==1){break s}d=v[E>>2];v[22440]=0;U(388,d|0,2,c|0);d=v[22440];v[22440]=0;if((d|0)==1){break r}rb(c);continue}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;rb(c);break a;case 14:v[22440]=0;Q(190,b|0,4)|0;c=v[22440];v[22440]=0;if((c|0)==1){break p}i=!x[k>>1]|i;continue;case 11:t:{if(!J){break t}if(!hc(v[p>>2],v[p+4>>2])){break t}v[22440]=0;R(702,e+160|0,b|0);c=v[22440];v[22440]=0;if((c|0)!=1){if(v[p>>2]){Ac(p);c=v[p>>2];Tn(p);zb(c);ja=xb(p),ka=0,v[ja>>2]=ka;v[p>>2]=0;v[p+4>>2]=0}c=e+160|0;v[p>>2]=v[c>>2];v[p+4>>2]=v[c+4>>2];d=xb(c);ja=xb(p),ka=v[d>>2],v[ja>>2]=ka;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Di(c);continue}i=P()|0;O()|0;break a}v[22440]=0;c=T(286,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break p}v[22440]=0;Q(190,b|0,c|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){continue}break p;case 3:case 4:case 10:g=th(v[m>>2],v[m+4>>2]);c=x[k>>1];if(g>>>0<=c>>>0){continue}u:{if((i|G)&1){break u}if(!Sh(a)){break u}h=c+1|0;u[k>>1]=h;r=Rb(e+344|0);v[22440]=0;c=T(176,e+160|0)|0;g=v[22440];v[22440]=0;v:{w:{x:{if((g|0)!=1){if((d|0)==-17){break x}if((d|0)!=-11){break w}v[22440]=0;d=T(286,b|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break v}v[22440]=0;U(192,e+320|0,b|0,d|0);d=v[22440];v[22440]=0;if((d|0)==1){break v}d=e+56|0;g=e+320|0;Sc(c,cc(d,g));sb(d);sb(g);break g}i=P()|0;O()|0;break d}v[22440]=0;R(703,e+56|0,b|0);d=v[22440];v[22440]=0;y:{if((d|0)!=1){d=e+56|0;xm(r,d);_b(d);qe(e+312|0,v[e+344>>2],v[e+348>>2]);ee(e+304|0);v[22440]=0;d=ea(337,d|0,v[e+312>>2],v[e+316>>2],v[e+304>>2],v[e+308>>2])|0;g=v[22440];v[22440]=0;if((g|0)==1){break y}Sc(c,d);sb(e+56|0);break g}i=P()|0;O()|0;break e}i=P()|0;O()|0;break e}v[22440]=0;R(704,e+56|0,b|0);d=v[22440];v[22440]=0;z:{if((d|0)!=1){d=e+56|0;xm(r,d);_b(d);qe(e+296|0,v[e+344>>2],v[e+348>>2]);ee(e+288|0);v[22440]=0;d=ea(337,d|0,v[e+296>>2],v[e+300>>2],v[e+288>>2],v[e+292>>2])|0;g=v[22440];v[22440]=0;if((g|0)==1){break z}Sc(c,d);sb(e+56|0);break g}i=P()|0;O()|0;break e}i=P()|0;O()|0;break e}i=P()|0;O()|0;break e}v[22440]=0;c=T(286,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break p}v[22440]=0;Q(190,b|0,c|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){continue}break p;case 9:if(!Sh(a)){continue}u[k>>1]=x[k>>1]+1;continue;case 8:A:{if(!J){break A}if(!hc(v[s>>2],v[s+4>>2])){break A}v[22440]=0;R(705,e+160|0,b|0);c=v[22440];v[22440]=0;if((c|0)!=1){c=e+160|0;KP(s,c);fc(c);continue}i=P()|0;O()|0;break a}v[22440]=0;c=T(286,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break p}v[22440]=0;Q(190,b|0,c|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){continue}break p;case 7:if(hc(v[m>>2],v[m+4>>2])){v[22440]=0;R(706,e+160|0,b|0);c=v[22440];v[22440]=0;if((c|0)!=1){if(v[m>>2]){Ac(m);c=v[m>>2];tz(m);zb(c);ja=xb(m),ka=0,v[ja>>2]=ka;v[m>>2]=0;v[m+4>>2]=0}c=e+160|0;v[m>>2]=v[c>>2];v[m+4>>2]=v[c+4>>2];d=xb(c);ja=xb(m),ka=v[d>>2],v[ja>>2]=ka;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;qt(c);continue}i=P()|0;O()|0;break a}v[22440]=0;c=T(286,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break p}v[22440]=0;Q(190,b|0,c|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){continue}break p;case 6:B:{if(!J){break B}if(!hc(v[q>>2],v[q+4>>2])){break B}v[22440]=0;R(707,e+160|0,b|0);c=v[22440];v[22440]=0;if((c|0)!=1){if(v[q>>2]){Ac(q);c=v[q>>2];it(q);zb(c);ja=xb(q),ka=0,v[ja>>2]=ka;v[q>>2]=0;v[q+4>>2]=0}c=e+160|0;v[q>>2]=v[c>>2];v[q+4>>2]=v[c+4>>2];d=xb(c);ja=xb(q),ka=v[d>>2],v[ja>>2]=ka;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;ml(c);continue}i=P()|0;O()|0;break a}v[22440]=0;c=T(286,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break p}v[22440]=0;Q(190,b|0,c|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){continue}break p;case 5:v[22440]=0;R(708,e+160|0,b|0);c=v[22440];v[22440]=0;if((c|0)==1){break o}C:{c=v[e+160>>2];d=v[e+164>>2];if(hc(c,d)){break C}v[22440]=0;W(346,I|0,c|0,Uc(c,d)|0,1);c=v[22440];v[22440]=0;if((c|0)!=1){break C}i=P()|0;O()|0;_b(e+160|0);break a}_b(e+160|0);continue;case 0:case 1:case 2:break q;default:break m}}v[22440]=0;c=T(286,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break p}v[22440]=0;Q(190,b|0,c|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){continue}}i=P()|0;O()|0;break a}j=0;if(!x[a+480188>>1]|!K){break m}b=v[m>>2];c=v[m+4>>2];if(hc(b,c)){break m}if(J){if(hc(v[p>>2],v[p+4>>2])){break m}if(hc(v[s>>2],v[s+4>>2])){break m}if(hc(v[q>>2],v[q+4>>2])){break m}}b=th(b,c);if(b>>>0>=256){v[22440]=0;R(709,m|0,255);b=v[22440];v[22440]=0;if((b|0)==1){break b}b=th(v[m>>2],v[m+4>>2])}u[a+480192>>1]=b;j=a+480192|0;ja=a,ka=x[ie(k,j)>>1],u[ja+480190>>1]=ka;if(i&1){v[22440]=0;b=Q(1,e+160|0,16490)|0;c=v[22440];v[22440]=0;if((c|0)==1){break h}c=v[a+1298464>>2];v[22440]=0;U(388,c|0,2,b|0);c=v[22440];v[22440]=0;if((c|0)==1){break i}rb(b)}i=0;D:while(1){if((i|0)==2){break n}b=1;while(1){g=b&65535;if(g>>>0>x[j>>1]){i=i+1|0;continue D}E:{h=mm(v[m>>2],g-1|0);if(w[h|0]){c=t[h+128|0]<0}else{c=1}if(c){break E}if((ot(h)|0)==((i|0)!=1|0)){break E}c=0;F:{if(!ot(h)){break F}if(wb(w[h+6|0]|w[h+7|0]<<8)){break F}if(wb(w[h+14|0]|w[h+15|0]<<8)>>>0>20){break F}c=(wb(w[h+18|0]|w[h+19|0]<<8)|0)==4}G:{H:{if(c){c=w[h+23|0];d=w[h+140|0];v[22440]=0;d=ea(710,h|0,a|0,(d&2)>>>1|0,(B(g,104)+a|0)+484380|0,o&65535)|0;f=v[22440];v[22440]=0;I:{J:{if((f|0)!=1){if(!d){break I}v[22440]=0;d=Q(56,e+160|0,10745)|0;f=v[22440];v[22440]=0;if((f|0)==1){break J}uc(((g<<5)+a|0)+946304|0,d);rb(d);f=v[m>>2];d=b;if(th(f,v[m+4>>2])>>>0<=c>>>0){break G}c=mm(f,c);t[h+143|0]=w[h+143|0]+w[c+143|0];break H}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}d=c+1|0;break G}c=0;K:{if(!ot(h)){break K}if((wb(w[h+6|0]|w[h+7|0]<<8)|0)!=1){break K}if((wb(w[h+14|0]|w[h+15|0]<<8)|0)!=2){break K}c=(wb(w[h+18|0]|w[h+19|0]<<8)|0)==10}d=b;if(!c){break G}ic(e+160|0,h,128);if(wb(w[e+180|0]|w[e+181|0]<<8)>>>0>=x[k>>1]){break H}v[22440]=0;d=T(699,e+56|0)|0;c=v[22440];v[22440]=0;L:{M:{if((c|0)!=1){c=wb(w[e+180|0]|w[e+181|0]<<8);f=w[e+196|0]|w[e+197|0]<<8;n=x[a+480190>>1];v[22440]=0;r=B(c,104);c=a+484380|0;f=wb(f);c=da(711,e+160|0,(r+c|0)+104|0,(f>>>0<n>>>0?(c+B(f,104)|0)+104|0:d)|0,c+B(g,104)|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break M}if(!c){break H}v[22440]=0;c=Q(56,e+320|0,11289)|0;d=v[22440];v[22440]=0;if((d|0)==1){break L}uc(((g<<5)+a|0)+946304|0,c);rb(c);t[h+139|0]=w[h+139|0]+12;break H}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}d=b}v[22440]=0;c=d&65535;d=Y(257,a|0,g|0,c|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){if(!d|c>>>0>x[k>>1]){break E}v[22440]=0;W(712,h|0,d|0,(B(c,104)+a|0)+484380|0,a|0);c=v[22440];v[22440]=0;if((c|0)!=1){break E}}i=P()|0;O()|0;break a}b=b+1|0;continue}}}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}I=Jg(e+56|0);r=Jg(e+320|0);b=pc(v[s>>2],v[s+4>>2]);$=B(x[a+480188>>1],K);aa=xl((b>>>0)/($>>>0)|0);v[22440]=0;N=a+484344|0;R(228,N|0,aa|0);b=v[22440];v[22440]=0;if((b|0)==1){break k}ba=a+484360|0;Ac(Nb(ba));b=x[a+480188>>1];v[22440]=0;E=Q(713,e+344|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break l}ja=e,ka=yb(v[q>>2]),v[ja+48>>2]=ka;ga=a+902204|0;ha=yb(v[q+4>>2]);while(1){N:{O:{P:{n=v[e+48>>2];if(!Qb(n,ha)){break P}b=Rd((w[n+6|0]|w[n+7|0]<<8)<<16>>16);if((b|0)==1){break N}if((b&65535)==65535){break P}h=wb(w[n|0]|w[n+1|0]<<8);b=v[p>>2];g=v[p+4>>2];c=ag(b,g);if(h>>>0>=c>>>0){break N}d=wb(w[n+2|0]|w[n+3|0]<<8);if(d>>>0>c>>>0|!d|h>>>0>c-d>>>0){break N}c=b+(ag(b,g)<<5)|0;v[e+160>>2]=b;ja=e,ka=ag(b,c),v[ja+164>>2]=ka;b=v[e+160>>2];$b(e+40|0,b+(wb(w[n|0]|w[n+1|0]<<8)<<5)|0,wb(w[n+2|0]|w[n+3|0]<<8));Q:{H=Nb(ba);if(hc(v[H>>2],v[H+4>>2])){break Q}v[22440]=0;R(535,H|0,65534);b=v[22440];v[22440]=0;if((b|0)!=1){break Q}break O}h=v[e+40>>2];ia=we(h,v[e+44>>2]);while(1){if((h|0)==(ia|0)){break N}b=Rd(Rd((w[n+8|0]|w[n+9|0]<<8)<<16>>16)+Rd((w[h+16|0]|w[h+17|0]<<8)<<16>>16)<<16>>16);t[h+16|0]=b;t[h+17|0]=b>>>8;b=Kd(I);while(1){R:{c=0;if(!b){break R}d=b+14|0;if(!kt(h,d)){c=1;if(!kt(d,h)){break R}b=b+4|0}b=v[b>>2];continue}break}S:{T:{U:{if(c){v[22440]=0;b=Q(714,I|0,h|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break O}D=x[b>>1];break U}D=0;if(!J){break U}b=w[h+12|0]|w[h+13|0]<<8;v[22440]=0;D=Y(370,N|0,wb(b)|0,0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break O}if((D|0)==65535){break N}v[22440]=0;b=Q(714,I|0,h|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break O}u[b>>1]=D;if(wb(w[h+8|0]|w[h+9|0]<<8)>>>0>=aa>>>0){break T}if(wb(w[h+10|0]|w[h+11|0]<<8)>>>0>=K>>>0){break T}o=wb(w[h+14|0]|w[h+15|0]<<8);ja=e,ka=yb(v[s>>2]),v[ja+16>>2]=ka;b=e+16|0;ja=e,ka=nl(b,B(wb(w[h+8|0]|w[h+9|0]<<8),$)),v[ja+160>>2]=ka;ja=e,ka=nl(e+160|0,B(x[a+480188>>1],wb(w[h+10|0]|w[h+11|0]<<8))),v[ja+32>>2]=ka;M=0;v[e+28>>2]=0;tg(b);V:while(1){W:{c=wb(w[h+12|0]|w[h+13|0]<<8);b=Sb(N,D);if(c>>>0<=M>>>0){break W}c=0;V=Zc(b,M,0);j=0;while(1){if(x[a+480188>>1]<=c>>>0){M=M+1|0;continue V}b=yb(v[s+4>>2]);d=v[e+32>>2];k=Qb(d,b)?d:e+28|0;b=yb(v[s+4>>2]);if(Qb(v[e+32>>2],b)){IP(e+32|0)}d=B(c,6)+V|0;g=w[k+1|0];b=(g>>>0<85?g+25|0:-1)<<24>>24;i=0;f=v[m>>2];F=th(f,v[m+4>>2]);G=w[k+3|0];X:{if(F>>>0<=G>>>0){break X}i=G+1|0;if(t[mm(f,G)+142|0]&1|(b|0)<0){break X}b=wl(Rd((w[h+16|0]|w[h+17|0]<<8)<<16>>16)+b<<24>>24)}Y:{if(!w[d|0]|!(w[k+2|0]?1:G|(w[k|0]|(g|0)!=255))){break Y}g=w[d+1|0];if(!g|g>>>0>F>>>0){break Y}if(w[mm(f,g-1|0)+132|0]!=2){break Y}Rn(d)}f=st(v[E>>2],c);Z:{if(j&1){g=v[e+16>>2];t[d|0]=g;t[d+1|0]=g>>>8;t[d+2|0]=g>>>16;t[d+3|0]=g>>>24;g=x[e+20>>1];t[d+4|0]=g;t[d+5|0]=g>>>8;_:{if(w[d+3|0]){break _}j=w[f+21|0];g=w[st(v[E>>2],c-1|0)+21|0];if((j|0)==(g|0)){break _}t[d+3|0]=21;t[f+21|0]=g;t[d+5|0]=g}j=0;g=1;F=w[k|0];if(!(F-24>>>0<2|(F|0)==9|!F&(w[k+2|0]+7&255)>>>0<2?g:0)){break Z}}$:{aa:{ba:{ca:{da:{ea:{switch(w[k|0]){case 5:g=w[f+17|0];break da;case 0:fa:{g=w[k+2|0];if(g>>>0>=201){j=0;ga:{switch(g-242|0){case 11:t[d+4|0]=1;t[d+2|0]=14;t[f+16|0]=0;break aa;case 9:t[d+4|0]=1;t[d+2|0]=15;break aa;case 8:if((o&255)>>>0<2){break aa}o=o-1|0;break ba;case 7:if((o&255)==255){o=255;break aa}o=o+1|0;break ba;case 6:t[f+17|0]=b;if(w[f+18|0]!=(i&255)){break aa}t[d|0]=b;t[d+5|0]=255;t[d+3|0]=4;u[f+32>>1]=0;v[f+8>>2]=0;break aa;case 5:t[d+5|0]=242;t[d+3|0]=2;break aa;case 4:t[d+5|0]=242;t[d+3|0]=3;break aa;case 3:t[d+5|0]=244;t[d+3|0]=2;break aa;case 2:t[d+5|0]=244;t[d+3|0]=3;break aa;case 1:t[d+5|0]=248;t[d+3|0]=2;break aa;case 12:break fa;case 0:break ga;default:break aa}}t[d+5|0]=248;t[d+3|0]=3;break aa}j=0;F=t[k+1|0];if((F|0)<0&g>>>0>99){break aa}if((F|0)>=0){t[f+17|0]=b;t[d|0]=b;t[f+18|0]=i;t[d+1|0]=i;u[f+32>>1]=0;v[f+8>>2]=0;g=w[k+2|0]}b=g&255;if(!b){break aa}ja=f,ka=rk(+(b>>>0)*.64),t[ja+19|0]=ka;l=z[f>>2];v[f>>2]=0;j=l!=C(0);break aa}t[d+4|0]=0;t[d+2|0]=14;t[f+16|0]=1;break aa;case 1:v[f+4>>2]=0;z[f>>2]=C(w[k+2|0])*C(.0333000011742115);break $;case 2:v[f+4>>2]=0;z[f>>2]=C(w[k+2|0])*C(-.0333000011742115);break $;case 12:t[e+160|0]=15;t[e+12|0]=w[k+3|0]>>>3;b=w[Tb(e+160|0,e+12|0)|0];t[e+160|0]=15;t[e+12|0]=w[k+2|0]>>>3;ja=f,ka=w[Tb(e+160|0,e+12|0)|0]|b<<4,t[ja+24|0]=ka;break $;case 3:v[f+12>>2]=0;b=w[k+2|0];u[f+32>>1]=0;z[f+8>>2]=C(b>>>0)*C(.0333000011742115);break $;case 4:v[f+12>>2]=0;b=w[k+2|0];u[f+32>>1]=0;z[f+8>>2]=C(b>>>0)*C(-.0333000011742115);break $;case 15:if(!w[k+2|0]|(b|0)<0){break $}j=b-w[f+17|0]|0;g=j>>31;g=g^g+(j<<5);v[e+160>>2]=g;t[f+17|0]=b;v[f+8>>2]=0;t[d|0]=b;t[d+3|0]=4;b=rg((g>>>0)/(w[k+2|0]<<1>>>0)|0);t[d+5|0]=b;t[f+27|0]=b;v[e+12>>2]=B(b,(o&255)-1|0);ja=f,ka=g-v[ld(e+160|0,e+12|0)>>2]|0,u[ja+32>>1]=ka;break $;case 13:t[e+160|0]=15;t[e+12|0]=w[k+3|0]>>>3;b=w[Tb(e+160|0,e+12|0)|0];t[e+160|0]=15;t[e+12|0]=w[k+2|0];ja=f,ka=w[Tb(e+160|0,e+12|0)|0]|b<<4,t[ja+23|0]=ka;break $;case 18:b=w[k+2|0]+w[f+17|0]&255;b=b?b>>>0<120?b:120:1;t[f+17|0]=b;t[d|0]=b;t[d+5|0]=255;t[d+3|0]=4;break ca;case 23:case 24:case 25:b=Kd(r);while(1){ha:{g=0;if(!b){break ha}j=b+13|0;if(!lt(k,j)){g=1;if(!lt(j,k)){break ha}b=b+4|0}b=v[b>>2];continue}break};if(g){t[d+3|0]=31;v[22440]=0;b=Q(715,r|0,k|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break O}t[d+5|0]=w[b|0];break $}b=v[xb(r)>>2];if(b>>>0>127){break $}v[e+8>>2]=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);v[22440]=0;v[e>>2]=v[e+8>>2];g=Y(716,e|0,we(ga,b&255)|0,a|0)|0;j=v[22440];v[22440]=0;ia:{if((j|0)==1){break ia}if(!g){break $}t[d+3|0]=31;v[22440]=0;g=Q(715,r|0,k|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break ia}b=b|-128;t[g|0]=b;t[d+5|0]=b;X=(w[k|0]&254)==24|X;break $}break O;case 16:if(!w[k+2|0]){break $}t[d+3|0]=15;v[e+160>>2]=15;v[e+12>>2]=w[k+3|0]+1;ja=d,ka=v[ld(e+160|0,e+12|0)>>2],t[ja+5|0]=ka;u[f+30>>1]=B(w[k+2|0],w[k+3|0]+1|0);break $;case 9:t[d+3|0]=16;b=w[k+2|0];o=b?b:4;t[d+5|0]=o;break $;case 19:ja:{b=w[k+1|0];switch(b|0){case 0:case 4:break ja;default:break $}}i=128;i=(b|0)==4?w[k+3|0]:i;t[e+7|0]=i;t[e+160|0]=w[k+2|0];t[e+12|0]=100;b=e+160|0;j=e+12|0;g=w[Tb(b,j)|0];v[e+160>>2]=128;v[e+12>>2]=256-(i&255);j=v[ld(b,j)>>2];t[e+160|0]=128;b=w[Tb(b,e+7|0)|0];j=(B(g,j)|0)/128|0;i=j&255;if((i|0)!=w[f+20|0]){t[f+20|0]=j;t[d+3|0]=21;j=wc(((B(i,w[f+19|0])+50&65535)>>>0)/100|0,0);t[f+21|0]=j;t[d+5|0]=j}if(w[k+1|0]!=4|(x[a+480188>>1]-1|0)<=(c|0)){break $}j=c+1|0;i=st(v[E>>2],j);b=B(b,g)>>>7|0;if(w[i+20|0]==(b&255)){break $}t[i+20|0]=b;b=B(j,6)+V|0;t[b+3|0]=21;g=wc(((B(w[f+20|0],w[f+19|0])+50&65535)>>>0)/100|0,0);t[f+21|0]=g;t[b+5|0]=g;break $;case 10:case 11:case 17:case 20:t[d+3|0]=0;break $;case 7:b=w[k+2|0];t[f+25|0]=0;t[f+26|0]=0;t[f+22|0]=b;break $;case 8:t[f+22|0]=w[f+22|0]+w[k+2|0];break $;case 14:t[f+25|0]=w[k+3|0];t[f+26|0]=w[k+2|0];break $;case 6:break ea;default:break $}}t[f+18|0]=i;t[f+17|0]=b;t[d+1|0]=i;g=b}t[d|0]=g;if((b|0)>=0){t[f+18|0]=i;t[d+1|0]=i}if(w[k|0]==5){t[d+4|0]=1;t[d+2|0]=11}g=w[f+22|0];b=w[f+26|0];if(!(b?1:g|w[k+2|0])){break ca}if(b){ca=(Bi(+x[f+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(b>>>0)*.25}else{ca=0}t[d+3|0]=44;ja=d,ka=rk(ca+ +(g+w[k+2|0]|0)),t[ja+5|0]=ka}u[f+32>>1]=0;break $}t[d+5|0]=o;t[d+3|0]=16}b=wc(((B(w[f+20|0],w[f+19|0])+50&65535)>>>0)/100|0,0);if(!(!j&w[f+21|0]==(b&255))){t[f+21|0]=b;t[d+5|0]=b;t[d+3|0]=21}if(c&1|t[k+1|0]<=0|(x[a+480188>>1]-1|0)<=(c|0)){break $}b=v[m>>2];if(th(b,v[m+4>>2])>>>0<=G>>>0){break $}if(w[mm(b,G)+132|0]!=1){break $}j=c+1|0;b=B(j,6)+V|0;g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[b|0]=g;t[b+1|0]=g>>>8;t[b+2|0]=g>>>16;t[b+3|0]=g>>>24;g=w[d+4|0]|w[d+5|0]<<8;t[b+4|0]=g;t[b+5|0]=g>>>8;t[b+1|0]=w[b+1|0]+1;b=st(v[E>>2],j);t[b+19|0]=w[f+19|0];z[b>>2]=z[f>>2];z[b+4>>2]=z[f+4>>2];z[b+8>>2]=z[f+8>>2];z[b+12>>2]=z[f+12>>2];u[b+30>>1]=x[f+30>>1]}ka:{if(w[d|0]){t[f+16|0]=0;break ka}j=0;if(w[f+16|0]){break Z}}la:{if(!x[f+30>>1]){break la}b=o&255;u[e+160>>1]=b;g=f+30|0;ja=g,ka=x[ie(g,e+160|0)>>1]-b|0,u[ja>>1]=ka;if(w[d+3|0]){break la}t[d+3|0]=15;t[d+5|0]=0}l=z[f>>2];ma:{if(l==C(0)){break ma}b=o&255;l=C(C(l*C(b>>>0))+z[f+4>>2]);z[f+4>>2]=l;if(w[d+3|0]){break ma}na:{oa:{pa:{qa:{if(b>>>0>=2){g=b-1|0;A=C(g|0);if(!(A<=l)){break qa}t[e+160|0]=15;ja=e,ka=gh(C(l/A)),t[ja+12|0]=ka;b=w[Tb(e+160|0,e+12|0)|0];z[f+4>>2]=l-C(B(b,g)|0);t[d+3|0]=22;i=b<<4;break na}if(!(l>=C(1))){break pa}break oa}if(l>=C(1)){break oa}if(!(l<=C(1-b|0))){break pa}t[e+160|0]=15;ja=e,ka=gh(C(C(-l)/A)),t[ja+12|0]=ka;i=w[Tb(e+160|0,e+12|0)|0];z[f+4>>2]=l+C(B(g,i)|0);t[d+3|0]=22;break na}if(!(l<=C(-1))){break ma}t[e+160|0]=14;ja=e,ka=gh(C(-l)),t[ja+12|0]=ka;b=w[Tb(e+160|0,e+12|0)|0];z[f+4>>2]=l+C(b>>>0);t[d+3|0]=22;i=b|-16;break na}t[e+160|0]=15;ja=e,ka=gh(l),t[ja+12|0]=ka;b=w[Tb(e+160|0,e+12|0)|0];z[f+4>>2]=l-C(b>>>0);t[d+3|0]=22;i=b<<4|15}t[d+5|0]=i}l=z[f+8>>2];ra:{if(l==C(0)){break ra}b=o&255;l=C(C(l*C(b>>>0))+z[f+12>>2]);z[f+12>>2]=l;sa:{if(!w[d+3|0]){ta:{ua:{if(b>>>0>=2){g=b-1|0;A=C(g|0);if(!(A<=l)){break ua}t[e+160|0]=223;ja=e,ka=gh(C(l/A)),t[ja+12|0]=ka;b=w[Tb(e+160|0,e+12|0)|0];z[f+12>>2]=l-C(B(b,g)|0);t[d+3|0]=2;t[d+5|0]=b;break ra}if(!(l>=C(1))){break ta}break sa}if(l>=C(1)){break sa}if(!(l<=C(1-b|0))){break ta}t[e+160|0]=223;ja=e,ka=gh(C(C(-l)/A)),t[ja+12|0]=ka;b=w[Tb(e+160|0,e+12|0)|0];z[f+12>>2]=l+C(B(b,g)|0);t[d+3|0]=3;t[d+5|0]=b;break ra}if(!(l<=C(-1))){break ra}t[e+160|0]=14;ja=e,ka=gh(C(-l)),t[ja+12|0]=ka;b=w[Tb(e+160|0,e+12|0)|0];z[f+12>>2]=l+C(b>>>0);t[d+3|0]=3;t[d+5|0]=b|240;break ra}if(w[d+2|0]|b>>>0<2){break ra}fa=C(l*C(.25));g=b-1|0;A=C(g|0);if(fa>=A){t[e+160|0]=9;ja=e,ka=gh(C(l/A))>>>2|0,t[ja+12|0]=ka;b=w[Tb(e+160|0,e+12|0)|0];z[f+12>>2]=l-C(B(b,g)<<2);t[d+2|0]=12;t[d+4|0]=b;break ra}if(!(C(1-b|0)>=fa)){break ra}t[e+160|0]=9;ja=e,ka=gh(C(C(-l)/A))>>>2|0,t[ja+12|0]=ka;b=w[Tb(e+160|0,e+12|0)|0];z[f+12>>2]=l+C(B(b,g)<<2);t[d+2|0]=13;t[d+4|0]=b;break ra}t[e+160|0]=15;ja=e,ka=gh(l),t[ja+12|0]=ka;b=w[Tb(e+160|0,e+12|0)|0];z[f+12>>2]=l-C(b>>>0);t[d+3|0]=2;t[d+5|0]=b|240}va:{wa:{xa:{ya:{za:{Aa:{Ba:{b=w[d+3|0];switch(b|0){case 4:break va;case 0:break Ba;default:break Aa}}Ca:{b=w[f+23|0];if(!b){b=w[f+24|0];if(b){break Ca}if(!x[f+32>>1]){break va}j=f+32|0;break za}t[d+3|0]=5;t[d+5|0]=b;if(!x[f+32>>1]){break va}break ya}t[d+3|0]=8;t[d+5|0]=b;if(x[f+32>>1]){break ya}break va}if(!x[f+32>>1]){break va}j=f+32|0;if(b){break xa}}t[d+3|0]=4;break wa}j=f+32|0}t[d+2|0]=11}u[e+160>>1]=B(w[f+27|0],(o&255)-1|0);ja=f,ka=x[f+32>>1]-x[Kc(j,e+160|0)>>1]|0,u[ja+32>>1]=ka}u[f+28>>1]=x[f+28>>1]+B(w[f+25|0],o&255)&1023;j=0;if(c&1){break Z}b=w[f+18|0];if(!b){break Z}g=v[m>>2];if(th(g,v[m+4>>2])>>>0<b>>>0){break Z}b=mm(g,b-1|0);if(!(w[b+142|0]&4)){break Z}v[e+16>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);u[e+20>>1]=w[d+4|0]|w[d+5|0]<<8;d=w[e+17|0];if(!d){j=1;break Z}j=1;if(w[b+132|0]!=1){break Z}t[e+17|0]=d+1}c=c+1|0;continue}}break}xe(b,yh(Pe(Je(e+160|0,16,wb(w[h+14|0]|w[h+15|0]<<8)&255),0)))}b=yl(H);ja=e,ka=wb(w[h+4|0]|w[h+5|0]<<8),u[ja+160>>1]=ka;u[e+16>>1]=1;c=x[ie(e+160|0,e+16|0)>>1];v[22440]=0;W(717,H|0,b|0,c|0,D&65535);b=v[22440];v[22440]=0;if((b|0)==1){break S}b=Rd((w[n+8|0]|w[n+9|0]<<8)<<16>>16);b=Rd(Rd((w[h+16|0]|w[h+17|0]<<8)<<16>>16)-b<<16>>16);t[h+16|0]=b;t[h+17|0]=b>>>8}h=h+32|0;continue}break}break O}b=0;Da:{if(X&1){v[22440]=0;Z(291,a+906300|0);b=v[22440];v[22440]=0;if((b|0)==1){break Da}b=a+906316|0;v[b>>2]=1299020115;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[e+160>>2]=0;c=a+906348|0;b=e+160|0;HU(a+906332|0,c,b);v[22440]=0;b=Q(56,b|0,9585)|0;d=v[22440];v[22440]=0;if((d|0)==1){break Da}yB(c,b);rb(b);v[22440]=0;b=Q(56,e+160|0,9578)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Da}ou(a+906380|0,b);rb(b);v[22440]=0;b=Q(56,e+160|0,9570)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Da}yB(a+906508|0,b);rb(b);b=0}while(1){Ea:{if(x[a+480188>>1]<=b>>>0){v[22440]=0;b=Q(1,e+160|0,12133)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break Ea}break O}fB(a,b&65535);c=(b<<5)+a|0;u[c+480284>>1]=b<<8&256;if(X&1){t[c+480288|0]=1}b=b+1|0;continue}break}Cb(a+1298344|0,b);rb(b);v[22440]=0;b=Q(1,e+160|0,12351)|0;c=v[22440];v[22440]=0;Fa:{Ga:{Ha:{if((c|0)!=1){Cb(a+1298356|0,b);rb(b);if(_){break Ha}v[22440]=0;b=Q(1,e+160|0,12133)|0;c=v[22440];v[22440]=0;if((c|0)==1){break O}break Ga}break O}if(th(v[m>>2],v[m+4>>2])>>>0<=128){v[22440]=0;b=Q(1,e+160|0,9327)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break Ga}break O}v[22440]=0;b=Q(1,e+160|0,14889)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Fa}}Cb(a+1298368|0,b);rb(b);v[a+1298404>>2]=2;yz(E);BP(r);AP(I);j=1;break m}}}i=P()|0;O()|0;yz(E);break j}Sp(e+48|0);continue}}qt(m);fc(s);ml(q);Di(p);break c}i=P()|0;O()|0;break j}i=P()|0;O()|0}BP(r);AP(I);break a}i=P()|0;O()|0;rb(b);break a}i=P()|0;O()|0;break a}v[22440]=0;d=h&65535;h=Y(718,a|0,d|0,c|0)|0;g=v[22440];v[22440]=0;Ia:{Ja:{Ka:{La:{if((g|0)==1){break La}if(h){break Ia}v[22440]=0;h=ea(719,a|0,d|0,c|0,0,0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break La}if(h){break Ia}v[22440]=0;h=da(720,a|0,d|0,c|0,0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break La}if(h){break Ia}v[22440]=0;c=Q(721,(B(d,104)+a|0)+484380|0,c|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break La}if(c){break Ia}v[22440]=0;c=Q(1,e+56|0,16196)|0;h=v[22440];v[22440]=0;if((h|0)==1){break Ka}h=v[E>>2];v[22440]=0;U(388,h|0,2,c|0);h=v[22440];v[22440]=0;if((h|0)==1){break Ja}rb(c);break Ia}i=P()|0;O()|0;break e}i=P()|0;O()|0;break e}i=P()|0;O()|0;rb(c);break e}Ma:{Na:{Oa:{D=B(d,104)+a|0;if(w[D+484414|0]&64){if(Sh(a)){break Oa}}c=v[m>>2];if(th(c,v[m+4>>2])>>>0<=d>>>0){break Na}if(w[mm(c,d)+132|0]!=2){break Na}if(!Sh(a)){break Na}u[k>>1]=x[k>>1]+1;break Na}c=x[a+480190>>1]+1|0;u[a+480190>>1]=c;H=B(c&65535,104)+a|0;n=H+484380|0;f=D+484380|0;Pa:{if(!Sd(f)){break Pa}c=x[f+34>>1];if((f|0)==(n|0)|(zd(c)|0)!=2){break Pa}h=(f|0)==(n|0);if(!(Sd(n)?h:1)){break Pa}Sd(f);if((f|0)==(n|0)){d=v[f+20>>2]}else{d=nt(v[f>>2],Nm(c))}g=v[f+20>>2];if(!(g?d:0)){if(!h){kz(d)}break Pa}Qa:{Ra:{switch(Nm(x[f+34>>1])-1|0){case 1:c=d;h=g;i=v[f+20>>2];j=v[f>>2];while(1){if(j){u[c>>1]=x[i>>1];u[h>>1]=x[i+2>>1];i=i+4|0;h=h+2|0;c=c+2|0;j=j-1|0;continue}break};break Qa;case 0:break Ra;default:break Qa}}c=d;h=g;i=v[f+20>>2];j=v[f>>2];while(1){if(j){t[c|0]=w[i|0];t[h|0]=w[i+1|0];i=i+2|0;h=h+1|0;c=c+1|0;j=j-1|0;continue}break}}h=Sn(n,f);v[h+20>>2]=d;u[h+34>>1]=x[h+34>>1]&65471;d=Sn(f,f);v[d+20>>2]=g;u[d+34>>1]=x[d+34>>1]&65471;g=a+1298224|0;c=a+1074992|0;while(1){if((c|0)!=(g|0)){j=v[c+104>>2];if(!((j|0)!=(h|0)&(d|0)!=(j|0))){v[c+88>>2]=v[c+88>>2]&-65}c=c+872|0;continue}break}Ai(h,a);Ai(d,a)}v[22440]=0;c=Q(56,e+56|0,6323)|0;d=v[22440];v[22440]=0;if((d|0)==1){break Ma}pe(H+484423|0,c);rb(c);v[22440]=0;c=Q(56,e+56|0,6226)|0;d=v[22440];v[22440]=0;if((d|0)==1){break f}pe(D+484423|0,c);rb(c)}sb(e+160|0);_b(r);i=0;continue}break}i=P()|0;O()|0;break e}i=P()|0;O()|0}sb(e+160|0)}_b(r);break a}cb=e+432|0;return j|0}i=P()|0;O()|0}qt(m);fc(s);ml(q);Di(p);S(i|0);L()}function Ct(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,T=0,V=0,X=0,_=0,$=0,aa=0,ba=0,ca=0,fa=0,ha=0,ia=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Ba=0,Ca=0,Da=C(0),Ea=0,Fa=0,Ga=C(0),Ha=0;i=cb-208|0;cb=i;aa=Rb(a);q=i+176|0;t[q+26|0]=0;u[q+24>>1]=0;v[q+16>>2]=0;v[q+20>>2]=-1;v[q+8>>2]=-1;v[q+12>>2]=-1;v[q>>2]=0;v[q+4>>2]=0;K=v[d+16>>2];$=w[d+6|0];la=b+484360|0;if($>>>0>=qj(la)>>>0){$=w[b+484376|0]}E=xj(la,$);v[22440]=0;r=Q(596,i+144|0,b|0)|0;a=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{if((a|0)!=1){k=v[r+4>>2];v[22440]=0;I=Y(597,i+104|0,b|0,$|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break f}ha=c&7;a=x[d+4>>1];while(1){g=a&65535;if(Fc(v[E>>2],v[E+4>>2])>>>0<=g>>>0){break d}v[22440]=0;g=Q(318,E|0,g|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break e}if(g){break d}v[d>>2]=0;a=a+1|0;u[d+4>>1]=a;continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}g=v[d>>2];v[k+52>>2]=g;J=k+48|0;v[J>>2]=g;v[q+16>>2]=g;u[k+74>>1]=a;u[k+72>>1]=a;u[q+24>>1]=a;ma=i+96|0;ee(ma);pa=Rp(i+88|0);g:{if((ha|0)!=7){break g}el(el(el(el(el(el(el(el(ma,1),2),3),28),38),40),39),41);aN(aN(pa,12),13);if((K|0)!=2){break g}a=v[E>>2];e=Fc(a,v[E+4>>2]);g=x[d+12>>1];if(e>>>0<=g>>>0){break g}e=b+484344|0;a=x[Xb(a,g)>>1];if(!ve(e,a)){break g}g=Sb(e,a);e=v[d+8>>2];if(y[g+12>>2]<=e>>>0){break g}a=0;m=Zc(g,e,0);g=x[b+480188>>1];e=v[r+8>>2];p=b+480192|0;while(1){if((a|0)==(g|0)){break g}h:{i:{j:{k:{f=w[m|0];switch(f-253|0){case 1:case 2:break i;case 0:break k;default:break j}}if(x[p>>1]){break i}}if(!Rc(f)){break h}if(Rs(m)){break h}}Ea=Xe(e,a),Fa=-1,v[Ea>>2]=Fa}m=m+6|0;a=a+1|0;continue}}ba=c&1;if(ba){$M(k+223860|0)}V=k+74|0;wa=(K|0)!=3;X=k+80|0;xa=b+901692|0;ya=b+902204|0;za=k+44|0;ca=k+223860|0;fa=k+20|0;F=b+1074312|0;qa=k+616|0;N=b+484344|0;ia=32768;ra=A[d+8>>3];o(+ra);a=j(1)|0;Ba=j(0)|0;na=a;sa=(K|0)!=2;ka=b+480188|0;G=b+480180|0;ta=b+480192|0;Ca=(ha|0)!=7;p=0;l:{m:{n:{o:{p:{q:{r:while(1){g=na;while(1){_M(i+24|0,b,k,h&1);if(!(!(A[r+24>>3]>=ra)|wa)){break n}e=w[i+24|0];a=65535;f=v[E>>2];l=Fc(f,v[E+4>>2]);d=x[k+72>>1];if(l>>>0>d>>>0){a=x[Xb(f,d)>>1]}u[k+70>>1]=a;f=a&65535;if(!(ve(N,f)|(f|0)==65535|sa)&(d|0)==(g&65535)){break n}s:{t:{while(1){d=a&65535;if(Cf(N)>>>0>d>>>0){break s}a=x[k+72>>1];u:{v:{if((d|0)!=65535){f=v[E>>2];m=Fc(f,v[E+4>>2]);if(a>>>0<m>>>0){break v}}d=x[E+28>>1];if((a|0)==(d|0)){break s}f=v[E>>2];m=Fc(f,v[E+4>>2]);break u}d=a+1|0}u[k+72>>1]=d;a=65535;l=d&65535;if(l>>>0<m>>>0){a=x[Xb(f,l)>>1]}u[k+74>>1]=d;u[k+70>>1]=a;if(ve(N,a&65535)){continue}a=Bp(i+24|0,qa);v[22440]=0;a=ea(598,I|0,d&65535,0,a|0,(e|0)!=0|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){if(a){break t}a=x[k+70>>1];continue}break}a=P()|0;O()|0;break c}if(K>>>0<2){a=x[k+72>>1];v[q+8>>2]=0;u[q+20>>1]=a;if(!K){break s}}v[22440]=0;a=da(599,I|0,V|0,J|0,1)|0;d=v[22440];v[22440]=0;if((d|0)==1){break o}if(!a){break s}A[q>>3]=A[r+24>>3];v[22440]=0;R(600,aa|0,q|0);a=v[22440];v[22440]=0;if((a|0)==1){break o}v[q+16>>2]=v[J>>2];u[q+24>>1]=x[V>>1];v[22440]=0;Z(601,r|0);a=v[22440];v[22440]=0;if((a|0)==1){break o}a=x[k+74>>1];u[k+72>>1]=a;Ea=k,Fa=x[Xb(v[E>>2],a)>>1],u[Ea+70>>1]=Fa;v[k+52>>2]=v[k+48>>2]}if(x[V>>1]==65535){break m}a=x[k+70>>1];if(!ve(N,a)){a=x[k+72>>1];if((a|0)==x[E+28>>1]){if(!K){break m}v[22440]=0;a=da(599,I|0,V|0,J|0,1)|0;d=v[22440];v[22440]=0;if((d|0)==1){break o}if(!a){break m}A[q>>3]=A[r+24>>3];v[22440]=0;R(600,aa|0,q|0);a=v[22440];v[22440]=0;if((a|0)==1){break o}v[q+16>>2]=v[J>>2];u[q+24>>1]=x[V>>1];v[22440]=0;Z(601,r|0);a=v[22440];v[22440]=0;if((a|0)==1){break o}v[k+52>>2]=v[k+48>>2];continue}u[V>>1]=a+1;continue}d=v[J>>2];if(d>>>0>=y[Sb(N,a)+12>>2]){v[J>>2]=0;d=0}if(!(x[k+72>>1]!=(g&65535)|sa)&(d|0)==(Ba|0)){break n}a=0;if(!((K|0)==3|y[i+132>>2]<ia>>>0)){v[r+24>>2]=0;v[r+28>>2]=2146435072;ia=ia>>>(ia>>>0>256)|0;v[i+132>>2]=0;d=v[J>>2];a=1}f=x[k+72>>1];l=Bp(i+24|0,qa);v[22440]=0;d=ea(598,I|0,f|0,d|0,l|0,(e|0)!=0|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break q}if((a|d)==1){if(K>>>0<2){u[q+20>>1]=x[k+72>>1];v[q+8>>2]=v[k+48>>2];if(!K){break m}}v[22440]=0;a=da(599,I|0,V|0,J|0,1)|0;d=v[22440];v[22440]=0;if((d|0)==1){break p}if(!a){break m}A[q>>3]=A[r+24>>3];v[22440]=0;R(600,aa|0,q|0);a=v[22440];v[22440]=0;if((a|0)==1){break p}v[q+16>>2]=v[J>>2];u[q+24>>1]=x[V>>1];v[22440]=0;Z(601,r|0);a=v[22440];v[22440]=0;if((a|0)==1){break p}v[k+52>>2]=v[k+48>>2];continue}u[q+22>>1]=x[k+72>>1];v[q+12>>2]=v[k+48>>2];ZM(b,k,0);d=v[k+48>>2];f=x[k+70>>1];if(d>>>0>=y[Sb(N,f)+12>>2]){v[J>>2]=0;d=0}if(e){continue}break}a=0;d=Zc(Sb(N,f),d,0);ub(i+24|0,F,77);h=tb(v[v[i+24>>2]>>2],v[i+28>>2]);w:{while(1){m=x[ka>>1];if(m>>>0>a>>>0){x:{if(!(!My(d)&(!h|!(w[((a<<5)+b|0)+480281|0]&4)))){Rn((k+B(a,872)|0)+1404|0);break x}if(eh(w[d|0])){y:{if(!YM(ca)){break y}g=w[d+1|0];if(g-251>>>0<5|!g){break y}f=w[d+5|0];l=w[d+3|0];s=ek(w[d+2|0],w[d+4|0]);e=i+24|0;t[e|0]=g-1;v[e+4>>2]=s&65535;v[22440]=0;g=Q(602,ca+12|0,e|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break w}Ea=g,Ga=C(C(ek(l,f)>>>0)/C(999)),z[Ea>>2]=Ga}Rn((k+B(a,872)|0)+1404|0);break x}g=k+B(a,872)|0;e=g+1408|0;f=w[d+4|0]|w[d+5|0]<<8;t[e|0]=f;t[e+1|0]=f>>>8;g=g+1404|0;e=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[g|0]=e;t[g+1|0]=e>>>8;t[g+2|0]=e>>>16;t[g+3|0]=e>>>24;z:{switch(w[d+3|0]-16|0){case 0:Ly(b,k,w[d+5|0]);break x;case 1:ub(i+24|0,F,5);if(!tb(v[v[i+24>>2]>>2],v[i+28>>2])){break x}g=w[d+5|0];if(!g){break x}Ly(b,k,g);break x;case 4:g=w[d+5|0];e=g&240;if((e|0)!=224){if((e|0)!=96){break x}v[k+24>>2]=v[k+24>>2]+(g&15);break x}if(v[fa>>2]){break x}g=g&15;if(g?0:w[G|0]&2){break x}v[fa>>2]=g+1;break x;case 3:break z;default:break x}}g=w[d+5|0];if((g&240)!=224){break x}v[fa>>2]=(g&15)+1}d=d+6|0;a=a+1|0;continue}break}g=dl(k);v[i+24>>2]=1;a=v[Pc(fa,i+24|0)>>2];u[k+68>>1]=65535;v[k+60>>2]=-1;v[k+64>>2]=-1;T=g-1|0;a=g-a|0;oa=B(a,1e4);d=0;while(1){if((m&65535)>>>0<=d>>>0){if(v[G>>2]==4&v[k+40>>2]==65535){break m}v[k+32>>2]=v[b+480216>>2];a=x[k+70>>1];d=Sb(N,a);if(WM(v[d+16>>2],v[d+20>>2])){Ea=k,Fa=v[Sb(N,a)+16>>2],v[Ea+32>>2]=Fa}e=VM(b,k);a=B(e,g);A[r+24>>3]=A[r+24>>3]+ +(a>>>0)/+y[b+24620>>2];v[k>>2]=a+v[k>>2];A:{B:{if(Ca){break B}m=0;oa=(p|0)!=0&(e|0)!=(p|0);while(1){if(x[ka>>1]<=m>>>0){break B}H=Xe(v[r+8>>2],m);C:{if(v[H>>2]==-1){break C}n=k+B(m,872)|0;M=n+1404|0;_=v[n+1316>>2];if(!_){if(My(M)){break C}}l=n+1409|0;D=1;D:{E:{T=n+1407|0;h=w[T|0];switch(h-4|0){case 0:case 2:break D;default:break E}}D=w[n+1406|0]==11}a=w[l|0];if(w[n+1405|0]){v[n+1276>>2]=0}f=n+616|0;d=a&15;s=0;F:{G:{H:{if(!Rc(w[M|0])){break H}if(!(!D|!w[H+4|0])){Ky(i+24|0,b,f,_,0);h=v[i+28>>2];v[n+624>>2]=v[i+24>>2];v[n+628>>2]=h}t[n+1418|0]=w[n+1415|0];H=n+1308|0;_=v[H>>2];h=w[n+1419|0];if(h){Ap(b,f,h,D,1,1)}h=w[M|0];v[22440]=0;ja(603,b|0,f|0,h|0,D|0,1,0,65535);h=v[22440];v[22440]=0;if((h|0)==1){break G}a=a>>>4|0;UM(b,k,m&65535);ua=Xe(v[r+8>>2],m);t[ua+4|0]=1;h=w[T|0];I:{if(!((w[l|0]&240)!=208|(h-19&255)>>>0>1)){s=d;if(d>>>0<g>>>0){break I}}s=(h|0)==33?a>>>0<g>>>0?a:0:0}va=v[fa>>2];if(!(!(v[G>>2]&16777250)|(!s|va>>>0<2))){s=B(va-1|0,v[k+24>>2]+v[k+40>>2]|0)+s|0}if(!D){v[ua>>2]=0}J:{if((h|0)==9){break J}K:{if((h|0)!=19){if((h|0)!=20|(a|0)!=8){break K}break J}if((a|0)==8){break J}}if(w[n+1406|0]!=2){break H}}v[H>>2]=_}L:{if(!Rc(w[M|0])){ub(i+24|0,F,114);if(!tb(v[v[i+24>>2]>>2],v[i+28>>2])){break L}h=w[T|0]}M:{N:{O:{P:{a=h&255;switch(a-42|0){case 1:break M;case 0:break N;case 2:break O;default:break P}}if((a|0)!=10){break M}a=x[k+70>>1];h=v[k+48>>2];v[22440]=0;ga(604,b|0,f|0,m&65535,h|0,a|0);a=v[22440];v[22440]=0;if((a|0)!=1){break L}break A}H=kka(w[l|0],0,v[n+692>>2],0);h=fb;a=h>>>8|0;Gn(b,f,wc((h&255)<<24|H>>>8,a));break L}if(!v[n+720>>2]){break M}v[22440]=0;W(605,r|0,m&65535,p|0,-1);a=v[22440];v[22440]=0;if((a|0)==1){break A}SM(f,w[l|0]);s=v[k+40>>2]-1|0;break L}if(w[n+1406|0]!=15){break L}h=v[n+720>>2];if(!h){break L}a=w[n+1408|0];if(a>>>0>9){break L}Q:{if(!a){h=v[n+1280>>2];break Q}h=v[Ib(h+68|0,a-1|0)>>2];v[n+1280>>2]=h}Gn(b,f,h)}R:{S:{T:{switch(w[M|0]-253|0){case 0:if(x[ta>>1]){break S}break;case 1:case 2:break S;default:break T}}a=w[T|0];if(!((w[l|0]&240)!=192|(a-19&255)>>>0>1)&d>>>0<g>>>0){break S}h=0;if((a|0)==33&(d|0)!=0&g>>>0>d+s>>>0){break S}if((a|0)!=25){break R}}a=w[T|0];h=1}H=n+1304|0;U:{if((a|0)!=13){if(w[n+1406|0]!=1){break U}d=n+1408|0}else{d=l}v[H>>2]=w[d|0]<<2}V:{if(!(!v[n+720>>2]|h)){h=0;W:{X:{Y:{if(a>>>0>45){break Y}ub(i+24|0,ma,a);if(tb(v[v[i+24>>2]>>2],v[i+28>>2])){break X}if(w[T|0]!=19){break Y}a=w[l|0]&240;h=(a|0)==16|(a|0)==32}a=w[n+1406|0];if(a>>>0<16){break W}if(h){break V}break F}h=1;a=w[n+1406|0];if(a>>>0>=16){break V}}Cc(i+24|0,pa,a);a=tb(v[v[i+24>>2]>>2],v[i+28>>2]);if(h){break V}if(!a){break F}break V}if(!h){break F}}IO(f);Ea=Xe(v[r+8>>2],m),Fa=0,v[Ea>>2]=Fa;break C}a=P()|0;O()|0;break c}if(oa){v[22440]=0;W(605,r|0,m&65535,p|0,-1);a=v[22440];v[22440]=0;if((a|0)==1){break A}}Z:{_:{$:{aa:{ba:{a=w[T|0];if(a-6>>>0>=2){ca:{switch(a-19|0){case 1:break aa;case 0:break ba;default:break ca}}if(a-35>>>0<2){break _}if((a|0)==45){break $}if((a|0)!=11){break Z}}if(!w[l|0]&v[G>>2]==1){break Z}a=n+1467|0;d=0;while(1){if((d|0)==(g|0)){break Z}t[a|0]=!d|w[a|0]&254;Fn(b,f,w[l|0]);d=d+1|0;continue}}d=w[l|0];a=d&15;if(!(v[G>>2]&1048580?1:a)){break Z}h=n+1467|0;t[h|0]=w[h|0]|1;d=d&240;if((d|0)!=176){if((d|0)!=160){break Z}En(b,f,a,0);break Z}Dn(b,f,a,0);break Z}da:{ea:{fa:{a=w[l|0];switch(a-158|0){case 1:break ea;case 0:break fa;default:break da}}v[22440]=0;W(605,r|0,m&65535,p|0,-1);a=v[22440];v[22440]=0;if((a|0)==1){break A}v[n+704>>2]=v[n+704>>2]&-129;break Z}v[22440]=0;W(605,r|0,m&65535,p|0,-1);a=v[22440];v[22440]=0;if((a|0)==1){break A}a=v[n+704>>2];v[n+704>>2]=a|128;if(v[f+4>>2]){break Z}d=v[n+692>>2];if(!d){break Z}if(!(Ea=Rc(w[M|0]),Fa=1,Ha=a&2,Ha?Ea:Fa)){break Z}v[f>>2]=-1;v[f+4>>2]=d-1;break Z}if((a&240)!=112|a>>>0<115){break Z}FO(f,a,b);break Z}RM(f,w[l|0]);break Z}v[22440]=0;a=m&65535;W(605,r|0,a|0,p|0,-1);d=v[22440];v[22440]=0;if((d|0)==1){break A}QM(b,a,k,0)}d=n+1467|0;a=w[d|0]|1;t[d|0]=a;ga:{ha:{ia:{ja:{ka:{l=n+1406|0;switch(w[l|0]-3|0){case 11:break ha;case 0:case 1:break ia;case 3:break ja;case 2:break ka;default:break ga}}a=w[n+1408|0];ub(i+24|0,F,41);En(b,f,a,tb(v[v[i+24>>2]>>2],v[i+28>>2]));break ga}a=w[n+1408|0];ub(i+24|0,F,41);Dn(b,f,a,tb(v[v[i+24>>2]>>2],v[i+28>>2]));break ga}h=w[n+1408|0];la:{if(h){break la}ub(i+24|0,F,41);h=0;if(!tb(v[v[i+24>>2]>>2],v[i+28>>2])){break la}h=w[n+1450|0];if(!h){break ga}}h=w[l|0]==3?h<<4:h;a=0;while(1){if((a|0)==(g|0)){break ga}t[d|0]=!a|w[d|0]&254;Fn(b,f,h&255);a=a+1|0;continue}}h=w[n+1408|0];if(h>>>0>1){break ga}t[d|0]=a&247|!h<<3}if(w[d|0]&8){break C}if(D){d=Xe(v[r+8>>2],m);a=v[d>>2];v[d>>2]=a+g;v[22440]=0;W(605,r|0,m&65535,e|0,(a+s|0)+1|0);a=v[22440];v[22440]=0;if((a|0)!=1){break C}a=P()|0;O()|0;break c}a=Xe(v[r+8>>2],m);v[a>>2]=v[a>>2]+(g-s|0)}m=m+1|0;continue}}h=PM(b,k,E,0);p=e;continue r}a=P()|0;O()|0;break c}l=k+B(d,872)|0;m=l+1404|0;ma:{if(My(m)){break ma}s=l+616|0;M=l+1409|0;f=w[M|0];H=l+1407|0;n=w[H|0];na:{oa:{if(!ba){break oa}e=w[m|0];D=w[l+1405|0];if(D){t[l+1415|0]=0;t[l+1419|0]=D;Ea=Xe(v[r+8>>2],d),Fa=255,t[Ea+5|0]=Fa;h=w[m|0]}else{h=e}pa:{qa:{if(Rc(h)){t[l+1415|0]=e;break qa}if(!D){break pa}}_=l+1419|0;D=w[_|0];ra:{if(!D){D=0;break ra}if(x[ta>>1]<D>>>0){break ra}h=v[((D<<2)+b|0)+900380>>2];if(!h|!(t[h+15|0]&1)){break ra}Mp(s,v[h+8>>2],b);D=w[_|0]}e=dq(b,e,D);if(!e){break pa}e=B(e,104)+b|0;if(!(w[e+484414|0]&32)){break pa}Mp(s,x[e+484408>>1],b)}sa:{ta:{ua:{e=w[l+1406|0];switch(e-1|0){case 1:break oa;case 2:case 3:break ta;case 0:break ua;default:break sa}}Ea=Xe(v[r+8>>2],d),Fa=w[l+1408|0],t[Ea+5|0]=Fa;break oa}e=w[l+1408|0];if(!e){break oa}t[l+1450|0]=e;break oa}if(!w[l+1408|0]|(e|0)!=11){break oa}e=i+24|0;Jy(e,b,m,0);u[l+1384>>1]=x[e>>1];if(w[Oe(e)|0]){break na}}va:{wa:{switch(n-12|0){case 0:OM(b,k,d&65535);break va;case 2:e=NM(b,k,d&65535,f);if((e|0)==-1){break va}v[k+60>>2]=e;break va;case 5:ub(i+24|0,F,5);if(tb(v[v[i+24>>2]>>2],v[i+28>>2])){break va}m=B(Cn(b,x[k+70>>1],v[k+48>>2],d&65535,0),1e4);xa:{if(!ba|!(v[G>>2]&16777250)){break xa}if(m>>>0>=1e4){t[l+1451|0]=(m>>>0)/1e4;break xa}m=B(w[l+1451|0],1e4)}h=(m>>>0)/1e4|0;ya:{if(m>>>0>319999){break ya}m=B(oa,h&15);e=v[k+44>>2];if((h&240)==16){m=e+m|0;break ya}h=e-m|0;m=e>>>0<h>>>0?0:h}v[k+44>>2]=m;e=v[b+8>>2];h=v[e+20>>2];e=v[e+24>>2];ub(i+24|0,F,8);xo(za,B(h,1e4),tb(v[v[i+24>>2]>>2],v[i+28>>2])?255e4:B(e,1e4));break va;case 8:za:{switch((f&240)-144>>>4|0){case 0:if(f>>>0>145){break va}v[l+704>>2]=v[l+704>>2]&-257|((f|0)==145)<<8;break va;case 1:t[l+1452|0]=f&15;break va;case 2:Ps(b,k,s,f&15);break va;case 6:break za;default:break va}}t[l+1460|0]=f&15;break va;case 7:e=f&240;if((e|0)!=240){if((e|0)!=96){break va}Ps(b,k,s,f&15);break va}t[l+1460|0]=f&15;break va;case 1:case 3:case 4:case 6:break va;default:break wa}}if((n|0)!=28|(f&240)!=160){break va}ub(i+24|0,F,58);if(tb(v[v[i+24>>2]>>2],v[i+28>>2])){break va}t[l+1452|0]=f&15}if(!ba){break ma}Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{switch(n-2|0){case 0:if(!f){break na}ub(i+24|0,F,90);if(!tb(v[v[i+24>>2]>>2],v[i+28>>2])){t[l+1428|0]=f}t[l+1427|0]=f;break na;case 1:if(!f){break na}ub(i+24|0,F,90);if(!tb(v[v[i+24>>2]>>2],v[i+28>>2])){t[l+1427|0]=f}t[l+1428|0]=f;break na;case 2:if(!f){break na}u[l+1384>>1]=f;break na;case 8:if(!f){break na}v[l+1280>>2]=f<<8;break na;case 4:case 9:if(!f){break na}t[l+1425|0]=f;break na;case 11:Ea=Xe(v[r+8>>2],d),Fa=f,t[Ea+5|0]=Fa;break na;case 21:e=v[G>>2];h=f<<(!(e&59593760)&f<<24>>24>=0)&255;if(h>>>0<=128){v[X>>2]=h<<1;break na}if(e&16777250){break na}v[X>>2]=256;break na;case 22:ub(i+24|0,F,9);Ia:{if(tb(v[v[i+24>>2]>>2],v[i+28>>2])){e=l+1433|0;if(f){t[e|0]=f;break Ia}f=w[e|0];break Ia}if(f){t[k+1433|0]=f;break Ia}f=w[k+1433|0]}e=f&240;h=f&15;Ja:{if(!(!e|(h|0)!=15)){m=v[X>>2]+(e>>>4<<!(v[G>>2]&59593760)<<1)|0;break Ja}m=v[X>>2]-(h<<(v[G>>2]&59593760?1:2))|0;if(!(!h|(e|0)!=240)){break Ja}m=v[X>>2]+B(a,(f>>>3&30)<<!(v[G>>2]&59593760))|0;if(e){break Ja}m=v[X>>2]-B(a,h<<(v[G>>2]&59593760?1:2))|0}v[X>>2]=m;oe(X,0,256);break na;case 19:if(f>>>0>64){break na}v[l+1364>>2]=f;break na;case 20:e=l+1432|0;Ka:{if(f){t[e|0]=f;break Ka}f=w[e|0]}m=f&255;n=l+1364|0;e=v[n>>2];D=f&240;h=f&15;La:{if(!(!D|(h|0)!=15)){v[i+24>>2]=e+(m>>>4|0);break La}if(!(!h|(D|0)!=240)){v[i+24>>2]=e-h;break La}if(h){v[i+24>>2]=e-B(a,h);break La}v[i+24>>2]=e+B(a,m>>>4|0)}oe(i+24|0,0,64);v[n>>2]=v[i+24>>2];break na;case 7:im(b,s,f,8);break na;case 29:case 30:break Aa;case 25:break Ba;case 6:break Ca;case 24:break Da;case 3:break Ea;case 5:break Fa;case 18:break Ga;case 17:break Ha;default:break na}}if(f>>>0>15){break Ga}e=(f&1)<<14;h=x[ka>>1];m=0;while(1){if((h|0)==(m|0)){break Ga}n=k+B(m,872)|0;v[n+704>>2]=(e|v[n+704>>2]&-16385)^16384;m=m+1|0;continue}}if((f&240)!=128){break na}im(b,s,f&15,4);break na}if(f){t[l+1425|0]=f}f=0}cl(s,f);break na}MM(b,s,f);break na}LM(s,f);break na}KM(s,f);break na}if(f<<24>>24>=0){e=w[l+1460|0];h=w[M|0];v[22440]=0;ja(606,b|0,k|0,d&65535,0,we(xa,e)|0,h|0,0);e=v[22440];v[22440]=0;if((e|0)!=1){break na}break l}e=w[M|0];v[22440]=0;ja(606,b|0,k|0,d&65535,0,we(ya,f&127)|0,e|0,0);e=v[22440];v[22440]=0;if((e|0)==1){break l}}Ma:{Na:{switch(w[l+1406|0]-2|0){case 0:im(b,s,w[l+1408|0],6);break Ma;case 5:ub(i+24|0,F,53);e=w[l+1408|0];if(tb(v[v[i+24>>2]>>2],v[i+28>>2])){t[l+1439|0]=e&15;break Ma}cl(s,e<<4);break Ma;case 6:break Na;default:break Ma}}cl(s,w[l+1408|0])}Oa:{Pa:{Qa:{Ra:{e=w[H|0];switch(e-5|0){case 1:break ma;case 3:break Pa;case 0:case 2:break Qa;default:break Ra}}switch(e-26|0){case 1:break Oa;case 0:break Qa;default:break ma}}Sa:{if(v[G>>2]&16777248){e=g;if(!(w[b+480208|0]&4)){break Sa}}e=a}h=w[l+1439|0];ub(i+24|0,F,21);f=l+1435|0;l=w[f|0];e=B(e,h);Ea=f,Fa=(tb(v[v[i+24>>2]>>2],v[i+28>>2])?e<<2:e)+l|0,t[Ea|0]=Fa;break ma}Ta:{if(v[G>>2]&16777248){e=g;if(!(w[b+480208|0]&4)){break Ta}}e=a}h=w[l+1442|0];ub(i+24|0,F,21);f=l+1436|0;l=w[f|0];e=B(e,h);Ea=f,Fa=(tb(v[v[i+24>>2]>>2],v[i+28>>2])?e<<2:e)+l|0,t[Ea|0]=Fa;break ma}e=l+1437|0;t[e|0]=w[e|0]+B(T,w[l+1445|0]);IM(b,s)}d=d+1|0;m=x[ka>>1];continue}}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}t[q+26|0]=1}Ua:{if((ha|0)!=7){break Ua}a=0;d=b+480188|0;while(1){if(x[d>>1]<=a>>>0){break Ua}Va:{if(v[Xe(v[r+8>>2],a)>>2]==-1){break Va}v[22440]=0;W(605,r|0,a&65535,p|0,-1);g=v[22440];v[22440]=0;if((g|0)!=1){break Va}a=P()|0;O()|0;break c}a=a+1|0;continue}}if(w[q+26|0]){u[q+20>>1]=x[k+72>>1];v[q+8>>2]=v[k+48>>2]}A[q>>3]=A[r+24>>3];v[22440]=0;R(600,aa|0,q|0);a=v[22440];v[22440]=0;Wa:{Xa:{Ya:{if((a|0)!=1){if(!ba){break Wa}if(!(K?w[q+26|0]:1)){break Ya}e=i+56|0;a=e;uM(a);if(Ed(w[ca+24|0])){xM(a,ca)}Iy(ca);a=ic(b+1074376|0,k,614);d=0;while(1){if((d|0)==256){xm(a+223848|0,k+223848|0);d=a+223860|0;p=w[d+24|0];g=k+223860|0;Za:{if((Ed(w[g+24|0])|0)==(p|0)){if(!p){break Za}p=bc(d);Ls(d,v[p>>2]);v[d>>2]=v[g>>2];v[d+4>>2]=v[g+4>>2];v[d+8>>2]=v[g+8>>2];_a:{if(!v[xb(d)>>2]){v[d>>2]=p;break _a}v[v[p>>2]+8>>2]=p;p=bc(g);v[g>>2]=p;v[p>>2]=0;Ea=xb(g),Fa=0,v[Ea>>2]=Fa}d=d+12|0;p=bc(d);Ks(d,v[p>>2]);g=g+12|0;v[d>>2]=v[g>>2];v[d+4>>2]=v[g+4>>2];v[d+8>>2]=v[g+8>>2];$a:{if(!v[xb(d)>>2]){v[d>>2]=p;break $a}v[v[p>>2]+8>>2]=p;d=bc(g);v[g>>2]=d;v[d>>2]=0;Ea=xb(g),Fa=0,v[Ea>>2]=Fa}break Za}if(p){Iy(d);break Za}xM(d,g)}}else{g=B(d,872);wp((g+a|0)+616|0,(g+k|0)+616|0);d=d+1|0;continue}break}Hy(a);a=0;v[b+1074400>>2]=0;t[b+1074476|0]=1;d=b+1074392|0;v[d>>2]=-2;v[d+4>>2]=0;v[b+1074428>>2]=v[b+1074424>>2];ab:{bb:{d=b+1298300|0;if(!Bd(d)){break bb}g=v[d>>2];v[22440]=0;Z(607,g|0);g=v[22440];v[22440]=0;if((g|0)!=1){break bb}break ab}while(1){if(x[b+480188>>1]<=a>>>0){a=Mz(i+24|0);d=e+12|0;Ea=i,Fa=qk(d),v[Ea+16>>2]=Fa;Ea=i,Fa=Af(d),v[Ea+8>>2]=Fa;while(1){if(!ih(i+16|0,i+8|0)){cb:{f=250;d=a;db:{while(1){if(f>>>0>=32){if(v[a>>2]){a=1;break db}else{f=f-32|0;a=a+4|0;continue}}break}a=(v[d+28>>2]&67108863)!=0}if(!a){break cb}a=0;while(1){if((a|0)==250){break cb}ub(i,d,a);eb:{if(!tb(v[v[i>>2]>>2],v[i+4>>2])){break eb}g=v[(B(a,160)+b|0)+906300>>2];p=v[v[g>>2]+176>>2];v[22440]=0;Z(p|0,g|0);g=v[22440];v[22440]=0;if((g|0)!=1){break eb}break ab}a=a+1|0;continue}}Ea=i,Fa=qk(e),v[Ea>>2]=Fa;Ea=i,Fa=Af(e),v[Ea+16>>2]=Fa;while(1)if(ih(i,i+16|0)){a=od(i);Ea=(B(w[a|0],160)+b|0)+906444|0,Ga=z[bc(a)>>2],z[Ea>>2]=Ga;mk(i);continue}else{yp(e);break Xa}}g=od(i+16|0);h=xb(g);fb:{p=w[g|0];d=v[(B(p,160)+b|0)+906300>>2];if(d){ub(i,a,p);if(!tb(v[v[i>>2]>>2],v[i+4>>2])){v[22440]=0;Q(608,a|0,p|0)|0;p=v[22440];v[22440]=0;if((p|0)==1){break fb}p=v[v[d>>2]+172>>2];v[22440]=0;R(p|0,d|0,-1);p=v[22440];v[22440]=0;if((p|0)==1){break fb}}Da=z[h>>2];g=v[g+4>>2];p=v[v[d>>2]+44>>2];v[22440]=0;Aa(p|0,d|0,g|0,C(Da));d=v[22440];v[22440]=0;if((d|0)==1){break fb}}mk(i+16|0);continue}break}break ab}g=B(a,872)+b|0;p=w[g+1075791|0];if(p){t[g+1075794|0]=p}g=Xe(v[r+8>>2],a);if(!((ha|0)==7|w[g+5|0]==255)){t[i+24|0]=64;Ea=(B(a,872)+b|0)+1075680|0,Fa=w[Tb(g+5|0,i+24|0)|0]<<2,v[Ea>>2]=Fa}gb:{p=B(a,872)+b|0;g=v[p+1075096>>2];hb:{if(!g|!(w[g+35|0]&2)){break hb}if(!Bd(d)){break hb}h=v[d>>2];v[22440]=0;na=h;h=a&65535;U(609,na|0,h|0,g+68|0);g=v[22440];v[22440]=0;if((g|0)==1){break gb}g=v[d>>2];v[22440]=0;U(610,g|0,h|0,1);g=v[22440];v[22440]=0;if((g|0)==1){break gb}}v[p+1075008>>2]=0;a=a+1|0;continue}break}}a=P()|0;O()|0;yp(e);break c}a=P()|0;O()|0;break c}if((c|0)==3){break Xa}v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+1074456>>2]=v[b+480200>>2]}if(w[b+484376|0]==($|0)){break Wa}Hi(la,$)}if(c&9){a=b+1298264|0;if(v[a>>2]){IN(a);b=v[a>>2];Ek(a);zb(b);Ea=xb(a),Fa=0,v[Ea>>2]=Fa;v[a>>2]=0;v[a+4>>2]=0}v[a>>2]=v[I>>2];v[a+4>>2]=v[I+4>>2];b=xb(I);Ea=xb(a),Fa=v[b>>2],v[Ea>>2]=Fa;v[b>>2]=0;v[I>>2]=0;v[I+4>>2]=0;a=a+12|0;c=bc(a);Fp(a,v[c>>2]);b=I+12|0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];ib:{if(!v[xb(a)>>2]){v[a>>2]=c;break ib}v[v[c>>2]+8>>2]=c;a=bc(b);v[b>>2]=a;v[a>>2]=0;Ea=xb(b),Fa=0,v[Ea>>2]=Fa}}xp(i+104|0);HM(r);cb=i+208|0;return}a=P()|0;O()|0}xp(i+104|0)}HM(r)}Di(aa);S(a|0);L()}function Vfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0;d=cb-1728|0;cb=d;sc(b);h=cb-16|0;cb=h;i=d+1600|0;aR(h+8|0,i);n=b;b=v[h+12>>2];Yb(h,n,v[h+8>>2],b);l=v[h+4>>2];if((l|0)==(b|0)){Ob(n,v[h+12>>2])}cb=h+16|0;b=(b|0)==(l|0);if(!b){$Q(i)}a:{if(!b){break a}if(!bR(d+1600|0)){break a}if(!Kb(n,wc(256,0))){break a}b:{if(!c){break b}ud(a,1048576);eg(a);b=cb-16|0;cb=b;e=jc(b,4233);zc(d+1344|0,e);rb(e);cb=b+16|0;r=d+1608|0;b=w[r|0]|w[r+1|0]<<8;v[d+160>>2]=b>>>8;v[22440]=0;v[d+16>>2]=b&255;R(445,d+88|0,d+16|0);b=v[22440];v[22440]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((b|0)!=1){v[22440]=0;W(431,d+240|0,d+1344|0,d+160|0,d+88|0);b=v[22440];v[22440]=0;if((b|0)==1){break m}b=d+240|0;Cb(a+1298344|0,b);rb(b);h=d+88|0;rb(h);e=d+1344|0;Ab(e);i=jc(b,15215);Cb(a+1298356|0,i);rb(i);Ie(h,2,d+1610|0);xc(e,v[d+88>>2],v[d+92>>2],w[d+96|0]);v[22440]=0;U(11,b|0,8,e|0);b=v[22440];v[22440]=0;if((b|0)==1){break i}b=d+240|0;Cb(a+1298368|0,b);rb(b);e=d+1344|0;rb(e);v[a+1298404>>2]=8;Nz(e,2,d+1642|0);xc(b,v[d+1344>>2],v[d+1348>>2],w[d+1352|0]);tc(a+1298308|0,b);rb(b);h=d+1712|0;u[a+480188>>1]=w[h|0]|w[h+1|0]<<8;h=w[d+1716|0];v[a+480204>>2]=125e4;v[a+480208>>2]=32792;V=a,X=wd(h,1,31),v[V+480196>>2]=X;F=d+1722|0;u[a+480192>>1]=w[F|0]|w[F+1|0]<<8;A=d+1724|0;u[a+480190>>1]=w[A|0]|w[A+1|0]<<8;h=wd(w[d+1717|0],1,32);v[a+480216>>2]=h;v[a+480228>>2]=96;v[a+480232>>2]=48;v[a+480220>>2]=h<<2;Ou(n,e);C=a+484360|0;G=d+1706|0;zq(Nb(C),e,w[G|0]|w[G+1|0]<<8,65535,65535);e=d+1708|0;Qe(Nb(C),w[e|0]|w[e+1|0]<<8);D=Sg(n);Td(b,n,D?274:0);I=cc(d+1320|0,b);sb(b);v[22440]=0;b=T(159,n|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break k}v[22440]=0;U(192,d+240|0,n|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break k}b=d+240|0;H=cc(d+1296|0,b);sb(b);b=a+480188|0;i=x[b>>1];if(D){u[b>>1]=i+8}E=c&1;if(!E){break j}b=d+1710|0;b=w[b|0]|w[b+1|0]<<8;v[22440]=0;R(228,a+484344|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break j}f=P()|0;O()|0;break e}f=P()|0;O()|0;break l}f=P()|0;O()|0;rb(d+88|0)}Ab(d+1344|0);break c}f=P()|0;O()|0;break d}o=a+484344|0;l=d+1718|0;q=d+1710|0;K=a+480188|0;while(1){n:{o:{p:{q:{r:{s:{if((w[q|0]|w[q+1|0]<<8)>>>0<=z>>>0){b=d+1714|0;b=w[b|0]|w[b+1|0]<<8;if((b-2&65535)>>>0>=4998){break q}if(!(f&1)){break s}g=0;b=yc(((b>>>1|0)+11025e5>>>0)/(b>>>0)|0,0);break r}v[22440]=0;b=T(196,n|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break f}v[d+160>>2]=b;v[22440]=0;b=T(159,n|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break g}v[22440]=0;U(192,d+88|0,n|0,b+1&-2);b=v[22440];v[22440]=0;if((b|0)==1){break g}b=d+88|0;m=cc(d+240|0,b);sb(b);qc(d+160|0,1024);if(!E){break o}s=v[d+160>>2];if(!s){break o}v[22440]=0;b=Y(229,o|0,z&65535,s|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){if(!b){break o}k=0;e=0;if(t[l|0]&1){break p}t:while(1){if((k|0)==(s|0)){break o}e=0;b=Gf(Sb(o,z),k);while(1){if((e|0)==(i|0)){k=k+1|0;continue t}v[22440]=0;R(617,m|0,d+88|0);h=v[22440];v[22440]=0;if((h|0)!=1){f=_Q(b+B(e,6)|0,d+88|0)|f;e=e+1|0;continue}break}break}break h}break h}g=2;b=Le(2646e3/+(B(b,B(v[a+480216>>2],v[a+480196>>2]))>>>0)*1e4)}t[a+480224|0]=g;v[a+480204>>2]=b}k=a+480188|0;b=x[k>>1];v[22440]=0;t[d+240|0]=0;z=Y(618,d+1280|0,b|0,d+240|0)|0;b=v[22440];v[22440]=0;u:{v:{if((b|0)!=1){m=a+1298320|0;s=a+1298332|0;p=d+240|3;h=0;w:{x:{y:{z:{A:{while(1){v[22440]=0;b=Q(158,H|0,8)|0;e=v[22440];v[22440]=0;B:{if((e|0)!=1){if(b){break B}g=0;k=a+480188|0;while(1){e=x[k>>1];if(e>>>0<=g>>>0){C:{v[d+232>>2]=0;v[d+236>>2]=0;v[d+224>>2]=0;v[d+228>>2]=0;v[d+216>>2]=0;v[d+220>>2]=0;v[d+208>>2]=0;v[d+212>>2]=0;if(D){break C}break v}}else{b=t[Eb(v[z>>2],g)|0];D:{if((b|0)<=(g|0)|(b|0)>=(e|0)){break D}f=w[((b<<5)+a|0)+480288|0];if(!f){break D}b=((g<<5)+a|0)+480288|0;e=w[b|0];if(!e){t[b|0]=f;break D}e=e-1|0;while(1){b=(B(e&255,160)+a|0)+906300|0;e=Mm(b);if((e|0)!=255){continue}break}b=b+28|0;e=f-1&255;e=e>>>0<250?e+128|0:0;t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24}g=g+1|0;continue}break}v[22440]=0;R(619,I|0,d+240|0);b=v[22440];v[22440]=0;if((b|0)!=1){e=0;while(1){if((e|0)==8){b=w[d+240|0]|w[d+241|0]<<8;v[22440]=0;m=Q(221,d+16|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){e=0;E:{F:{G:{H:{while(1){if((w[d+240|0]|w[d+241|0]<<8)>>>0<=e>>>0){b=w[q|0]|w[q+1|0]<<8;v[22440]=0;s=Y(620,d+88|0,b|0,27036)|0;b=v[22440];v[22440]=0;if((b|0)==1){break F}D=a+480188|0;k=0;break G}v[22440]=0;b=T(196,n|0)|0;f=v[22440];v[22440]=0;if((f|0)!=1){v[22440]=0;U(192,d+160|0,n|0,b<<5);b=v[22440];v[22440]=0;if((b|0)==1){break H}b=d+88|0;f=d+160|0;g=cc(b,f);Sc(Ng(v[m>>2],e),g);e=e+1|0;sb(b);sb(f);continue}break}f=P()|0;O()|0;break E}f=P()|0;O()|0;break E}while(1){if((w[G|0]|w[G+1|0]<<8)>>>0<=k>>>0){_c(s);Ic(m);break v}I:{f=d+k|0;e=w[f+258|0];if(e>>>0>=(w[d+240|0]|w[d+241|0]<<8)>>>0){break I}if(x[Xb(v[Nb(C)>>2],k)>>1]>=(w[q|0]|w[q+1|0]<<8)>>>0){break I}J:{g=v[s>>2];b=x[Xb(v[Nb(C)>>2],k)>>1];g=Xb(g,b);p=x[g>>1];K:{if((p|0)==65535){u[g>>1]=e;break K}if((e|0)==(p|0)){break K}v[22440]=0;e=Y(621,o|0,b|0,0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break J}if((e|0)==65535){break K}V=Xb(v[Nb(C)>>2],k),X=e,u[V>>1]=X;b=e}if(!ve(o,b)){break I}j=Ng(v[m>>2],w[f+258|0]);sc(j);v[22440]=0;e=T(162,j|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break J}E=e>>>5|0;g=0;L:while(1){if(y[Sb(o,b)+12>>2]<=g>>>0){break I}f=0;e=Zc(Sb(o,b),g,x[D>>1]-8&65535);while(1){if((f|0)==8){g=g+1|0;continue L}Ej(d+160|0);p=x[d+164>>1];t[e+4|0]=p;t[e+5|0]=p>>>8;p=v[d+160>>2];t[e|0]=p;t[e+1|0]=p>>>8;t[e+2|0]=p>>>16;t[e+3|0]=p>>>24;M:{if(g>>>0>=E>>>0){break M}v[22440]=0;Q(622,j|0,d+160|0)|0;p=v[22440];v[22440]=0;if((p|0)==1){break J}if(t[d+160|0]>=0){break M}t[e|0]=61;t[e+1|0]=w[(d+224|0)+(f<<1)|0];p=w[d+160|0]&31;t[d+64|0]=p;if(p){yf(d- -64|0,15);t[e+3|0]=20;t[e+5|0]=w[d+64|0]|208}t[e+2|0]=1;t[e+4|0]=w[d+161|0]+3>>>2}e=e+6|0;f=f+1|0;continue}}}f=P()|0;O()|0;_c(s);break E}k=k+1|0;continue}}f=P()|0;O()|0}Ic(m);break u}f=P()|0;O()|0;break u}f=e<<1;g=f+(d+224|0)|0;b=x[a+480192>>1]+1&65535;k=x[v[a+8>>2]+58>>1];while(1){N:{O:{m=b&65535;if(m>>>0<=k>>>0){if(v[((m<<2)+a|0)+900380>>2]){break O}}else{b=65535}b=b&65535;break N}b=b+1|0;continue}break}u[g>>1]=b;j=f+(d+208|0)|0;f=d+f|0;f=w[f+242|0]|w[f+243|0]<<8;u[j>>1]=f;P:{if((b|0)!=65535){v[22440]=0;b=Y(257,a|0,b|0,f+1&65535)|0;f=v[22440];v[22440]=0;Q:{R:{if((f|0)!=1){if(!b){break P}v[22440]=0;R(293,d+160|0,4478);f=v[22440];v[22440]=0;if((f|0)==1){break R}v[22440]=0;v[d+16>>2]=e+1;U(623,d+88|0,d+160|0,d+16|0);f=v[22440];v[22440]=0;if((f|0)==1){break Q}f=b+492|0;b=d+88|0;uc(f,b);rb(b);Ab(d+160|0);break P}f=P()|0;O()|0;break u}f=P()|0;O()|0;break u}f=P()|0;O()|0;Ab(d+160|0);break u}u[g>>1]=0}e=e+1|0;continue}}f=P()|0;O()|0;break u}f=P()|0;O()|0;break u}v[22440]=0;g=T(159,H|0)|0;b=v[22440];v[22440]=0;S:{T:{U:{V:{W:{X:{Y:{Z:{_:{if((b|0)!=1){v[22440]=0;b=T(159,H|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break _}v[22440]=0;U(192,d+240|0,H|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break _}e=d+240|0;b=cc(d+88|0,e);sb(e);if((g|0)==4674381){break W}if((g|0)==5068115){break V}if((g|0)==726487106){break Z}if((g|0)==844387158){break U}e=0;if((g|0)==1280004692){break Y}if((g|0)==1314144592){break X}if((g|0)!=1397445204){break T}v[22440]=0;e=T(196,b|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break x}e=e>>>0<256?48:e>>>8|0;v[a+480228>>2]=e;v[a+480232>>2]=e>>>1;e=0;while(1){if(x[k>>1]<=e>>>0){break T}v[22440]=0;g=Q(624,b|0,d+240|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break A}if(g){u[((e<<5)+a|0)+480286>>1]=(w[d+240|0]|w[d+241|0]<<8)>>>10;V=Eb(v[z>>2],e),X=w[p|0],t[V|0]=X}e=e+1|0;continue}}f=P()|0;O()|0;break u}f=P()|0;O()|0;break u}if(f&1){break T}t[a+480224|0]=2;v[22440]=0;J=+ma(625,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break S}if(!(J>1e-8)){break T}V=a,X=Le(2646e3/(J*+(B(v[a+480216>>2],v[a+480196>>2])>>>0))*1e4),v[V+480204>>2]=X;break T}while(1){$:{if(x[k>>1]<=e>>>0){break T}v[22440]=0;g=Q(158,d+88|0,1)|0;j=v[22440];v[22440]=0;if((j|0)==1){break z}if(!g){break T}g=Db(d+240|0);v[22440]=0;U(361,b|0,g|0,-1);j=v[22440];v[22440]=0;if((j|0)!=1){ef(d+16|0,3,Fb(g),vb(g));v[22440]=0;W(225,d+160|0,v[d+16>>2],v[d+20>>2],w[d+24|0]);j=v[22440];v[22440]=0;if((j|0)==1){break $}j=d+160|0;Al(((e<<5)+a|0)+480289|0,j);rb(j);rb(g);e=e+1|0;continue}}break}f=P()|0;O()|0;rb(g);break w}while(1){if((w[q|0]|w[q+1|0]<<8)>>>0<=e>>>0){break T}v[22440]=0;g=Q(158,d+88|0,1)|0;j=v[22440];v[22440]=0;if((j|0)==1){break y}if(!g){break T}if(!Dm(o,e&65535)){break T}g=Db(d+240|0);v[22440]=0;U(361,b|0,g|0,-1);j=v[22440];v[22440]=0;aa:{if((j|0)==1){break aa}j=Sb(o,e);v[22440]=0;R(288,j|0,g|0);j=v[22440];v[22440]=0;if((j|0)==1){break aa}rb(g);e=e+1|0;continue}break}f=P()|0;O()|0;rb(g);break w}v[22440]=0;Q(190,d+88|0,1)|0;e=v[22440];v[22440]=0;if((e|0)==1){break x}v[22440]=0;e=T(204,d+88|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break x}v[22440]=0;W(340,s|0,b|0,e|0,2);b=v[22440];v[22440]=0;if((b|0)!=1){break T}break x}v[22440]=0;Q(626,b|0,d+16|0)|0;e=v[22440];v[22440]=0;ba:{if((e|0)!=1){e=Db(d+240|0);v[22440]=0;U(361,b|0,e|0,-1);b=v[22440];v[22440]=0;if((b|0)==1){break ba}if(gq(e,12650)){v[22440]=0;U(11,d+160|0,8,e|0);b=v[22440];v[22440]=0;if((b|0)==1){break ba}b=d+160|0;Cb(m,b);rb(b)}rb(e);break T}f=P()|0;O()|0;break w}f=P()|0;O()|0;rb(e);break w}v[22440]=0;h=T(159,b|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break x}}sb(d+88|0);continue}break}f=P()|0;O()|0;break w}f=P()|0;O()|0;break w}f=P()|0;O()|0;break w}f=P()|0;O()|0;break w}f=P()|0;O()|0}sb(d+88|0);break u}f=P()|0;O()|0;break e}ca:{da:{b=l;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(b&2)){break da}if(b&8){i=x[a+480188>>1]}h=(((w[r|0]|w[r+1|0]<<8)>>>0>591?h:0)+i|0)+(b>>>4&1)|0;b=0;ea:while(1){e=0;if((w[q|0]|w[q+1|0]<<8)>>>0<=b>>>0){break da}while(1){fa:{if((e|0)!=(h|0)){v[22440]=0;i=Q(158,n|0,4)|0;l=v[22440];v[22440]=0;if((l|0)==1){break ca}if(i){break fa}}b=b+1|0;continue ea}i=w[r|0]|w[r+1|0]<<8;v[22440]=0;R(627,i|0,n|0);i=v[22440];v[22440]=0;if((i|0)==1){break ca}e=e+1|0;continue}}}v[22440]=0;m=Q(221,d+192|0,255)|0;b=v[22440];v[22440]=0;if((b|0)!=1){b=d+88|0;G=b|7;s=b|1;C=b|4;q=b|2;p=b|3;j=a+480208|0;h=0;while(1){ga:{b=h;ha:{if((b|0)==255){r=Mz(d+88|0);h=d+16|4;q=Mz(d+160|0);f=0;while(1){ia:{ja:{ka:{if((f|0)==256){k=0;break ka}v[22440]=0;R(628,n|0,d+240|0);b=v[22440];v[22440]=0;if((b|0)==1){break ja}v[22440]=0;b=T(159,n|0)|0;e=v[22440];v[22440]=0;la:{ma:{na:{if((e|0)!=1){v[22440]=0;U(192,d+16|0,n|0,b|0);e=v[22440];v[22440]=0;if((e|0)==1){break na}e=d+16|0;i=cc(d- -64|0,e);sb(e);if((w[A|0]|w[A+1|0]<<8)>>>0>f>>>0){Ie(d+48|0,2,d+240|0);v[22440]=0;W(225,d+16|0,v[d+48>>2],v[d+52>>2],w[d+56|0]);e=v[22440];v[22440]=0;if((e|0)==1){break la}e=d+16|0;uc(((f<<5)+a|0)+946336|0,e);rb(e)}if(!b){break ia}if((w[A|0]|w[A+1|0]<<8)>>>0>f>>>0){break ma}break ia}f=P()|0;O()|0;break ha}f=P()|0;O()|0;break ha}v[22440]=0;b=B(f+1|0,104)+a|0;e=b+484380|0;R(284,e|0,32);l=v[22440];v[22440]=0;oa:{pa:{qa:{if((l|0)!=1){v[22440]=0;R(629,i|0,d+16|0);i=v[22440];v[22440]=0;if((i|0)==1){break la}g=w[d+16|0]|w[d+17|0]<<8|(w[d+18|0]<<16|w[d+19|0]<<24);v[e>>2]=g;v[b+484404>>2]=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);if(w[d+24|0]>=2){i=b+484414|0;u[i>>1]=x[i>>1]|1;g=g>>>1|0;v[e>>2]=g}if(w[d+25|0]>=2){i=b+484414|0;u[i>>1]=x[i>>1]|64;v[e>>2]=g>>>1}g=2;switch(w[d+27|0]-1|0){case 0:break pa;case 1:break qa;default:break oa}}break la}g=6}e=b+484414|0;u[e>>1]=x[e>>1]|g}v[b+484384>>2]=w[d+28|0]|w[d+29|0]<<8|(w[d+30|0]<<16|w[d+31|0]<<24);v[b+484388>>2]=w[d+32|0]|w[d+33|0]<<8|(w[d+34|0]<<16|w[d+35|0]<<24);u[b+484410>>1]=(w[d+36|0]|w[d+37|0]<<8)>>>7;e=w[d+38|0];ra:{if((e|0)==128){e=b+484414|0;k=x[e>>1]|256;u[e>>1]=k;break ra}u[b+484408>>1]=(e<<24>>24)+128;k=x[b+484414>>1]}i=b+484414|0;u[i>>1]=k|32;t[b+484416|0]=w[d+39|0];e=w[d+26|0];if(e&2){b=d+48|0;ub(b,q,f);rm(b);e=w[d+26|0]}if(e&5){u[i>>1]=x[i>>1]|16384;e=w[d+26|0]}if(!(e&8)){break ia}b=d+48|0;ub(b,r,f);rm(b);e=0;while(1){if((e|0)==8){break ia}b=e<<1;sa:{if(x[b+(d+208|0)>>1]!=(f|0)){break sa}b=v[((x[b+(d+224|0)>>1]<<2)+a|0)+900380>>2];if(!b){break sa}t[b+14|0]=0}e=e+1|0;continue}}f=P()|0;O()|0;sb(d- -64|0);break ha}while(1){ta:{ua:{if((w[F|0]|w[F+1|0]<<8)>>>0<=k>>>0){if(!(c&2)){break ua}e=a+1298404|0;h=a+1298464|0;f=0;va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{while(1){if(x[a+480190>>1]<=f>>>0){break ua}f=f+1|0;c=B(f,104)+a|0;i=c+484380|0;b=c+484416|0;vl(i,(+(t[b|0]-49|0)+ +t[c+484417|0]*-.0078125)/-12);u[b>>1]=0;b=x[c+484414>>1];if(!(b&16384)){b=Nc(d+240|0,b&1?16:8,b&64?3:1,0,11);v[22440]=0;Y(222,b|0,i|0,n|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){continue}f=P()|0;O()|0;break ha}v[22440]=0;i=T(159,n|0)|0;b=v[22440];v[22440]=0;Da:{if((b|0)==1){break Da}v[22440]=0;Q(190,n|0,12)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Da}b=Db(d+240|0);v[22440]=0;U(275,n|0,b|0,i|0);i=v[22440];v[22440]=0;if((i|0)==1){break Ca}pe(c+484423|0,b);v[22440]=0;R(386,d- -64|0,16448);c=v[22440];v[22440]=0;if((c|0)==1){break Ba}v[d+12>>2]=f;c=v[e>>2];v[22440]=0;U(11,d+48|0,c|0,b|0);c=v[22440];v[22440]=0;if((c|0)==1){break Aa}v[22440]=0;W(431,d+16|0,d- -64|0,d+12|0,d+48|0);c=v[22440];v[22440]=0;if((c|0)==1){break za}c=v[h>>2];v[22440]=0;U(388,c|0,2,d+16|0);c=v[22440];v[22440]=0;if((c|0)==1){break ya}rb(d+16|0);rb(d+48|0);Ab(d- -64|0);rb(b);continue}break}f=P()|0;O()|0;break ha}f=P()|0;O()|0;break va}f=P()|0;O()|0;break va}f=P()|0;O()|0;break wa}f=P()|0;O()|0;break xa}f=P()|0;O()|0;rb(d+16|0)}rb(d+48|0)}Ab(d- -64|0)}rb(b);break ha}b=v[m>>2];v[22440]=0;b=T(162,Ng(b,k)|0)|0;e=v[22440];v[22440]=0;Ea:{Fa:{if((e|0)!=1){if(!b){k=k+1|0;continue}b=Ng(v[m>>2],k);sc(b);v[22440]=0;R(630,b|0,d+240|0);b=v[22440];v[22440]=0;if((b|0)==1){break Fa}i=Rb(d+16|0);b=w[d+240|0]|w[d+241|0]<<8;v[22440]=0;U(631,n|0,i|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break Ea}k=k+1|0;b=v[((k<<2)+a|0)+900380>>2];if(!b|w[b+34|0]){break ta}v[b+4>>2]=32;e=0;Kt(b,0);g=b+108|0;o=b+236|0;while(1){if((e|0)==96){break ta}h=w[(d+e|0)+242|0];Ga:{if(h>>>0>=(w[d+240|0]|w[d+241|0]<<8)>>>0){break Ga}l=Xe(v[d+16>>2],h);A=e+12|0;j=Xb(o,A);h=w[l|0];f=h+1|0;u[j>>1]=f;if(h>>>0>=x[a+480190>>1]){break Ga}h=B(f,104)+a|0;t[h+484418|0]=w[d+338|0]&3;t[h+484419|0]=w[d+339|0];t[h+484420|0]=w[d+340|0];t[h+484421|0]=w[d+341|0];u[h+484412>>1]=w[l+1|0]<<1;t[h+484417|0]=w[l+2|0];h=f-1|0;ub(d- -64|0,r,h);if(tb(v[v[d+64>>2]>>2],v[d+68>>2])){t[b+14|0]=0}ub(d- -64|0,q,h);if(!tb(v[v[d+64>>2]>>2],v[d+68>>2])){break Ga}V=Eb(g,A),X=61,t[V|0]=X}e=e+1|0;continue}}f=P()|0;O()|0;break ha}f=P()|0;O()|0;break ha}f=P()|0;O()|0;de(i);break ha}Ic(m);_b(z);sb(H);sb(I);break b}de(i);continue}}f=P()|0;O()|0;break ha}f=f+1|0;sb(d- -64|0);continue}}v[22440]=0;R(628,n|0,d+160|0);e=v[22440];v[22440]=0;Ha:{Ia:{Ja:{Ka:{if((e|0)!=1){v[22440]=0;e=T(159,n|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break Ka}h=w[r|0]|w[r+1|0]<<8;v[22440]=0;e=(e|0)==32?428:e;e=e?h>>>0>513?e+4|0:e:e;U(192,d+88|0,n|0,e|0);h=v[22440];v[22440]=0;if((h|0)==1){break Ja}h=b+1|0;i=d+240|0;l=d+88|0;f=cc(i,l);f=be(d+16|0,Sc(Ng(v[m>>2],b),f));sb(i);sb(l);if(b>>>0>=(w[F|0]|w[F+1|0]<<8)>>>0){break ga}v[22440]=0;b=h&65535;i=Y(257,a|0,b|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break Ia}break Ha}f=P()|0;O()|0;break ha}f=P()|0;O()|0;break ha}f=P()|0;O()|0;break ha}if(!i){break ga}Ie(d+88|0,2,d+160|0);v[22440]=0;W(225,d+240|0,v[d+88>>2],v[d+92>>2],w[d+96|0]);b=v[22440];v[22440]=0;La:{if((b|0)!=1){b=d+240|0;uc(i+492|0,b);rb(b);if(!e){break ga}v[22440]=0;R(630,f|0,d+240|0);b=v[22440];v[22440]=0;if((b|0)!=1){b=3;g=0;if((w[r|0]|w[r+1|0]<<8)>>>0<513){k=0;break La}v[22440]=0;k=T(196,f|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break Ha}if((w[r|0]|w[r+1|0]<<8)>>>0<514){break La}v[22440]=0;b=T(159,f|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){break La}break Ha}break Ha}break Ha}v[i>>2]=w[d+342|0]|w[d+343|0]<<8;t[i+16|0]=w[((w[d+344|0]|w[d+345|0]<<8)&3)+27038|0];t[i+17|0]=w[(w[d+345|0]&3)+27038|0];t[i+18|0]=w[((w[d+344|0]|w[d+345|0]<<8)>>>12&3)+27042|0];while(1){Ma:{Na:{if((g|0)==4){if(!(t[i+60|0]&1|w[i+16|0]==3)){v[i>>2]=32767}Jj(i,127,1);Ij(i,0,1);if(!k){break ga}v[22440]=0;R(632,f|0,d+88|0);b=v[22440];v[22440]=0;if((b|0)==1){break Ha}if(k&2){Jj(i,PA(v[j>>2],+((w[q|0]|w[q+1|0]<<8)>>>0)),1);Ij(i,w[C|0],1)}t[i+25|0]=w[s|0]==1;if(!(k&4)){break ga}t[i+31|0]=w[G|0]+1;t[i+34|0]=w[d+96|0]+1;if(t[d+96|0]<0){t[i+30|0]=w[d+103|0]+1}if(!w[d+100|0]){break Na}l=i+108|0;e=0;while(1){if((e|0)==128){break Na}b=e+1|0;v[d+64>>2]=b+t[d+100|0];XQ(d- -64|0);V=Eb(l,e),X=v[d+64>>2],t[V|0]=X;e=b;continue}}if(!(b&1)){break Ma}v[22440]=0;R(633,f|0,d+88|0);e=v[22440];v[22440]=0;Oa:{if((e|0)!=1){l=Bh(i,w[g+27046|0]);Pa:{if((g|0)!=3){e=d+88|0;o=w[l+12|0]&-17;break Pa}e=d+88|0;o=w[l+12|0]&-17|w[e|0]<<4&16}t[l+12|0]=o;o=o&-2|t[e|0]&1;t[l+12|0]=o;o=o&-5|w[e|0]<<1&4;t[l+12|0]=o;t[l+12|0]=o&253|w[e|0]>>>1&2;t[d+64|0]=w[s|0];t[d+48|0]=16;e=w[Tb(d- -64|0,d+48|0)|0];v[22440]=0;R(298,l|0,e|0);e=v[22440];v[22440]=0;if((e|0)==1){break Oa}e=w[q|0];t[l+15|0]=e;t[l+16|0]=e;t[l+13|0]=w[p|0];t[l+14|0]=w[C|0];D=v[l>>2];e=0;while(1){if(Dd(l)>>>0<=e>>>0){break Ma}E=Ib(D,e);o=(d+88|0)+(e<<2)|0;u[E>>1]=w[o+8|0]|w[o+9|0]<<8;V=E,X=wd(w[o+10|0]|w[o+11|0]<<8,0,64),t[V+2|0]=X;e=e+1|0;continue}}break Ha}break Ha}Kt(i,0);break ga}g=g+1|0;b=b>>>1|0;continue}}f=P()|0;O()|0;sb(d+16|0)}Ic(m);break u}sb(d+16|0);continue}}f=P()|0;O()|0;break u}f=P()|0;O()|0}_b(z);break e}while(1){v[22440]=0;b=Q(158,d+240|0,1)|0;h=v[22440];v[22440]=0;Qa:{if((h|0)!=1){if(!b){break o}v[22440]=0;g=T(208,m|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break h}p=0;if((g|0)!=255){break Qa}v[22440]=0;p=T(208,m|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){v[22440]=0;g=T(208,m|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break Qa}}break h}break h}if(g&127){h=Zc(Sb(o,z),e,k&65535);yu(d+88|0);if(g&1){v[22440]=0;b=T(208,m|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break n}t[d+88|0]=b}if(g&2){v[22440]=0;b=T(208,m|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break n}t[d+89|0]=b}if(g&4){v[22440]=0;b=T(208,m|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break n}t[d+90|0]=b}if(g&8){v[22440]=0;b=T(208,m|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break n}t[d+91|0]=b}if(g&16){v[22440]=0;b=T(208,m|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break n}t[d+92|0]=b}if(g&32){v[22440]=0;b=T(208,m|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break n}t[d+93|0]=b}if(g&64){v[22440]=0;b=T(208,m|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break n}t[d+94|0]=b}M=_Q(h,d+88|0);v[d+16>>2]=p;v[d+64>>2]=s+(e^-1);N=v[Bb(d+16|0,d- -64|0)>>2];g=0;b=h;while(1){if((g|0)!=(N|0)){b=B(x[K>>1],6)+b|0;j=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[b|0]=j;t[b+1|0]=j>>>8;t[b+2|0]=j>>>16;t[b+3|0]=j>>>24;j=w[h+4|0]|w[h+5|0]<<8;t[b+4|0]=j;t[b+5|0]=j>>>8;g=g+1|0;continue}break}f=f|M}e=(e+p|0)+1|0;while(1){if(e>>>0>=s>>>0){k=k+1|0;e=e-s|0;continue}break}if(i>>>0>(k&65535)>>>0){continue}break}}z=z+1|0;sb(d+240|0);continue}break}break h}f=P()|0;O()|0;rb(d+1344|0);break c}f=P()|0;O()|0;sb(d+240|0);break e}f=P()|0;O()|0;break e}f=P()|0;O()|0}sb(H)}sb(I)}S(f|0);L()}e=1}cb=d+1728|0;return e|0}function FR(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=0,r=C(0),s=0,A=C(0),D=0,E=0,F=0,G=C(0),H=C(0),I=C(0),J=0,K=C(0),M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=C(0),X=C(0),Y=0,Z=0,_=C(0),$=C(0),aa=C(0),ba=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;Z=cb-16|0;cb=Z;a:{if(v[a+1420>>2]>=0){v[f>>2]=0;e=v[a+1420>>2];d=(e|0)>0?e:0;while(1){if((d|0)!=(g|0)){v[(B(g,20)+a|0)+1436>>2]=0;g=g+1|0;continue}break}b:{c:{d:{if((e|0)>3){break d}g=0;if((c|0)<4){break c}c=c-3|0;d=0;while(1){if((c|0)==(d|0)){break d}e:{f:{j=b+d|0;if(w[j|0]!=79){break f}if(Mb(j,89272,4)){break f}n=d+26|0;if((n|0)>=(c|0)){break e}q=d+27|0;i=b+n|0;f=w[i|0];if((q+f|0)>=(c|0)){break e}h=f+27|0;g=0;O=0;while(1)if((f|0)==(O|0)){O=0;while(1){f=22;if((g|0)!=22){O=Mw(O,w[(d+g|0)+b|0]);g=g+1|0;continue}break}while(1){if((f|0)!=26){f=f+1|0;O=Mw(O,0);continue}break}v[a+1420>>2]=e+1;e=B(e,20)+a|0;v[e+1432>>2]=O;v[e+1428>>2]=h-26;v[e+1424>>2]=w[j+22|0]|w[j+23|0]<<8|(w[j+24|0]<<16|w[j+25|0]<<24);f=w[(n+w[i|0]|0)+b|0]==255?-1:w[j+6|0]|w[j+7|0]<<8|(w[j+8|0]<<16|w[j+9|0]<<24);v[e+1436>>2]=n;v[e+1440>>2]=f;e=v[a+1420>>2];if((e|0)!=4){break f}e=4;break d}else{h=w[(q+O|0)+b|0]+h|0;O=O+1|0;continue}}d=d+1|0;continue}break}c=d}d=0;g:while(1){q=(d|0)>(e|0)?d:e;while(1){if((d|0)==(q|0)){break b}g=0;f=B(d,20)+a|0;h=v[f+1436>>2];j=c-h|0;i=f+1428|0;n=v[i>>2];j=(j|0)<(n|0)?j:n;o=(j|0)>0?j:0;k=f+1432|0;O=v[k>>2];while(1){if((g|0)!=(o|0)){O=Mw(O,w[(g+h|0)+b|0]);g=g+1|0;continue}break}g=n-j|0;v[i>>2]=g;v[k>>2]=O;if(g){d=d+1|0;continue}else{f=f+1424|0;if(v[f>>2]==(O|0)){v[a+1380>>2]=-1;v[a+992>>2]=0;v[a+1420>>2]=-1;b=v[(B(d,20)+a|0)+1440>>2];v[a+1060>>2]=b;v[a+1064>>2]=(b|0)!=-1;g=h+j|0;break c}e=e-1|0;v[a+1420>>2]=e;e=B(e,20)+a|0;v[f+16>>2]=v[e+1440>>2];g=e+1432|0;j=v[g+4>>2];v[f+8>>2]=v[g>>2];v[f+12>>2]=j;e=e+1424|0;g=v[e+4>>2];v[f>>2]=v[e>>2];v[f+4>>2]=g;e=v[a+1420>>2];continue g}}}}c=g}break a}v[a+100>>2]=0;v[a+32>>2]=b;v[a+40>>2]=b+c;if(!iH(a)){v[f>>2]=0;c=0;break a}ga=cb-16|0;cb=ga;ja=Z+4|0;v[a+1504>>2]=0;v[a+1508>>2]=0;h:{if(v[a+96>>2]){break h}i:{j:{k:{if(v[a+1380>>2]!=-1){break k}c=Ve(a);if(v[a+96>>2]){break i}if((c|0)!=79){break j}if((Ve(a)|0)!=103){break j}if((Ve(a)|0)!=103){break j}if((Ve(a)|0)!=83){break j}if(!hH(a)){break i}if(!(t[a+1375|0]&1)){break k}t[a+1376|0]=0;v[a+1384>>2]=0;Zb(a,32);break i}j=Jw(a);break i}Zb(a,30)}if(!j){break h}if(kc(a,1)){Zb(a,35);break h}l:{m:{if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){c=kc(a,Yl(v[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=v[a+408>>2]){break h}v[ga+12>>2]=c;h=B(c,6)+a|0;if(!w[h+412|0]){g=v[a+112>>2];j=g>>1;break m}g=v[a+116>>2];j=g>>1;c=kc(a,1);n=kc(a,1);if(c|!w[h+412|0]){break m}v[ja>>2]=g-v[a+112>>2]>>2;c=v[a+112>>2]+g>>2;break l}ca(6328,13226,3152,10753);L()}v[ja>>2]=0;c=j}v[ga+8>>2]=c;n:{if(!(!w[h+412|0]|n)){c=B(g,3);v[Z+8>>2]=c-v[a+112>>2]>>2;g=c+v[a+112>>2]>>2;break n}v[Z+8>>2]=j}v[ga+4>>2]=g;g=1}if(g){ba=v[ja>>2];la=v[Z+8>>2];ka=v[ga+4>>2];P=cb-2368|0;cb=P;F=v[a+404>>2];oa=B(v[ga+12>>2],6)+a|0;E=w[oa+413|0];R=F+B(E,40)|0;V=v[((w[oa+412|0]<<2)+a|0)+104>>2];da=V>>1;ra=0-da|0;o:{while(1){c=v[a+4>>2];if((c|0)>(q|0)){c=w[(v[R+4>>2]+B(q,3)|0)+2|0];Q=(P+1344|0)+(q<<2)|0;v[Q>>2]=0;g=w[(c+R|0)+9|0];if(!x[((g<<1)+a|0)+132>>1]){Zb(a,21);c=0;break o}j=v[a+260>>2];p:{q:{if(!kc(a,1)){break q}c=2;h=v[((q<<2)+a|0)+996>>2];j=j+B(g,1596)|0;k=v[(w[j+1588|0]<<2)+68652>>2];g=Yl(k)-1|0;ta=h,ua=kc(a,g),u[ta>>1]=ua;ta=h,ua=kc(a,g),u[ta+2>>1]=ua;m=0;while(1){if(w[j|0]>m>>>0){N=w[(j+m|0)+1|0];g=N+j|0;D=w[g+49|0];o=-1<<D;p=w[g+33|0];r:{if(!D){n=0;break r}g=v[a+124>>2]+B(w[g+65|0],2096)|0;if(v[a+1396>>2]<=9){Vk(a)}i=v[a+1392>>2];n=u[(g+((i&1023)<<1)|0)+36>>1];s:{if((n|0)>=0){s=i;i=w[n+v[g+8>>2]|0];v[a+1392>>2]=s>>>i;S=v[a+1396>>2]-i|0;i=(S|0)<0;v[a+1396>>2]=i?0:S;n=i?-1:n;break s}n=Xl(a,g)}if(!w[g+23|0]){break r}n=v[v[g+2088>>2]+(n<<2)>>2]}S=o^-1;g=c+p|0;while(1){if((c|0)!=(g|0)){o=0;i=u[((j+(N<<4)|0)+((n&S)<<1)|0)+82>>1];t:{if((i|0)<0){break t}i=v[a+124>>2]+B(i&65535,2096)|0;if(v[a+1396>>2]<=9){Vk(a)}p=v[a+1392>>2];o=u[(i+((p&1023)<<1)|0)+36>>1];u:{if((o|0)>=0){s=p;p=w[o+v[i+8>>2]|0];v[a+1392>>2]=s>>>p;J=v[a+1396>>2]-p|0;p=(J|0)<0;v[a+1396>>2]=p?0:J;o=p?-1:o;break u}o=Xl(a,i)}if(!w[i+23|0]){break t}o=v[v[i+2088>>2]+(o<<2)>>2]}n=n>>D;u[h+(c<<1)>>1]=o;c=c+1|0;continue}break}m=m+1|0;c=g;continue}break}if(v[a+1396>>2]==-1){break q}u[P+320>>1]=257;n=j+1592|0;c=2;while(1){o=v[n>>2];if((o|0)<=(c|0)){c=0;while(1){if((c|0)>=(o|0)){break p}if(!w[(P+320|0)+c|0]){u[h+(c<<1)>>1]=65535;o=v[n>>2]}c=c+1|0;continue}}else{g=j+338|0;i=c<<1;D=i+j|0;p=w[D+1088|0];m=p<<1;o=x[g+m>>1];Q=w[D+1089|0];N=Q<<1;S=u[h+m>>1];D=u[N+h>>1]-S|0;m=D>>31;g=(B(x[g+i>>1]-o|0,m^m+D)|0)/(x[g+N>>1]-o|0)|0;o=S+((D|0)<0?0-g|0:g)|0;m=h+i|0;i=x[m>>1];v:{w:{if(i){g=P+320|0;t[g+Q|0]=1;t[g+p|0]=1;t[c+g|0]=1;g=i<<16>>16;D=k-o|0;if((g|0)>=((o|0)>(D|0)?D:o)<<1){if((o|0)<(D|0)){break v}o=k+(i^-1)|0;break w}if(g&1){o=o-(g+1>>>1|0)|0;break w}o=(g>>1)+o|0;break w}t[(P+320|0)+c|0]=0}u[m>>1]=o}c=c+1|0;continue}}}v[Q>>2]=1}q=q+1|0;continue}break}if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){ic(P+320|0,P+1344|0,c<<2);j=x[R>>1];c=0;while(1){if((c|0)==(j|0)){ha=F+B(E,40)|0}else{h=v[R+4>>2]+B(c,3)|0;g=w[h+1|0];o=P+1344|0;h=o+(w[h|0]<<2)|0;if(!(v[(g<<2)+o>>2]?v[h>>2]:0)){v[(P+1344|0)+(g<<2)>>2]=0;v[h>>2]=0}c=c+1|0;continue}break}n=0;while(1){x:{if(w[ha+8|0]>n>>>0){o=0;c=v[a+4>>2];h=(c|0)>0?c:0;c=0;while(1){if((c|0)==(h|0)){break x}if(w[(v[R+4>>2]+B(c,3)|0)+2|0]==(n|0)){i=o+P|0;j=c<<2;y:{if(v[j+(P+1344|0)>>2]){j=0;g=1;break y}j=v[(a+j|0)+800>>2];g=0}t[i|0]=g;v[(P+256|0)+(o<<2)>>2]=j;o=o+1|0}c=c+1|0;continue}}if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){h=(da|0)>0?da:0;g=x[R>>1];j=a+800|0;z:while(1){if((g|0)<=0){Q=da<<2;o=0;c=0;while(1){n=v[a+4>>2];if((n|0)<=(c|0)){while(1){if((o|0)<(n|0)){Q=w[oa+412|0];R=V>>1;g=R<<2;ha=v[a+92>>2];k=V>>3;S=V>>2;j=v[((o<<2)+a|0)+800>>2];c=R<<2;p=j+c|0;A:{if(v[a+80>>2]){n=nn(a,g);break A}n=Hd(g)}g=(n+c|0)-8|0;h=v[((Q<<2)+a|0)+1068>>2];i=h;c=j;while(1){if((c|0)!=(p|0)){z[g+4>>2]=C(z[c>>2]*z[i>>2])-C(z[i+4>>2]*z[c+8>>2]);z[g>>2]=C(z[c>>2]*z[i+4>>2])+C(z[c+8>>2]*z[i>>2]);c=c+16|0;i=i+8|0;g=g-8|0;continue}break}c=((R<<2)+j|0)-12|0;while(1){if(g>>>0>=n>>>0){z[g+4>>2]=C(z[c>>2]*z[i+4>>2])-C(z[c+8>>2]*z[i>>2]);z[g>>2]=C(C(-z[c+8>>2])*z[i+4>>2])-C(z[i>>2]*z[c>>2]);c=c-16|0;i=i+8|0;g=g-8|0;continue}break}c=S<<2;m=c+j|0;g=c+n|0;i=(h+(R<<2)|0)-32|0;c=n;q=j;while(1){if(h>>>0<=i>>>0){l=z[c>>2];r=z[g>>2];A=z[g+4>>2];G=z[c+4>>2];z[m+4>>2]=A+G;z[m>>2]=z[g>>2]+z[c>>2];A=C(A-G);l=C(r-l);z[q+4>>2]=C(A*z[i+16>>2])-C(z[i+20>>2]*l);z[q>>2]=C(l*z[i+16>>2])+C(A*z[i+20>>2]);l=z[c+8>>2];r=z[g+8>>2];A=z[g+12>>2];G=z[c+12>>2];z[m+12>>2]=A+G;z[m+8>>2]=z[g+8>>2]+z[c+8>>2];A=C(A-G);l=C(r-l);z[q+12>>2]=C(A*z[i>>2])-C(z[i+4>>2]*l);z[q+8>>2]=C(l*z[i>>2])+C(A*z[i+4>>2]);c=c+16|0;g=g+16|0;q=q+16|0;m=m+16|0;i=i-32|0;continue}break}g=Yl(V);c=V>>4;q=R-1|0;i=0-k|0;eH(c,j,q,i,h);eH(c,j,q-S|0,i,h);N=V>>5;c=0-c|0;Xo(N,j,q,c,h,16);Xo(N,j,q-k|0,c,h,16);Xo(N,j,q-(k<<1)|0,c,h,16);Xo(N,j,q+B(k,-3)|0,c,h,16);c=g-4>>1;m=(c|0)>2?c:2;c=2;while(1){B:{C:{D:{if((c|0)==(m|0)){c=g-7|0;ea=(c|0)<(m|0)?m:c;break D}i=0;k=2<<c;k=(k|0)>0?k:0;D=8<<c;E=V>>c+4;F=V>>c+2;J=0-(F>>1)|0;while(1){if((i|0)==(k|0)){break C}Xo(E,j,q-B(i,F)|0,J,h,D);i=i+1|0;continue}}while(1){E:{if((m|0)!=(ea|0)){D=2<<m;J=8<<m;ma=J<<2;i=V>>m+6;Y=V>>m+2;fa=0-(Y>>1)|0;g=q;c=h;while(1){if((i|0)<=0){break E}k=D;E=(g<<2)+j|0;F=E+(fa<<2)|0;T=B(J,12)+c|0;l=z[T>>2];M=(J<<3)+c|0;r=z[M>>2];s=(J<<2)+c|0;A=z[s>>2];G=z[T+4>>2];I=z[M+4>>2];W=z[s+4>>2];X=z[c+4>>2];aa=z[c>>2];T=0-Y<<2;while(1){if((k|0)>0){M=F-4|0;K=z[M>>2];_=z[E>>2];$=z[F>>2];z[E>>2]=_+$;s=E-4|0;H=z[s>>2];z[s>>2]=H+z[M>>2];H=C(H-K);K=C(_-$);z[M>>2]=C(H*aa)+C(X*K);z[F>>2]=C(K*aa)-C(X*H);M=F-12|0;_=z[M>>2];s=E-8|0;H=z[s>>2];U=s;s=F-8|0;$=z[s>>2];z[U>>2]=H+$;U=E-12|0;K=z[U>>2];z[U>>2]=K+z[M>>2];K=C(K-_);H=C(H-$);z[M>>2]=C(K*A)+C(W*H);z[s>>2]=C(H*A)-C(W*K);M=F-20|0;_=z[M>>2];s=E-16|0;H=z[s>>2];U=s;s=F-16|0;$=z[s>>2];z[U>>2]=H+$;U=E-20|0;K=z[U>>2];z[U>>2]=K+z[M>>2];K=C(K-_);H=C(H-$);z[M>>2]=C(K*r)+C(I*H);z[s>>2]=C(H*r)-C(I*K);M=F-28|0;_=z[M>>2];s=E-24|0;H=z[s>>2];U=s;s=F-24|0;$=z[s>>2];z[U>>2]=H+$;U=E-28|0;K=z[U>>2];z[U>>2]=K+z[M>>2];K=C(K-_);H=C(H-$);z[M>>2]=C(K*l)+C(G*H);z[s>>2]=C(H*l)-C(G*K);k=k-1|0;F=F+T|0;E=E+T|0;continue}break}i=i-1|0;g=g-8|0;c=(ma<<2)+c|0;continue}}c=(q<<2)+j|0;q=c-(N<<6)|0;l=z[h+(V>>3<<2)>>2];aa=C(-l);while(1){if(c>>>0>q>>>0){I=z[c>>2];g=c-32|0;W=z[g>>2];z[c>>2]=I+W;h=c-4|0;r=z[h>>2];i=h;h=c-36|0;X=z[h>>2];z[i>>2]=r+X;i=c-8|0;A=z[i>>2];k=i;i=c-40|0;H=z[i>>2];z[k>>2]=A+H;k=c-12|0;G=z[k>>2];s=k;k=c-44|0;K=z[k>>2];z[s>>2]=G+K;z[g>>2]=I-W;z[h>>2]=r-X;h=c-16|0;r=z[h>>2];s=h;h=c-48|0;_=z[h>>2];z[s>>2]=r+_;A=C(A-H);G=C(G-K);z[i>>2]=l*C(A+G);z[k>>2]=l*C(G-A);i=c-28|0;A=z[i>>2];k=c-60|0;G=z[k>>2];D=c-24|0;I=z[D>>2];m=c-56|0;W=z[m>>2];E=c-20|0;X=z[E>>2];s=E;E=c-52|0;H=z[E>>2];z[s>>2]=X+H;z[D>>2]=I+W;z[i>>2]=A+G;z[h>>2]=X-H;z[E>>2]=-C(r-_);r=C(A-G);A=C(I-W);z[m>>2]=l*C(r-A);z[k>>2]=C(A+r)*aa;dH(c);dH(g);c=c+-64|0;continue}break}k=R-4|0;g=n+(k<<2)|0;i=(n+(S<<2)|0)-16|0;c=v[((Q<<2)+a|0)+1100>>2];while(1){if(i>>>0>=n>>>0){h=(x[c>>1]<<2)+j|0;z[g+12>>2]=z[h>>2];z[g+8>>2]=z[h+4>>2];z[i+12>>2]=z[h+8>>2];z[i+8>>2]=z[h+12>>2];h=(x[c+2>>1]<<2)+j|0;z[g+4>>2]=z[h>>2];z[g>>2]=z[h+4>>2];z[i+4>>2]=z[h+8>>2];z[i>>2]=z[h+12>>2];c=c+4|0;g=g-16|0;i=i-16|0;continue}break}c=v[((Q<<2)+a|0)+1084>>2];i=n;g=i+(R<<2)|0;h=g;while(1){q=h-16|0;if(q>>>0>i>>>0){l=z[i+4>>2];D=h-4|0;r=z[D>>2];A=C(l-r);G=z[c+4>>2];l=C(l+r);r=z[i>>2];m=h-8|0;I=z[m>>2];W=C(r-I);X=z[c>>2];aa=C(C(G*l)-C(W*X));z[i+4>>2]=A+aa;r=C(r+I);l=C(C(G*W)+C(l*X));z[i>>2]=r+l;z[D>>2]=aa-A;z[m>>2]=r-l;l=z[i+8>>2];r=z[q>>2];A=C(l+r);G=z[c+12>>2];l=C(l-r);r=z[i+12>>2];h=h-12|0;I=z[h>>2];W=C(r+I);X=z[c+8>>2];aa=C(C(G*l)+C(W*X));z[i+8>>2]=A+aa;r=C(r-I);l=C(C(G*W)-C(l*X));z[i+12>>2]=r+l;z[q>>2]=A-aa;z[h>>2]=l-r;i=i+16|0;c=c+16|0;h=q;continue}break}i=v[((Q<<2)+a|0)+1076>>2]+(R<<2)|0;c=(k<<2)+j|0;h=((V<<2)+j|0)-16|0;while(1){q=g-32|0;if(q>>>0>=n>>>0){l=z[g-8>>2];r=z[i-4>>2];A=z[i-8>>2];G=z[g-4>>2];I=C(C(l*r)-C(A*G));z[j>>2]=I;z[c+12>>2]=-I;l=C(C(A*C(-l))-C(r*G));z[p>>2]=l;z[h+12>>2]=l;l=z[g-16>>2];r=z[i-12>>2];A=z[i-16>>2];G=z[g-12>>2];I=C(C(l*r)-C(A*G));z[j+4>>2]=I;z[c+8>>2]=-I;l=C(C(A*C(-l))-C(r*G));z[p+4>>2]=l;z[h+8>>2]=l;l=z[g-24>>2];r=z[i-20>>2];A=z[i-24>>2];G=z[g-20>>2];I=C(C(l*r)-C(A*G));z[j+8>>2]=I;z[c+4>>2]=-I;l=C(C(A*C(-l))-C(r*G));z[p+8>>2]=l;z[h+4>>2]=l;l=z[q>>2];r=z[i-28>>2];i=i-32|0;A=z[i>>2];G=z[g-28>>2];I=C(C(l*r)-C(A*G));z[j+12>>2]=I;z[c>>2]=-I;l=C(C(A*C(-l))-C(r*G));z[p+12>>2]=l;z[h>>2]=l;h=h-16|0;c=c-16|0;p=p+16|0;j=j+16|0;g=q;continue}break}if(!v[a+80>>2]){zb(n)}v[a+92>>2]=ha;break B}m=m+1|0;continue}}c=c+1|0;continue}break}o=o+1|0;n=v[a+4>>2];continue}break}}else{j=c<<2;g=j+a|0;F:{if(v[j+(P+320|0)>>2]){Hb(v[g+800>>2],0,Q);break F}m=v[g+800>>2];F=v[g+996>>2];G:{g=w[(w[(v[R+4>>2]+B(c,3)|0)+2|0]+R|0)+9|0];if(!x[((g<<1)+a|0)+132>>1]){Zb(a,21);break G}q=V>>1;D=v[a+260>>2]+B(g,1596)|0;N=D+1592|0;S=D+1588|0;j=B(w[D+1588|0],u[F>>1]);i=1;g=0;while(1){if(v[N>>2]>(i|0)){h=w[(i+D|0)+838|0]<<1;n=u[h+F>>1];if((n|0)>=0){n=B(w[S|0],n&65535);h=x[(h+D|0)+338>>1];if((h|0)!=(g|0)){k=n-j|0;p=h-g|0;E=(k|0)/(p|0)|0;H:{J=(h|0)>(q|0)?q:h;if((J|0)<=(g|0)){break H}s=k;k=k>>31;T=E>>31;T=(s+k^k)-B(p,T+E^T)|0;M=k|1;k=m+(g<<2)|0;z[k>>2]=z[((j&255)<<2)+68672>>2]*z[k>>2];J=J-1|0;k=0;while(1){if((g|0)==(J|0)){break H}g=g+1|0;ha=m+(g<<2)|0;k=k+T|0;ea=(k|0)<(p|0);j=(j+E|0)+(ea?0:M)|0;z[ha>>2]=z[((j&255)<<2)+68672>>2]*z[ha>>2];k=k-(ea?0:p)|0;continue}}g=h}j=n}i=i+1|0;continue}break}if((g|0)>=(q|0)){break G}j=(j<<2)+68672|0;while(1){if((g|0)==(q|0)){break G}h=m+(g<<2)|0;z[h>>2]=z[j>>2]*z[h>>2];g=g+1|0;continue}}}c=c+1|0;continue}break}gH(a);I:{if(w[a+1377|0]){v[a+1060>>2]=ra;t[a+1377|0]=0;v[a+1064>>2]=1;v[a+1412>>2]=V-ka;break I}c=v[a+1412>>2];if(!c){break I}g=la-ba|0;if((g|0)<=(c|0)){v[a+1412>>2]=c-g;v[ja>>2]=la;ba=la;break I}ba=c+ba|0;v[ja>>2]=ba;v[a+1412>>2]=0}c=v[a+1064>>2];J:{K:{L:{M:{if(v[a+1388>>2]==v[a+1404>>2]){N:{if(!c|!(w[a+1375|0]&4)){break N}c=v[a+1408>>2];g=v[a+1060>>2];if(c>>>0>=g+(ka-ba|0)>>>0){break N}g=c-g|0;c=(c>>>0<g>>>0?0:g)+ba|0;c=(c|0)>(ka|0)?ka:c;v[Z+12>>2]=c;v[a+1060>>2]=c+v[a+1060>>2];break K}v[a+1064>>2]=1;c=v[a+1408>>2]+(ba-da|0)|0;break M}if(!c){break L}c=v[a+1060>>2]}v[a+1060>>2]=c+(la-ba|0)}if(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0){break J}v[Z+12>>2]=ka}c=1;break o}ca(6328,13226,3451,5637);L()}g=g-1|0;c=v[R+4>>2]+B(g,3)|0;n=v[j+(w[c+1|0]<<2)>>2];q=v[j+(w[c|0]<<2)>>2];c=0;while(1){if((c|0)==(h|0)){continue z}i=c<<2;o=i+n|0;A=z[o>>2];i=i+q|0;l=z[i>>2];O:{if(l>C(0)){if(A>C(0)){r=C(l-A);break O}r=l;l=C(l+A);break O}if(A>C(0)){r=C(l+A);break O}r=l;l=C(l-A)}z[i>>2]=l;z[o>>2]=r;c=c+1|0;continue}}}ca(6328,13226,3335,5637);L()}S=P+256|0;q=0;F=cb-16|0;cb=F;p=v[a+4>>2];m=v[a+396>>2];h=w[(n+ha|0)+24|0];D=m+B(h,24)|0;g=v[D+4>>2];ea=x[((h<<1)+a|0)+268>>1];c=da<<((ea|0)==2);i=c>>>0>g>>>0?g:c;g=v[D>>2];Q=(i-(c>>>0>g>>>0?g:c)>>>0)/y[D+8>>2]|0;j=Q<<2;c=B(p,j+4|0);M=v[v[a+124>>2]+B(w[D+13|0],2096)>>2];U=v[a+92>>2];P:{if(v[a+80>>2]){g=nn(a,c);p=v[a+4>>2];break P}g=Hd(c)}i=(o|0)>0?o:0;E=da<<2;c=0;N=(p|0)>0?p:0;k=(p<<2)+g|0;while(1){if((c|0)!=(N|0)){v[(c<<2)+g>>2]=k;c=c+1|0;k=j+k|0;continue}break}j=g;c=0;while(1){if((c|0)!=(i|0)){if(!w[c+P|0]){Hb(v[S+(c<<2)>>2],0,E)}c=c+1|0;continue}break}Q:{if(!((o|0)==1|(ea|0)!=2)){c=0;while(1){R:{if((c|0)!=(i|0)){if(w[c+P|0]){break R}}else{c=i}if((c|0)==(o|0)){break Q}k=m+B(h,24)|0;E=(o|0)!=2;N=(o|0)<3;while(1){if((q|0)==8){break Q}S:{if(!E){g=0;m=0;while(1){if((m|0)>=(Q|0)){break S}c=v[D>>2]+B(v[D+8>>2],m)|0;v[F+12>>2]=c&1;v[F+8>>2]=c>>1;c=0;if(!q){i=v[a+124>>2]+B(w[D+13|0],2096)|0;if(v[a+1396>>2]<=9){Vk(a)}p=v[a+1392>>2];h=u[(i+((p&1023)<<1)|0)+36>>1];T:{if((h|0)>=0){s=p;p=w[h+v[i+8>>2]|0];v[a+1392>>2]=s>>>p;J=v[a+1396>>2]-p|0;p=(J|0)<0;v[a+1396>>2]=p?0:J;h=p?-1:h;break T}h=Xl(a,i)}h=w[i+23|0]?v[v[i+2088>>2]+(h<<2)>>2]:h;if((h|0)==-1){break Q}v[v[j>>2]+(g<<2)>>2]=v[v[k+16>>2]+(h<<2)>>2]}while(1){if(!((c|0)>=(M|0)|(m|0)>=(Q|0))){h=v[D+8>>2];i=u[(v[k+20>>2]+(w[v[v[j>>2]+(g<<2)>>2]+c|0]<<4)|0)+(q<<1)>>1];U:{if((i|0)>=0){if(fH(a,v[a+124>>2]+B(i&65535,2096)|0,S,2,F+12|0,F+8|0,da,h)){break U}break Q}h=v[D>>2]+(h+B(h,m)|0)|0;v[F+8>>2]=h>>1;v[F+12>>2]=h&1}m=m+1|0;c=c+1|0;continue}break}g=g+1|0;continue}}if(N){break S}g=0;m=0;while(1){if((m|0)>=(Q|0)){break S}h=v[D>>2]+B(v[D+8>>2],m)|0;c=(h|0)/(o|0)|0;v[F+12>>2]=h-B(c,o);v[F+8>>2]=c;c=0;if(!q){i=v[a+124>>2]+B(w[D+13|0],2096)|0;if(v[a+1396>>2]<=9){Vk(a)}p=v[a+1392>>2];h=u[(i+((p&1023)<<1)|0)+36>>1];V:{if((h|0)>=0){s=p;p=w[h+v[i+8>>2]|0];v[a+1392>>2]=s>>>p;J=v[a+1396>>2]-p|0;p=(J|0)<0;v[a+1396>>2]=p?0:J;h=p?-1:h;break V}h=Xl(a,i)}h=w[i+23|0]?v[v[i+2088>>2]+(h<<2)>>2]:h;if((h|0)==-1){break Q}v[v[j>>2]+(g<<2)>>2]=v[v[k+16>>2]+(h<<2)>>2]}while(1){if(!((c|0)>=(M|0)|(m|0)>=(Q|0))){h=v[D+8>>2];i=u[(v[k+20>>2]+(w[v[v[j>>2]+(g<<2)>>2]+c|0]<<4)|0)+(q<<1)>>1];W:{if((i|0)>=0){if(!fH(a,v[a+124>>2]+B(i&65535,2096)|0,S,o,F+12|0,F+8|0,da,h)){break Q}break W}h=v[D>>2]+(h+B(h,m)|0)|0;i=(h|0)/(o|0)|0;v[F+8>>2]=i;v[F+12>>2]=h-B(i,o)}m=m+1|0;c=c+1|0;continue}break}g=g+1|0;continue}}q=q+1|0;continue}}c=c+1|0;continue}}ma=m+B(h,24)|0;o=0;while(1){if((o|0)==8){break Q}q=0;J=0;X:while(1){if((q|0)<(Q|0)){g=0;c=0;Y:{if(o){break Y}while(1){if((c|0)==(i|0)){break Y}if(!w[c+P|0]){k=v[a+124>>2]+B(w[D+13|0],2096)|0;if(v[a+1396>>2]<=9){Vk(a)}m=v[a+1392>>2];h=u[(k+((m&1023)<<1)|0)+36>>1];Z:{if((h|0)>=0){s=m;m=w[h+v[k+8>>2]|0];v[a+1392>>2]=s>>>m;p=v[a+1396>>2]-m|0;m=(p|0)<0;v[a+1396>>2]=m?0:p;h=m?-1:h;break Z}h=Xl(a,k)}h=w[k+23|0]?v[v[k+2088>>2]+(h<<2)>>2]:h;if((h|0)==-1){break Q}v[v[j+(c<<2)>>2]+(J<<2)>>2]=v[v[ma+16>>2]+(h<<2)>>2]}c=c+1|0;continue}}while(1){_:{$:{if((g|0)>=(M|0)){break $}c=0;if((q|0)>=(Q|0)){break $}while(1){if((c|0)==(i|0)){break _}aa:{if(w[c+P|0]){break aa}h=c<<2;k=u[(v[ma+20>>2]+(w[v[v[h+j>>2]+(J<<2)>>2]+g|0]<<4)|0)+(o<<1)>>1];if((k|0)<0){break aa}m=v[a+124>>2]+B(k&65535,2096)|0;Y=v[h+S>>2];T=v[D+8>>2];N=v[D>>2]+B(T,q)|0;ba:{ca:{if(ea){p=0;while(1){h=1;if((p|0)>=(T|0)){break ba}fa=Y+(N<<2)|0;h=T-p|0;E=0;l=C(0);da:{s=cH(a,m);if((s|0)<0){break da}k=v[m>>2];h=(h|0)>(k|0)?k:h;s=B(k,s);if(w[m+22|0]){k=0;h=(h|0)>0?h:0;E=1;while(1){if((h|0)==(k|0)){break da}ia=fa+(k<<2)|0;l=C(l+z[v[m+28>>2]+(k+s<<2)>>2]);z[ia>>2]=z[ia>>2]+l;k=k+1|0;l=C(l+z[m+12>>2]);continue}}k=0;h=(h|0)>0?h:0;E=1;while(1){if((h|0)==(k|0)){break da}ia=fa+(k<<2)|0;z[ia>>2]=z[ia>>2]+C(z[v[m+28>>2]+(k+s<<2)>>2]+C(0));k=k+1|0;continue}}if(!E){break ca}h=v[m>>2];N=h+N|0;p=h+p|0;continue}}p=0;fa=(T|0)/v[m>>2]|0;s=(fa|0)>0?fa:0;ia=Y+(N<<2)|0;h=1;while(1){if((p|0)==(s|0)){break ba}k=p+N|0;E=p<<2;p=p+1|0;sa=E+ia|0;Y=T-k|0;k=0;l=C(0);ea:{na=cH(a,m);if((na|0)<0){break ea}E=0;k=v[m>>2];Y=(k|0)<(Y|0)?k:Y;Y=(Y|0)>0?Y:0;na=B(k,na);k=1;while(1){if((E|0)==(Y|0)){break ea}qa=sa+(B(E,fa)<<2)|0;r=C(l+z[v[m+28>>2]+(E+na<<2)>>2]);z[qa>>2]=z[qa>>2]+r;l=w[m+22|0]?r:l;E=E+1|0;continue}}if(k){continue}break}}h=0}if(!h){break Q}}c=c+1|0;continue}}J=J+1|0;continue X}q=q+1|0;g=g+1|0;continue}}break}o=o+1|0;continue}}if(!v[a+80>>2]){zb(j)}v[a+92>>2]=U;cb=F+16|0;n=n+1|0;continue}}ca(6328,13226,3302,5637);L()}cb=P+2368|0}else{c=0}cb=ga+16|0;if(!c){fa:{ga:{ha:{c=v[a+100>>2];switch(c-32|0){case 0:break ga;case 3:break ha;default:break fa}}v[a+100>>2]=0;while(1){if(ta=0,ua=(rh(a)|0)!=-1,va=v[a+96>>2],va?ta:ua){continue}break}v[f>>2]=0;c=v[a+32>>2]-b|0;break a}if(v[a+992>>2]){break fa}v[a+100>>2]=0;while(1){if(ta=0,ua=(rh(a)|0)!=-1,va=v[a+96>>2],va?ta:ua){continue}break}v[f>>2]=0;c=v[a+32>>2]-b|0;break a}v[a+1420>>2]=0;v[a+992>>2]=0;v[a+1504>>2]=0;v[a+1508>>2]=0;v[a+1412>>2]=0;v[a+1416>>2]=0;t[a+1377|0]=0;v[a+1064>>2]=0;v[a+100>>2]=c;v[f>>2]=0;c=1;break a}h=v[Z+12>>2];q=v[Z+4>>2];j=v[Z+8>>2];ia:{ja:{n=v[a+992>>2];if(n){g=n<<1;ka:{if((g|0)==v[a+112>>2]){c=a+1092|0}else{c=0;if((g|0)!=v[a+116>>2]){break ka}c=a+1096|0}c=v[c>>2]}g=c;if(!g){break ja}o=(n|0)>0?n:0;while(1){if(v[a+4>>2]>(O|0)){i=(O<<2)+a|0;c=0;while(1){if((c|0)!=(o|0)){k=v[i+800>>2]+(c+q<<2)|0;s=k;l=z[k>>2];k=c<<2;z[s>>2]=C(l*z[k+g>>2])+C(z[k+v[i+928>>2]>>2]*z[g+(n+(c^-1)<<2)>>2]);c=c+1|0;continue}break}O=O+1|0;continue}break}O=v[a+992>>2]}v[a+992>>2]=h-j;n=(h|0)<(j|0);i=(n?j:h)-j|0;while(1){if(v[a+4>>2]>(pa|0)){g=(pa<<2)+a|0;c=0;while(1){if((c|0)!=(i|0)){z[v[g+928>>2]+(c<<2)>>2]=z[v[g+800>>2]+(c+j<<2)>>2];c=c+1|0;continue}break}pa=pa+1|0;continue}break}if(!O){break ja}c=(n?h:j)-q|0;v[a+1416>>2]=c+v[a+1416>>2];break ia}c=0}g=c;v[Z+12>>2]=c;c=0;j=v[a+4>>2];h=(j|0)>0?j:0;while(1){if((c|0)!=(h|0)){n=(c<<2)+a|0;v[n+864>>2]=v[n+800>>2]+(q<<2);c=c+1|0;continue}break}if(d){v[d>>2]=j}v[f>>2]=g;v[e>>2]=a+864;c=v[a+32>>2]-b|0}cb=Z+16|0;return c}function Ria(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0;d=cb-1136|0;cb=d;sc(b);e=cb-16|0;cb=e;m=d+896|0;kT(e+8|0,m);g=v[e+12>>2];Yb(e,b,v[e+8>>2],g);o=v[e+4>>2];if((o|0)==(g|0)){Ob(b,v[e+12>>2])}cb=e+16|0;e=(g|0)==(o|0);if(!e){jT(m)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if(!e){break o}if(!mT(d+896|0)){break o}if(!Kb(b,wc(lT(d+896|0),fb))){break o}if(!c){f=1;break o}ud(a,16777216);eg(a);e=a+480208|0;v[e>>2]=v[e>>2]|16809984;g=d+432|0;eq(g,32);f=v[d+444>>2];e=a+1074320|0;v[e>>2]=v[d+440>>2];v[e+4>>2]=f;e=v[d+436>>2];v[a+1074312>>2]=v[d+432>>2];v[a+1074316>>2]=e;f=d+896|3;m=f;Gb(Gb(a+1074312|0,57,w[f|0]>5),114,1);e=eo(d+848|0);K=e,M=wd(w[d+1096|0],1,31),v[K+12>>2]=M;K=e,M=wd(w[d+1097|0],1,12)-1|0,v[K+16>>2]=M;o=d+1098|0;K=e,M=wb(w[o|0]|w[o+1|0]<<8)-1900|0,v[K+20>>2]=M;pB(a+1298408|0,e);u[a+480188>>1]=32;iT(d+328|0,3,d+1100|0);e=d+40|0;xc(e,v[d+328>>2],v[d+332>>2],w[d+336|0]);v[22440]=0;U(11,g|0,1,e|0);e=v[22440];v[22440]=0;p:{q:{if((e|0)!=1){e=d+432|0;Cb(a+1298368|0,e);rb(e);rb(d+40|0);r:{if(w[m|0]<=5){Xf(d+40|0,3927);break r}e=cb-16|0;cb=e;g=jc(e,3996);zc(d+40|0,g);rb(g);cb=e+16|0}v[22440]=0;U(373,d+432|0,d+40|0,f|0);e=v[22440];v[22440]=0;if((e|0)==1){break q}e=d+432|0;Cb(a+1298344|0,e);rb(e);f=d+40|0;Ab(f);g=jc(e,15219);Cb(a+1298356|0,g);rb(g);v[a+1298404>>2]=2;Ie(f,3,d+904|0);xc(e,v[d+40>>2],v[d+44>>2],w[d+48|0]);tc(a+1298308|0,e);rb(e);v[a+480228>>2]=256;v[a+480200>>2]=384/(x[a+480188>>1]+3>>>0);if(w[m|0]>5){break p}e=d+1124|0;K=d,M=wb(w[e|0]|w[e+1|0]<<8),u[K+432>>1]=M;u[d+40>>1]=1;e=d+432|0;f=d+40|0;K=a,M=x[ie(e,f)>>1],v[K+480196>>2]=M;g=d+1126|0;K=d,M=wb(w[g|0]|w[g+1|0]<<8),u[K+432>>1]=M;u[d+40>>1]=1;K=a,M=B(x[ie(e,f)>>1],1e4),v[K+480204>>2]=M;g=d+1128|0;K=d,M=wc(((wb(w[g|0]|w[g+1|0]<<8)<<8)+2047>>>0)/4095|0,0),v[K+432>>2]=M;v[d+40>>2]=256;K=a,M=v[Bb(e,f)>>2],v[K+480200>>2]=M;f=d+1130|0;K=d,M=wb(w[f|0]|w[f+1|0]<<8),u[K+432>>1]=M;Kf(e,127);f=0;e=x[d+432>>1];while(1){if((e|0)==(f|0)){break p}K=d,M=wc(((Ii(b)<<8)+2047>>>0)/4095|0,0),u[K+40>>1]=M;u[d+328>>1]=256;K=((f<<5)+a|0)+480284|0,M=x[Kc(d+40|0,d+328|0)>>1],u[K>>1]=M;f=f+1|0;continue}}a=P()|0;O()|0;rb(d+40|0);break a}a=P()|0;O()|0;Ab(d+40|0);break a}e=d+896|4;Tc(b,Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24)));o=be(d+824|0,b);v[22440]=0;R(378,d+808|0,o|0);b=v[22440];v[22440]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((b|0)!=1){v[22440]=0;U(379,d+432|0,d+808|0,1346458707);b=v[22440];v[22440]=0;if((b|0)==1){break I}v[22440]=0;b=Q(158,d+432|0,2)|0;e=v[22440];v[22440]=0;if((e|0)==1){break L}if(!b){break J}v[22440]=0;b=T(278,d+432|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break L}if((b-1&65535)>>>0>126){break J}u[a+480188>>1]=b;b=d+432|0;sb(b);v[22440]=0;U(379,b|0,d+808|0,1397706311);b=v[22440];v[22440]=0;if((b|0)!=1){break M}a=P()|0;O()|0;break c}a=P()|0;O()|0;break b}v[22440]=0;b=Q(158,d+432|0,2)|0;e=v[22440];v[22440]=0;if((e|0)==1){break G}if(!b){break J}v[22440]=0;b=T(278,d+432|0)|0;e=v[22440];v[22440]=0;N:{if((e|0)==1){break N}u[d+40>>1]=b;b=a+484360|0;e=Nb(b);v[22440]=0;f=T(278,d+432|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break N}Qe(e,f);v[22440]=0;e=T(204,d+432|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break N}Kf(d+40|0,xl(e>>>1|0));b=Nb(b);v[22440]=0;U(281,b|0,d+432|0,x[d+40>>1]);b=v[22440];v[22440]=0;if((b|0)!=1){break K}}break G}a=P()|0;O()|0;sb(d+432|0);break c}b=d+432|0;sb(b);v[22440]=0;U(379,b|0,d+808|0,1480806221);b=v[22440];v[22440]=0;if((b|0)==1){break H}v[22440]=0;b=Q(158,d+432|0,3)|0;e=v[22440];v[22440]=0;if((e|0)!=1){if(b){break F}b=160;while(1){O:{f=b;if(!b){f=0;break O}b=f-1|0;if(w[(d+b|0)+936|0]==32){continue}}break}v[22440]=0;W(346,a+1298332|0,d+936|0,f|0,4);b=v[22440];v[22440]=0;if((b|0)!=1){break E}break D}break D}sb(d+432|0);f=0;break s}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;sb(d+432|0);break c}v[22440]=0;b=T(278,d+432|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){v[22440]=0;W(340,a+1298332|0,d+432|0,b|0,4);b=v[22440];v[22440]=0;if((b|0)!=1){break E}}break D}b=d+432|0;sb(b);v[22440]=0;U(379,b|0,d+808|0,1413697073);b=v[22440];v[22440]=0;if((b|0)==1){break C}v[22440]=0;b=T(208,d+432|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break A}if(b){break B}v[22440]=0;b=Q(157,d+432|0,2648)|0;e=v[22440];v[22440]=0;if((e|0)==1){break A}if(!b){break B}f=0;v[22440]=0;b=T(286,d+432|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break A}while(1){if((f|0)==32){break B}e=((f<<5)+a|0)+480280|0;v[e>>2]=v[e>>2]&-1025|!(b>>>f&1)<<10;f=f+1|0;continue}}a=P()|0;O()|0;sb(d+432|0);break c}a=P()|0;O()|0;break c}b=d+432|0;sb(b);v[22440]=0;U(379,b|0,d+808|0,1413697074);b=v[22440];v[22440]=0;if((b|0)==1){break z}v[22440]=0;b=Q(158,d+432|0,12)|0;e=v[22440];v[22440]=0;if((e|0)==1){break y}P:{if(!b){break P}v[22440]=0;R(380,d+40|0,d+432|0);b=v[22440];v[22440]=0;if((b|0)==1){break y}e=d+40|0;b=Oe(e);f=bc(e);g=hT(e);k=xb(e);l=gT(e);h=B(wd(wb(w[b|0]|w[b+1|0]<<8),32,999),1e4);b=kka(wb(w[f|0]|w[f+1|0]<<8),0,1e4,0)+32768|0;f=fb;f=b>>>0<32768?f+1|0:f;K=a,M=h+((wc((f&65535)<<16|b>>>16,f>>>16|0)>>>0)%1e4|0)|0,v[K+480204>>2]=M;K=a,M=wd(wb(w[g|0]|w[g+1|0]<<8),1,255),v[K+480196>>2]=M;b=16/(wd(wb(w[l|0]|w[l+1|0]<<8),1,16)>>>0)|0;v[a+480216>>2]=b;K=a,M=B(wd(wb(w[k|0]|w[k+1|0]<<8),1,16),b),v[K+480220>>2]=M;if(!wb(w[e|0]|w[e+1|0]<<8)){break P}v[22440]=0;b=T(278,d+432|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break y}e=a+480208|0;v[e>>2]=v[e>>2]&-17|!b<<4}b=d+432|0;sb(b);v[22440]=0;U(379,b|0,d+808|0,1414942540);b=v[22440];v[22440]=0;if((b|0)==1){break x}v[22440]=0;b=Q(158,d+432|0,2)|0;e=v[22440];v[22440]=0;if((e|0)==1){break v}if(!b){break w}v[22440]=0;b=T(278,d+432|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break v}u[d+40>>1]=b;u[d+328>>1]=x[a+480188>>1];b=x[Kc(d+40|0,d+328|0)>>1];f=0;while(1){if((b|0)==(f|0)){break w}v[22440]=0;e=T(278,d+432|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break v}u[d+40>>1]=e;u[d+328>>1]=4096;K=((f<<5)+a|0)+480286|0,M=x[Kc(d+40|0,d+328|0)>>1]>>>6&255,u[K>>1]=M;f=f+1|0;continue}}a=P()|0;O()|0;sb(d+432|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;sb(d+432|0);break c}a=P()|0;O()|0;break c}sb(d+432|0);v[22440]=0;U(379,d+40|0,d+808|0,1296652368);b=v[22440];v[22440]=0;if((b|0)==1){break u}v[22440]=0;b=Q(158,d+40|0,56)|0;e=v[22440];v[22440]=0;if((e|0)==1){break d}if(!b){break t}v[22440]=0;R(381,d+40|0,d+432|0);b=v[22440];v[22440]=0;if((b|0)==1){break d}if((wb(w[d+466|0]|w[d+467|0]<<8)|0)!=4){break t}if((wb(w[d+480|0]|w[d+481|0]<<8)|0)!=257){break t}K=d,M=wb(w[d+472|0]|w[d+473|0]<<8),u[K+328>>1]=M;u[d+792>>1]=16384;e=d+328|0;f=x[Kc(e,d+792|0)>>1];b=f>>>24|0;f=(f<<8)+2048|0;b=f>>>0<2048?b+1|0:b;K=a,M=wc((b&4095)<<20|f>>>12,b>>>12|0),v[K+480200>>2]=M;k=e|4;l=e|6;e=e|2;h=a+480188|0;f=0;while(1){if(wb(w[d+470|0]|w[d+471|0]<<8)>>>0<=(f&65535)>>>0){break t}v[22440]=0;R(382,d+40|0,d+328|0);b=v[22440];v[22440]=0;if((b|0)==1){break d}Q:{if(w[d+328|0]){break Q}b=wb(w[e|0]|w[e+1|0]<<8);if(b>>>0>=x[h>>1]){break Q}b=(b<<5)+a|0;K=b+480284|0,M=wc(((wb(w[l|0]|w[l+1|0]<<8)<<8)+2047>>>0)/4095|0,0),u[K>>1]=M;i=b+480286|0;g=wb(w[k|0]|w[k+1|0]<<8);b=g>>>26|0;g=(g<<6)+2048|0;b=g>>>0<2048?b+1|0:b;K=i,M=wc((b&4095)<<20|g>>>12,b>>>12|0)&255,u[K>>1]=M}f=f+1|0;continue}}a=P()|0;O()|0;sb(d+432|0);break c}a=P()|0;O()|0;break c}b=d+40|0;sb(b);v[22440]=0;U(383,b|0,d+808|0,1396788530);b=v[22440];v[22440]=0;if((b|0)==1){break e}K=d,M=yb(v[d+40>>2]),v[K+744>>2]=M;f=c&2;k=d+432|2;l=yb(v[d+44>>2]);g=a+480190|0;h=a+1298464|0;R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{while(1){e=v[d+744>>2];if(!Qb(e,l)){b=d+40|0;Ic(b);v[22440]=0;U(383,b|0,d+808|0,1396788560);b=v[22440];v[22440]=0;if((b|0)==1){break f}K=d,M=yb(v[d+40>>2]),v[K+776>>2]=M;k=d+432|2;l=yb(v[d+44>>2]);e=a+480190|0;break R}v[22440]=0;b=Q(384,e|0,d+432|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break T}$:{aa:{if(!b){break aa}b=wb(w[d+432|0]|w[d+433|0]<<8);if(!b|b>>>0>3999){break aa}if(wb(w[d+480|0]|w[d+481|0]<<8)>>>0>1){break aa}if(wb(w[d+462|0]|w[d+463|0]<<8)>>>0>1){break aa}if(x[g>>1]<b>>>0){u[g>>1]=b;b=wb(w[d+432|0]|w[d+433|0]<<8)}v[22440]=0;i=B(b,104)+a|0;n=i+484380|0;R(385,d+432|0,n|0);b=v[22440];v[22440]=0;ba:{ca:{da:{if((b|0)==1){break da}Gi(d+792|0,3,k);v[22440]=0;W(225,d+328|0,v[d+792>>2],v[d+796>>2],w[d+800|0]);b=v[22440];v[22440]=0;if((b|0)==1){break ca}b=d+328|0;uc(((wb(w[d+432|0]|w[d+433|0]<<8)<<5)+a|0)+946304|0,b);rb(b);if(!f){break aa}b=w[d+506|0]|w[d+507|0]<<8|(w[d+508|0]<<16|w[d+509|0]<<24);v[22440]=0;b=Q(157,e|0,Wb(b)-8|0)|0;p=v[22440];v[22440]=0;if((p|0)==1){break da}if(!b){break aa}if(wb(w[d+462|0]|w[d+463|0]<<8)){break ba}p=d+328|0;b=d+432|0;j=b+32|0;q=(wb(w[j|0]|w[j+1|0]<<8)|0)==8?8:16;j=b+36|0;b=b+34|0;Nc(p,q,(wb(w[j|0]|w[j+1|0]<<8)|0)==1?1:2,!wb(w[b|0]|w[b+1|0]<<8),0);v[22440]=0;Y(222,p|0,n|0,e|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break ba}a=P()|0;O()|0;break S}a=P()|0;O()|0;break S}a=P()|0;O()|0;break S}b=Db(d+328|0);n=w[d+482|0]|w[d+483|0]<<8;v[22440]=0;U(275,e|0,b|0,wb(n)|0);e=v[22440];v[22440]=0;if((e|0)==1){break V}pe(i+484423|0,b);if((wb(w[d+462|0]|w[d+463|0]<<8)|0)==1){v[22440]=0;R(386,d+776|0,16448);e=v[22440];v[22440]=0;if((e|0)==1){break $}v[22440]=0;U(11,d+760|0,0,b|0);e=v[22440];v[22440]=0;if((e|0)==1){break _}v[22440]=0;W(387,d+792|0,d+776|0,d+432|0,d+760|0);e=v[22440];v[22440]=0;if((e|0)==1){break Z}e=v[h>>2];v[22440]=0;U(388,e|0,2,d+792|0);e=v[22440];v[22440]=0;if((e|0)==1){break Y}rb(d+792|0);rb(d+760|0);Ab(d+776|0)}rb(b)}Uf(d+744|0);continue}break}a=P()|0;O()|0;break U}a=P()|0;O()|0;break W}a=P()|0;O()|0;break X}a=P()|0;O()|0;rb(d+792|0)}rb(d+760|0)}Ab(d+776|0);break U}a=P()|0;O()|0}rb(b);break S}a=P()|0;O()|0}Ic(d+40|0);break c}ea:{while(1){fa:{g=v[d+776>>2];if(!Qb(g,l)){Ic(d+40|0);v[22440]=0;U(383,d+792|0,d+808|0,1447382614);b=v[22440];v[22440]=0;if((b|0)!=1){break ea}a=P()|0;O()|0;break c}v[22440]=0;b=Q(389,g|0,d+432|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break fa}ga:{ha:{if(!b){break ha}b=wb(w[d+432|0]|w[d+433|0]<<8);if(!b|b>>>0>3999){break ha}if(wb(w[d+486|0]|w[d+487|0]<<8)){break ha}if(x[e>>1]<b>>>0){u[e>>1]=b;b=wb(w[d+432|0]|w[d+433|0]<<8)}v[22440]=0;b=(B(b,104)+a|0)+484380|0;R(390,d+432|0,b|0);h=v[22440];v[22440]=0;if((h|0)==1){break fa}Gi(d+792|0,3,k);v[22440]=0;W(225,d+328|0,v[d+792>>2],v[d+796>>2],w[d+800|0]);h=v[22440];v[22440]=0;if((h|0)==1){break fa}h=d+328|0;uc(((wb(w[d+432|0]|w[d+433|0]<<8)<<5)+a|0)+946304|0,h);rb(h);if(!f){break ha}h=d+328|0;i=d+432|0;n=i+34|0;i=i+30|0;Nc(h,(wb(w[n|0]|w[n+1|0]<<8)|0)==8?8:16,wb(w[i|0]|w[i+1|0]<<8)&1?2:1,1,0);v[22440]=0;Y(222,h|0,b|0,g|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break ga}}Uf(d+776|0);continue}}break}a=P()|0;O()|0;Ic(d+40|0);break c}v[22440]=0;U(383,d+776|0,d+808|0,1413828182);b=v[22440];v[22440]=0;if((b|0)==1){break h}v[22440]=0;U(383,d+760|0,d+808|0,1346719318);b=v[22440];v[22440]=0;if((b|0)==1){break j}v[22440]=0;U(383,d+744|0,d+808|0,1229869908);b=v[22440];v[22440]=0;if((b|0)==1){break l}K=d,M=yb(v[d+744>>2]),v[K>>2]=M;b=d+40|0;k=b|4;l=b|2;h=b|6;n=d+378|0;p=d+328|2;j=d+432|2;C=yb(v[d+748>>2]);D=a+480190|0;E=a+480208|0;while(1){ia:{ja:{ka:{la:{g=v[d>>2];if(!Qb(g,C)){Ic(d+744|0);v[22440]=0;U(383,d+328|0,d+808|0,1346458692);b=v[22440];v[22440]=0;if((b|0)!=1){break la}a=P()|0;O()|0;break k}v[22440]=0;b=Q(391,g|0,d+432|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break n}if(!b){break ia}if(wb(w[d+462|0]|w[d+463|0]<<8)){break ia}b=w[d+432|0]|w[d+433|0]<<8;v[22440]=0;e=Y(257,a|0,wb(b)|0,0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break n}if(!e){break ia}b=wb(w[d+432|0]|w[d+433|0]<<8);if(b>>>0>x[a+480192>>1]){u[a+480192>>1]=b}Gi(d+328|0,3,j);v[22440]=0;W(225,d+40|0,v[d+328>>2],v[d+332>>2],w[d+336|0]);b=v[22440];v[22440]=0;if((b|0)==1){break ka}b=d+40|0;uc(e+492|0,b);rb(b);t[e+33|0]=2;if((Rd((w[d+466|0]|w[d+467|0]<<8)<<16>>16)|0)>0){t[e+15|0]=w[e+15|0]|1;f=Rd((w[d+466|0]|w[d+467|0]<<8)<<16>>16);b=f>>>24|0;i=(f<<8&-256)+2047|0;f=b&255;K=e,M=wc(nka(i,i>>>0<2047?f+1|0:f,4095,0),fb),v[K+8>>2]=M}i=e+108|0;r=e+236|0;b=0;while(1){ma:{v[d+40>>2]=128;v[d+328>>2]=128;f=b&255;if(f>>>0>=y[Bb(d+40|0,d+328|0)>>2]){v[22440]=0;R(392,d+40|0,e|0);b=v[22440];v[22440]=0;if((b|0)==1){break ma}b=d+40|0;K=d,M=qk(b),v[K+328>>2]=M;f=Af(b);while(1){if(Qb(v[d+328>>2],f)){b=x[Xn(d+328|0)>>1];if(!(!b|b>>>0>x[D>>1])){K=(B(b,104)+a|0)+484410|0,M=wb(w[d+464|0]|w[d+465|0]<<8),u[K>>1]=M}um(d+328|0);continue}break}Ut(d+40|0);Jj(e,127,1);Ij(e,0,1);b=wb(w[d+482|0]|w[d+483|0]<<8);if(!b){v[e>>2]=0;b=w[d+468|0]|w[d+469|0]<<8;v[22440]=0;W(393,e|0,0,wb(b)|0,d+792|0);b=v[22440];v[22440]=0;if((b|0)==1){break n}b=w[d+472|0]|w[d+473|0]<<8;v[22440]=0;W(393,e|0,1,wb(b)|0,d+760|0);b=v[22440];v[22440]=0;if((b|0)==1){break n}b=w[d+470|0]|w[d+471|0]<<8;v[22440]=0;W(393,e|0,2,wb(b)|0,d+776|0);b=v[22440];v[22440]=0;if((b|0)!=1){break ia}break n}v[22440]=0;U(394,g|0,d+328|0,((b|0)==1?98:102)|0);b=v[22440];v[22440]=0;na:{oa:{pa:{if((b|0)!=1){f=wb(w[d+328|0]|w[d+329|0]<<8);i=f&1;if(!i){break ja}b=f&24;if(b){break pa}b=0;break oa}a=P()|0;O()|0;break m}if((b|0)!=8){break na}b=1}t[e+25|0]=b;f=wb(w[d+328|0]|w[d+329|0]<<8)}qa:{ra:{sa:{ta:{if(!(f&2)){break ta}v[22440]=0;b=Y(395,d+40|0,p|0,24)|0;f=v[22440];v[22440]=0;if((f|0)==1){break sa}v[22440]=0;A=+ma(396,b|0);f=v[22440];v[22440]=0;if((f|0)==1){break ra}rb(b);if(!(A>20)){break ta}Jj(e,PA(v[E>>2],A),1)}if(wb(w[d+328|0]|w[d+329|0]<<8)&4){break qa}break ja}a=P()|0;O()|0;break m}a=P()|0;O()|0;rb(b);break m}v[22440]=0;b=Y(395,d+40|0,n|0,24)|0;f=v[22440];v[22440]=0;ua:{if((f|0)!=1){v[22440]=0;A=+ma(396,b|0);f=v[22440];v[22440]=0;if((f|0)==1){break ua}rb(b);Ij(e,rk(A*127/24),1);break ja}a=P()|0;O()|0;break m}a=P()|0;O()|0;rb(b);break m}else{s=(d+432|0)+(f<<1)|0;K=Xb(r,f),M=w[s+52|0],u[K>>1]=M;f=Eb(i,f);K=f,M=wl(t[s+53|0]+w[f|0]|0),t[K|0]=M;b=b+1|0;continue}}break}a=P()|0;O()|0;break m}b=v[d+332>>2];e=v[d+328>>2];v[22440]=0;k=a+484344|0;R(228,k|0,Df(e,b)&65535);b=v[22440];v[22440]=0;va:{if((b|0)!=1){v[d+32>>2]=v[a+480204>>2];v[d+28>>2]=v[a+480196>>2];K=d,M=yb(v[d+328>>2]),v[K+16>>2]=M;C=c&1;b=d+744|0;D=b|4;E=b|2;r=b|1;s=yb(v[d+332>>2]);q=a+480188|0;while(1){wa:{xa:{ya:{za:{Aa:{Ba:{b=v[d+16>>2];if(!Qb(b,s)){v[22440]=0;U(379,d+40|0,d+808|0,1414414669);b=v[22440];v[22440]=0;if((b|0)!=1){break Ba}a=P()|0;O()|0;break va}if(!C){break wa}v[22440]=0;c=Q(158,b|0,24)|0;e=v[22440];v[22440]=0;if((e|0)==1){break Aa}if(!c){break wa}v[22440]=0;l=T(278,b|0)|0;c=v[22440];v[22440]=0;Ca:{Da:{Ea:{Fa:{if((c|0)!=1){t[d+448|0]=0;v[d+440>>2]=0;v[d+444>>2]=0;v[d+432>>2]=0;v[d+436>>2]=0;v[22440]=0;R(397,b|0,d+432|0);c=v[22440];v[22440]=0;if((c|0)==1){break Fa}v[22440]=0;n=T(278,b|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Ea}v[22440]=0;h=T(278,b|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Da}v[22440]=0;i=T(278,b|0)|0;c=v[22440];v[22440]=0;Ga:{if((c|0)==1){break Ga}v[22440]=0;c=Q(158,b|0,B(B(h,i),5)|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break Ga}if(!(c&n>>>0<2)){break wa}v[22440]=0;c=Y(229,k|0,l|0,h|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break Ga}if(!c){break wa}c=Sb(k,l);v[22440]=0;R(398,c|0,d+432|0);c=v[22440];v[22440]=0;if((c|0)!=1){break Ca}}a=P()|0;O()|0;break va}a=P()|0;O()|0;break va}a=P()|0;O()|0;break va}a=P()|0;O()|0;break va}a=P()|0;O()|0;break va}t[d|0]=0;c=ae(d+744|0,0,d);v[22440]=0;p=Y(374,d+40|0,i|0,c|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break xa}g=0;Ha:while(1){if((g|0)==(h|0)){_c(p);break wa}f=0;F=Gf(Sb(k,l),g);while(1){if((f|0)==(i|0)){g=g+1|0;continue Ha}G=tg(d+744|0);e=x[q>>1];v[22440]=0;R(399,b|0,d|0);c=v[22440];v[22440]=0;Ia:{if((c|0)==1){break Ia}c=F+B(f,6)|0;e=e>>>0>f>>>0;j=w[d|0];if((j-1&255)>>>0<=119){j=j+1|0;t[(e?c:d+744|0)|0]=j;K=Xb(v[d+40>>2],f),M=j,t[K|0]=M}j=w[d+1|0];if(j){t[(e?c+1|0:r)|0]=j;K=Xb(v[d+40>>2],f),M=j,t[K+1|0]=M}j=w[d+4|0];if(j){t[(e?c+2|0:E)|0]=1;t[(e?c+4|0:D)|0]=n?j-16|0:j>>>2|0}j=w[m|0];H=w[d+3|0];I=w[d+2|0];z=Xb(v[d+40>>2],f);J=w[z+1|0];z=w[z|0];v[22440]=0;Ca(376,a|0,(e?c:G)|0,I|0,H|0,j|0,z|0,J|0,d+32|0,d+28|0);c=v[22440];v[22440]=0;if((c|0)==1){break Ia}f=f+1|0;continue}break}break}a=P()|0;O()|0;_c(p);break va}v[22440]=0;b=Q(158,d+40|0,38)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(!b){break ya}v[22440]=0;c=T(278,d+40|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break za}b=d+432|0;e=b|4;b=b|2;g=a+480188|0;f=0;Ja:{while(1){if(c>>>0<=(f&65535)>>>0){break ya}v[22440]=0;m=Q(158,d+40|0,36)|0;k=v[22440];v[22440]=0;Ka:{if((k|0)!=1){if(m){break Ka}break ya}break za}v[22440]=0;R(400,d+40|0,d+432|0);m=v[22440];v[22440]=0;if((m|0)!=1){La:{if(wb(w[d+432|0]|w[d+433|0]<<8)){break La}if(wb(w[b|0]|w[b+1|0]<<8)>>>0>=x[g>>1]){break La}Ie(d,3,e);v[22440]=0;W(225,d+744|0,v[d>>2],v[d+4>>2],w[d+8|0]);m=v[22440];v[22440]=0;if((m|0)==1){break Ja}m=d+744|0;Al(((wb(w[b|0]|w[b+1|0]<<8)<<5)+a|0)+480289|0,m);rb(m)}f=f+1|0;continue}break}break za}break za}break za}a=P()|0;O()|0;break va}a=P()|0;O()|0;sb(d+40|0);break va}sb(d+40|0);Ic(d+328|0);Ic(d+760|0);Ic(d+776|0);Ic(d+792|0);f=1;break s}a=P()|0;O()|0;break va}Uf(d+16|0);continue}}a=P()|0;O()|0}Ic(d+328|0);break k}a=P()|0;O()|0;break m}f=0;while(1){if(w[d+429|0]<=f>>>0){break ia}v[22440]=0;R(401,g|0,d+40|0);b=v[22440];v[22440]=0;Ma:{Na:{if((b|0)!=1){v[d+32>>2]=33620480;K=d,M=(wb(w[d+468|0]|w[d+469|0]<<8)|0)!=0,t[K+28|0]=M;K=d,M=(wb(w[d+470|0]|w[d+471|0]<<8)|0)!=0,t[K+29|0]=M;K=d,M=(wb(w[d+472|0]|w[d+473|0]<<8)|0)!=0,t[K+30|0]=M;K=d,M=i&(wb(w[d+474|0]|w[d+475|0]<<8)|0)!=0,t[K+31|0]=M;if(!w[(d+28|0)+f|0]|f>>>0>3){break Ma}b=(f|0)!=3;if(!b&(t[e+100|0]&1)){break Ma}v[22440]=0;r=w[(d+32|0)+f|0];U(402,d+40|0,e|0,r|0);s=v[22440];v[22440]=0;if((s|0)==1){break Na}if(!b){t[e+100|0]=w[e+100|0]|16}Oa:{switch(r|0){case 0:if(wb(w[d+52|0]|w[d+53|0]<<8)&1){b=wb(w[d+50|0]|w[d+51|0]<<8)&32767}else{b=0}v[e>>2]=b;break Ma;case 2:break Oa;default:break Ma}}if(!(wb(w[d+52|0]|w[d+53|0]<<8)&2)){break Ma}K=d,M=wb(w[h|0]|w[h+1|0]<<8),u[K+16>>1]=M;u[d+26>>1]=1;b=x[ie(d+16|0,d+26|0)>>1];r=El(wc(((wb(w[l|0]|w[l+1|0]<<8)<<6|48)>>>0)/100|0,0));K=d,M=wb(w[k|0]|w[k+1|0]<<8),u[K+16>>1]=M;u[d+26>>1]=1;s=rg(256/x[ie(d+16|0,d+26|0)>>1]|0);q=wb(w[d+432|0]|w[d+433|0]<<8);F=w[d+48|0]|w[d+49|0]<<8;v[22440]=0;z=q;q=wb(F);ka(403,a|0,z|0,w[(q>>>0<6?q:0)+26704|0],255/(b>>>0)|0,r|0,s|0);b=v[22440];v[22440]=0;if((b|0)!=1){break Ma}a=P()|0;O()|0;break m}a=P()|0;O()|0;break m}a=P()|0;O()|0;break m}f=f+1|0;continue}}Uf(d);continue}}Qd(d+808|0);sb(o)}cb=d+1136|0;return f|0}a=P()|0;O()|0}Ic(d+744|0);break k}a=P()|0;O()|0}Ic(d+760|0);break i}a=P()|0;O()|0}Ic(d+776|0);break g}a=P()|0;O()|0}Ic(d+792|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;sb(d+40|0)}Qd(d+808|0)}sb(o)}S(a|0);L()}function G9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,T=0,U=0,V=0,X=0,Z=0,_=0,$=0,aa=0,ba=0,da=0;n=cb-1152|0;cb=n;sc(b);a:{if(!Yq(b,n+1128|0)){break a}if(!VK(n+1128|0)){break a}d=n+1136|0;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=(Ck(b)|0)){break a}m=n+1144|0;if((w[m|0]|w[m+1|0]<<8|(w[m+2|0]<<16|w[m+3|0]<<24))!=(_e(b)|0)){break a}if(!c){h=1;break a}g=n+1072|0;Hb(g,0,56);k=-2;b:{if(!g){break b}v[g+44>>2]=0;v[g+48>>2]=0;v[g+52>>2]=0;v[g+20>>2]=0;v[g+24>>2]=0;v[g+8>>2]=0;d=v[g+32>>2];if(!d){v[g+32>>2]=1116;d=1116}if(!v[g+36>>2]){v[g+36>>2]=1117}d=gb[d|0](v[g+40>>2],1,43784)|0;k=-4;if(!d){break b}v[g+28>>2]=d;v[d+43780>>2]=1;v[d+10992>>2]=0;v[d+10996>>2]=0;v[d>>2]=0;v[d+11008>>2]=15;v[d+11e3>>2]=1;v[d+11004>>2]=0;k=0}if(k){break a}h=w[m|0]|w[m+1|0]<<8|(w[m+2|0]<<16|w[m+3|0]<<24);v[n+1068>>2]=h;d=n+1148|0;I=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);T=JS(n+1056|0,I);c:{d:{while(1){if(!(!h|!I|(e|0)==1)){v[n+16>>2]=1024;e=n+16|0;U=v[Bb(e,n+1068|0)>>2];$b(n+24|0,n+32|0,U);v[22440]=0;W(167,e|0,b|0,v[n+24>>2],v[n+28>>2]);e=v[22440];v[22440]=0;if((e|0)==1){break d}d=n+32|0;e=d;h=U;g=aa^-1;while(1){if(h>>>0<4){while(1){if(h){g=v[((w[e|0]^g&255)<<2)+59088>>2]^g>>>8;h=h-1|0;e=e+1|0;continue}break}e=g^-1}else{g=v[((w[e|0]^g&255)<<2)+59088>>2]^g>>>8;g=g>>>8^v[((w[e+1|0]^g&255)<<2)+59088>>2];g=g>>>8^v[((w[e+2|0]^g&255)<<2)+59088>>2];g=g>>>8^v[((w[e+3|0]^g&255)<<2)+59088>>2];h=h-4|0;e=e+4|0;continue}break}aa=e;v[n+1076>>2]=U;v[n+1072>>2]=d;v[n+1088>>2]=I;v[n+1084>>2]=v[T>>2]+ba;F=cb-16|0;cb=F;e=-2;p=n+1072|0;e:{if(!p){break e}i=v[p+28>>2];if(!i){break e}da=v[p+4>>2];v[i+11e3>>2]=0;f:{if(v[i+43780>>2]<0){break f}if(v[i+11004>>2]){break e}g=v[i+11008>>2];e=0;v[i+11004>>2]=0;d=v[i+10996>>2];if(!d){z=(g|0)>0?11:10;J=i+11012|0;h=v[p+4>>2];k=v[i+10992>>2];while(1){v[F+12>>2]=h;v[F+8>>2]=32768-k;E=v[p>>2];d=0;h=0;m=0;G=0;K=0;V=0;_=0;$=cb-144|0;cb=$;g:{h:{D=k+J|0;if(J>>>0<=D>>>0){e=v[F+8>>2];X=z&4;Z=X?-1:e+((J^-1)+D|0)|0;s=Z+1|0;if(!(s&Z)){break h}}v[F+8>>2]=0;v[F+12>>2]=0;o=-3;break g}M=e+D|0;r=v[F+12>>2];C=r+E|0;N=v[i+60>>2];A=v[i+40>>2];e=v[i+36>>2];q=v[i+32>>2];g=v[i+56>>2];f=v[i+4>>2];o=-1;j=E;l=D;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{k=v[i>>2];switch(k|0){case 36:break l;case 39:break n;case 10:break o;case 35:break p;case 17:break q;case 21:break r;case 37:break s;case 34:break t;case 42:break x;case 41:break y;case 53:break z;case 52:break A;case 51:break B;case 38:break C;case 27:break D;case 26:break E;case 25:break F;case 24:break G;case 23:break H;case 18:break I;case 16:break J;case 14:break K;case 11:break L;case 9:break M;case 7:break N;case 6:break O;case 3:break P;case 32:break Q;case 5:break R;case 2:break T;case 1:break U;case 0:break V;default:break k}}v[i+28>>2]=1;g=0;v[i+8>>2]=0;v[i+12>>2]=0;v[i+16>>2]=1;A=0;e=0;q=0;f=0;if(z&1){break U}break S}if((r|0)<=0){v[i>>2]=1;break j}v[i+8>>2]=w[E|0];j=E+1|0}if(j>>>0>=C>>>0){v[i>>2]=2;o=z&2?1:-4;break i}e=w[j|0];v[i+12>>2]=e;j=j+1|0;W:{h=v[i+8>>2];X:{if(!(((e|h<<8)>>>0)%31|e&32)){d=h&15;if(X){break W}d=(d|0)!=8;break X}k=36;d=1;if(X){break m}}k=36;e=256<<(h>>>4);if(e>>>0>32768|e>>>0>s>>>0){break m}e=0;if(d){break m}break S}e=0;k=36;if((d|0)!=8){break m}}d=0;break w}if((r|0)<=0){v[i>>2]=5;break j}V=f+8|0;j=E+1|0;g=w[E|0]<<f|g;d=2;break w}if((r|0)<=0){v[i>>2]=32;break j}j=E+1|0;g=w[E|0]<<f|g;f=f+8|0;break v}d=1;break w}d=4;break w}d=3;break w}d=7;break w}d=9;break w}d=10;break w}d=11;break w}d=12;break w}d=13;break w}d=14;break w}d=15;break w}d=16;break w}d=17;break w}d=8;break w}d=5;break w}d=6;break w}d=18;break w}k=2;break u}k=1;break u}Y:while(1){Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{switch(d|0){case 0:if(f>>>0>2){break Ea}d=1;continue;case 4:break Ba;case 3:break Ca;case 2:break Da;case 1:break Fa;case 9:break ia;case 10:break ja;case 11:break ka;case 12:break la;case 13:break ma;case 14:break na;case 15:break oa;case 16:break pa;case 17:break qa;case 8:break wa;case 7:break xa;case 6:break ya;case 5:break za;default:break ra}}while(1){if(j>>>0>=C>>>0){v[i>>2]=3;o=z&2?1:-4;break i}g=w[j|0]<<f|g;j=j+1|0;f=f+8|0;if(f>>>0<3){continue}break}}d=g&7;v[i+20>>2]=d;k=d>>>1|0;v[i+24>>2]=k;f=f-3|0;g=g>>>3|0;if(d>>>0>=2){break va}V=f;break sa}f=V&-8;g=g>>>(V&7)|0;e=0;d=0;break ua}if(j>>>0<C>>>0){break Aa}v[i>>2]=7;o=z&2?1:-4;break i}while(1){if(j>>>0>=C>>>0){v[i>>2]=6;o=z&2?1:-4;break i}g=w[j|0]<<f|g;d=f>>>0>4294967287;j=j+1|0;f=f+8|0;if(d){continue}break}d=1;break ua}t[(e+i|0)+10528|0]=w[j|0];j=j+1|0;d=2;break ua}while(1){if(j>>>0>=C>>>0){v[i>>2]=51;o=z&2?1:-4;break i}g=w[j|0]<<f|g;d=f>>>0>4294967287;j=j+1|0;f=f+8|0;if(d){continue}break}break aa}if(l>>>0<M>>>0){t[l|0]=q;e=e-1|0;l=l+1|0;break ba}o=2;k=52;break l}if(l>>>0<M>>>0){break ta}o=2;k=9;break l}if(j>>>0<C>>>0){d=M-l|0;h=C-j|0;d=d>>>0<h>>>0?d:h;d=d>>>0<e>>>0?d:e;e=e-d|0;l=ic(l,j,d)+d|0;j=d+j|0;break $}v[i>>2]=38;o=z&2?1:-4;break i}h=0;Ga:{switch(k-1|0){case 0:v[i+44>>2]=288;v[i+48>>2]=32;d=i+3552|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i+3560|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i+3568|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i+3576|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i- -64|0;k=0;while(1){h=144;if((k|0)==144){while(1){k=256;if((h|0)==256){while(1){h=280;if((k|0)==280){while(1){if((h|0)==288){break fa}t[d|0]=8;h=h+1|0;d=d+1|0;continue}}else{t[d|0]=7;k=k+1|0;d=d+1|0;continue}}}else{t[d|0]=9;h=h+1|0;d=d+1|0;continue}}}else{t[d|0]=8;k=k+1|0;d=d+1|0;continue}};case 2:break o;default:break Ga}}d=0;break ha}while(1){Ha:{Ia:{Ja:{Ka:{La:{switch(d|0){case 0:if(e>>>0>3){break Ka}if(!f){f=0;d=3;continue Y}if(f>>>0>7){break Ia}d=4;continue Y;case 1:t[(e+i|0)+10528|0]=g;f=f-8|0;g=g>>>8|0;break Ha;default:break La}}e=e+1|0;break Ja}e=x[i+10528>>1];if((e|0)==(x[i+10530>>1]^65535)){break ba}break n}d=0;continue}d=1;continue}d=2;continue}}d=8;continue}d=2;continue}if(l>>>0>=M>>>0){o=2;k=53;break l}t[l|0]=w[(N-q&Z)+J|0];l=l+1|0;N=N+1|0;d=7;break ca}while(1){if(j>>>0>=C>>>0){v[i>>2]=27;o=z&2?1:-4;break i}g=w[j|0]<<f|g;j=j+1|0;f=f+8|0;if(A>>>0>f>>>0){continue}break}d=6;break ca}if(j>>>0>=C>>>0){v[i>>2]=26;o=z&2?1:-4;break i}g=w[j|0]<<f|g;j=j+1|0;f=f+8|0;d=4;if(f>>>0<15){break ca}d=5;break ca}while(1){if(j>>>0>=C>>>0){v[i>>2]=25;o=z&2?1:-4;break i}g=w[j|0]<<f|g;j=j+1|0;f=f+8|0;if(A>>>0>f>>>0){continue}break}d=3;break ca}if(l>>>0>=M>>>0){o=2;k=24;break l}t[l|0]=e;l=l+1|0;break da}if(j>>>0>=C>>>0){v[i>>2]=23;o=z&2?1:-4;break i}g=w[j|0]<<f|g;j=j+1|0;f=f+8|0;d=0;if(f>>>0<15){break ca}d=1;break ca}while(1){if(j>>>0>=C>>>0){v[i>>2]=18;o=z&2?1:-4;break i}g=w[j|0]<<f|g;j=j+1|0;f=f+8|0;if(A>>>0>f>>>0){continue}break}_=q-16|0;d=3;break ea}if(j>>>0>=C>>>0){v[i>>2]=16;o=z&2?1:-4;break i}g=w[j|0]<<f|g;j=j+1|0;f=f+8|0;d=1;if(f>>>0<15){break ea}d=2;break ea}while(1){if(j>>>0>=C>>>0){v[i>>2]=14;o=z&2?1:-4;break i}g=w[j|0]<<f|g;j=j+1|0;f=f+8|0;if(f>>>0<3){continue}break}d=1;break ga}d=e+21666|0;while(1){if(j>>>0>=C>>>0){v[i>>2]=11;o=z&2?1:-4;break i}g=w[j|0]<<f|g;j=j+1|0;f=f+8|0;K=t[d|0];if(f>>>0<K>>>0){continue}break}h=e;d=1}while(1){Ma:{Na:{Oa:{if(!d){if(h>>>0>2){break Oa}e=h;K=t[e+21666|0];if(K>>>0<=f>>>0){break Ma}d=9;continue Y}e=h<<2;v[(e+i|0)+44>>2]=v[e+60624>>2]+((-1<<K^-1)&g);h=h+1|0;f=f-K|0;g=g>>>K|0;break Na}e=0;Hb(i+7040|0,0,288);d=0;break ga}d=0;continue}d=1;continue}}while(1){Pa:{Qa:{Ra:{if(!d){if(y[i+52>>2]<=e>>>0){break Ra}if(f>>>0>2){break Pa}d=10;continue Y}t[(w[e+60640|0]+i|0)+7040|0]=g&7;e=e+1|0;f=f-3|0;g=g>>>3|0;break Qa}v[i+52>>2]=19;break fa}d=0;continue}d=1;continue}}G=v[i+24>>2];d=0}while(1){Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{switch(d|0){case 0:d=0;if((G|0)<0){break da}Q=Hb($,0,64);k=B(G,3488)+i|0;Hb(k+352|0,0,3200);H=v[i+24>>2];h=v[((H<<2)+i|0)+44>>2];while(1){if((d|0)!=(h|0)){r=(w[(d+k|0)- -64|0]<<2)+Q|0;v[r>>2]=v[r>>2]+1;d=d+1|0;continue}break};v[Q+64>>2]=0;v[Q+68>>2]=0;s=0;d=1;k=0;while(1){if((d|0)!=16){r=d<<2;d=d+1|0;r=v[r+Q>>2];k=r+k<<1;v[(Q- -64|0)+(d<<2)>>2]=k;s=s+r|0;continue}break};R=0;r=-1;if((k|0)!=65536&s>>>0>=2){break p}while(1){if(h>>>0>R>>>0){s=w[((B(G,3488)+i|0)+R|0)- -64|0];bb:{if(!s){break bb}d=(Q- -64|0)+(s<<2)|0;k=v[d>>2];v[d>>2]=k+1;d=0;h=s;while(1){if(h){d=k&1|d<<1;k=k>>>1|0;h=h-1|0;continue}break}if(s>>>0<=10){h=1<<s;k=s<<9|R;s=B(G,3488)+i|0;while(1){if(d>>>0>1023){break bb}u[(s+(d<<1)|0)+352>>1]=k;d=d+h|0;continue}}H=B(G,3488)+i|0;k=H+((d&1023)<<1)|0;h=u[k+352>>1];cb:{if(h){k=r;r=h;break cb}u[k+352>>1]=r;k=r-2|0}d=d>>>9|0;while(1){d=d>>>1|0;h=d&1;if(s>>>0>=12){h=(H+(h+(r^-1)<<1)|0)+2400|0;r=u[h>>1];if(!r){u[h>>1]=k;r=k;k=k-2|0}s=s-1|0;continue}break}u[((B(G,3488)+i|0)+(h+(r^-1)<<1)|0)+2400>>1]=R;r=k}R=R+1|0;H=v[i+24>>2];h=v[((H<<2)+i|0)+44>>2];continue}break};d=0;if((H|0)!=2){break Va}break Za;case 1:d=u[(((g&1023)<<1)+i|0)+7328>>1];db:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>f>>>0){break db}break Ya}if(f>>>0<11){break db}h=10;while(1){d=u[(((g>>>h&1)+(d^-1)<<1)+i|0)+9376>>1];if((d|0)<0){k=h+2|0;h=h+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break Ya}}d=11;continue Y;case 2:q=u[(((g&1023)<<1)+i|0)+7328>>1];if((q|0)>=0){break $a}d=10;while(1){h=g>>>d|0;d=d+1|0;q=u[(((h&1)+(q^-1)<<1)+i|0)+9376>>1];if((q|0)<0){continue}break};break _a;default:break ab}}d=t[_+17875|0]+((-1<<A^-1)&g)|0;f=f-A|0;g=g>>>A|0;h=e+i|0;Hb(h+10532|0,(q|0)==16?w[h+10531|0]:0,d);d=d+e|0;break Za}d=q>>9;q=q&511}f=f-d|0;g=g>>>d|0;if(q>>>0>15){break Xa}t[(e+i|0)+10532|0]=q;d=e+1|0}h=v[i+48>>2];e=v[i+44>>2];k=h+e|0;if(k>>>0<=d>>>0){break Wa}if(f>>>0<=14){if((C-j|0)<=1){e=d;d=1;continue}g=w[j|0]<<f|g|w[j+1|0]<<f+8;j=j+2|0;f=f+16|0}e=d}d=2;continue}if(!((q|0)!=16|e)){e=0;q=16;break q}A=t[q+21641|0];if(A>>>0>f>>>0){break Ua}_=q-16|0;break Sa}if((d|0)!=(k|0)){e=d;break r}k=i+10532|0;ic(i- -64|0,k,e);ic(i+3552|0,e+k|0,h);H=v[i+24>>2];e=d}G=H-1|0;v[i+24>>2]=G;break Ta}d=12;continue Y}d=0;continue}d=3;continue}}m=g;d=2}eb:while(1){fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{switch(d|0){case 0:d=u[(((g&1023)<<1)+i|0)+352>>1];ub:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>f>>>0){break ub}break fb}if(f>>>0<11){break ub}h=10;while(1){d=u[(((g>>>h&1)+(d^-1)<<1)+i|0)+2400>>1];if((d|0)<0){k=h+2|0;h=h+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break fb}}d=13;continue Y;case 1:e=u[(((g&1023)<<1)+i|0)+352>>1];if((e|0)>=0){break sb}d=10;while(1){h=g>>>d|0;d=d+1|0;e=u[(((h&1)+(e^-1)<<1)+i|0)+2400>>1];if((e|0)<0){continue}break};break rb;case 3:break ib;case 4:break jb;case 5:break nb;case 6:break ob;case 2:break tb;default:break pb}}while(1){d=C-j|0;if(!((M-l|0)>1&(d|0)>=4)){if(f>>>0>14){g=m;break fb}if((d|0)<=1){g=m;d=0;continue eb}g=w[j|0]<<f|m|w[j+1|0]<<f+8;f=f+16|0;j=j+2|0;break fb}if(f>>>0>14){k=j}else{m=(w[j|0]|w[j+1|0]<<8)<<f|m;f=f+16|0;k=j+2|0}e=u[(((m&1023)<<1)+i|0)+352>>1];vb:{if((e|0)<0){d=10;while(1){g=m>>>d|0;d=d+1|0;e=u[(((g&1)+(e^-1)<<1)+i|0)+2400>>1];if((e|0)<0){continue}break}break vb}d=e>>9}f=f-d|0;g=m>>>d|0;if(e&256){j=k;break qb}if(!(f>>>0>14)){g=(w[k|0]|w[k+1|0]<<8)<<f|g;k=k+2|0;f=f+16|0}s=f;j=k;h=u[(((g&1023)<<1)+i|0)+352>>1];wb:{if((h|0)<0){d=10;while(1){m=g>>>d|0;d=d+1|0;h=u[(((m&1)+(h^-1)<<1)+i|0)+2400>>1];if((h|0)<0){continue}break}break wb}d=h>>9}t[l|0]=e;f=s-d|0;m=g>>>d|0;if(!(h&256)){t[l+1|0]=h;l=l+2|0;continue}break}l=l+1|0;g=m;e=h;break qb}d=e>>9;e=e&511}f=f-d|0;g=g>>>d|0;if(e>>>0>255){break qb}d=14;continue Y}h=e&511;e=256;if((h|0)==256){break _}d=h<<2;e=v[d+59084>>2];A=0;if(h-285>>>0<4294967276){break hb}A=v[d+59212>>2];if(A>>>0>f>>>0){d=15;continue Y}d=3;continue}if(!e){m=g;e=-1;break lb}e=e-1|0;d=18;continue Y}f=f-A|0;m=g>>>A|0;q=((-1<<A^-1)&g)+q|0;break mb}d=u[(((g&1023)<<1)+i|0)+3840>>1];xb:{if((d|0)<0){h=10;while(1){k=g>>>h|0;h=h+1|0;d=u[(((k&1)+(d^-1)<<1)+i|0)+5888>>1];if((d|0)<0){continue}break}break xb}h=d>>9;d=d&511}f=f-h|0;g=g>>>h|0;h=d<<2;q=v[h+60368>>2];A=0;if(d-30>>>0<4294967270){m=g;break mb}A=v[h+60496>>2];if(A>>>0<=f>>>0){break kb}d=17;continue Y}N=l-J|0;if(!(!X|(q|0)!=0&N>>>0>=q>>>0)){g=m;break s}d=(N-q&Z)+J|0;if((d>>>0<l>>>0?l:d)+e>>>0>M>>>0){g=m;d=7;continue}while(1){if(e>>>0>=3){t[l|0]=w[d|0];t[l+1|0]=w[d+1|0];t[l+2|0]=w[d+2|0];e=e-3|0;d=d+3|0;l=l+3|0;continue}break}if(!e){e=0;break lb}t[l|0]=w[d|0];if((e|0)!=1){t[l+1|0]=w[d+1|0]}l=e+l|0}d=2;continue}d=6;continue}d=u[(((g&1023)<<1)+i|0)+3840>>1];yb:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>f>>>0){break yb}break gb}if(f>>>0<11){break yb}h=10;while(1){d=u[(((g>>>h&1)+(d^-1)<<1)+i|0)+5888>>1];if((d|0)<0){k=h+2|0;h=h+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break gb}}d=16;continue Y}f=f-A|0;e=((-1<<A^-1)&g)+e|0;g=g>>>A|0}if(f>>>0>14){break gb}if((C-j|0)<=1){d=4;continue}g=w[j|0]<<f|g|w[j+1|0]<<f+8;f=f+16|0;j=j+2|0}d=5;continue}d=1;continue}}if(!e|!f){break $}if(f>>>0>7){break aa}d=5;continue}f=f-8|0;q=g&255;g=g>>>8|0;d=6;continue}if(e){break Z}e=0}if(t[i+20|0]&1){break v}d=0;continue}d=7;continue}}h=0;m=f>>>3|0;d=j-E|0;d=d>>>0>j>>>0?0:d;m=d?d>>>0>m>>>0?m:d:0;d=(f&-8)-(m<<3)|0;if(!d){j=j-m|0;g=(((d&63)>>>0>=32?0:-1<<d)^-1)&g>>>(f&7);d=0;f=0;if(!(z&1)){break t}k=0;break u}ca(6842,13204,2797,6852);L()}while(1){zb:{Ab:{Bb:{Cb:{Db:{Eb:{switch(k|0){case 0:if(h>>>0>3){e=h;f=d;break t}if(d){break Db}f=0;e=h;k=1;continue;case 1:break Eb;default:break Cb}}if(j>>>0<C>>>0){break Ab}v[i>>2]=42;o=z&2?1:-4;break i}e=h;f=d;if(d>>>0>7){break Bb}k=2;continue}while(1){if(j>>>0>=C>>>0){v[i>>2]=41;o=z&2?1:-4;break i}g=w[j|0]<<f|g;h=f>>>0>4294967287;j=j+1|0;d=f+8|0;f=d;if(h){continue}break}h=e}k=g&255;g=g>>>8|0;d=d-8|0;break zb}k=w[j|0];j=j+1|0;h=e;d=f}v[i+16>>2]=v[i+16>>2]<<8|k;h=h+1|0;k=0;continue}}o=0;k=34;break l}k=37;break l}k=21;break l}k=17;break l}k=35;break l}k=10;break l}k=39;break l}e=1}v[i>>2]=k}d=f-7|0;h=(d>>>0>f>>>0?0:d)+7>>>3|0;d=j-E|0;d=d>>>0>j>>>0?0:d;d=d?d>>>0>h>>>0?h:d:0;j=j-d|0;f=f-(d<<3)|0;break i}o=z&2?1:-4}v[i+4>>2]=f;v[i+60>>2]=N;v[i+40>>2]=A;v[i+36>>2]=e;v[i+32>>2]=q;v[i+56>>2]=(((f&63)>>>0>=32?0:-1<<f)^-1)&g;v[F+12>>2]=j-E;g=l-D|0;v[F+8>>2]=g;if(!(z&9)|(o|0)<0){break g}f=(g>>>0)%5552|0;e=v[i+28>>2];d=e>>>16|0;h=e&65535;while(1){k=0;if(g){while(1){if((k|7)>>>0<f>>>0){e=w[D|0]+h|0;m=e+w[D+1|0]|0;j=m+w[D+2|0]|0;r=j+w[D+3|0]|0;s=r+w[D+4|0]|0;l=s+w[D+5|0]|0;E=l+w[D+6|0]|0;h=E+w[D+7|0]|0;d=h+(E+(l+(s+(r+(j+(m+(d+e|0)|0)|0)|0)|0)|0)|0)|0;D=D+8|0;k=k+8|0;continue}break}e=f&7;k=f&8184;j=D;while(1){if((f|0)!=(k|0)){k=k+1|0;h=w[j|0]+h|0;d=h+d|0;j=j+1|0;continue}break}g=g-f|0;d=(d>>>0)%65521|0;h=(h>>>0)%65521|0;D=e+D|0;f=5552;continue}else{e=d<<16|h;v[i+28>>2]=e;if(o){break g}o=0;if(!(z&1)){break g}e=(e|0)==v[i+16>>2]?0:-2}break}o=e}cb=$+144|0;v[i+43780>>2]=o;e=v[F+12>>2];v[p>>2]=e+v[p>>2];v[p+4>>2]=v[p+4>>2]-e;v[p+8>>2]=e+v[p+8>>2];v[p+48>>2]=v[i+28>>2];e=v[F+8>>2];v[i+10996>>2]=e;d=v[p+16>>2];e=d>>>0>e>>>0?e:d;ic(v[p+12>>2],v[i+10992>>2]+J|0,e);v[p+12>>2]=e+v[p+12>>2];v[p+16>>2]=v[p+16>>2]-e;v[p+20>>2]=e+v[p+20>>2];d=v[i+10996>>2]-e|0;v[i+10996>>2]=d;k=e+v[i+10992>>2]&32767;v[i+10992>>2]=k;if((o|0)<0){break f}if(!((o|0)!=1|da)){e=-5;break e}if(o){e=0;h=v[p+4>>2];if(!h|!v[p+16>>2]){break e}if(!d){continue}break e}break}e=!d;break e}g=v[p+16>>2];d=d>>>0<g>>>0?d:g;ic(v[p+12>>2],(v[i+10992>>2]+i|0)+11012|0,d);v[p+12>>2]=d+v[p+12>>2];v[p+16>>2]=v[p+16>>2]-d;v[p+20>>2]=d+v[p+20>>2];g=v[i+10996>>2]-d|0;v[i+10996>>2]=g;v[i+10992>>2]=d+v[i+10992>>2]&32767;if(v[i+43780>>2]){break e}e=!g;break e}e=-3}cb=F+16|0;h=v[n+1068>>2]-U|0;v[n+1068>>2]=h;d=I+ba|0;I=v[n+1088>>2];ba=d-I|0;continue}break}b=n+1072|0;Fb:{if(!b){break Fb}d=v[b+28>>2];if(!d){break Fb}gb[v[b+36>>2]](v[b+40>>2],d);v[b+28>>2]=0}h=0;Gb:{Hb:{b=n+1140|0;if(!((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=(aa|0)|I|(e|0)!=1)){qe(n+8|0,v[T>>2],v[T+4>>2]);b=ee(n);e=v[b+4>>2];b=v[b>>2];v[22440]=0;b=ea(553,n+32|0,v[n+8>>2],v[n+12>>2],b|0,e|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break Hb}v[22440]=0;h=Y(895,a|0,b|0,c|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break Gb}sb(b)}_b(T);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;sb(b);break c}a=P()|0;O()|0}_b(T);S(a|0);L()}cb=n+1152|0;return h|0}function rga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=C(0),A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,T=C(0),U=C(0),W=0,Z=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=C(0),na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=C(0);p=cb-11360|0;cb=p;sc(c);a:{b:{c:{d:{while(1){e:{if(!Kb(c,4)){break e}f=p+16|0;g=cb-16|0;cb=g;f:{if(!Kb(c,3)){d=f;h=f+3|0;while(1){if((d|0)!=(h|0)){ug(d);d=d+1|0;continue}break}break f}gv(g+8|0,f);md(g,c,v[g+8>>2],v[g+12>>2])}cb=g+16|0;g:{h:{if(!Mb(f,15111,3)){d=p+4648|0;f=cb-16|0;cb=f;i:{if(!Kb(c,7)){g=d+7|0;while(1){if((d|0)!=(g|0)){ug(d);d=d+1|0;continue}break}break i}mo(f+8|0,d);md(f,c,v[f+8>>2],v[f+12>>2])}cb=f+16|0;d=0;A=3;while(1){if((A|0)==7){break g}f=w[(p+4648|0)+A|0];if(f&128){break h}A=A+1|0;d=f|d<<7;continue}}j:{if(Mb(p+16|0,14284,3)){break j}if(!oR(c,13599)){break j}Ob(c,Ag(c)+16|0);continue}if(!Mb(p+16|0,30334,3)){continue}if(!Mb(p+16|0,30338,3)){continue}d=w[p+16|0];if(!d){xg(c,2);continue}if(PO(d,w[p+17|0],w[p+18|0])){break e}}A=0;break d}Ob(c,d);continue}break}sc(c);d=p+11336|0;yA(d,c);ca=v[p+11336>>2];A=ce(d);W=Rb(p+11320|0);c=p+4648|0;Hb(c,0,6668);Ty(c);c=p+4640|0;v[c>>2]=0;v[c+4>>2]=0;c=p+4632|0;v[c>>2]=0;v[c+4>>2]=0;v[p+4624>>2]=0;v[p+4628>>2]=0;d=0;c=0;k:{while(1){g=yc(ca,da);aa=p+16|0;N=p+4624|0;f=0;n=cb-17168|0;cb=n;v[n+17164>>2]=0;l:{m:{H=p+4648|0;n:{if(w[H+6152|0]!=255|(g|0)<5){break n}if(!Zo(H+6152|0,A)){break n}o=Rw(w[A+1|0],w[A+2|0],v[H+6148>>2])+Yo(A)|0;v[n+17164>>2]=o;if((g|0)==(o|0)){o=g;break m}o:{if((g|0)>=(o+4|0)){if(Zo(A,o+A|0)){break o}}v[n+17164>>2]=0;break n}if(o){break m}}i=A;m=Hb(H,0,6668)+6148|0;s=n+17164|0;q=0;k=0;J=g-4|0;D=(J|0)>0?J:0;while(1){p:{q:{r:{s:{if((q|0)==(D|0)){q=g;break s}if(!pH(i)){break q}l=Rw(w[i+1|0],w[i+2|0],v[m>>2]);f=l+Yo(i)|0;h=4;r=q+4|0;t:{while(1){if(!(h>>>0>2303|l)){if((J|0)<=((h<<1)+q|0)){break t}l=0;o=h+i|0;u:{if(!Zo(i,o)){break u}j=h-Yo(i)|0;E=Yo(o)+j|0;if((g|0)<(E+(h+r|0)|0)){break u}if(!Zo(i,o+E|0)){break u}v[m>>2]=j;l=j;f=h}h=h+1|0;continue}break}if(!l|(g|0)<(f+q|0)){break t}r=g-q|0;h=0;o=0;while(1){v:{w:{if((o|0)!=10){j=(o|0)!=0;G=h;h=h+i|0;h=(G+Rw(w[h+1|0],w[h+2|0],l)|0)+Yo(h)|0;if((r|0)<(h+4|0)){break v}if(Zo(i,h+i|0)){break w}j=0}else{j=1}break v}o=o+1|0;continue}break}if(!j){break t}k=f;break s}if((f|0)!=(g|0)|q){break r}q=0;k=g}v[s>>2]=k;f=q;break p}v[m>>2]=0}i=i+1|0;q=q+1|0;continue}break}o=v[n+17164>>2];if((g|0)>=(f+o|0)?o:0){break m}v[N>>2]=f;q=0;break l}g=f+A|0;v[H+6152>>2]=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);v[N+4>>2]=f;v[N>>2]=f+o;v[N+8>>2]=w[g+3|0]>191?1:2;sa=N,ta=sH(w[g+1|0],w[g+2|0]),v[sa+12>>2]=ta;v[N+16>>2]=4-(w[g+1|0]>>>1&3);sa=N,ta=Qw(w[g+1|0],w[g+2|0]),v[sa+20>>2]=ta;if(!aa){q=Pw(w[g+1|0]);break l}rH(n+17152|0,g+4|0,o-4|0);if(!(t[g+1|0]&1)){he(n+17152|0,16)}x:{if(v[N+16>>2]==3){q=0;k=n+17152|0;f=n+3740|0;i=0;h=w[g+1|0];l=B((h>>>3&1)+(h>>>4&1)|0,3)+(w[g+2|0]>>>2&3)|0;j=l-((l|0)!=0)|0;J=g;g=w[g+3|0]>191?1:2;y:{if(h&8){l=he(k,9);g=g<<1;i=he(k,g+7|0);break y}l=he(k,g|8)>>>g|0}h=B(j,40);s=h+60960|0;D=h+61280|0;r=B(j,23)+60768|0;m=-1;o=0;z:{while(1){h=w[J+3|0];E=he(k,12);u[f+4>>1]=E;j=he(k,9);u[f+6>>1]=j;if((j&65535)>>>0>288){break z}h=h>>>0>191?i<<4:i;sa=f,ta=he(k,8),t[sa+10|0]=ta;i=he(k,w[J+1|0]&8?4:9);t[f+13|0]=22;t[f+14|0]=0;v[f>>2]=r;u[f+8>>1]=i;A:{if(he(k,1)){i=he(k,2);t[f+11|0]=i;if(!(i&255)){break z}i=he(k,1);u[f+18>>1]=65287;t[f+12|0]=i;if(w[f+11|0]==2){B:{if(!(i&255)){v[f>>2]=s;t[f+18|0]=8;j=39;i=0;break B}v[f>>2]=D;j=30;i=w[J+1|0]&8?8:6}t[f+14|0]=j;t[f+13|0]=i;h=h&3855}i=he(k,10);sa=f,ta=he(k,3),t[sa+21|0]=ta;sa=f,ta=he(k,3),t[sa+22|0]=ta;sa=f,ta=he(k,3),t[sa+23|0]=ta;i=i<<5;break A}t[f+11|0]=0;t[f+12|0]=0;i=he(k,15);sa=f,ta=he(k,4),t[sa+18|0]=ta;j=he(k,3);t[f+20|0]=255;t[f+19|0]=j}t[f+17|0]=i&31;t[f+15|0]=i>>>10;t[f+16|0]=i>>>5&31;o=(E&65535)+o|0;C:{if(w[J+1|0]&8){i=he(k,1);break C}i=x[f+8>>1]>499}t[f+24|0]=i;sa=f,ta=he(k,1),t[sa+25|0]=ta;i=he(k,1);t[f+27|0]=h>>>12&15;t[f+26|0]=i;f=f+28|0;i=h<<4;g=g-1|0;if(g){continue}break}m=(v[k+4>>2]+o|0)>(v[k+8>>2]+(l<<3)|0)?-1:l}if(!((m|0)<0|v[n+17156>>2]>v[n+17160>>2])){f=n+17152|0;l=v[f+4>>2];k=v[f+8>>2];i=n+912|0;g=v[H+6144>>2];h=g-m|0;g=(g|0)>(m|0)?m:g;h=ic(i+12|0,(((h|0)>0?h:0)+H|0)+6156|0,g);j=v[f>>2]+(v[f+4>>2]/8|0)|0;f=(k-l|0)/8|0;ic(g+h|0,j,f);rH(i,h,f+g|0);D:{o=v[H+6144>>2]>=(m|0);if(!o){break D}na=H+2304|0;oa=n+8620|0;pa=n+3852|0;while(1){if((w[J+1|0]&8?2:1)>>>0<=q>>>0){break D}qa=Hb(pa,0,4608);f=v[N+8>>2];E=(B(B(f,q),28)+n|0)+3740|0;F=0;ja=(f|0)>0?f:0;K=n+912|0;D=K+7548|0;ba=H+6152|0;while(1){if((F|0)!=(ja|0)){g=B(F,28)+E|0;$=x[g+4>>1];Z=v[K+4>>2];l=D;k=cb-48|0;cb=k;s=!w[g+13|0]+(w[g+14|0]!=0)|0;M=w[g+25|0];r=(K+B(F,39)|0)+16156|0;j=k;ea=j+44|0;E:{if(w[ba+1|0]&8){f=w[g+27|0];h=w[x[g+8>>1]+61696|0];i=h&3;t[k+47|0]=i;t[k+46|0]=i;h=h>>>2|0;t[k+45|0]=h;t[k+44|0]=h;h=B(s,28)+61600|0;break E}f=(w[ba+3|0]&16)>>>4&(F|0)!=0;m=f?12:0;i=x[g+8>>1]>>>f|0;while(1){if((i|0)>=0){f=3;h=1;while(1){if((f|0)>=0){I=w[(f+m|0)+61712|0];t[(k+44|0)+f|0]=((i|0)/(h|0)|0)%(I|0);f=f-1|0;h=B(h,I);continue}break}m=m+4|0;i=i-h|0;continue}break}f=-16;h=(B(s,28)+m|0)+61600|0}i=0;while(1){F:{G:{H:{if((i|0)==4){break H}s=w[h+i|0];if(!s){break H}if(f&8){ic(j,r,s);break G}I=w[i+ea|0];if(!I){Hb(j,0,s);Hb(r,0,s);break G}ga=(f|0)>=0?-1:-1<<I^-1;m=0;while(1){if((m|0)==(s|0)){break G}G=he(K,I);t[m+r|0]=(G|0)==(ga|0)?-1:G;t[j+m|0]=G;m=m+1|0;continue}}t[j+2|0]=0;t[j|0]=0;t[j+1|0]=0;break F}f=f<<1;i=i+1|0;j=j+s|0;r=r+s|0;continue}break}I:{h=w[g+14|0];if(h){f=2-M|0;j=w[g+23|0]<<f;m=w[g+22|0]<<f;s=w[g+21|0]<<f;r=w[g+13|0];f=0;while(1){if(f>>>0>=h>>>0){break I}i=k+(f+r|0)|0;t[i|0]=s+w[i|0];t[i+1|0]=m+w[i+1|0];t[i+2|0]=j+w[i+2|0];f=f+3|0;continue}}if(!w[g+24|0]){break I}f=0;while(1){if((f|0)==10){break I}i=f+k|0;t[i+11|0]=w[i+11|0]+w[f+61736|0];f=f+1|0;continue}}i=M+1|0;f=0;y=Ow(C(2048),((((w[ba+3|0]&224)==96)<<1)-w[g+10|0]|0)+258|0);while(1){if(w[g+13|0]+(h&255)>>>0>f>>>0){sa=(f<<2)+l|0,ua=Ow(y,w[f+k|0]<<i),z[sa>>2]=ua;f=f+1|0;h=w[g+14|0];continue}break}cb=k+48|0;m=(K+B(F,2304)|0)+2940|0;ga=$+Z|0;y=C(0);k=v[K+4>>2];f=v[K>>2]+((k|0)/8|0)|0;h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);h=(h<<24|h<<8&16711680|(h>>>8&65280|h>>>24))<<(k&7);j=k|-8;r=f+4|0;s=g;M=v[g>>2];I=x[g+6>>1];g=0;while(1){J:{K:{if((I|0)>0){k=g+1|0;g=g+s|0;f=w[g+15|0];ka=(u[(f<<1)+66160>>1]<<1)+61776|0;$=w[g+18|0];if(f>>>0>=16){ha=w[f+66224|0];ra=32-ha|0;while(1){ia=w[M|0]>>>1|0;G=I>>>0>ia>>>0?ia:I;y=z[l>>2];while(1){f=h>>>27|0;g=5;while(1){f=u[ka+(f<<1)>>1];if((f|0)<0){h=h<<g;i=f&7;f=(h>>>32-i|0)-(f>>3)|0;j=g+j|0;g=i;continue}break}g=f>>8;j=g+j|0;h=h<<g;i=0;while(1){if((i|0)!=2){Z=f&15;L:{if((Z|0)==15){j=j+ha|0;g=h<<ha;while(1){if((j|0)>=0){g=w[r|0]<<j|g;r=r+1|0;j=j-8|0;continue}break}Z=(h>>>ra|0)+15|0;h=Z;M:{if((h|0)<=128){T=z[(h<<2)+66320>>2];break M}la=h>>>0<1024;h=la?h<<3:h;ea=h<<1&64;U=C(C((h&63)-ea|0)/C(ea+(h&-64)|0));T=C((la?C(16):C(256))*C(C(C(U*C(C(U*C(.2222222238779068))+C(1.3333333730697632)))+C(1))*z[(h+ea>>6<<2)+66320>>2]))}T=C(C(y*T)*C(g>>31|1));break L}g=h;T=C(y*z[(((g>>>27&16|Z)^16)<<2)+66256>>2])}z[m>>2]=T;f=f>>4;m=m+4|0;i=i+1|0;h=(Z|0)!=0;j=h+j|0;h=g<<h;continue}break}while(1){if((j|0)>=0){h=w[r|0]<<j|h;r=r+1|0;j=j-8|0;continue}break}G=G-1|0;if(G){continue}break}l=l+4|0;M=M+1|0;I=I-ia|0;if((I|0)<=0){break K}f=($|0)>0;$=$-1|0;if(f){continue}break}break K}while(1){G=w[M|0]>>>1|0;Z=G>>>0<I>>>0?G:I;y=z[l>>2];while(1){g=h>>>27|0;f=5;while(1){g=u[ka+(g<<1)>>1];if((g|0)<0){h=h<<f;i=g&7;g=(h>>>32-i|0)-(g>>3)|0;j=f+j|0;f=i;continue}break}f=g>>8;j=f+j|0;h=h<<f;f=0;while(1){if((f|0)!=2){i=g&15;z[m>>2]=y*z[(((i|h>>>27&16)^16)<<2)+66256>>2];g=g>>4;m=m+4|0;f=f+1|0;i=(i|0)!=0;j=i+j|0;h=h<<i;continue}break}while(1){if((j|0)>=0){h=w[r|0]<<j|h;r=r+1|0;j=j-8|0;continue}break}Z=Z-1|0;if(Z){continue}break}l=l+4|0;M=M+1|0;I=I-G|0;if((I|0)<=0){break K}f=($|0)>0;$=$-1|0;if(f){continue}break}break K}f=1-I|0;while(1){N:{k=w[s+26|0]?66144:66112;g=w[k+(h>>>28|0)|0];if(!(g&8)){g=w[k+((h<<4>>>32-(g&3))+(g>>>3)|0)|0]}k=g&7;j=k+j|0;if((ga|0)<((j+(r-v[K>>2]<<3)|0)-24|0)){break N}f=f-1|0;if(!f){f=w[M|0];if(f>>>0<2){break N}M=M+1|0;y=z[l>>2];l=l+4|0;f=f>>>1|0}h=h<<k;if(g&128){z[m>>2]=(h|0)<0?C(-y):y;j=j+1|0;h=h<<1}if(g&64){z[m+4>>2]=(h|0)<0?C(-y):y;j=j+1|0;h=h<<1}f=f-1|0;if(!f){f=w[M|0];if(f>>>0<2){break N}M=M+1|0;y=z[l>>2];l=l+4|0;f=f>>>1|0}if(g&32){z[m+8>>2]=(h|0)<0?C(-y):y;j=j+1|0;h=h<<1}if(g&16){z[m+12>>2]=(h|0)<0?C(-y):y;j=j+1|0;h=h<<1}while(1){if((j|0)>=0){h=w[r|0]<<j|h;r=r+1|0;j=j-8|0;continue}break}m=m+16|0;continue}break}v[K+4>>2]=ga;break J}g=k;continue}break}F=F+1|0;continue}break}f=w[H+6155|0];O:{if(f&16){j=cb-16|0;cb=j;g=K+2940|0;h=g+2304|0;s=v[E>>2];D=w[E+14|0];l=D+w[E+13|0]|0;f=0;m=j+4|0;v[m+8>>2]=-1;v[m>>2]=-1;v[m+4>>2]=-1;while(1){if((f|0)!=(l|0)){r=f+s|0;i=w[r|0];k=0;P:{while(1){if(i>>>0<=k>>>0){break P}F=k<<2;if(z[F+h>>2]==C(0)){k=k+2|0;if(z[(F|4)+h>>2]==C(0)){continue}}break}v[m+((f>>>0)%3<<2)>>2]=f;i=w[r|0]}f=f+1|0;h=(i<<2)+h|0;continue}break}if(w[E+13|0]){f=v[j+12>>2];h=v[j+8>>2];k=v[j+4>>2];h=(h|0)>(k|0)?h:k;f=(f|0)>(h|0)?f:h;v[j+12>>2]=f;v[j+8>>2]=f;v[j+4>>2]=f}i=K+16195|0;h=D?3:1;k=l-h|0;f=0;while(1){if((f|0)!=(h|0)){m=f+k|0;l=m-h|0;if((l|0)<=v[(j+4|0)+(f<<2)>>2]){l=w[ba+1|0]<<28>>31&3}else{l=w[i+l|0]}t[i+m|0]=l;f=f+1|0;continue}break}m=v[E>>2];s=j+4|0;D=u[E+36>>1]&1;f=0;r=w[ba+1|0]&8?7:64;while(1){F=f+m|0;h=w[F|0];if(h){k=w[ba+3|0]&32;Q:{R:{if(v[s+((f>>>0)%3<<2)>>2]>=(f|0)){break R}l=w[f+i|0];if(l>>>0>=r>>>0){break R}T=k?C(1.4142135381698608):C(1);S:{if(w[ba+1|0]&8){l=l<<3;y=z[l+66852>>2];U=z[l+66848>>2];break S}U=Ow(C(1),l+1>>>1<<D);l=l&1;y=l?C(1):U;U=l?U:C(1)}U=C(T*U);T=C(T*y);k=0;while(1){if((h|0)!=(k|0)){l=(k<<2)+g|0;y=z[l>>2];z[l+2304>>2]=y*T;z[l>>2]=y*U;k=k+1|0;continue}break}break Q}if(!k){break Q}oH(g,h)}f=f+1|0;g=(w[F|0]<<2)+g|0;continue}break}cb=j+16|0;break O}if((f&224)!=96){break O}oH(K+2940|0,576)}l=K+7708|0;F=0;while(1){if((F|0)!=(ja|0)){f=w[H+6153|0];i=(w[E+12|0]!=0)<<1<<((B((f>>>3&1)+(f>>>4&1)|0,3)+(w[H+6154|0]>>>2&3)|0)==2);k=(K+B(F,2304)|0)+2940|0;h=k;if(w[E+14|0]){m=v[E>>2]+w[E+13|0]|0;D=((K+B(F,2304)|0)+B(i,72)|0)+2940|0;G=D;g=l;while(1){j=w[m|0];if(j){s=j<<1;f=0;while(1){if((f|0)!=(j|0)){z[g>>2]=z[G>>2];z[g+4>>2]=z[(j<<2)+G>>2];z[g+8>>2]=z[(s<<2)+G>>2];G=G+4|0;f=f+1|0;g=g+12|0;continue}break}m=m+3|0;G=(s<<2)+G|0;continue}break}ic(D,l,g-l|0);f=i-1|0}else{f=31}while(1){g=0;if((f|0)>0){while(1){if((g|0)!=8){j=g<<2;m=j+h|0;y=z[m+72>>2];U=z[j+66912>>2];T=z[j+66944>>2];j=(17-g<<2)+h|0;ma=z[j>>2];z[m+72>>2]=C(y*U)-C(T*ma);z[j>>2]=C(y*T)+C(ma*U);g=g+1|0;continue}break}h=h+72|0;f=f-1|0;continue}break}g=k;f=B(F,1152)+H|0;h=w[E+11|0];if(i){nH(g,f,66976,i);g=B(i,72)+g|0;f=B(i,36)+f|0}T:{if((h|0)==2){i=32-i|0;h=cb-80|0;cb=h;m=h|8;s=h|4;while(1){if((i|0)>0){j=ic(h,g,72);D=v[f+20>>2];v[g+16>>2]=v[f+16>>2];v[g+20>>2]=D;D=v[f+12>>2];v[g+8>>2]=v[f+8>>2];v[g+12>>2]=D;D=v[f+4>>2];v[g>>2]=v[f>>2];v[g+4>>2]=D;D=j;j=f+24|0;Nw(D,g+24|0,j);Nw(s,g+48|0,j);Nw(m,f,j);g=g+72|0;f=f+36|0;i=i-1|0;continue}break}cb=h+80|0;break T}nH(g,f,B((h|0)==3,72)+66976|0,32-i|0)}g=0;f=k+72|0;while(1){i=1;if(g>>>0<=31){while(1){if(i>>>0<=17){h=(i<<2)+f|0;z[h>>2]=-z[h>>2];i=i+2|0;continue}break}f=f+144|0;g=g+2|0;continue}break}E=E+28|0;F=F+1|0;continue}break}qH(na,qa,18,v[N+8>>2],aa,oa);q=q+1|0;aa=B(v[N+8>>2],1152)+aa|0;continue}}f=n+912|0;q=v[f+8>>2]>>>3|0;k=v[f+4>>2]+7>>>3|0;g=q-k|0;h=(g|0)>511;l=h?511:g;if((g|0)>0){gj(H+6156|0,(f+(h?q-511|0:k)|0)+12|0,l)}v[H+6144>>2]=l;break x}Ty(H);break l}j=n+17152|0;i=0;h=0;l=0;o=0;q=g;U:{V:{W:{f=w[g+3|0];k=f>>>6|0;switch(k-1|0){case 2:break U;case 0:break W;default:break V}}h=(f>>>2&12)+4|0;break U}h=32}f=w[q+1|0];X:{if((f&6)==6){g=32;f=68380;break X}if(!(f&8)){g=30;f=68383;break X}m=w[q+2|0];g=m>>>2&3;f=Qw(f,m)>>>((k|0)!=3)|0;f=f?f:192;if(f>>>0<=55){g=(g|0)==2?12:8;f=68404;break X}g=f>>>0>95?(g|0)!=1?30:27:27;f=68392}t[n+768|0]=g;t[n+769|0]=g>>>0<h>>>0?g:h;g=f;k=68288;while(1){h=w[n+768|0];if(i>>>0>=h>>>0){i=0;while(1){g=h<<1&510;if(g>>>0>i>>>0){f=i+n|0;Y:{if(!w[f+770|0]){g=6;break Y}g=2;if((w[q+1|0]&6)==6){break Y}g=he(j,2);h=w[n+768|0]}t[f+834|0]=g;i=i+1|0;continue}break}h=n+770|0;k=n+834|0;f=n;i=0;l=g;while(1){if((i|0)!=(l|0)){o=w[h|0];q=o?19>>>w[i+k|0]&3|4:0;h=h+1|0;o=B(o,3)-6|0;y=C(0);g=4;while(1){if(g){if(g&q){m=he(j,6);J=(m|0)/3|0;y=C(z[(o+(B(J,-3)+m|0)<<2)+68416>>2]*C(2097152>>>J|0))}z[f>>2]=y;g=g>>>1|0;f=f+4|0;continue}break}i=i+1|0;continue}break}i=w[n+769|0];f=w[n+768|0];f=f>>>0<i>>>0?i:f;while(1){if((f|0)!=(i|0)){t[((i<<1)+n|0)+771|0]=0;i=i+1|0;continue}break}}else{if((i|0)==(o|0)){k=w[g|0]+68288|0;o=w[g+2|0]+i|0;l=w[g+1|0];g=g+3|0}f=i<<1;h=w[he(j,l)+k|0];t[(f+n|0)+770|0]=h;m=w[n+769|0];if(m>>>0>i>>>0){h=w[he(j,l)+k|0];m=w[n+769|0]}t[((f|1)+n|0)+770|0]=m?h:0;i=i+1|0;continue}break}k=0;g=Hb(n+3852|0,0,4608);E=H+2304|0;F=n+8620|0;q=0;Z:{while(1){if((q|0)==3){break Z}K=((k<<2)+n|0)+3852|0;s=n+17152|0;i=0;J=v[N+16>>2]|1;D=(J|0)>0?J:0;m=576;while(1){if((i|0)!=4){h=K+(B(i,J)<<2)|0;l=0;while(1){if(w[n+768|0]<<1>>>0>l>>>0){_:{j=w[(l+n|0)+770|0];if(!j){break _}if(j>>>0<=16){o=(-1<<j-1)+1|0;f=0;while(1){if((f|0)==(D|0)){break _}sa=(f<<2)+h|0,ua=C(he(s,j)+o|0),z[sa>>2]=ua;f=f+1|0;continue}}j=2<<j-17;M=j>>>1|0;r=j|1;f=0;o=he(s,(j-(j>>>3|0)|0)+3|0);while(1){if((f|0)==(D|0)){break _}j=o;o=(o>>>0)/(r>>>0)|0;z[(f<<2)+h>>2]=j-(M+B(r,o)|0)|0;f=f+1|0;continue}}l=l+1|0;h=(m<<2)+h|0;m=18-m|0;continue}break}i=i+1|0;continue}break}k=(J<<2)+k|0;if((k|0)==12){k=(q<<2)+n|0;f=g;h=w[n+769|0];l=f+B(h,72)|0;ic(l+2304|0,l,B(w[n+768|0]-h|0,72));h=0;while(1){if(w[n+768|0]>h>>>0){i=0;while(1){if((i|0)!=12){l=(i<<2)+f|0;z[l>>2]=z[k>>2]*z[l>>2];l=l+2304|0;z[l>>2]=z[k+12>>2]*z[l>>2];i=i+1|0;continue}break}k=k+24|0;f=f+72|0;h=h+1|0;continue}break}qH(E,g,12,v[N+8>>2],aa,F);Hb(g,0,4608);aa=B(v[N+8>>2],768)+aa|0;k=0}q=q+1|0;if(v[n+17156>>2]<=v[n+17160>>2]){continue}break}Ty(H);q=0;break l}o=1}q=B(Pw(w[H+6153|0]),o)}cb=n+17168|0;f=v[p+4624>>2];if((f|0)<0|(f?0:q)|!(f|q)){break k}$:{if(f){g=v[p+4636>>2];if((g|0)!=(d|0)?d:0){break k}f=v[p+4632>>2];if((f|0)!=(c|0)?c:0){break k}if(f-3>>>0<4294967294|(g|0)<=0){break $}v[p+12>>2]=0;sa=p,ta=yc(ca,da),v[sa+8>>2]=ta;c=v[Gj(p+4624|0,p+12|0,p+8|0)>>2];v[p+12>>2]=0;sa=p,ta=yc(ca,da),v[sa+8>>2]=ta;A=c+A|0;c=ca;d=v[Gj(p+4624|0,p+12|0,p+8|0)>>2];ca=c-d|0;da=da-((d>>31)+(c>>>0<d>>>0)|0)|0;aa:{if(!q){break aa}v[22440]=0;c=p+16|0;Y(590,W|0,c|0,c+(B(f,q)<<1)|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break aa}A=V(88360)|0;if((O()|0)!=(fa(88360)|0)){break a}_(A|0)|0;v[22440]=0;X(18);h=v[22440];v[22440]=0;d=g;c=f;if((h|0)!=1){break k}A=P()|0;O()|0;break a}d=g;c=f}if((Fc(v[W>>2],v[W+4>>2])>>>0)/(c>>>0)>>>0>268435456){break k}if(!!ca&(da|0)>=0|(da|0)>0){continue}break k}break}d=g;c=f}A=0;ba:{if(!d|!c){break ba}f=v[W>>2];g=v[W+4>>2];if(hc(f,g)){break ba}if((Fc(f,g)>>>0)/(c>>>0)>>>0>268435456){break ba}Ts(a,b);if(!e){v[22440]=0;f=Q(56,p+16|0,21685)|0;g=v[22440];v[22440]=0;if((g|0)==1){break b}uc(((b<<5)+a|0)+946304|0,f);rb(f);v[22440]=0;f=B(b,104)+a|0;R(284,f+484380|0,0);g=v[22440];v[22440]=0;if((g|0)==1){break c}v[f+484404>>2]=d}d=B(b,104)+a|0;b=d+484380|0;sa=b,ta=(Fc(v[W>>2],v[W+4>>2])>>>0)/(c>>>0)|0,v[sa>>2]=ta;g=d+484414|0;f=x[g>>1];u[g>>1]=(c|0)==2?f|65:f&65470|1;Lg(b);if(Sd(b)){Hn(yb(v[W>>2]),yb(v[W+4>>2]),v[d+484400>>2])}if(!e){bt(b,v[a+480180>>2]);Ai(b,a)}A=Sd(b)}_c(W);vc(p+11336|0)}cb=p+11360|0;return A|0}A=P()|0;O()|0;break a}A=P()|0;O()|0}_c(W);vc(p+11336|0);S(A|0);L()}function $z(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),A=0,E=0,F=0,G=0,I=C(0),J=0,K=0,M=0,N=0,O=C(0);r=cb-1520|0;cb=r;e=r+8|0;M=Hb(e,0,1512),N=-1,v[M+1420>>2]=N;t[r+56|0]=1;v[r+48>>2]=a+b;v[r+40>>2]=a;l=cb-1024|0;cb=l;t[e+1377|0]=1;a:{if(!Mr(e)){break a}b=w[e+1375|0];if(!(b&2)){Zb(e,34);break a}if(b&4){Zb(e,34);break a}if(b&1){Zb(e,34);break a}if(v[e+1116>>2]!=1){Zb(e,34);break a}b=w[e+1120|0];if((b|0)!=30){b:{if((b|0)!=64){break b}if(!Kw(e,l+1018|0,6)|w[l+1018|0]!=102|(w[l+1019|0]!=105|w[l+1020|0]!=115)){break b}if(w[l+1021|0]!=104|w[l+1022|0]!=101|w[l+1023|0]!=97){break b}if((Ve(e)|0)!=100){break b}if(Ve(e)){break b}Zb(e,38);break a}Zb(e,34);break a}if((Ve(e)|0)!=1){Zb(e,34);break a}if(!Kw(e,l+1018|0,6)){Zb(e,10);break a}if(!Iw(l+1018|0)){Zb(e,34);break a}if(dj(e)){Zb(e,34);break a}b=Ve(e);v[e+4>>2]=b;if(!b){Zb(e,34);break a}if(b>>>0>=17){Zb(e,5);break a}b=dj(e);v[e>>2]=b;if(!b){Zb(e,34);break a}dj(e);dj(e);dj(e);b=Ve(e);i=b>>>4|0;v[e+116>>2]=1<<i;g=b&15;v[e+112>>2]=1<<g;if(g-14>>>0<=4294967287){Zb(e,20);break a}if((b<<24)+536870912>>24>=0){Zb(e,20);break a}c:{if(g>>>0>i>>>0){Zb(e,20);break c}if(!(Ve(e)&1)){Zb(e,34);break c}if(!Mr(e)){break a}if(!Jw(e)){break a}if(!Lw(e)){break a}if((rh(e)|0)==3){while(1){if((f|0)!=6){M=(l+1018|0)+f|0,N=rh(e),t[M|0]=N;f=f+1|0;continue}break}if(!Iw(l+1018|0)){Zb(e,20);break c}b=Hw(e);f=ge(e,b+1|0);v[e+20>>2]=f;if(f){f=0;g=(b|0)>0?b:0;while(1){if((f|0)!=(g|0)){i=rh(e);t[v[e+20>>2]+f|0]=i;f=f+1|0;continue}break}t[b+v[e+20>>2]|0]=0;b=Hw(e);v[e+28>>2]=0;v[e+24>>2]=b;d:{if((b|0)<=0){break d}b=ge(e,b<<2);v[e+28>>2]=b;if(b){break d}Zb(e,3);break c}while(1){e:{f:{if(v[e+24>>2]>(h|0)){b=Hw(e);f=ge(e,b+1|0);g=h<<2;v[g+v[e+28>>2]>>2]=f;if(!v[g+v[e+28>>2]>>2]){break f}f=0;i=(b|0)>0?b:0;while(1){if((f|0)==(i|0)){break e}j=rh(e);t[v[g+v[e+28>>2]>>2]+f|0]=j;f=f+1|0;continue}}if(!(rh(e)&1)){Zb(e,20);break c}bH(e,w[e+1376|0]);t[e+1376|0]=0;while(1){b=Lw(e);bH(e,b);t[e+1376|0]=0;if(b){continue}break}f=0;if(!Jw(e)){break a}if(!iH(e)){if(v[e+100>>2]!=21){break a}v[e+100>>2]=20;break a}b=0;while(1){if((b|0)!=256){h=b<<24;i=0;while(1){if((i|0)!=8){h=h>>31&79764919^h<<1;i=i+1|0;continue}break}v[(b<<2)+458640>>2]=h;b=b+1|0;continue}break}if((rh(e)|0)==5){while(1){if((f|0)!=6){M=(l+1018|0)+f|0,N=rh(e),t[M|0]=N;f=f+1|0;continue}break}if(!Iw(l+1018|0)){Zb(e,20);break c}b=kc(e,8)+1|0;v[e+120>>2]=b;b=ge(e,B(b,2096));v[e+124>>2]=b;if(!b){Zb(e,3);break c}Hb(b,0,B(v[e+120>>2],2096));g:{h:{while(1){i:{if(v[e+120>>2]>(p|0)){b=v[e+124>>2];if((kc(e,8)&255)!=66){Zb(e,20);break c}if((kc(e,8)&255)!=67){Zb(e,20);break c}if((kc(e,8)&255)!=86){Zb(e,20);break c}g=b+B(p,2096)|0;M=g,N=kc(e,8)&255|kc(e,8)<<8,v[M>>2]=N;M=g,N=kc(e,8)&255|(kc(e,8)<<8&65280|kc(e,8)<<16),v[M+4>>2]=N;m=g+4|0;f=0;k=kc(e,1);if(!k){f=kc(e,1)}t[g+23|0]=f;h=v[m>>2];if(v[g>>2]){b=h;break i}b=0;if(!h){break i}Zb(e,20);break c}b=kc(e,6)+1&255;f=0;j:{while(1){if((b|0)==(f|0)){break j}f=f+1|0;if(!kc(e,16)){continue}break}Zb(e,20);break c}b=kc(e,6)+1|0;v[e+128>>2]=b;b=ge(e,B(b,1596));v[e+260>>2]=b;k:{if(b){k=0;m=0;l:while(1){if(v[e+128>>2]<=(m|0)){break k}b=kc(e,16);u[((m<<1)+e|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){Zb(e,20);break c}if(!b){b=v[e+260>>2]+B(m,1596)|0;M=b,N=kc(e,8),t[M|0]=N;M=b,N=kc(e,16),u[M+2>>1]=N;M=b,N=kc(e,16),u[M+4>>1]=N;M=b,N=kc(e,6),t[M+6|0]=N;M=b,N=kc(e,8),t[M+7|0]=N;i=kc(e,4)+1|0;t[b+8|0]=i;h=b+9|0;f=0;while(1){if((i&255)>>>0>f>>>0){M=f+h|0,N=kc(e,8),t[M|0]=N;f=f+1|0;i=w[b+8|0];continue}break}Zb(e,4);break c}g=v[e+260>>2]+B(m,1596)|0;b=kc(e,5);t[g|0]=b;f=0;i=-1;while(1)if((b&255)>>>0<=f>>>0){i=i+1|0;b=0;while(1){if((b|0)!=(i|0)){h=b+g|0;M=h,N=kc(e,3)+1|0,t[M+33|0]=N;j=kc(e,2);t[h+49|0]=j;f=0;m:{if(!(j&255)){break m}j=kc(e,8);t[h+65|0]=j;if(v[e+120>>2]>(j&255)){break m}Zb(e,20);break c}n:{while(1){if(1<<w[h+49|0]<=(f|0)){break n}j=kc(e,8)-1|0;u[((g+(b<<4)|0)+(f<<1)|0)+82>>1]=j;f=f+1|0;if(v[e+120>>2]>j<<16>>16){continue}break}Zb(e,20);break c}b=b+1|0;continue}break}b=2;M=g,N=kc(e,2)+1|0,t[M+1588|0]=N;f=kc(e,4);v[g+1592>>2]=2;h=0;u[g+338>>1]=0;t[g+1589|0]=f;u[g+340>>1]=1<<f;f=g+1592|0;n=g+338|0;p=g+1589|0;j=0;while(1){if(w[g|0]>j>>>0){o=g+w[(g+j|0)+1|0]|0;i=0;while(1){if(w[o+33|0]>i>>>0){b=kc(e,w[p|0]);u[(g+(v[f>>2]<<1)|0)+338>>1]=b;b=v[f>>2]+1|0;v[f>>2]=b;i=i+1|0;continue}break}j=j+1|0;continue}break}while(1){if((b|0)>(h|0)){b=x[(g+(h<<1)|0)+338>>1];i=(l+16|0)+(h<<2)|0;u[i+2>>1]=h;u[i>>1]=b;h=h+1|0;b=v[f>>2];continue}break}aH(l+16|0,b,1118);i=0;b=v[f>>2];h=b-1|0;j=(h|0)>0?h:0;h=0;o:{while(1){if((h|0)==(j|0)){break o}p=l+16|0;o=x[p+(h<<2)>>1];h=h+1|0;if((o|0)!=x[p+(h<<2)>>1]){continue}break}Zb(e,20);break c}while(1){if((b|0)>(i|0)){t[(g+i|0)+838|0]=w[((l+16|0)+(i<<2)|0)+2|0];i=i+1|0;b=v[f>>2];continue}break}i=2;while(1){if((b|0)>(i|0)){v[l+12>>2]=0;v[l+8>>2]=0;b=0;F=(i|0)>0?i:0;j=n+(i<<1)|0;o=65536;p=-1;while(1){if((b|0)!=(F|0)){q=n+(b<<1)|0;h=x[q>>1];if(!((p|0)>=(h|0)|x[j>>1]<=h>>>0)){v[l+12>>2]=b;h=x[q>>1];p=h}if(!((h|0)>=(o|0)|x[j>>1]>=h>>>0)){v[l+8>>2]=b;o=x[q>>1]}b=b+1|0;continue}break}b=g+(i<<1)|0;t[b+1088|0]=v[l+12>>2];t[b+1089|0]=v[l+8>>2];i=i+1|0;b=v[f>>2];continue}break}k=(b|0)>(k|0)?b:k;m=m+1|0;continue l}else{b=kc(e,4);t[(f+g|0)+1|0]=b;b=b&255;i=(b|0)>(i|0)?b:i;f=f+1|0;b=w[g|0];continue}}}Zb(e,3);break c}b=kc(e,6)+1|0;v[e+264>>2]=b;b=ge(e,B(b,24));v[e+396>>2]=b;if(!b){Zb(e,3);break c}j=0;Hb(b,0,B(v[e+264>>2],24));p:{q:{r:{s:{while(1){if(v[e+264>>2]>(j|0)){b=v[e+396>>2];h=kc(e,16);u[((j<<1)+e|0)+268>>1]=h;if((h&65535)>>>0>=3){Zb(e,20);break c}g=b+B(j,24)|0;M=g,N=kc(e,24),v[M>>2]=N;b=kc(e,24);v[g+4>>2]=b;if(b>>>0<y[g>>2]){Zb(e,20);break c}M=g,N=kc(e,24)+1|0,v[M+8>>2]=N;M=g,N=kc(e,6)+1|0,t[M+12|0]=N;b=kc(e,8);t[g+13|0]=b;if(v[e+120>>2]<=(b&255)){break r}f=0;while(1){b=w[g+12|0];if(b>>>0>f>>>0){h=(l+16|0)+f|0;i=kc(e,3);if(kc(e,1)){b=kc(e,5)}else{b=0}t[h|0]=i+(b<<3);f=f+1|0;continue}break}b=ge(e,b<<4);v[g+20>>2]=b;if(!b){break q}h=0;while(1){if(w[g+12|0]>h>>>0){b=w[(l+16|0)+h|0];f=0;while(1){if((f|0)!=8){t:{if(b>>>f&1){i=kc(e,8);n=f<<1;m=h<<4;u[n+(m+v[g+20>>2]|0)>>1]=i;if(v[e+120>>2]>u[n+(m+v[g+20>>2]|0)>>1]){break t}Zb(e,20);break c}u[(v[g+20>>2]+(h<<4)|0)+(f<<1)>>1]=65535}f=f+1|0;continue}break}h=h+1|0;continue}break}h=ge(e,v[(v[e+124>>2]+B(w[g+13|0],2096)|0)+4>>2]<<2);v[g+16>>2]=h;if(!h){Zb(e,3);break c}b=0;Hb(h,0,v[(v[e+124>>2]+B(w[g+13|0],2096)|0)+4>>2]<<2);while(1){h=v[e+124>>2]+B(w[g+13|0],2096)|0;if(v[h+4>>2]>(b|0)){f=v[h>>2];i=ge(e,f);h=b<<2;v[h+v[g+16>>2]>>2]=i;i=b;if(!v[h+v[g+16>>2]>>2]){break s}while(1){if((f|0)>0){f=f-1|0;t[f+v[h+v[g+16>>2]>>2]|0]=(i|0)%w[g+12|0];i=(i|0)/w[g+12|0]|0;continue}break}b=b+1|0;continue}break}j=j+1|0;continue}break}b=kc(e,6)+1|0;v[e+400>>2]=b;b=ge(e,B(b,40));v[e+404>>2]=b;if(!b){Zb(e,3);break c}Hb(b,0,B(v[e+400>>2],40));j=0;while(1){if(v[e+400>>2]>(j|0)){b=v[e+404>>2];if(kc(e,16)){Zb(e,20);break c}g=b+B(j,40)|0;b=ge(e,B(v[e+4>>2],3));v[g+4>>2]=b;if(!b){Zb(e,3);break c}if(kc(e,1)){b=kc(e,4)+1|0}else{b=1}t[g+8|0]=b;u:{if(kc(e,1)){b=kc(e,8)+1|0;u[g>>1]=b;f=0;h=v[e+4>>2];if((h|0)<(b&65535)){Zb(e,20);break c}while(1){if((b&65535)>>>0<=f>>>0){break u}h=kc(e,Yl(h-1|0));b=B(f,3);t[b+v[g+4>>2]|0]=h;h=kc(e,Yl(v[e+4>>2]-1|0));t[(b+v[g+4>>2]|0)+1|0]=h;h=v[e+4>>2];b=b+v[g+4>>2]|0;i=w[b|0];if((h|0)<=(i|0)){Zb(e,20);break c}b=w[b+1|0];if((b|0)>=(h|0)){Zb(e,20);break c}if((b|0)!=(i|0)){f=f+1|0;b=x[g>>1];continue}break}Zb(e,20);break c}u[g>>1]=0}if(kc(e,2)){Zb(e,20);break c}h=0;b=0;f=0;v:{if(w[g+8|0]>=2){while(1){if(v[e+4>>2]<=(b|0)){break v}f=kc(e,4);i=B(b,3);t[(i+v[g+4>>2]|0)+2|0]=f;b=b+1|0;if(w[(i+v[g+4>>2]|0)+2|0]<w[g+8|0]){continue}break}Zb(e,20);break c}while(1){if(v[e+4>>2]<=(f|0)){break v}t[(v[g+4>>2]+B(f,3)|0)+2|0]=0;f=f+1|0;continue}}w:{while(1){if(w[g+8|0]<=h>>>0){break w}kc(e,8);b=g+h|0;M=b,N=kc(e,8),t[M+9|0]=N;f=kc(e,8);t[b+24|0]=f;if(v[e+128>>2]<=w[b+9|0]){Zb(e,20);break c}h=h+1|0;if(v[e+264>>2]>(f&255)){continue}break}Zb(e,20);break c}j=j+1|0;continue}break}f=kc(e,6)+1|0;v[e+408>>2]=f;i=0;x:{while(1){if((f|0)<=(i|0)){break x}b=B(i,6)+e|0;M=b,N=kc(e,1),t[M+412|0]=N;M=b,N=kc(e,16),u[M+414>>1]=N;M=b,N=kc(e,16),u[M+416>>1]=N;h=kc(e,8);t[b+413|0]=h;if(x[b+414>>1]){Zb(e,20);break c}if(x[b+416>>1]){Zb(e,20);break c}if(v[e+400>>2]>(h&255)){i=i+1|0;f=v[e+408>>2];continue}break}Zb(e,20);break c}gH(e);v[e+992>>2]=0;h=k<<1;f=0;while(1){if(v[e+4>>2]>(f|0)){b=(f<<2)+e|0;M=b,N=ge(e,v[e+116>>2]<<2),v[M+800>>2]=N;M=b,N=ge(e,v[e+116>>2]<<1&2147483646),v[M+928>>2]=N;g=ge(e,h);v[b+996>>2]=g;i=v[b+800>>2];if(g?!i|!v[b+928>>2]:1){Zb(e,3);break c}Hb(i,0,v[e+116>>2]<<2);f=f+1|0;continue}break}f=0;if(!$G(e,0,v[e+112>>2])){break a}if(!$G(e,1,v[e+116>>2])){break a}v[e+104>>2]=v[e+112>>2];g=v[e+116>>2];v[e+108>>2]=g;b=v[e+264>>2];j=(b|0)>0?b:0;b=(g|0)/2|0;h=0;while(1){if((f|0)!=(j|0)){i=v[e+396>>2]+B(f,24)|0;k=v[i+4>>2];p=b>>>0>k>>>0?k:b;k=v[i>>2];i=(p-(b>>>0>k>>>0?k:b)>>>0)/y[i+8>>2]|0;h=(h|0)<(i|0)?i:h;f=f+1|0;continue}break}b=g<<1&2147483646;h=B(v[e+4>>2],(h<<2)+4|0);b=b>>>0>h>>>0?b:h;v[e+12>>2]=b;y:{if(!v[e+80>>2]){break y}h=v[e+92>>2];if((h|0)!=v[e+84>>2]){break p}if(h>>>0>=(b+v[e+88>>2]|0)+1512>>>0){break y}Zb(e,3);break c}if(v[e+1380>>2]==-1){v[e+52>>2]=w[e+48|0]?0:v[e+32>>2]-v[e+36>>2]|0;f=1;break a}v[e+52>>2]=0;f=1;break a}Zb(e,3);break c}Zb(e,20);break c}Zb(e,3);break c}ca(7304,13226,4196,8858);L()}z:{if(f&255){i=nn(e,b);break z}i=ge(e,b);v[g+8>>2]=i}if(!i){Zb(e,3);break c}j=0;A:{if(!k){f=0;while(1){b=v[m>>2];if((f|0)>=(b|0)){break A}B:{C:{if(w[g+23|0]){if(!kc(e,1)){break C}}b=kc(e,5)+1|0;t[f+i|0]=b;if((b&255)!=32){j=j+1|0;break B}Zb(e,20);break c}t[f+i|0]=255}f=f+1|0;continue}}h=kc(e,5);f=0;while(1){b=v[m>>2];if((f|0)>=(b|0)){break A}k=kc(e,Yl(b-f|0));h=h+1|0;if((h|0)>=32){Zb(e,20);break c}b=f+k|0;if((b|0)>v[m>>2]){Zb(e,20);break c}else{Hb(f+i|0,h,k);f=b;continue}}}D:{E:{F:{if(w[g+23|0]){if(b>>2>(j|0)){break F}if(v[e+16>>2]<(b|0)){v[e+16>>2]=b;b=v[m>>2]}b=ge(e,b);v[g+8>>2]=b;if(!b){Zb(e,3);break c}ic(b,i,v[m>>2]);cj(e,i,v[m>>2]);i=v[g+8>>2];t[g+23|0]=0;b=v[m>>2]}h=0;j=(b|0)>0?b:0;f=0;while(1){if((f|0)!=(j|0)){h=((w[f+i|0]-11&255)>>>0<244)+h|0;f=f+1|0;continue}break}v[g+2092>>2]=h;b=ge(e,b<<2);v[g+32>>2]=b;if(b){k=g+2092|0;f=0;break E}Zb(e,3);break c}v[g+2092>>2]=j;k=g+2092|0;G:{if(!j){f=0;h=0;break G}b=ge(e,j);v[g+8>>2]=b;if(!b){Zb(e,3);break c}b=nn(e,v[k>>2]<<2);v[g+32>>2]=b;if(!b){Zb(e,3);break c}f=nn(e,v[k>>2]<<2);if(!f){break D}b=v[m>>2];h=v[k>>2]}b=(h<<3)+b|0;if(b>>>0<=y[e+16>>2]){break E}v[e+16>>2]=b}n=v[m>>2];b=0;h=cb-128|0;cb=h;o=Hb(h,0,128);h=(n|0)>0?n:0;while(1){H:{I:{if((b|0)!=(h|0)){if(w[b+i|0]==255){break I}h=b}if((h|0)==(n|0)){b=1;if(!v[g+2092>>2]){break H}ca(15764,13226,1103,7548);L()}b=h+i|0;j=w[b|0];if(j>>>0<32){ZG(g,0,h,0,j,f);q=1;j=w[b|0]+1|0;b=1;J:{while(1){if((b|0)==(j|0)){K:while(1){L:{b=1;h=h+1|0;if((n|0)<=(h|0)){break H}E=h+i|0;j=w[E|0];if((j|0)==255){continue}b=j;if(b>>>0>=32){break L}while(1){if((b|0)<=0){b=0;break H}G=o+(b<<2)|0;F=v[G>>2];if(!F){b=b-1|0;continue}break}v[G>>2]=0;ZG(g,Wl(F),h,q,j,f);q=q+1|0;j=w[E|0];if((j|0)==(b|0)){continue}while(1){if((b|0)>=(j|0)){continue K}E=o+(j<<2)|0;if(v[E>>2]){break J}v[E>>2]=F+(1<<32-j);j=j-1|0;continue}}break}}else{v[o+(b<<2)>>2]=1<<32-b;b=b+1|0;continue}break}ca(15268,13226,1118,7548);L()}ca(15808,13226,1133,7548);L()}ca(15275,13226,1104,7548);L()}b=b+1|0;continue}break}cb=o+128|0;if(!b){if(w[g+23|0]){cj(e,f,0)}Zb(e,20);break c}b=v[k>>2];if(b){b=ge(e,(b<<2)+4|0);v[g+2084>>2]=b;if(!b){Zb(e,3);break c}b=ge(e,(v[k>>2]<<2)+4|0);v[g+2088>>2]=b;if(!b){Zb(e,3);break c}v[g+2088>>2]=b+4;v[b>>2]=-1;b=0;j=0;M:{N:{O:{if(w[g+23|0]){while(1){j=v[g+2092>>2];if((j|0)<=(b|0)){break O}h=b<<2;M=h+v[g+2084>>2]|0,N=Wl(v[h+v[g+32>>2]>>2]),v[M>>2]=N;b=b+1|0;continue}}while(1){if(v[g+4>>2]>(b|0)){if(YG(w[g+23|0],w[b+i|0])){M=v[g+2084>>2]+(j<<2)|0,N=Wl(v[v[g+32>>2]+(b<<2)>>2]),v[M>>2]=N;j=j+1|0}b=b+1|0;continue}break}if(v[g+2092>>2]!=(j|0)){break N}}aH(v[g+2084>>2],j,1119);v[v[g+2084>>2]+(v[g+2092>>2]<<2)>>2]=-1;h=0;b=v[g+(w[g+23|0]?2092:4)>>2];F=(b|0)>0?b:0;P:{while(1){if((h|0)!=(F|0)){b=h;j=w[g+23|0];b=j?v[(b<<2)+f>>2]:b;E=w[b+i|0];Q:{if(!YG(j,E)){break Q}G=h<<2;n=Wl(v[G+v[g+32>>2]>>2]);b=v[g+2092>>2];j=0;while(1){if((b|0)>=2){o=b>>>1|0;J=o+j|0;q=n>>>0<y[v[g+2084>>2]+(J<<2)>>2];b=q?o:b-o|0;j=q?j:J;continue}break}b=j<<2;if((n|0)!=v[b+v[g+2084>>2]>>2]){break P}if(w[g+23|0]){v[b+v[g+2088>>2]>>2]=v[f+G>>2];t[v[g+8>>2]+j|0]=E;break Q}v[b+v[g+2088>>2]>>2]=h}h=h+1|0;continue}break}break M}ca(12267,13226,1230,10001);L()}ca(7489,13226,1200,10001);L()}}if(w[g+23|0]){cj(e,f,v[k>>2]<<2);cj(e,v[g+32>>2],v[k>>2]<<2);cj(e,i,v[m>>2]);v[g+32>>2]=0}b=0;f=0;while(1){if((b|0)!=1024){u[(g+(b<<1)|0)+36>>1]=65535;b=b+1|0;continue}break}b=v[g+(w[g+23|0]?2092:4)>>2];b=(b|0)<32767?b:32767;h=(b|0)>0?b:0;while(1){if((f|0)!=(h|0)){R:{if(w[v[g+8>>2]+f|0]>10){break R}S:{if(w[g+23|0]){b=Wl(v[v[g+2084>>2]+(f<<2)>>2]);break S}b=v[v[g+32>>2]+(f<<2)>>2]}while(1){if(b>>>0>1023){break R}u[(g+(b<<1)|0)+36>>1]=f;b=(1<<w[v[g+8>>2]+f|0])+b|0;continue}}f=f+1|0;continue}break}b=kc(e,4);t[g+21|0]=b;b=b&255;if(b>>>0>=3){Zb(e,20);break c}if(b){M=g,O=_G(kc(e,32)),z[M+12>>2]=O;M=g,O=_G(kc(e,32)),z[M+16>>2]=O;M=g,N=kc(e,4)+1|0,t[M+20|0]=N;M=g,N=kc(e,1),t[M+22|0]=N;f=v[g>>2];h=v[m>>2];T:{if(w[g+21|0]==1){A=H(qx(+C(C(jp(+C(h|0)))/C(f|0))));U:{if(D(A)<2147483648){b=~~A;break U}b=-2147483648}A=+(f|0);K=H(_j(+C(C(b|0)+C(1)),A));V:{if(D(K)<2147483648){f=~~K;break V}f=-2147483648}b=((f|0)<=(h|0))+b|0;s=C(b|0);if(_j(+C(s+C(1)),A)<=+(h|0)){f=-1}else{A=H(_j(+s,A));W:{if(D(A)<2147483648){f=~~A;break W}f=-2147483648}f=(f|0)>(h|0)?-1:b}if((f|0)>=0){break T}Zb(e,20);break c}f=B(f,h)}v[g+24>>2]=f;if(!f){Zb(e,20);break c}n=nn(e,f<<1);if(!n){break h}f=0;while(1){i=v[g+24>>2];if((i|0)>(f|0)){b=kc(e,w[g+20|0]);if((b|0)==-1){cj(e,n,v[g+24>>2]<<1);Zb(e,20);break c}else{u[n+(f<<1)>>1]=b;f=f+1|0;continue}}break}X:{Y:{if(w[g+21|0]==1){o=w[g+23|0];Z:{if(o){f=v[k>>2];if(f){break Z}break X}f=v[m>>2]}b=ge(e,B(v[g>>2],f)<<2);v[g+28>>2]=b;if(!b){cj(e,n,v[g+24>>2]<<1);Zb(e,3);break c}h=0;b=v[(o?k:m)>>2];m=(b|0)>0?b:0;q=g+2088|0;s=C(0);while(1){if((h|0)==(m|0)){break Y}j=o?v[v[q>>2]+(h<<2)>>2]:h;i=v[g>>2];f=0;b=1;while(1){if((f|0)<(i|0)){I=C(s+C(C(C(x[n+(((j>>>0)/(b>>>0)>>>0)%y[g+24>>2]<<1)>>1])*z[g+16>>2])+z[g+12>>2]));z[v[g+28>>2]+(B(h,i)+f<<2)>>2]=I;s=w[g+22|0]?I:s;f=f+1|0;i=v[g>>2];if((f|0)>=(i|0)){continue}k=v[g+24>>2];kka(k,0,b,0);if(fb){cj(e,n,k<<1);Zb(e,20);break c}else{b=B(b,k);continue}}break}h=h+1|0;continue}}b=ge(e,i<<2);v[g+28>>2]=b;if(!b){break g}f=0;s=C(0);while(1){i=v[g+24>>2];if((i|0)<=(f|0)){break X}I=C(s+C(C(C(x[n+(f<<1)>>1])*z[g+16>>2])+z[g+12>>2]));z[v[g+28>>2]+(f<<2)>>2]=I;s=w[g+22|0]?I:s;f=f+1|0;continue}}t[g+21|0]=2;i=v[g+24>>2]}cj(e,n,i<<1)}p=p+1|0;continue}break}Zb(e,3);break c}Zb(e,3);break c}cj(e,n,v[g+24>>2]<<1);Zb(e,3);break c}Zb(e,20);break c}Zb(e,3);break c}t[b+v[v[e+28>>2]+(h<<2)>>2]|0]=0;h=h+1|0;continue}}Zb(e,3);break c}Zb(e,20)}f=0}cb=l+1024|0;_:{$:{if(!f){v[d>>2]=v[r+104>>2]?1:v[r+108>>2];break $}b=ge(r+8|0,1512);if(b){M=c,N=v[ic(b,r+8|0,1512)+32>>2]-a|0,v[M>>2]=N;v[d>>2]=0;break _}}kH(r+8|0);b=0}cb=r+1520|0;return b}function WF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0;s=cb-48|0;cb=s;a:{if(c>>>0<=2){c=c<<2;F=v[c+75484>>2];H=v[c+75472>>2];while(1){c=v[b+4>>2];b:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break b}c=id(b)}if(Pk(c)){continue}break}n=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}n=(c|0)==45?-1:1;c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break c}c=id(b)}e:{f:{while(1){if(t[g+4955|0]==(c|32)){g:{if(g>>>0>6){break g}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break g}c=id(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){v[b+4>>2]=v[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}l=cb-16|0;cb=l;i=(p(C(C(n|0)*C(N))),j(2));b=i&2147483647;h:{if(b-8388608>>>0<=2130706431){n=b<<25;c=(b>>>7|0)+1065353216|0;break h}n=i<<25;c=i>>>7|2147418112;if(b>>>0>=2139095040){break h}n=0;c=0;if(!b){break h}c=b;b=E(b);Tf(l,c,0,0,0,b+81|0);h=v[l>>2];k=v[l+4>>2];n=v[l+8>>2];c=v[l+12>>2]^65536|16265-b<<16}v[s>>2]=h;v[s+4>>2]=k;v[s+8>>2]=n;v[s+12>>2]=i&-2147483648|c;cb=l+16|0;D=v[s+8>>2];z=v[s+12>>2];h=v[s>>2];k=v[s+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(t[g+9997|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break l}c=id(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=v[b+4>>2];o:{if((g|0)!=v[b+104>>2]){v[b+4>>2]=g+1;f=w[g|0];break o}f=id(b)}if((f&-33)==88){c=0;f=cb-432|0;cb=f;p:{q:{g=b;b=v[b+4>>2];if(v[g+104>>2]!=(b|0)){v[g+4>>2]=b+1;c=w[b|0];break q}b=0;break p}b=1}while(1){r:{s:{t:{u:{v:{w:{x:{y:{if(!b){c=id(g);break y}if((c|0)!=48){z=1073676288;if((c|0)==46){break w}break v}b=v[g+4>>2];if((b|0)==v[g+104>>2]){break x}o=1;v[g+4>>2]=b+1;c=w[b|0]}b=1;continue}o=1;break s}b=v[g+4>>2];z:{if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break z}c=id(g)}if((c|0)==48){break u}G=1}break t}while(1){b=h;h=b-1|0;k=k-!b|0;G=1;b=v[g+4>>2];A:{if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break A}c=id(g)}if((c|0)==48){continue}break}o=1}while(1){L=c|32;B:{C:{M=c-48|0;if(M>>>0<10){break C}if(!((c|0)==46|L-97>>>0<6)){b=c;break r}b=46;if((c|0)!=46){break C}if(G){break r}G=1;h=l;k=i;break B}b=(c|0)>57?L-87|0:M;D:{if((i|0)<=0&l>>>0<=7|(i|0)<0){q=b+(q<<4)|0;break D}if(!i&l>>>0<=28){$g(f+48|0,b);Fd(f+32|0,m,A,D,z,0,0,0,1073414144);m=v[f+32>>2];A=v[f+36>>2];D=v[f+40>>2];z=v[f+44>>2];Fd(f+16|0,v[f+48>>2],v[f+52>>2],v[f+56>>2],v[f+60>>2],m,A,D,z);Eg(f,v[f+16>>2],v[f+20>>2],v[f+24>>2],v[f+28>>2],r,e,u,x);u=v[f+8>>2];x=v[f+12>>2];r=v[f>>2];e=v[f+4>>2];break D}if(!b|I){break D}Fd(f+80|0,m,A,D,z,0,0,0,1073610752);Eg(f- -64|0,v[f+80>>2],v[f+84>>2],v[f+88>>2],v[f+92>>2],r,e,u,x);u=v[f+72>>2];x=v[f+76>>2];I=1;r=v[f+64>>2];e=v[f+68>>2]}b=l+1|0;i=b?i:i+1|0;l=b;o=1}b=v[g+4>>2];if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0]}else{c=id(g)}continue}}b=0;continue}break}E:{if(!o){b=v[g+116>>2];F:{G:{if((b|0)>0|(b|0)>=0){b=v[g+4>>2];v[g+4>>2]=b-1;if(!d){break G}v[g+4>>2]=b-2;if(!G){break F}v[g+4>>2]=b-3;break F}if(d){break F}}hi(g,0,0)}$i(f+96|0,+(n|0)*0);r=v[f+96>>2];e=v[f+100>>2];c=v[f+108>>2];b=v[f+104>>2];break E}if((i|0)<=0&l>>>0<=7|(i|0)<0){D=l;z=i;while(1){q=q<<4;m=z;c=D+1|0;m=c?m:m+1|0;D=c;z=m;if((c|0)!=8|m){continue}break}}H:{I:{J:{if((b&-33)==80){D=VF(g,d);b=fb;z=b;if(D|(b|0)!=-2147483648){break H}if(d){b=v[g+116>>2];if((b|0)>0|(b|0)>=0){break J}break I}r=0;e=0;hi(g,0,0);c=0;b=0;break E}D=0;z=0;if(v[g+116>>2]<0){break H}}v[g+4>>2]=v[g+4>>2]-1}D=0;z=0}if(!q){$i(f+112|0,+(n|0)*0);r=v[f+112>>2];e=v[f+116>>2];c=v[f+124>>2];b=v[f+120>>2];break E}b=G?h:l;i=(G?k:i)<<2|b>>>30;b=D+(b<<2)|0;d=i+z|0;d=b>>>0<D>>>0?d+1|0:d;l=b-32|0;i=d-(b>>>0<32)|0;b=i;if(l>>>0>0-F>>>0&(b|0)>=0|(b|0)>0){v[114922]=68;$g(f+160|0,n);Fd(f+144|0,v[f+160>>2],v[f+164>>2],v[f+168>>2],v[f+172>>2],-1,-1,-1,2147418111);Fd(f+128|0,v[f+144>>2],v[f+148>>2],v[f+152>>2],v[f+156>>2],-1,-1,-1,2147418111);r=v[f+128>>2];e=v[f+132>>2];c=v[f+140>>2];b=v[f+136>>2];break E}b=F-226|0;c=b>>31;if((i|0)>=(c|0)&b>>>0<=l>>>0|(c|0)<(i|0)){if((q|0)>=0){while(1){Eg(f+416|0,r,e,u,x,0,0,0,-1073807360);c=OA(r,e,u,x,1073610752);b=(c|0)<0;Eg(f+400|0,r,e,u,x,b?r:v[f+416>>2],b?e:v[f+420>>2],b?u:v[f+424>>2],b?x:v[f+428>>2]);b=l;l=b-1|0;i=i-!b|0;u=v[f+408>>2];x=v[f+412>>2];r=v[f+400>>2];e=v[f+404>>2];q=q<<1|(c|0)>=0;if((q|0)>=0){continue}break}}d=i-((F>>31)+(l>>>0<F>>>0)|0)|0;b=(l-F|0)+32|0;d=b>>>0<32?d+1|0:d;c=b>>>0<H>>>0&(d|0)<=0|(d|0)<0?(b|0)>0?b:0:H;K:{if((c|0)>=113){$g(f+384|0,n);h=v[f+392>>2];k=v[f+396>>2];m=v[f+384>>2];A=v[f+388>>2];i=0;b=0;break K}$i(f+352|0,Tj(1,144-c|0));$g(f+336|0,n);m=v[f+336>>2];A=v[f+340>>2];h=v[f+344>>2];k=v[f+348>>2];YF(f+368|0,v[f+352>>2],v[f+356>>2],v[f+360>>2],v[f+364>>2],m,A,h,k);J=v[f+376>>2];K=v[f+380>>2];i=v[f+372>>2];b=v[f+368>>2]}c=!(q&1)&((wm(r,e,u,x,0,0,0,0)|0)!=0&(c|0)<32);bn(f+320|0,c+q|0);Fd(f+304|0,m,A,h,k,v[f+320>>2],v[f+324>>2],v[f+328>>2],v[f+332>>2]);d=b;Eg(f+272|0,v[f+304>>2],v[f+308>>2],v[f+312>>2],v[f+316>>2],b,i,J,K);b=c;Fd(f+288|0,m,A,h,k,b?0:r,b?0:e,b?0:u,b?0:x);Eg(f+256|0,v[f+288>>2],v[f+292>>2],v[f+296>>2],v[f+300>>2],v[f+272>>2],v[f+276>>2],v[f+280>>2],v[f+284>>2]);ey(f+240|0,v[f+256>>2],v[f+260>>2],v[f+264>>2],v[f+268>>2],d,i,J,K);b=v[f+240>>2];c=v[f+244>>2];d=v[f+248>>2];h=v[f+252>>2];if(!wm(b,c,d,h,0,0,0,0)){v[114922]=68}XF(f+224|0,b,c,d,h,l);r=v[f+224>>2];e=v[f+228>>2];c=v[f+236>>2];b=v[f+232>>2];break E}v[114922]=68;$g(f+208|0,n);Fd(f+192|0,v[f+208>>2],v[f+212>>2],v[f+216>>2],v[f+220>>2],0,0,0,65536);Fd(f+176|0,v[f+192>>2],v[f+196>>2],v[f+200>>2],v[f+204>>2],0,0,0,65536);r=v[f+176>>2];e=v[f+180>>2];c=v[f+188>>2];b=v[f+184>>2]}v[s+16>>2]=r;v[s+20>>2]=e;v[s+24>>2]=b;v[s+28>>2]=c;cb=f+432|0;D=v[s+24>>2];z=v[s+28>>2];h=v[s+16>>2];k=v[s+20>>2];break a}if(v[b+116>>2]<0){break n}v[b+4>>2]=v[b+4>>2]-1}f=b;r=n;n=0;g=0;e=cb-8976|0;cb=e;G=F+H|0;L=0-G|0;L:{M:{while(1){if((c|0)!=48){N:{if((c|0)!=46){break L}b=v[f+4>>2];if((b|0)==v[f+104>>2]){break N}v[f+4>>2]=b+1;c=w[b|0];break M}}else{b=v[f+4>>2];if((b|0)!=v[f+104>>2]){n=1;v[f+4>>2]=b+1;c=w[b|0]}else{n=1;c=id(f)}continue}break}c=id(f)}o=1;if((c|0)!=48){break L}while(1){b=h;h=b-1|0;k=k-!b|0;b=v[f+4>>2];O:{if((b|0)!=v[f+104>>2]){v[f+4>>2]=b+1;c=w[b|0];break O}c=id(f)}if((c|0)==48){continue}break}n=1}v[e+784>>2]=0;P:{Q:{b=(c|0)==46;m=c-48|0;R:{S:{T:{U:{if(!(!b&m>>>0>9)){while(1){V:{if(b&1){if(!o){h=l;k=i;o=1;break V}b=!n;break U}b=l+1|0;i=b?i:i+1|0;l=b;if((g|0)<=2044){I=(c|0)==48?I:l;b=(e+784|0)+(g<<2)|0;if(q){m=(B(v[b>>2],10)+c|0)-48|0}v[b>>2]=m;n=1;c=q+1|0;b=(c|0)==9;q=b?0:c;g=b+g|0;break V}if((c|0)==48){break V}v[e+8960>>2]=v[e+8960>>2]|1;I=18396}b=v[f+4>>2];W:{if((b|0)!=v[f+104>>2]){v[f+4>>2]=b+1;c=w[b|0];break W}c=id(f)}b=(c|0)==46;m=c-48|0;if(b|m>>>0<10){continue}break}}h=o?h:l;k=o?k:i;if(!(!n|(c&-33)!=69)){m=VF(f,d);b=fb;A=b;X:{if(m|(b|0)!=-2147483648){break X}if(!d){break R}m=0;A=0;if(v[f+116>>2]<0){break X}v[f+4>>2]=v[f+4>>2]-1}if(!n){break S}k=k+A|0;b=h+m|0;k=b>>>0<m>>>0?k+1|0:k;h=b;break Q}b=!n;if((c|0)<0){break T}}if(v[f+116>>2]<0){break T}v[f+4>>2]=v[f+4>>2]-1}if(!b){break Q}}v[114922]=28}l=0;i=0;hi(f,0,0);h=0;k=0;break P}b=v[e+784>>2];if(!b){$i(e,+(r|0)*0);h=v[e+8>>2];k=v[e+12>>2];l=v[e>>2];i=v[e+4>>2];break P}if(!((h|0)!=(l|0)|(i|0)!=(k|0)|(l>>>0>9&(i|0)>=0|(i|0)>0)|(b>>>H|0?(H|0)<=30:0))){$g(e+48|0,r);bn(e+32|0,b);Fd(e+16|0,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+60>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2],v[e+44>>2]);h=v[e+24>>2];k=v[e+28>>2];l=v[e+16>>2];i=v[e+20>>2];break P}if(h>>>0>(F|0)/-2>>>0&(k|0)>=0|(k|0)>0){v[114922]=68;$g(e+96|0,r);Fd(e+80|0,v[e+96>>2],v[e+100>>2],v[e+104>>2],v[e+108>>2],-1,-1,-1,2147418111);Fd(e- -64|0,v[e+80>>2],v[e+84>>2],v[e+88>>2],v[e+92>>2],-1,-1,-1,2147418111);h=v[e+72>>2];k=v[e+76>>2];l=v[e+64>>2];i=v[e+68>>2];break P}b=F-226|0;c=h>>>0<b>>>0;b=b>>31;if(c&(k|0)<=(b|0)|(b|0)>(k|0)){v[114922]=68;$g(e+144|0,r);Fd(e+128|0,v[e+144>>2],v[e+148>>2],v[e+152>>2],v[e+156>>2],0,0,0,65536);Fd(e+112|0,v[e+128>>2],v[e+132>>2],v[e+136>>2],v[e+140>>2],0,0,0,65536);h=v[e+120>>2];k=v[e+124>>2];l=v[e+112>>2];i=v[e+116>>2];break P}if(q){if((q|0)<=8){b=(e+784|0)+(g<<2)|0;f=v[b>>2];while(1){f=B(f,10);q=q+1|0;if((q|0)!=9){continue}break}v[b>>2]=f}g=g+1|0}Y:{o=h;if((I|0)>(h|0)|(I|0)>8|(h|0)>17){break Y}if((o|0)==9){$g(e+192|0,r);bn(e+176|0,v[e+784>>2]);Fd(e+160|0,v[e+192>>2],v[e+196>>2],v[e+200>>2],v[e+204>>2],v[e+176>>2],v[e+180>>2],v[e+184>>2],v[e+188>>2]);h=v[e+168>>2];k=v[e+172>>2];l=v[e+160>>2];i=v[e+164>>2];break P}if((o|0)<=8){$g(e+272|0,r);bn(e+256|0,v[e+784>>2]);Fd(e+240|0,v[e+272>>2],v[e+276>>2],v[e+280>>2],v[e+284>>2],v[e+256>>2],v[e+260>>2],v[e+264>>2],v[e+268>>2]);$g(e+224|0,v[(0-o<<2)+75472>>2]);_P(e+208|0,v[e+240>>2],v[e+244>>2],v[e+248>>2],v[e+252>>2],v[e+224>>2],v[e+228>>2],v[e+232>>2],v[e+236>>2]);h=v[e+216>>2];k=v[e+220>>2];l=v[e+208>>2];i=v[e+212>>2];break P}b=(B(o,-3)+H|0)+27|0;c=v[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break Y}$g(e+352|0,r);bn(e+336|0,c);Fd(e+320|0,v[e+352>>2],v[e+356>>2],v[e+360>>2],v[e+364>>2],v[e+336>>2],v[e+340>>2],v[e+344>>2],v[e+348>>2]);$g(e+304|0,v[(o<<2)+75400>>2]);Fd(e+288|0,v[e+320>>2],v[e+324>>2],v[e+328>>2],v[e+332>>2],v[e+304>>2],v[e+308>>2],v[e+312>>2],v[e+316>>2]);h=v[e+296>>2];k=v[e+300>>2];l=v[e+288>>2];i=v[e+292>>2];break P}while(1){c=g;g=c-1|0;if(!v[(e+784|0)+(g<<2)>>2]){continue}break}b=(o|0)%9|0;Z:{if(!b){q=0;b=0;break Z}d=(o|0)>=0?b:b+9|0;q=0;_:{if(!c){b=0;c=0;break _}h=v[(0-d<<2)+75472>>2];k=1e9/(h|0)|0;m=0;f=0;b=0;while(1){i=m;l=(e+784|0)+(f<<2)|0;n=v[l>>2];m=(n>>>0)/(h>>>0)|0;i=i+m|0;v[l>>2]=i;i=!i&(b|0)==(f|0);b=i?b+1&2047:b;o=i?o-9|0:o;m=B(k,n-B(h,m)|0);f=f+1|0;if((f|0)!=(c|0)){continue}break}if(!m){break _}v[(e+784|0)+(c<<2)>>2]=m;c=c+1|0}o=(o-d|0)+9|0}while(1){l=(e+784|0)+(b<<2)|0;g=(o|0)<36;while(1){$:{if(g){break $}if((o|0)==36){if(y[l>>2]<=10384592){break $}o=36}aa:{ba:while(1){d=c+1&2047;i=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(o|0)>45?9:1;ca:{while(1){n=b;f=0;da:{while(1){ea:{b=f+n&2047;if((b|0)==(c|0)){break ea}b=v[(e+784|0)+(b<<2)>>2];k=v[(f<<2)+75424>>2];if(b>>>0<k>>>0){break ea}if(b>>>0>k>>>0){break da}f=f+1|0;if((f|0)!=4){continue}}break}if((o|0)!=36){break da}h=0;k=0;f=0;l=0;i=0;while(1){b=f+n&2047;if((b|0)==(c|0)){c=c+1&2047;v[(e+(c<<2)|0)+780>>2]=0}bn(e+768|0,v[(e+784|0)+(b<<2)>>2]);Fd(e+752|0,h,k,l,i,0,0,1342177280,1075633366);Eg(e+736|0,v[e+752>>2],v[e+756>>2],v[e+760>>2],v[e+764>>2],v[e+768>>2],v[e+772>>2],v[e+776>>2],v[e+780>>2]);l=v[e+744>>2];i=v[e+748>>2];h=v[e+736>>2];k=v[e+740>>2];f=f+1|0;if((f|0)!=4){continue}break}$g(e+720|0,r);Fd(e+704|0,h,k,l,i,v[e+720>>2],v[e+724>>2],v[e+728>>2],v[e+732>>2]);l=v[e+712>>2];i=v[e+716>>2];h=0;k=0;m=v[e+704>>2];A=v[e+708>>2];f=q+113|0;d=f-F|0;g=(d|0)<(H|0);b=g?(d|0)>0?d:0:H;if((b|0)<=112){break ca}break aa}q=h+q|0;b=c;if((n|0)==(b|0)){continue}break}l=1e9>>>h|0;m=-1<<h^-1;f=0;b=n;while(1){k=f;g=(e+784|0)+(n<<2)|0;f=v[g>>2];k=k+(f>>>h|0)|0;v[g>>2]=k;k=!k&(b|0)==(n|0);b=k?b+1&2047:b;o=k?o-9|0:o;f=B(l,f&m);n=n+1&2047;if((n|0)!=(c|0)){continue}break}if(!f){continue}if((b|0)!=(d|0)){v[(e+784|0)+(c<<2)>>2]=f;c=d;continue ba}v[i>>2]=v[i>>2]|1;b=d;continue}break}break}$i(e+656|0,Tj(1,225-b|0));YF(e+688|0,v[e+656>>2],v[e+660>>2],v[e+664>>2],v[e+668>>2],m,A,l,i);D=v[e+696>>2];z=v[e+700>>2];J=v[e+688>>2];K=v[e+692>>2];$i(e+640|0,Tj(1,113-b|0));vP(e+672|0,m,A,l,i,v[e+640>>2],v[e+644>>2],v[e+648>>2],v[e+652>>2]);h=v[e+672>>2];k=v[e+676>>2];u=v[e+680>>2];x=v[e+684>>2];ey(e+624|0,m,A,l,i,h,k,u,x);Eg(e+608|0,J,K,D,z,v[e+624>>2],v[e+628>>2],v[e+632>>2],v[e+636>>2]);l=v[e+616>>2];i=v[e+620>>2];m=v[e+608>>2];A=v[e+612>>2]}o=n+4&2047;fa:{if((o|0)==(c|0)){break fa}o=v[(e+784|0)+(o<<2)>>2];ga:{if(o>>>0<=499999999){if(!o&(n+5&2047)==(c|0)){break ga}$i(e+496|0,+(r|0)*.25);Eg(e+480|0,h,k,u,x,v[e+496>>2],v[e+500>>2],v[e+504>>2],v[e+508>>2]);u=v[e+488>>2];x=v[e+492>>2];h=v[e+480>>2];k=v[e+484>>2];break ga}if((o|0)!=5e8){$i(e+592|0,+(r|0)*.75);Eg(e+576|0,h,k,u,x,v[e+592>>2],v[e+596>>2],v[e+600>>2],v[e+604>>2]);u=v[e+584>>2];x=v[e+588>>2];h=v[e+576>>2];k=v[e+580>>2];break ga}O=+(r|0);if((n+5&2047)==(c|0)){$i(e+528|0,O*.5);Eg(e+512|0,h,k,u,x,v[e+528>>2],v[e+532>>2],v[e+536>>2],v[e+540>>2]);u=v[e+520>>2];x=v[e+524>>2];h=v[e+512>>2];k=v[e+516>>2];break ga}$i(e+560|0,O*.75);Eg(e+544|0,h,k,u,x,v[e+560>>2],v[e+564>>2],v[e+568>>2],v[e+572>>2]);u=v[e+552>>2];x=v[e+556>>2];h=v[e+544>>2];k=v[e+548>>2]}if((b|0)>111){break fa}vP(e+464|0,h,k,u,x,0,0,0,1073676288);if(wm(v[e+464>>2],v[e+468>>2],v[e+472>>2],v[e+476>>2],0,0,0,0)){break fa}Eg(e+448|0,h,k,u,x,0,0,0,1073676288);u=v[e+456>>2];x=v[e+460>>2];h=v[e+448>>2];k=v[e+452>>2]}Eg(e+432|0,m,A,l,i,h,k,u,x);ey(e+416|0,v[e+432>>2],v[e+436>>2],v[e+440>>2],v[e+444>>2],J,K,D,z);l=v[e+424>>2];i=v[e+428>>2];m=v[e+416>>2];A=v[e+420>>2];ha:{if((-2-G|0)>=(f&2147483647)){break ha}v[e+408>>2]=l;v[e+412>>2]=i&2147483647;v[e+400>>2]=m;v[e+404>>2]=A;Fd(e+384|0,m,A,l,i,0,0,0,1073610752);z=v[e+400>>2];D=v[e+404>>2];o=v[e+408>>2];f=v[e+412>>2];c=OA(z,D,o,f,1081081856);n=(c|0)<0;l=n?l:v[e+392>>2];i=n?i:v[e+396>>2];m=n?m:v[e+384>>2];A=n?A:v[e+388>>2];q=((c|0)>=0)+q|0;if((q+110|0)<=(L|0)){if((((OA(z,D,o,f,1081081856)|0)<0?g:g&(b|0)!=(d|0))|0)!=1){break ha}if(!wm(h,k,u,x,0,0,0,0)){break ha}}v[114922]=68}XF(e+368|0,m,A,l,i,q);h=v[e+376>>2];k=v[e+380>>2];l=v[e+368>>2];i=v[e+372>>2];break P}n=c+2047|0;m=0;while(1){h=m;i=n&2047;n=(e+784|0)+(i<<2)|0;d=v[n>>2];m=d>>>3|0;k=d<<29;h=h+k|0;d=m;d=h>>>0<k>>>0?d+1|0:d;k=d;if(!k&h>>>0<1000000001){m=0}else{m=nka(h,k,1e9,0);d=kka(m,fb,-1e9,-1)+h|0;h=d}v[n>>2]=h;c=(i|0)!=(c-1&2047)?c:(b|0)==(i|0)?c:h?c:i;n=i-1|0;if((b|0)!=(i|0)){continue}break}q=q-29|0;if(!m){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=e+784|0;h=d+((c+2046&2047)<<2)|0;c=c-1&2047;v[h>>2]=v[h>>2]|v[d+(c<<2)>>2]}o=o+9|0;v[(e+784|0)+(b<<2)>>2]=m;continue}}v[s+40>>2]=h;v[s+44>>2]=k;v[s+32>>2]=l;v[s+36>>2]=i;cb=e+8976|0;D=v[s+40>>2];z=v[s+44>>2];h=v[s+32>>2];k=v[s+36>>2];break a;case 3:break j;default:break m}}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}break i}ia:{c=v[b+4>>2];ja:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break ja}c=id(b)}if((c|0)==40){g=1;break ia}z=2147450880;if(v[b+116>>2]<0){break a}v[b+4>>2]=v[b+4>>2]-1;break a}while(1){c=v[b+4>>2];ka:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break ka}c=id(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}z=2147450880;if((c|0)==41){break a}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}la:{if(d){if(g){break la}break a}break i}while(1){g=g-1|0;if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}if(g){continue}break}break a}v[114922]=28;hi(b,0,0)}z=0}v[a>>2]=h;v[a+4>>2]=k;v[a+8>>2]=D;v[a+12>>2]=z;cb=s+48|0}function ofa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;d=cb-336|0;cb=d;sc(b);a:{if(!ao(b,d+320|0)){break a}if(!HQ(d+320|0)){break a}q=be(d+296|0,b);p=bf(d+280|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if(!c){v[22440]=0;R(655,d|0,q|0);b=v[22440];v[22440]=0;if((b|0)==1){break y}break A}v[22440]=0;R(656,d|0,q|0);b=v[22440];v[22440]=0;if((b|0)==1){break z}}wt(p,d);Qd(d);v[22440]=0;U(657,d|0,p|0,1413891155);b=v[22440];v[22440]=0;B:{C:{if((b|0)!=1){v[22440]=0;e=Q(658,d|0,14213)|0;b=v[22440];v[22440]=0;if((b|0)==1){break C}sb(d);if(!c){break b}if(!(e^1)){break B}break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;sb(d);break c}v[22440]=0;R(252,a|0,4194304);b=v[22440];v[22440]=0;if((b|0)==1){break d}v[a+480208>>2]=12;v[22440]=0;U(657,d+256|0,p|0,1280592212);b=v[22440];v[22440]=0;if((b|0)==1){break e}v[22440]=0;b=T(162,d+256|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break g}v[22440]=0;U(457,d+256|0,a+1298308|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break g}m=a+484360|0;Ac(Nb(m));l=Rb(d+240|0);t[d+239|0]=0;v[22440]=0;U(659,d+224|0,p|0,1196314451);b=v[22440];v[22440]=0;if((b|0)==1){break i}y=d,z=yb(v[d+224>>2]),v[y+216>>2]=z;j=d+44|0;h=yb(v[d+228>>2]);D:{E:{while(1){b=v[d+216>>2];if(!Qb(b,h)){break E}e=be(d+192|0,b);v[22440]=0;f=Q(660,e|0,d+176|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break D}b=1;if(!(!f|w[d+185|0]!=1)){y=a,z=wd(w[d+186|0],x[a+480188>>1],127),u[y+480188>>1]=z;v[22440]=0;i=T(661,d|0)|0;b=v[22440];v[22440]=0;F:{G:{H:{I:{if((b|0)!=1){pf(d+160|0,d+176|0,9,1);v[22440]=0;W(225,d+120|0,v[d+160>>2],v[d+164>>2],w[d+168|0]);b=v[22440];v[22440]=0;if((b|0)==1){break I}b=d+152|0;$b(b,j,10);f=b;b=d+120|0;Kj(f,b);rb(b);b=Nb(m);if(hc(v[b>>2],v[b+4>>2])){break G}v[22440]=0;b=T(279,m|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break H}if((b|0)!=255){break G}b=2;break F}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=Nb(m);v[22440]=0;U(5,d+120|0,5,j|0);f=v[22440];v[22440]=0;if((f|0)==1){break n}v[22440]=0;R(280,b|0,d+120|0);b=v[22440];v[22440]=0;if((b|0)==1){break o}rb(d+120|0);v[22440]=0;R(656,d+160|0,e|0);b=v[22440];v[22440]=0;if((b|0)==1){break p}y=d,z=yb(v[d+160>>2]),v[y+144>>2]=z;k=yb(v[d+164>>2]);J:{K:{while(1){e=v[d+144>>2];if(!Qb(e,k)){b=0;if(x[d+36>>1]==65535|x[d+38>>1]==65535){break J}b=Nb(m);v[22440]=0;Z(662,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){v[22440]=0;R(663,l|0,i|0);e=v[22440];v[22440]=0;b=0;if((e|0)!=1){break J}}b=P()|0;O()|0;break m}ho(d+120|0,e);b=d+152|0;Uh(b,e);e=1;L:{f=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);M:{if((f|0)!=1212960847){b=0;if((f|0)!=1312903248){break M}while(1){if(x[a+480188>>1]<=b>>>0){break M}v[22440]=0;f=Q(158,d+120|0,2)|0;g=v[22440];v[22440]=0;if((g|0)!=1){if(!f){break M}v[22440]=0;R(267,d+96|0,d+120|0);f=v[22440];v[22440]=0;N:{O:{P:{Q:{if((f|0)!=1){switch(w[d+96|0]){case 4:break O;case 2:break P;case 0:break Q;default:break N}}break q}f=Ec(d+96|0);y=Eb(v[d>>2],b),z=w[f|0]^128,t[y|0]=z;f=d+104|0;ub(f,v[d+24>>2],b);Te(f,0);break N}y=Eb(v[d>>2],b),z=128,t[y|0]=z;f=d+104|0;ub(f,v[d+24>>2],b);Te(f,1);break N}y=Eb(v[d>>2],b),z=128,t[y|0]=z;f=d+104|0;ub(f,v[d+24>>2],b);Te(f,0)}b=b+1|0;continue}break}break q}if(om(d+152|0)>>>0<9){break M}b=0;v[22440]=0;Q(190,d+120|0,2)|0;e=v[22440];v[22440]=0;f=65535;if((e|0)==1){break L}while(1){R:{v[22440]=0;e=Q(158,d+120|0,1)|0;g=v[22440];v[22440]=0;S:{T:{U:{V:{W:{X:{Y:{Z:{if((g|0)!=1){if(!e){break R}v[22440]=0;g=T(208,d+120|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break q}e=0;switch(g|0){case 0:break R;case 14:break T;case 13:break U;case 12:break V;case 8:break W;case 7:break X;case 4:break Y;case 1:break Z;default:break M}}break q}if(x[d+36>>1]==65535){y=d,z=yl(Nb(m)),u[y+36>>1]=z}e=yl(Nb(m));v[22440]=0;u[d+38>>1]=e;e=Q(664,d+120|0,d+239|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break q}_:{$:{switch(e-254|0){case 1:e=65535;break _;case 0:break $;default:break _}}e=65534}g=Nb(m);v[22440]=0;R(535,g|0,e|0);e=v[22440];v[22440]=0;if((e|0)==1){break q}f=(f&65535)==65535?b:f;break S}v[22440]=0;e=T(196,d+120|0)|0;g=v[22440];v[22440]=0;aa:{ba:{if((g|0)!=1){if(e>>>0>=(f&65535)>>>0){break ba}e=x[d+40>>1];break aa}break q}e=e-f|0;u[d+40>>1]=e}Qe(Nb(m),e&65535);break S}v[22440]=0;e=T(208,d+120|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break q}t[d+43|0]=e;break S}v[22440]=0;e=T(208,d+120|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break q}t[d+42|0]=e;break S}v[22440]=0;g=Q(626,d+120|0,d+104|0)|0;n=v[22440];v[22440]=0;if((n|0)!=1){if(w[d+104|0]|!g|(w[d+106|0]|w[d+105|0]!=255)){break M}if(w[d+107|0]|w[d+108|0]!=1){break M}if(!w[d+109|0]){break S}break M}break q}v[22440]=0;R(547,d+112|0,d+120|0);e=v[22440];v[22440]=0;ca:{da:{ea:{fa:{if((e|0)!=1){n=Ec(d+112|0);e=v[d>>2];o=Uc(e,v[d+4>>2]);g=w[d+112|0];if(o>>>0<=g>>>0){break S}switch(w[Oe(d+112|0)|0]){case 4:break da;case 2:break ea;case 0:break fa;default:break ca}}break q}y=Eb(e,g),z=w[n|0]^128,t[y|0]=z;e=d+104|0;ub(e,v[d+24>>2],w[d+112|0]);Te(e,0);break ca}y=Eb(e,g),z=128,t[y|0]=z;e=d+104|0;ub(e,v[d+24>>2],w[d+112|0]);Te(e,1);break ca}y=Eb(e,g),z=128,t[y|0]=z;e=d+104|0;ub(e,v[d+24>>2],w[d+112|0]);Te(e,0)}ga:{if(r){break ga}r=0;e=v[l+4>>2];if(!Up(v[l>>2],e)){break S}g=e-56|0;e=w[d+112|0];if(w[Eb(v[g>>2],e)|0]!=w[Eb(v[d>>2],e)|0]){break ga}ub(d+104|0,v[g+24>>2],e);e=tb(v[v[d+104>>2]>>2],v[d+108>>2]);ub(d+96|0,v[d+24>>2],w[d+112|0]);if((tb(v[v[d+96>>2]>>2],v[d+100>>2])|0)==(e|0)){break S}}r=1;break S}v[22440]=0;R(267,d+104|0,d+120|0);e=v[22440];v[22440]=0;if((e|0)==1){break q}e=v[d+12>>2];n=Uc(e,v[d+16>>2]);g=w[d+104|0];if(n>>>0<=g>>>0){break S}n=Ec(d+104|0);y=Eb(e,g),z=(w[n|0]>>>2|0)+1|0,t[y|0]=z}b=b+1|0;continue}break}e=1}sb(d+120|0);if(!e){break K}zm(d+144|0);continue}break}break q}b=1}Qd(d+160|0)}vt(i)}sb(d+192|0);if(!b){Uf(d+216|0);continue}break}e=0;if((b|0)!=2){break v}}e=0;Hi(m,0);b=v[l>>2];if(hc(b,v[l+4>>2])){break v}if(!(c&2)){break w}v[22440]=0;U(659,d+192|0,p|0,1347244868);b=v[22440];v[22440]=0;if((b|0)!=1){y=d,z=yb(v[d+192>>2]),v[y+176>>2]=z;e=a+480190|0;f=d+13|0;i=d+17|0;g=yb(v[d+196>>2]);j=w[d+239|0];while(1){b=v[d+176>>2];if(!Qb(b,g)){Ic(d+192|0);b=v[l>>2];break w}ha:{ia:{ja:{if(!j){v[22440]=0;h=Q(665,b|0,d|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break ha}if(!h){break ia}h=w[d+52|0]|w[d+53|0]<<8;k=h+1|0;u[d+152>>1]=k;if(h>>>0>3998){break ja}y=a,z=x[ie(e,d+152|0)>>1],u[y+480190>>1]=z;v[22440]=0;R(666,d|0,(B(k&65535,104)+a|0)+484380|0);h=v[22440];v[22440]=0;if((h|0)==1){break ha}GQ(d+160|0,f);v[22440]=0;W(225,d+120|0,v[d+160>>2],v[d+164>>2],w[d+168|0]);h=v[22440];v[22440]=0;if((h|0)==1){break x}h=d+120|0;uc(((x[d+152>>1]<<5)+a|0)+946304|0,h);rb(h);break ja}v[22440]=0;h=Q(667,b|0,d|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break x}if(!h){break ia}h=w[d+56|0]|w[d+57|0]<<8;k=h+1|0;u[d+152>>1]=k;if(h>>>0>3998){break ja}y=a,z=x[ie(e,d+152|0)>>1],u[y+480190>>1]=z;v[22440]=0;R(668,d|0,(B(k&65535,104)+a|0)+484380|0);h=v[22440];v[22440]=0;if((h|0)==1){break x}GQ(d+160|0,i);v[22440]=0;W(225,d+120|0,v[d+160>>2],v[d+164>>2],w[d+168|0]);h=v[22440];v[22440]=0;if((h|0)==1){break x}h=d+120|0;uc(((x[d+152>>1]<<5)+a|0)+946304|0,h);rb(h)}if((x[d+152>>1]-1&65535)>>>0>3998){break ia}h=Nc(d,8,1,0,2);v[22440]=0;Y(222,h|0,(B(x[d+152>>1],104)+a|0)+484380|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break ia}break x}Uf(d+176|0);continue}break}break x}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;Ic(d+192|0);break j}b=Iz(b,0);v[a+480196>>2]=w[b+43|0];v[a+480204>>2]=B(w[b+42|0],1e4);Qe(Nb(m),x[b+40>>1]);b=0;while(1){if(x[a+480188>>1]>b>>>0){e=(b<<5)+a|0;f=e+480280|0;$e(f);i=Iz(v[l>>2],0);y=e+480286|0,z=w[Eb(v[i+12>>2],b)|0],u[y>>1]=z;y=e+480284|0,z=w[Eb(v[i>>2],b)|0],u[y>>1]=z;ub(d,v[i+24>>2],b);y=f,z=v[f>>2]&-257|(tb(v[v[d>>2]>>2],v[d+4>>2])?256:0),v[y>>2]=z;b=b+1|0;continue}break}ka:{if(w[d+239|0]){v[22440]=0;Q(1,d|0,17162)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break ka}break r}v[22440]=0;Q(1,d|0,17035)|0;b=v[22440];v[22440]=0;if((b|0)==1){break r}}Cb(a+1298344|0,d);rb(d);v[22440]=0;b=Q(1,d|0,10156)|0;f=v[22440];v[22440]=0;e=1;if((f|0)!=1){Cb(a+1298356|0,b);rb(b);v[a+1298404>>2]=5;if(!(c&1)|!x[a+480188>>1]){break v}v[22440]=0;U(659,d+120|0,p|0,1146045008);b=v[22440];v[22440]=0;if((b|0)==1){break s}b=v[d+124>>2];c=v[d+120>>2];v[22440]=0;g=a+484344|0;R(228,g|0,Df(c,b)&65535);b=v[22440];v[22440]=0;if((b|0)==1){break u}y=d,z=yb(v[d+120>>2]),v[y+160>>2]=z;s=yb(v[d+124>>2]);while(1){i=v[d+160>>2];if(!Qb(i,s)){la:{ma:{b=v[l>>2];e=v[l+4>>2];if(Up(b,e)>>>0<2){break ma}c=0;while(1){if(Up(b,e)>>>0<=c>>>0){break ma}i=xj(m,c&255);h=v[i>>2];f=Iz(b,c);j=x[f+36>>1];if(ve(g,x[Xb(h,j)>>1])){v[22440]=0;e=Q(371,i|0,j|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break la}na:{if(!r){break na}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break na}ub(d,v[f+24>>2],b);j=tb(v[v[d>>2]>>2],v[d+4>>2]);i=Sb(g,e);oa:{if(j){xe(i,yh(bo(Pe(Je(d,20,145),0),b&65535)));break oa}xe(i,yh(bo(Pe(Je(d,9,w[Eb(v[f>>2],b)|0]),0),b&65535)))}b=b+1|0;continue}}xe(Sb(g,e),yh(Pe(Je(d,16,w[f+43|0]),0)));xe(Sb(g,e),yh(Pe(Je(d,17,w[f+42|0]),0)));e=v[l+4>>2];b=v[l>>2]}c=c+1|0;continue}}Ic(d+120|0);e=1;break v}b=P()|0;O()|0;break t}v[22440]=0;b=T(162,i|0)|0;c=v[22440];v[22440]=0;pa:{qa:{ra:{sa:{ta:{ua:{va:{if((c|0)==1){break va}v[22440]=0;c=T(159,i|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break va}if((b|0)!=(c|0)){break pa}v[22440]=0;b=Q(669,i|0,8)|0;c=v[22440];v[22440]=0;if((c|0)==1){break va}if(!b){break pa}v[22440]=0;k=Q(664,i|0,d+239|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break qa}v[22440]=0;n=T(196,i|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break ra}v[22440]=0;b=Y(229,g|0,k|0,n|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break ra}if(!b){break pa}h=0;while(1){if((h|0)==(n|0)){break pa}c=Gf(Sb(g,k),h);v[22440]=0;b=T(196,i|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break ua}wa:{if(b>>>0>=3){v[22440]=0;U(192,d+192|0,i|0,b-2|0);b=v[22440];v[22440]=0;if((b|0)==1){break sa}b=d+192|0;j=cc(d,b);sb(b);while(1){v[22440]=0;b=Q(158,d|0,3)|0;e=v[22440];v[22440]=0;if((e|0)==1){break wa}if(b){v[22440]=0;R(267,d+192|0,j|0);b=v[22440];v[22440]=0;xa:{ya:{za:{Aa:{if((b|0)!=1){b=d+192|0;f=b;u[d+176>>1]=x[a+480188>>1]-1;y=d,z=w[Ec(b)|0],u[y+152>>1]=z;e=x[Kc(d+176|0,d+152|0)>>1];b=t[b|0];if((b|0)>=0){break xa}v[22440]=0;b=T(208,j|0)|0;o=v[22440];v[22440]=0;if((o|0)==1){break ta}if(w[d+239|0]){break za}if((b|0)!=255){break Aa}b=254;break ya}break ta}if(b>>>0>128){break ya}b=(B(b>>>4|0,12)+(b&15)|0)+13|0;break ya}b=b>>>0<85?b+36|0:b}t[c+B(e,6)|0]=b;b=w[f|0]}if(b&64){v[22440]=0;b=T(208,j|0)|0;o=v[22440];v[22440]=0;if((o|0)==1){break ta}t[(c+B(e,6)|0)+1|0]=b+1;b=w[f|0]}if(b&32){v[22440]=0;b=T(208,j|0)|0;o=v[22440];v[22440]=0;if((o|0)==1){break ta}t[d+176|0]=b;b=c+B(e,6)|0;t[b+2|0]=1;t[d+152|0]=127;y=b,z=w[Tb(d+176|0,d+152|0)|0]+1>>>1|0,t[y+4|0]=z;b=w[f|0]}if(!(b&16)){continue}v[22440]=0;R(267,d+176|0,j|0);b=v[22440];v[22440]=0;Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{if((b|0)!=1){b=c+B(e,6)|0;o=d+176|0;f=w[Ec(o)|0];t[b+5|0]=f;switch(w[o|0]-1|0){case 72:break Ca;case 71:break Da;case 70:break Ea;case 61:break Fa;case 60:break Ga;case 53:break Ha;case 52:break Ia;case 51:break Ja;case 50:break Ka;case 43:break La;case 42:break Ma;case 41:break Na;case 40:break Oa;case 31:break Pa;case 30:break Qa;case 23:break Ra;case 22:break Sa;case 21:break Ta;case 20:break Ua;case 18:break Va;case 17:break Wa;case 15:break Xa;case 16:break Ya;case 14:break Za;case 13:break _a;case 12:break $a;case 11:break ab;case 10:break bb;case 3:break cb;case 2:break db;case 1:break eb;case 0:break fb;default:break Ba}}break ta}t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[b+5|0]=f<<4|15;continue}t[b+5|0]=f<<3|15;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[b+5|0]=f<<4;continue}t[b+5|0]=f<<3&240;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[b+5|0]=f|240;continue}t[b+5|0]=f>>>1|240;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[b+5|0]=f&15;continue}if(f>>>0<=1){t[b+5|0]=f|240;continue}t[b+5|0]=f>>>1&15;continue}t[(c+B(e,6)|0)+3|0]=2;y=b,z=ut(f,w[d+239|0])|240,t[y+5|0]=z;continue}t[(c+B(e,6)|0)+3|0]=2;y=b,z=ut(f,w[d+239|0]),t[y+5|0]=z;continue}t[(c+B(e,6)|0)+3|0]=3;y=b,z=ut(f,w[d+239|0])|240,t[y+5|0]=z;continue}t[(c+B(e,6)|0)+3|0]=3;y=b,z=ut(f,w[d+239|0]),t[y+5|0]=z;continue}t[(c+B(e,6)|0)+3|0]=4;if(w[d+239|0]){continue}t[b+5|0]=(f&252)>>>2;continue}t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&1|16;continue}t[(c+B(e,6)|0)+3|0]=6;t[b+5|0]=f&240;continue}t[(c+B(e,6)|0)+3|0]=6;t[b+5|0]=(f&240)>>>4;continue}t[(c+B(e,6)|0)+3|0]=20;continue}t[(c+B(e,6)|0)+3|0]=5;continue}t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|48;continue}t[(c+B(e,6)|0)+3|0]=7;t[b+5|0]=f|240;continue}t[(c+B(e,6)|0)+3|0]=7;continue}t[(c+B(e,6)|0)+3|0]=8;continue}t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|64;continue}t[(c+B(e,6)|0)+3|0]=10;v[22440]=0;e=T(208,j|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break ta}t[b+5|0]=e;v[22440]=0;Q(190,d|0,1)|0;b=v[22440];v[22440]=0;if((b|0)!=1){continue}break ta}t[(c+B(e,6)|0)+3|0]=15;continue}t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|192;continue}t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|208;continue}t[(c+B(e,6)|0)+3|0]=12;t[b+5|0]=(f&254)>>>1;v[22440]=0;Q(190,d|0,1)|0;b=v[22440];v[22440]=0;if((b|0)!=1){continue}break ta}t[(c+B(e,6)|0)+3|0]=14;t[b+5|0]=0;continue}t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|176;continue}t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|224;continue}t[(c+B(e,6)|0)+3|0]=16;continue}t[(c+B(e,6)|0)+3|0]=17;continue}t[(c+B(e,6)|0)+3|0]=1;continue}t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|32;continue}t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|128;continue}t[(c+B(e,6)|0)+3|0]=0;continue}break}sb(d)}h=h+1|0;continue}break}break ta}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;sb(d);break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}Uf(d+160|0);continue}}b=P()|0;O()|0;break j}Ic(d+224|0);EQ(l);sb(d+256|0);break b}b=P()|0;O()|0}Ic(d+120|0);break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;sb(d+120|0);break m}b=P()|0;O()|0;break l}b=P()|0;O()|0;rb(d+120|0);break l}b=P()|0;O()|0;break l}Qd(d+160|0)}vt(i)}sb(d+192|0)}Ic(d+224|0);break h}b=P()|0;O()|0}EQ(l);break f}b=P()|0;O()|0}sb(d+256|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0}Qd(p);sb(q);S(b|0);L()}Qd(p);sb(q)}cb=d+336|0;return e|0}function kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0;e=cb-416|0;cb=e;sc(b);d=e+408|0;f=tu(b,d);if(!f){dS(d)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!f){break k}if(!eS(e+408|0)){break k}if(!c){s=1;break k}E=be(e+384|0,b);v[22440]=0;R(506,e+368|0,E|0);b=v[22440];v[22440]=0;l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if((b|0)!=1){v[22440]=0;U(507,e+344|0,e+368|0,20041);b=v[22440];v[22440]=0;if((b|0)==1){break v}v[22440]=0;b=T(180,e+344|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break m}if(!b){break l}v[22440]=0;b=Q(508,e+344|0,e+248|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break m}if(!b){break l}v[22440]=0;R(252,a|0,16384);b=v[22440];v[22440]=0;if((b|0)==1){break m}v[a+480208>>2]=8;v[22440]=0;b=Y(271,a+1074312|0,9,1)|0;d=v[22440];v[22440]=0;if((d|0)==1){break m}v[22440]=0;b=Y(271,b|0,114,1)|0;d=v[22440];v[22440]=0;if((d|0)==1){break m}v[22440]=0;b=Q(272,b|0,21)|0;d=v[22440];v[22440]=0;if((d|0)==1){break m}v[22440]=0;Q(272,b|0,30)|0;b=v[22440];v[22440]=0;if((b|0)==1){break m}v[22440]=0;b=Q(1,e+208|0,8309)|0;d=v[22440];v[22440]=0;if((d|0)==1){break s}Cb(a+1298344|0,b);rb(b);v[22440]=0;b=Q(1,e+208|0,10741)|0;d=v[22440];v[22440]=0;if((d|0)==1){break r}Cb(a+1298356|0,b);rb(b);v[22440]=0;b=Q(1,e+96|0,17532)|0;d=v[22440];v[22440]=0;if((d|0)==1){break q}d=w[e+412|0];switch(d-16|0){case 1:break p;case 0:break u;default:break t}}d=P()|0;O()|0;break a}d=P()|0;O()|0;break b}v[22440]=0;Q(1,e+232|0,15122)|0;d=v[22440];v[22440]=0;if((d|0)!=1){break n}break e}if(!d){break o}v[22440]=0;Q(1,e+232|0,21685)|0;d=v[22440];v[22440]=0;if((d|0)==1){break e}break n}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}v[22440]=0;Q(1,e+232|0,15141)|0;d=v[22440];v[22440]=0;if((d|0)!=1){break n}break e}v[22440]=0;Q(1,e+232|0,13299)|0;d=v[22440];v[22440]=0;if((d|0)==1){break e}}v[22440]=0;U(2,e+208|0,b|0,e+232|0);d=v[22440];v[22440]=0;if((d|0)==1){break f}d=e+208|0;Cb(a+1298368|0,d);rb(d);rb(e+232|0);rb(b);v[a+1298404>>2]=5;Ie(e+96|0,3,e+248|0);v[22440]=0;W(225,d|0,v[e+96>>2],v[e+100>>2],w[e+104|0]);b=v[22440];v[22440]=0;if((b|0)==1){break g}b=e+208|0;tc(a+1298308|0,b);rb(b);Bj(e+232|0,3,e+280|0);v[22440]=0;W(225,e+96|0,v[e+232>>2],v[e+236>>2],w[e+240|0]);b=v[22440];v[22440]=0;if((b|0)==1){break h}v[22440]=0;U(11,e+208|0,5,e+96|0);b=v[22440];v[22440]=0;if((b|0)==1){break i}b=e+208|0;Cb(a+1298320|0,b);rb(b);rb(e+96|0);v[a+480200>>2]=w[e+304|0]+1;K=a,M=wd(w[e+305|0],1,255),v[K+480196>>2]=M;K=a,M=B(wd(w[e+306|0],4,255),1e4),v[K+480204>>2]=M;b=a+484360|0;d=Nb(b);f=w[e+300|0]|w[e+301|0]<<8;v[22440]=0;ea(351,d|0,e+344|0,f|0,65535,65535)|0;d=v[22440];v[22440]=0;if((d|0)==1){break m}Qe(Nb(b),w[e+302|0]|w[e+303|0]<<8);u[a+480188>>1]=0;b=0;while(1){if((b|0)==32){v[22440]=0;U(507,e+208|0,e+368|0,17741);b=v[22440];v[22440]=0;if((b|0)!=1){d=e+344|0;f=e+208|0;b=Sc(d,f);sb(f);v[22440]=0;d=T(162,d|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break m}v[22440]=0;W(340,a+1298332|0,b|0,d|0,0);d=v[22440];v[22440]=0;if((d|0)==1){break m}v[22440]=0;U(507,e+208|0,e+368|0,21321);d=v[22440];v[22440]=0;if((d|0)!=1){d=e+208|0;b=Sc(b,d);sb(d);v[22440]=0;d=T(180,e+344|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break m}w:{x:{if(d){v[22440]=0;U(507,e+208|0,e+368|0,16723);d=v[22440];v[22440]=0;if((d|0)==1){break w}v[22440]=0;s=T(208,b|0)|0;d=v[22440];v[22440]=0;y:{if((d|0)!=1){o=c&2;l=a+480190|0;while(1){if(s>>>0<=(i&255)>>>0){break y}v[22440]=0;f=T(208,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break x}if(!f){break y}v[22440]=0;d=Q(158,e+344|0,56)|0;k=v[22440];v[22440]=0;if((k|0)==1){break x}if(!d){break y}if(f>>>0>x[l>>1]){u[l>>1]=f}v[22440]=0;d=B(f,104)+a|0;k=d+484380|0;R(284,k|0,0);g=v[22440];v[22440]=0;if((g|0)==1){break x}_n(k);v[22440]=0;U(321,b|0,((f<<5)+a|0)+946304|0,32);f=v[22440];v[22440]=0;if((f|0)==1){break x}v[22440]=0;R(324,b|0,d+484423|0);f=v[22440];v[22440]=0;if((f|0)==1){break x}z:{if(w[e+412|0]<=15){v[22440]=0;h=T(196,b|0)|0;f=v[22440];v[22440]=0;if((f|0)!=1){break z}break x}v[22440]=0;h=T(159,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break x}}v[d+484404>>2]=h<<1;v[22440]=0;f=T(159,b|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break x}v[k>>2]=f;v[22440]=0;g=T(159,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break x}f=d+484384|0;v[f>>2]=g;v[22440]=0;g=T(159,b|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break x}h=d+484388|0;v[h>>2]=g;if(g){j=d+484414|0;u[j>>1]=x[j>>1]|2;v[h>>2]=g+v[f>>2]}v[22440]=0;g=T(208,b|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break x}if(w[e+412|0]<=15){u[d+484410>>1]=g}v[22440]=0;j=T(208,b|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break x}q=d+484414|0;d=x[q>>1];g=8;if(j&1){d=d|1;u[q>>1]=d;v[k>>2]=v[k>>2]>>>1;v[f>>2]=v[f>>2]>>>1;v[h>>2]=v[h>>2]>>>1;g=16}u[q>>1]=d&65531|j<<1&4;d=Nc(e+96|0,g,1,0,((j&12)!=0)<<3);A:{if(!o){break A}v[22440]=0;Y(222,d|0,k|0,e+208|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){break A}break x}i=i+1|0;continue}}break x}sb(e+208|0)}v[22440]=0;U(507,e+208|0,e+368|0,18761);d=v[22440];v[22440]=0;B:{if((d|0)!=1){d=b;b=e+208|0;k=Sc(d,b);sb(b);v[22440]=0;b=T(180,e+344|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break m}if(!b){break B}g=Rb(e+96|0);h=Rb(e+232|0);i=Rb(e+192|0);v[22440]=0;U(507,e+168|0,e+368|0,17750);b=v[22440];v[22440]=0;C:{if((b|0)==1){break C}d=v[e+180>>2];b=e- -64|0;v[b>>2]=v[e+176>>2];v[b+4>>2]=d;v[e+72>>2]=v[e+184>>2];v[22440]=0;b=v[e+172>>2];v[e+56>>2]=v[e+168>>2];v[e+60>>2]=b;R(509,e+56|0,g|0);b=v[22440];v[22440]=0;if((b|0)==1){break C}v[22440]=0;U(507,e+144|0,e+368|0,17744);b=v[22440];v[22440]=0;if((b|0)==1){break C}b=v[e+156>>2];v[e+40>>2]=v[e+152>>2];v[e+44>>2]=b;v[e+48>>2]=v[e+160>>2];v[22440]=0;b=v[e+148>>2];v[e+32>>2]=v[e+144>>2];v[e+36>>2]=b;R(509,e+32|0,h|0);b=v[22440];v[22440]=0;if((b|0)==1){break C}v[22440]=0;U(507,e+120|0,e+368|0,17734);b=v[22440];v[22440]=0;if((b|0)==1){break C}b=v[e+132>>2];v[e+16>>2]=v[e+128>>2];v[e+20>>2]=b;v[e+24>>2]=v[e+136>>2];v[22440]=0;b=v[e+124>>2];v[e+8>>2]=v[e+120>>2];v[e+12>>2]=b;R(509,e+8|0,i|0);b=v[22440];v[22440]=0;if((b|0)==1){break C}v[22440]=0;A=T(208,k|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break C}b=e+208|0;y=b|4;z=b|2;m=b|6;p=b|5;r=b|3;l=b|1;C=a+480190|0;q=0;while(1){if(A>>>0<=(q&255)>>>0){Un(i);Un(h);Un(g);break B}v[22440]=0;R(267,e+80|0,k|0);b=v[22440];v[22440]=0;D:{if((b|0)!=1){o=Ec(e+80|0);E:{F:{if(!w[e+80|0]){break F}b=w[o|0];v[22440]=0;b=Q(158,e+344|0,B(b,14)+32|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break C}if(!b){break F}b=w[e+80|0];v[22440]=0;f=Y(257,a|0,b|0,0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break C}if(f){break E}}b=w[o|0];v[22440]=0;Q(190,e+344|0,B(b,14)+32|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break D}break C}v[22440]=0;U(321,k|0,f+492|0,32);b=v[22440];v[22440]=0;if((b|0)==1){break C}D=f+88|0;F=f+68|0;G=f+48|0;H=f+236|0;b=0;s=0;while(1){if(w[o|0]<=(s&255)>>>0){break D}v[22440]=0;R(510,k|0,e+208|0);d=v[22440];v[22440]=0;if((d|0)==1){break C}d=w[e+208|0];G:{if(!d|d>>>0>x[C>>1]){break G}if(w[l|0]>=129){t[l|0]=128}while(1){d=b&255;I=w[l|0];if(d>>>0>I>>>0){b=v[g+4>>2];d=v[g>>2];j=w[r|0];v[22440]=0;W(511,G|0,j|0,d|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break C}b=v[h+4>>2];d=v[h>>2];j=w[p|0];v[22440]=0;W(511,F|0,j|0,d|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break C}b=v[i+4>>2];d=v[i>>2];j=w[e+221|0];v[22440]=0;W(511,D|0,j|0,d|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break C}v[f>>2]=(w[m|0]|w[m+1|0]<<8)+1>>>1;b=w[e+208|0];H:{if(w[r|0]&64){u[(B(b,104)+a|0)+484410>>1]=w[z|0];break H}d=(B(b,104)+a|0)+484414|0;u[d>>1]=x[d>>1]|32768}u[e+118>>1]=w[y|0]<<1;u[e+116>>1]=254;j=B(b,104)+a|0;K=j+484408|0,M=x[Kc(e+118|0,e+116|0)>>1],u[K>>1]=M;t[j+484418|0]=w[(w[e+219|0]&3)+26772|0];d=j+484419|0;n=w[e+218|0];t[d|0]=n;J=w[e+217|0]+3>>>2|0;t[j+484420|0]=J;t[j+484421|0]=w[e+216|0];b=I+1|0;if(n){n=El(wc(((J<<8|n>>>1)>>>0)/(n>>>0)|0,0))}else{n=255}t[d|0]=n;if(!(w[p|0]&64)){break G}d=j+484414|0;u[d>>1]=x[d>>1]|32}else{K=Xb(H,d),M=w[e+208|0],u[K>>1]=M;b=b+1|0;continue}break}}s=s+1|0;continue}}break C}q=q+1|0;continue}}d=P()|0;O()|0;Un(i);Un(h);Un(g);break c}d=P()|0;O()|0;break c}s=1;o=Rb(e+232|0);I:{if(!(c&1)){break I}v[22440]=0;U(507,e+208|0,e+368|0,21076);b=v[22440];v[22440]=0;J:{K:{L:{M:{N:{O:{if((b|0)!=1){c=Sc(k,e+208|0);v[22440]=0;b=T(180,e+344|0)|0;d=v[22440];v[22440]=0;P:{Q:{R:{if((d|0)!=1){sb(e+208|0);if(!b){break P}v[22440]=0;b=T(196,c|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break R}v[22440]=0;d=b+1|0;R(512,o|0,d|0);b=v[22440];v[22440]=0;if((b|0)==1){break R}b=1;while(1){if((b|0)==(d|0)){break P}v[22440]=0;f=T(196,c|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break Q}v[22440]=0;U(192,e+96|0,e+344|0,f|0);f=v[22440];v[22440]=0;if((f|0)==1){break Q}f=e+208|0;k=e+96|0;g=cc(f,k);Sc(Ng(v[o>>2],b),g);b=b+1|0;sb(f);sb(k);continue}}d=P()|0;O()|0;sb(e+208|0);break J}d=P()|0;O()|0;break J}d=P()|0;O()|0;break J}v[22440]=0;U(507,e+208|0,e+368|0,16720);b=v[22440];v[22440]=0;if((b|0)==1){break L}n=Sc(c,e+208|0);v[22440]=0;b=T(180,e+344|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break M}sb(e+208|0);if(!b){break O}v[22440]=0;C=T(208,n|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break K}g=0;S:{T:{U:while(1){V:{if(C>>>0<=(g&65535)>>>0){v[22440]=0;Q(157,e+344|0,1)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break V}break K}i=32;W:{if(w[e+412|0]<16){break W}v[22440]=0;R(513,n|0,e+208|0);b=v[22440];v[22440]=0;if((b|0)==1){break S}i=w[e+208|0];if(i>>>0<=x[a+480188>>1]|i>>>0>32){break W}u[a+480188>>1]=i;i=w[e+208|0]}b=0;while(1){c=b&65535;if(c>>>0>=i>>>0){g=g+1|0;continue U}v[22440]=0;d=T(196,n|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break T}if(!(!d|c>>>0>31|c>>>0<x[a+480188>>1])){u[a+480188>>1]=b+1}b=b+1|0;continue}}break}v[22440]=0;r=a+484344|0;R(228,r|0,C|0);b=v[22440];v[22440]=0;if((b|0)==1){break K}b=e+208|0;F=b|2;G=b|1;c=0;while(1){if((c|0)==(C|0)){break O}A=Db(e+96|0);X:{if(w[e+412|0]<16){q=32;b=64;break X}v[22440]=0;R(513,n|0,e+208|0);b=v[22440];v[22440]=0;if((b|0)==1){break N}q=w[e+208|0];b=w[G|0];pf(e+80|0,F,16,3);v[22440]=0;W(225,e+192|0,v[e+80>>2],v[e+84>>2],w[e+88|0]);d=v[22440];v[22440]=0;if((d|0)==1){break N}d=e+192|0;tc(A,d);rb(d);b=b+1|0}v[22440]=0;k=b;b=Y(229,r|0,c&65535,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break N}Y:{if(!b){v[22440]=0;Q(190,e+344|0,q<<1)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break Y}break N}b=Sb(r,c);v[22440]=0;R(288,b|0,A|0);b=v[22440];v[22440]=0;if((b|0)==1){break N}H=k-1|0;D=0;while(1){y=D&65535;if(y>>>0>=q>>>0){break Y}v[22440]=0;b=T(196,n|0)|0;d=v[22440];v[22440]=0;Z:{if((d|0)!=1){if(!b){break Z}d=v[o>>2];if(Df(d,v[o+4>>2])>>>0<=b>>>0|y>>>0>=x[a+480188>>1]){break Z}j=Ng(d,b);sc(j);f=0;_:while(1){d=f;if(k>>>0<=d>>>0){break Z}v[22440]=0;b=Q(158,j|0,1)|0;f=v[22440];v[22440]=0;$:{aa:{ba:{ca:{da:{if((f|0)!=1){if(!b){break Z}b=Zc(Sb(r,c),d,y);v[22440]=0;f=T(208,j|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break N}h=f>>>2|0;switch((f&3)-1|0){case 2:break aa;case 1:break ba;case 0:break ca;default:break da}}break N}f=(d+h|0)+1|0;continue}f=0;if(!d){continue}g=Zc(Sb(r,c),d-1|0,y);while(1){f=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;f=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=f;t[b+5|0]=f>>>8;f=d+1|0;if((d|0)==(H|0)){continue _}b=B(x[a+480188>>1],6)+b|0;i=h&255;d=f;h=h-1|0;if(i){continue}break}continue}if(d>>>0<=h>>>0){break $}f=Zc(Sb(r,c),h,y);g=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[b|0]=g;t[b+1|0]=g>>>8;t[b+2|0]=g>>>16;t[b+3|0]=g>>>24;f=w[f+4|0]|w[f+5|0]<<8;t[b+4|0]=f;t[b+5|0]=f>>>8;break $}if(h&1){v[22440]=0;f=T(208,j|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break N}t[b|0]=f>>>0>120?-1:f}if(h&2){v[22440]=0;f=T(208,j|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break N}t[b+1|0]=f}i=0;f=0;ea:{if(h&4){v[22440]=0;f=T(208,j|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break ea}}g=0;if(h&8){v[22440]=0;g=T(208,j|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break ea}i=g&15;g=g>>>4|0}m=0;p=0;if(h&16){v[22440]=0;p=T(208,j|0)|0;l=v[22440];v[22440]=0;if((l|0)==1){break ea}}if(h&32){v[22440]=0;m=T(208,j|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break ea}}z=cb-32|0;cb=z;l=z+24|0;bS(l,i,p);p=Ec(l);h=z+16|0;bS(h,((g-1&255)>>>0<6?g+15|0:g)&255,m);i=Ec(h);fa:{ga:{ha:{if(w[l|0]==10){g=w[i|0];m=w[p|0]&15;t[p|0]=m?-1:g;g=g|m<<8;m=w[h|0];if((m|0)!=10){break ha}m=0;t[h|0]=0;break ha}if(w[h|0]!=10){break ga}g=w[i|0]&15;t[i|0]=g?-1:0;g=g<<8;m=w[l|0]}if(g-256>>>0>4294967038){break ga}if(Ji(m)>>>0>=Ji(10)>>>0){break ga}t[b+5|0]=g;t[b+2|0]=15;t[b+3|0]=10;t[b+4|0]=g>>>8;break fa}if(f){t[b+2|0]=1;t[b+4|0]=f+2>>>2}Bu(l,p,h,i);g=w[l|0];ia:{if(!g){break ia}m=w[h|0];if(!m){t[h|0]=g;t[i|0]=w[p|0];t[l|0]=0;break ia}if(!((g|0)==20|(g|0)!=(m|0))){t[l|0]=0;break ia}if(!f){io(z+8|0,b,g,w[p|0],m,w[i|0]);break fa}if(Ji(g)>>>0<=Ji(m)>>>0){break ia}xh(l,h);xh(p,i)}f=w[h|0];t[b+5|0]=w[i|0];t[b+3|0]=f}cb=z+32|0;break $}break N}f=d+1|0;continue}}break N}D=D+1|0;continue}}rb(A);c=c+1|0;continue}}d=P()|0;O()|0;break J}d=P()|0;O()|0;break J}d=P()|0;O()|0;break J}v[22440]=0;U(507,e+208|0,e+368|0,20048);b=v[22440];v[22440]=0;ja:{ka:{if((b|0)!=1){b=Sc(n,e+208|0);v[22440]=0;c=T(180,e+344|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break ka}sb(e+208|0);if(!c){break I}a=a+484344|0;while(1){if(!Cf(a)){break I}v[22440]=0;c=Q(158,e+344|0,16)|0;d=v[22440];v[22440]=0;if((d|0)==1){break ja}if(!c){break I}v[22440]=0;R(397,b|0,e+208|0);c=v[22440];v[22440]=0;if((c|0)!=1){c=Sb(a,0);v[22440]=0;R(398,c|0,e+208|0);c=v[22440];v[22440]=0;if((c|0)!=1){continue}}break}d=P()|0;O()|0;break J}d=P()|0;O()|0;break J}d=P()|0;O()|0;sb(e+208|0);break J}d=P()|0;O()|0;break J}d=P()|0;O()|0;rb(A);break J}d=P()|0;O()|0;sb(e+208|0);break J}d=P()|0;O()|0;break J}d=P()|0;O()|0}Ic(o);break c}Ic(o);break l}d=P()|0;O()|0;sb(e+208|0);break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=(b<<5)+a|0;f=d+480280|0;$e(f);k=b+e|0;g=w[k+307|0]<<1&254;u[d+480284>>1]=(g|0)==254?256:g;la:{if(t[k+307|0]<0){v[f>>2]=v[f>>2]|1024;break la}u[a+480188>>1]=b+1}v[22440]=0;R(514,e+344|0,d+480289|0);d=v[22440];v[22440]=0;if((d|0)==1){break j}b=b+1|0;continue}}d=P()|0;O()|0;break c}sb(e+344|0);Qd(e+368|0);sb(E)}cb=e+416|0;return s|0}d=P()|0;O()|0;break c}d=P()|0;O()|0;rb(e+96|0);break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;rb(e+232|0);break d}d=P()|0;O()|0}rb(b)}sb(e+344|0)}Qd(e+368|0)}sb(E);S(d|0);L()}function XU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;d=cb-432|0;cb=d;sc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if(!$h(b,d+424|0)){break F}if(!BB(d+424|0)){break F}if(!c){s=1;break F}y=be(d+400|0,b);v[22440]=0;R(268,d+384|0,y|0);b=v[22440];v[22440]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((b|0)!=1){v[22440]=0;U(269,d+240|0,d+384|0,1229866575);b=v[22440];v[22440]=0;if((b|0)==1){break da}v[22440]=0;s=Q(270,d+240|0,d+368|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break fa}sb(d+240|0);if(!s){break G}v[22440]=0;R(252,a|0,524288);b=v[22440];v[22440]=0;ga:{if((b|0)==1){break ga}eg(a);v[a+480208>>2]=12;I=a+480188|0,J=wd(wb(w[d+376|0]|w[d+377|0]<<8),1,127),u[I>>1]=J;b=d+368|0;I=d,J=wb(w[b|0]|w[b+1|0]<<8),u[I+240>>1]=J;u[d+344>>1]=255;I=a+480192|0,J=x[Kc(d+240|0,d+344|0)>>1],u[I>>1]=J;b=b|2;I=d,J=wb(w[b|0]|w[b+1|0]<<8),u[I+240>>1]=J;u[d+344>>1]=3999;I=a+480190|0,J=x[Kc(d+240|0,d+344|0)>>1],u[I>>1]=J;v[22440]=0;b=Y(271,a+1074312|0,6,1)|0;e=v[22440];v[22440]=0;if((e|0)==1){break ga}v[22440]=0;b=Q(272,b|0,21)|0;e=v[22440];v[22440]=0;if((e|0)==1){break ga}v[22440]=0;Q(272,b|0,13)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break ea}}b=P()|0;O()|0;break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;sb(d+240|0);break b}v[22440]=0;b=Q(1,d+240|0,9311)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}Cb(a+1298344|0,b);rb(b);v[22440]=0;b=Q(1,d+240|0,10336)|0;e=v[22440];v[22440]=0;if((e|0)==1){break d}Cb(a+1298356|0,b);rb(b);v[22440]=0;R(273,d+344|0,4339);b=v[22440];v[22440]=0;if((b|0)==1){break e}v[22440]=0;R(274,d+320|0,d+424|4);b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;R(274,d+296|0,d+424|5);b=v[22440];v[22440]=0;if((b|0)==1){break i}v[22440]=0;W(113,d+240|0,d+344|0,d+320|0,d+296|0);b=v[22440];v[22440]=0;if((b|0)==1){break j}b=d+240|0;Cb(a+1298368|0,b);rb(b);rb(d+296|0);rb(d+320|0);b=d+344|0;Ab(b);v[a+1298404>>2]=2;v[22440]=0;U(269,b|0,d+384|0,1312902469);b=v[22440];v[22440]=0;if((b|0)==1){break k}v[22440]=0;b=T(162,d+344|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break m}v[22440]=0;f=a+1298308|0;U(275,d+344|0,f|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break m}v[22440]=0;U(269,d+320|0,d+384|0,1397706311);b=v[22440];v[22440]=0;if((b|0)==1){break n}e=a+484360|0;Ac(Nb(e));b=d+368|4;g=wb(w[b|0]|w[b+1|0]<<8);b=0;ha:{ia:{while(1){if(g>>>0<=(b&65535)>>>0){break ha}v[22440]=0;h=Q(158,d+320|0,46)|0;i=v[22440];v[22440]=0;ja:{if((i|0)!=1){if(!h){break ha}v[22440]=0;R(276,d+320|0,d+240|0);h=v[22440];v[22440]=0;if((h|0)!=1){if(!xd(f)){break ja}v[22440]=0;Q(277,f|0,d+240|0)|0;h=v[22440];v[22440]=0;if((h|0)!=1){break ja}}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}v[22440]=0;h=T(278,d+320|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break ca}i=Nb(e);if(!hc(v[i>>2],v[i+4>>2])){v[22440]=0;i=T(279,e|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break ca}if((i|0)==255){break ha}}i=Nb(e);v[22440]=0;U(5,d+296|0,2,d+240|0);j=v[22440];v[22440]=0;if((j|0)!=1){v[22440]=0;R(280,i|0,d+296|0);i=v[22440];v[22440]=0;if((i|0)==1){break ia}rb(d+296|0);i=Nb(e);v[22440]=0;U(281,i|0,d+320|0,h|0);h=v[22440];v[22440]=0;if((h|0)==1){break ca}b=b+1|0;continue}break}b=P()|0;O()|0;break o}b=P()|0;O()|0;rb(d+296|0);break o}Hi(e,0);v[22440]=0;U(269,d+296|0,d+384|0,1229869908);b=v[22440];v[22440]=0;if((b|0)==1){break ba}v[22440]=0;b=T(282,d+296|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break p}ka:{if(!b){break ka}g=a+480192|0;b=1;la:{while(1){e=b&65535;if(e>>>0>x[g>>1]){v[22440]=0;U(269,d+216|0,d+384|0,1447382614);b=v[22440];v[22440]=0;if((b|0)!=1){break la}break p}v[22440]=0;R(283,d+296|0,d+240|0);f=v[22440];v[22440]=0;if((f|0)==1){break p}f=w[d+270|0]|w[d+271|0]<<8;v[22440]=0;e=Y(257,a|0,e|0,wb(f)|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break p}ma:{na:{if(!e){break na}if(wb(w[d+270|0]|w[d+271|0]<<8)>>>0>3999){break na}pu(d+128|0,2,d+240|0);v[22440]=0;W(225,d+152|0,v[d+128>>2],v[d+132>>2],w[d+136|0]);f=v[22440];v[22440]=0;if((f|0)==1){break ma}f=d+152|0;uc(e+492|0,f);rb(f);pu(d+128|0,2,d+240|0);v[22440]=0;W(225,f|0,v[d+128>>2],v[d+132>>2],w[d+136|0]);f=v[22440];v[22440]=0;if((f|0)==1){break p}f=d+152|0;uc(((wb(w[d+270|0]|w[d+271|0]<<8)<<5)+a|0)+946304|0,f);rb(f);v[e>>2]=0;I=e,J=Rd((w[d+286|0]|w[d+287|0]<<8)<<16>>16)+128&65535,v[I+8>>2]=J;qc(e+8|0,256);t[e+15|0]=w[e+15|0]|1;e=w[d+270|0]|w[d+271|0]<<8;v[22440]=0;e=B(wb(e),104)+a|0;R(284,e+484380|0,0);f=v[22440];v[22440]=0;if((f|0)==1){break p}I=d,J=wb(w[d+272|0]|w[d+273|0]<<8),u[I+152>>1]=J;u[d+128>>1]=64;I=e+484410|0,J=x[Kc(d+152|0,d+128|0)>>1]<<2,u[I>>1]=J;I=e+484404|0,J=Wb(w[d+274|0]|w[d+275|0]<<8|(w[d+276|0]<<16|w[d+277|0]<<24)),v[I>>2]=J;if(!Wb(w[d+282|0]|w[d+283|0]<<8|(w[d+284|0]<<16|w[d+285|0]<<24))){break na}if(!(wb(w[d+288|0]|w[d+289|0]<<8)&3)){break na}f=Wb(w[d+278|0]|w[d+279|0]<<8|(w[d+280|0]<<16|w[d+281|0]<<24));v[e+484384>>2]=f;I=e+484388|0,J=Wb(w[d+282|0]|w[d+283|0]<<8|(w[d+284|0]<<16|w[d+285|0]<<24))+f|0,v[I>>2]=J;e=e+484414|0;f=x[e>>1];u[e>>1]=f|2;if(!(wb(w[d+288|0]|w[d+289|0]<<8)&2)){break na}u[e>>1]=f|6}b=b+1|0;continue}break}break p}b=v[d+228>>2];v[d+32>>2]=v[d+224>>2];v[d+36>>2]=b;v[d+40>>2]=v[d+232>>2];v[22440]=0;b=v[d+220>>2];v[d+24>>2]=v[d+216>>2];v[d+28>>2]=b;W(285,d+24|0,0,a|0,0);b=v[22440];v[22440]=0;if((b|0)==1){break p}v[22440]=0;U(269,d+192|0,d+384|0,1346719318);b=v[22440];v[22440]=0;if((b|0)==1){break p}b=v[d+204>>2];v[d+8>>2]=v[d+200>>2];v[d+12>>2]=b;v[d+16>>2]=v[d+208>>2];v[22440]=0;b=v[d+196>>2];v[d>>2]=v[d+192>>2];v[d+4>>2]=b;W(285,d|0,1,a|0,w[d+428|0]>2|0);b=v[22440];v[22440]=0;if((b|0)==1){break p}f=x[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>f>>>0){break ka}e=v[((e<<2)+a|0)+900380>>2];if(!(!e|t[e+60|0]&1)){v[e>>2]=32767}b=b+1|0;continue}}sb(d+296|0);v[22440]=0;U(269,d+240|0,d+384|0,1346458708);b=v[22440];v[22440]=0;if((b|0)==1){break q}v[22440]=0;b=T(180,d+240|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break s}if(!(!(c&1)|b^1)){v[22440]=0;U(269,d+296|0,d+384|0,1347305805);b=v[22440];v[22440]=0;if((b|0)==1){break t}v[22440]=0;Q(190,d+296|0,1)|0;b=v[22440];v[22440]=0;if((b|0)==1){break v}p=d+368|6;b=w[p|0]|w[p+1|0]<<8;v[22440]=0;n=a+484344|0;R(228,n|0,wb(b)|0);b=v[22440];v[22440]=0;if((b|0)==1){break v}b=d+128|0;D=b|3;E=b|1;j=Rb(d+176|0);F=a+480188|0;h=0;while(1){if(wb(w[p|0]|w[p+1|0]<<8)>>>0<=m>>>0){_c(j);f=h;sb(d+296|0);if(!(c&4)){break $}e=0;if(!G){break aa}g=x[a+480188>>1];b=0;e=1;while(1){if((b|0)==(g|0)){break aa}h=(b<<5)+a|0;t[h+480288|0]=1;h=h+480280|0;v[h>>2]=v[h>>2]|67108864;b=b+1|0;continue}}v[22440]=0;b=T(278,d+240|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break x}v[22440]=0;e=T(286,d+240|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break y}v[22440]=0;U(192,d+128|0,d+240|0,e|0);e=v[22440];v[22440]=0;if((e|0)==1){break z}e=d+128|0;k=cc(d+152|0,e);sb(e);v[22440]=0;e=Y(229,n|0,m&65535,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break B}oa:{if(e){q=Db(d+112|0);v[22440]=0;R(287,d+296|0,q|0);e=v[22440];v[22440]=0;if((e|0)==1){break oa}e=Sb(n,m);v[22440]=0;R(288,e|0,q|0);e=v[22440];v[22440]=0;if((e|0)==1){break oa}o=0;C=Gf(Sb(n,m),0);Ac(j);H=(b>>>0>1?b:1)-1|0;pa:while(1){v[22440]=0;b=Q(158,d+152|0,1)|0;e=v[22440];v[22440]=0;if((e|0)==1){break C}qa:{if(!b){break qa}v[22440]=0;e=T(208,k|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break C}if(!e){I=d,J=yb(v[j>>2]),v[I+104>>2]=J;e=yb(v[j+4>>2]);while(1){b=v[d+104>>2];if(Qb(b,e)){xe(Sb(n,m),Pe(Je(d+128|0,w[b|0],w[b+1|0]),o));Ne(d+104|0);continue}else{Ac(j);if((o|0)==(H|0)){break qa}o=o+1|0;C=Gf(Sb(n,m),o);continue pa}}}Ej(d+128|0);f=x[F>>1];v[22440]=0;b=T(208,k|0)|0;g=v[22440];v[22440]=0;ra:{sa:{if((g|0)!=1){z=B(e-1|0,6)+C|0;A=e>>>0>f>>>0;i=A?d+128|0:z;ta:{if(!(b&1)){break ta}v[22440]=0;e=T(208,k|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break C}if((e|0)!=31){if((e-1&255)>>>0>252){break ta}f=(B(e>>>4|0,12)+(e&15)|0)+13|0}else{f=255}t[i|0]=f}if(!(b&2)){break ra}v[22440]=0;e=T(208,k|0)|0;f=v[22440];v[22440]=0;if((f|0)!=1){break sa}}break C}t[(A?E:z+1|0)|0]=e}if(!(b&60)){continue}e=0;g=0;if(b&4){v[22440]=0;g=T(208,k|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break C}}if(b&8){v[22440]=0;e=T(208,k|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break C}}f=0;l=0;if(b&16){v[22440]=0;l=T(208,k|0)|0;r=v[22440];v[22440]=0;if((r|0)==1){break C}}if(b&32){v[22440]=0;f=T(208,k|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break C}}b=d+104|0;LU(b,l,f);f=b;r=Ec(b);l=d+96|0;LU(l,g,e);e=Ec(l);b=w[l|0];ua:{if((b|0)!=13){if(b){break ua}b=0;if(w[f|0]==13){break ua}}xh(f,l);xh(r,e);b=w[l|0]}io(d+88|0,i,w[f|0],w[r|0],b&255,w[e|0]);if(KU(w[d+88|0],w[d+89|0])){ac(d+80|0,yb(v[j>>2]));v[22440]=0;U(289,j|0,v[d+80>>2],d+88|0);b=v[22440];v[22440]=0;if((b|0)==1){break C}}b=w[(A?D:z+3|0)|0];if((b|0)==43){G=1;continue}if((b|0)!=31){continue}h=1;continue}break}rb(q)}m=m+1|0;sb(d+152|0);continue}break}break C}f=0;e=0;if(c&4){break aa}break H}b=P()|0;O()|0;break b}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}v[d+152>>2]=-1778364416;v[d+156>>2]=-16756736;v[22440]=0;U(269,d+296|0,d+384|0,1146310725);b=v[22440];v[22440]=0;if((b|0)==1){break E}v[22440]=0;b=T(282,d+296|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break D}if(b){v[22440]=0;i=T(278,d+296|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break D}j=a+480188|0;b=0;g=e;while(1){va:{if((b|0)==(i|0)){v[22440]=0;R(290,d+296|0,d+152|0);b=v[22440];v[22440]=0;if((b|0)!=1){break va}break D}v[22440]=0;h=T(208,d+296|0)|0;k=v[22440];v[22440]=0;wa:{xa:{if((k|0)!=1){if(x[j>>1]<=b>>>0){break wa}if(!e){break xa}k=((b<<5)+a|0)+480280|0;v[k>>2]=v[k>>2]&-67108865|((h|0)!=0)<<26;break wa}break D}if(h){break wa}g=1;t[((b<<5)+a|0)+480288|0]=1}b=b+1|0;continue}break}e=g&1}sb(d+296|0);if(!e){break $}v[22440]=0;Z(291,a+906300|0);b=v[22440];v[22440]=0;if((b|0)==1){break _}b=a+906316|0;v[b>>2]=810369604;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[d+296>>2]=0;e=a+906348|0;b=d+296|0;HU(a+906332|0,e,b);v[22440]=0;b=Q(56,b|0,9585)|0;g=v[22440];v[22440]=0;if((g|0)==1){break Z}yB(e,b);rb(b);v[22440]=0;b=Q(56,d+296|0,9549)|0;e=v[22440];v[22440]=0;if((e|0)==1){break Y}ou(a+906380|0,b);rb(b);v[22440]=0;b=a+906304|0;R(292,b|0,8);e=v[22440];v[22440]=0;if((e|0)==1){break _}GU(d+296|0,w[d+153|0],w[d+155|0],w[d+157|0],w[d+159|0]);e=v[d+300>>2];b=v[b>>2];g=v[d+296>>2];t[b|0]=g;t[b+1|0]=g>>>8;t[b+2|0]=g>>>16;t[b+3|0]=g>>>24;t[b+4|0]=e;t[b+5|0]=e>>>8;t[b+6|0]=e>>>16;t[b+7|0]=e>>>24}if(!f){break H}e=a+902204|0;b=0;while(1){if((b|0)==32){break H}v[d+176>>2]=B(b,127)>>>5;v[22440]=0;R(293,d+152|0,4096);f=v[22440];v[22440]=0;if((f|0)==1){break X}v[22440]=0;R(294,d+128|0,d+176|0);f=v[22440];v[22440]=0;if((f|0)==1){break W}v[22440]=0;U(295,d+296|0,d+152|0,d+128|0);f=v[22440];v[22440]=0;if((f|0)==1){break V}f=d+296|0;se(d+72|0,f);df(we(e,b),v[d+72>>2],v[d+76>>2]);rb(f);rb(d+128|0);f=d+152|0;Ab(f);v[22440]=0;R(293,f|0,4078);f=v[22440];v[22440]=0;if((f|0)==1){break T}v[22440]=0;R(294,d+128|0,d+176|0);f=v[22440];v[22440]=0;if((f|0)==1){break S}v[22440]=0;U(295,d+296|0,d+152|0,d+128|0);f=v[22440];v[22440]=0;if((f|0)==1){break R}f=d+296|0;se(d- -64|0,f);df(we(e,b+32|0),v[d+64>>2],v[d+68>>2]);rb(f);rb(d+128|0);f=d+152|0;Ab(f);v[22440]=0;R(293,f|0,4069);f=v[22440];v[22440]=0;if((f|0)==1){break P}v[22440]=0;R(294,d+128|0,d+176|0);f=v[22440];v[22440]=0;if((f|0)==1){break O}v[22440]=0;U(295,d+296|0,d+152|0,d+128|0);f=v[22440];v[22440]=0;if((f|0)==1){break N}f=d+296|0;se(d+56|0,f);df(we(e,b- -64|0),v[d+56>>2],v[d+60>>2]);rb(f);rb(d+128|0);f=d+152|0;Ab(f);v[22440]=0;R(293,f|0,4042);f=v[22440];v[22440]=0;if((f|0)==1){break L}v[22440]=0;R(294,d+128|0,d+176|0);f=v[22440];v[22440]=0;if((f|0)==1){break K}v[22440]=0;U(295,d+296|0,d+152|0,d+128|0);f=v[22440];v[22440]=0;if((f|0)==1){break J}f=d+296|0;se(d+48|0,f);df(we(e,b+96|0),v[d+48>>2],v[d+52>>2]);b=b+1|0;rb(f);rb(d+128|0);Ab(d+152|0);continue}}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break U}b=P()|0;O()|0;rb(d+128|0)}Ab(d+152|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break Q}b=P()|0;O()|0;rb(d+128|0)}Ab(d+152|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break M}b=P()|0;O()|0;rb(d+128|0)}Ab(d+152|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break I}b=P()|0;O()|0;rb(d+128|0)}Ab(d+152|0);break r}v[22440]=0;U(269,d+296|0,d+384|0,1397575756);b=v[22440];v[22440]=0;ya:{if((b|0)!=1){v[22440]=0;b=T(180,d+296|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){za:{if(!(c&2)|b^1){break ya}e=a+480190|0;b=1;while(1){f=b&65535;if(f>>>0>x[e>>1]){break ya}v[22440]=0;c=T(286,d+296|0)|0;g=v[22440];v[22440]=0;Aa:{if((g|0)!=1){v[22440]=0;g=T(286,d+296|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break za}if(!(c&7)){break Aa}f=(B(f,104)+a|0)+484380|0;v[f>>2]=g;c=Nc(d+152|0,c&4?32:c&2?16:8,1,1,0);v[22440]=0;Y(222,c|0,f|0,d+296|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break Aa}break za}break za}b=b+1|0;continue}}}b=P()|0;O()|0;sb(d+296|0);break r}b=P()|0;O()|0;break r}sb(d+296|0);sb(d+240|0);sb(d+320|0);sb(d+344|0)}Qd(d+384|0);sb(y)}cb=d+432|0;return s|0}b=P()|0;O()|0;break r}b=P()|0;O()|0;sb(d+296|0);break r}b=P()|0;O()|0;rb(q);break A}b=P()|0;O()|0}sb(d+152|0);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}b=P()|0;O()|0}_c(j);break u}b=P()|0;O()|0}sb(d+296|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0}sb(d+240|0);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;sb(d+296|0)}sb(d+320|0);break l}b=P()|0;O()|0;break l}b=P()|0;O()|0}sb(d+344|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;rb(d+296|0);break h}b=P()|0;O()|0}rb(d+320|0);break f}b=P()|0;O()|0}Ab(d+344|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}Qd(d+384|0)}sb(y);S(b|0);L()}function sja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=cb-240|0;cb=d;sc(b);e=cb-16|0;cb=e;g=d+216|0;$t(e+8|0,g);h=v[e+12>>2];Yb(e,b,v[e+8>>2],h);i=v[e+4>>2];if((i|0)==(h|0)){Ob(b,v[e+12>>2])}cb=e+16|0;e=(h|0)==(i|0);if(!e){KT(g)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!e){break n}if(!LT(d+216|0)){break n}if(!c){f=1;break n}ud(a,1024);eg(a);v[a+480208>>2]=v[a+480208>>2]|12;Vf(a+1074312|0,21);e=wb(w[d+232|0]|w[d+233|0]<<8);if(e){v[a+480204>>2]=B(e,1e4)}e=wb(w[d+230|0]|w[d+231|0]<<8);if(e){v[a+480196>>2]=e}if(!w[d+226|0]){mh(a,1)}e=d+216|4;qu(b,a+1298308|0,Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-14|0);b=be(d+112|0,b);v[22440]=0;R(349,d+200|0,b|0);e=v[22440];v[22440]=0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((e|0)!=1){sb(b);v[22440]=0;U(350,d+112|0,d+200|0,1395544366);b=v[22440];v[22440]=0;if((b|0)==1){break s}v[22440]=0;b=T(282,d+112|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break y}if(!b){break r}v[22440]=0;b=T(278,d+112|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break y}v[22440]=0;e=T(278,d+112|0)|0;f=v[22440];v[22440]=0;A:{if((f|0)==1){break A}v[22440]=0;Q(190,d+112|0,4)|0;f=v[22440];v[22440]=0;if((f|0)==1){break A}f=a+484360|0;h=Nb(f);v[22440]=0;ea(351,h|0,d+112|0,b|0,65535,65535)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break z}}break y}e=P()|0;O()|0;sb(b);break a}Qe(Nb(f),e);b=d+112|0;sb(b);v[22440]=0;U(350,b|0,d+200|0,1346458708);b=v[22440];v[22440]=0;if((b|0)==1){break x}v[22440]=0;e=T(282,d+112|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break w}f=0;b=0;if(!e){break t}v[22440]=0;e=T(278,d+112|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break w}u[a+480188>>1]=e;if((e-33&65535)>>>0<65504){break t}v[22440]=0;b=T(278,d+112|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break w}v[22440]=0;R(228,a+484344|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break w}b=0;v[22440]=0;o=T(286,d+112|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break w}switch(o-841887796|0){case 1:break t;case 0:case 2:break u;default:break v}}e=P()|0;O()|0;sb(d+112|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;sb(d+112|0);break b}if(o){break t}}b=1}sb(d+112|0);if(!b){break o}v[22440]=0;U(350,d+176|0,d+200|0,1398157625);b=v[22440];v[22440]=0;if((b|0)==1){break d}v[22440]=0;b=T(282,d+176|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}if(!b){break q}v[22440]=0;Q(190,d+176|0,2)|0;b=v[22440];v[22440]=0;if((b|0)==1){break c}v[22440]=0;b=T(286,d+176|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}G=a,H=Le((+(b>>>0)*2.3283064365386963e-10+ +(y[a+480204>>2]/1e4>>>0))*1e4),v[G+480204>>2]=H;b=0;v[22440]=0;Q(352,d+176|0,d+112|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}f=a+480188|0;while(1){if((b|0)!=32&x[f>>1]>b>>>0){e=(d+112|0)+(b<<1)|0;G=d,H=wb(w[e|0]|w[e+1|0]<<8),v[G+48>>2]=H;v[d+32>>2]=180;e=v[ld(d+48|0,d+32|0)>>2]-90|0;h=e>>31;G=((b<<5)+a|0)+480284|0,H=yc(lka(e<<7|45,h<<7|e>>>25,90,0),fb)+128|0,u[G>>1]=H;b=b+1|0;continue}else{B:{v[22440]=0;Q(190,d+176|0,16)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break B}break c}}break}v[22440]=0;b=Q(158,d+176|0,2)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}C:{if(b){v[22440]=0;b=T(278,d+176|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break C}u[d+48>>1]=b;u[d+32>>1]=256;G=a,H=x[Kc(d+48|0,d+32|0)>>1],v[G+480200>>2]=H}v[22440]=0;Q(190,d+176|0,128)|0;b=v[22440];v[22440]=0;if((b|0)==1){break c}v[22440]=0;b=Q(352,d+176|0,d+48|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){if(!b){break q}b=0;e=a+480188|0;while(1)if((b|0)!=32&x[e>>1]>b>>>0){f=(d+48|0)+(b<<1)|0;G=d,H=wb(w[f|0]|w[f+1|0]<<8),v[G+32>>2]=H;v[d+16>>2]=128;G=((b<<5)+a|0)+480286|0,H=v[ld(d+32|0,d+16|0)>>2]/2&255,u[G>>1]=H;b=b+1|0;continue}else{v[a+480228>>2]=v[a+480228>>2]<<1;break q}}break c}break c}e=P()|0;O()|0;break b}sb(d+112|0);break p}sb(d+176|0);v[22440]=0;U(350,d+112|0,d+200|0,1413830740);b=v[22440];v[22440]=0;D:{E:{if((b|0)!=1){v[22440]=0;b=T(282,d+112|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break e}if(!b){break D}v[22440]=0;R(353,d+112|0,d+48|0);b=v[22440];v[22440]=0;if((b|0)==1){break e}if((wb(w[d+58|0]|w[d+59|0]<<8)|0)!=65535){break E}v[22440]=0;Q(190,d+112|0,1)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break E}break e}e=P()|0;O()|0;break b}v[22440]=0;b=T(204,d+112|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break e}v[22440]=0;W(340,a+1298332|0,d+112|0,b|0,2);b=v[22440];v[22440]=0;if((b|0)==1){break e}}sb(d+112|0);v[22440]=0;U(350,d+48|0,d+200|0,1229869908);b=v[22440];v[22440]=0;if((b|0)==1){break h}v[22440]=0;b=T(282,d+48|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break l}if(b){F:{v[22440]=0;b=T(278,d+48|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break i}G:{H:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break H}v[22440]=0;e=Q(158,d+48|0,B(f,(b>>>14&2)+50|0)|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break g}if(!e){break H}u[a+480190>>1]=f;h=a+480190|0;g=d+130|0;i=(b|0)>=0;b=1;I:{J:{K:{L:{while(1){if(f>>>0<(b&65535)>>>0){v[22440]=0;b=T(278,d+48|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){break I}break g}M:{if(i){q=b}else{v[22440]=0;e=T(278,d+48|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break M}q=e+1|0}u[d+16>>1]=q;v[22440]=0;R(354,d+48|0,d+112|0);e=v[22440];v[22440]=0;if((e|0)==1){break L}e=x[d+16>>1];if((e-4e3&65535)>>>0>=61537){G=a,H=x[ie(h,d+16|0)>>1],u[G+480190>>1]=H;j=w[d+234|0]|w[d+235|0]<<8|(w[d+236|0]<<16|w[d+237|0]<<24);v[22440]=0;W(355,d+112|0,(B(e,104)+a|0)+484380|0,Wb(j)|0,o|0);e=v[22440];v[22440]=0;if((e|0)==1){break K}Bl(d+32|0,2,g);v[22440]=0;W(225,d+176|0,v[d+32>>2],v[d+36>>2],w[d+40|0]);e=v[22440];v[22440]=0;if((e|0)==1){break J}e=d+176|0;uc(((x[d+16>>1]<<5)+a|0)+946304|0,e);rb(e)}b=b+1|0;continue}break}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}if((b|0)!=4){break G}u[d+112>>1]=x[a+480190>>1];u[d+176>>1]=255;i=a+480192|0;b=d+176|0;G=i,H=x[Kc(d+112|0,b)>>1],u[G>>1]=H;v[22440]=0;U(350,b|0,d+200|0,1229278806);b=v[22440];v[22440]=0;if((b|0)==1){break j}b=d+32|0;h=b|4;j=b|3;g=b|5;l=b|7;N:{O:while(1){v[22440]=0;b=Q(158,d+48|0,15)|0;e=v[22440];v[22440]=0;if((e|0)==1){break N}if(b){v[22440]=0;R(356,d+48|0,d+32|0);b=v[22440];v[22440]=0;if((b|0)==1){break k}b=wb(w[d+32|0]|w[d+33|0]<<8);if(b>>>0>=x[i>>1]){continue}b=B(b,104)+a|0;t[b+484524|0]=w[d+40|0];e=w[l|0];t[b+484523|0]=255;t[b+484525|0]=e;b=w[d+32|0]|w[d+33|0]<<8;v[22440]=0;b=wb(b)+1&65535;e=Y(257,a|0,b|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break k}if(!e){continue}G=d,H=wb(w[g|0]|w[g+1|0]<<8),u[G+112>>1]=H;u[d+16>>1]=4095;G=e,H=x[Kc(d+112|0,d+16|0)>>1],v[G>>2]=H;b=w[j|0];if((b|0)==255){continue}v[22440]=0;b=Q(157,d+176|0,B(b,34)+2|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break k}if(!b){continue}v[22440]=0;R(357,d+176|0,d+112|0);b=v[22440];v[22440]=0;if((b|0)==1){break k}t[e+60|0]=w[e+60|0]|1;b=w[d+112|0]|w[d+113|0]<<8;v[d+20>>2]=16;v[d+24>>2]=240;G=d,H=wb(b),v[G+16>>2]=H;b=xB(d+16|0);v[22440]=0;f=e+48|0;R(298,f|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break k}b=0;while(1)if(Dd(f)>>>0<=b>>>0){if(w[h|0]!=255){t[e+60|0]=w[e+60|0]|4;b=w[h|0];t[e+63|0]=b;t[e- -64|0]=b}if(hc(v[f>>2],v[e+52>>2])){continue O}t[e+60|0]=w[e+60|0]|2;b=Dd(f)-1|0;t[e+61|0]=b;t[e+62|0]=b;continue O}else{t[d+16|0]=64;m=(d+112|0)+(b<<1)|0;t[d+8|0]=w[m+2|0];r=Tb(d+16|0,d+8|0);p=Ib(v[f>>2],b);t[p+2|0]=w[r|0];u[p>>1]=w[m+3|0];b=b+1|0;continue}}break}sb(d+176|0);break F}break k}sb(d+48|0);break p}}}sb(d+48|0);v[22440]=0;U(358,d+176|0,d+200|0,1145131092);b=v[22440];v[22440]=0;if((b|0)==1){break m}G=d,H=yb(v[d+176>>2]),v[G+8>>2]=H;i=a+484344|0;A=c&1;r=d+48|4;C=yb(v[d+180>>2]);p=(o|0)!=841887798;s=a+480188|0;D=(o|0)!=841887796;while(1){P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{h=v[d+8>>2];if(!Qb(h,C)){Ic(d+176|0);v[22440]=0;U(350,d+112|0,d+200|0,1346458702);b=v[22440];v[22440]=0;if((b|0)!=1){break aa}e=P()|0;O()|0;break b}v[22440]=0;Q(190,h|0,4)|0;b=v[22440];v[22440]=0;if((b|0)!=1){v[22440]=0;l=T(278,h|0)|0;b=v[22440];v[22440]=0;ba:{if((b|0)!=1){v[22440]=0;j=T(278,h|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break R}j=p?j:(j>>>0)/y[a+480196>>2]|0;if(!A|l>>>0>255){break P}v[22440]=0;b=Y(229,i|0,l|0,j|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break R}if(b){break ba}break P}e=P()|0;O()|0;break Q}if(!p){g=0;v[22440]=0;Q(190,h|0,4)|0;b=v[22440];v[22440]=0;if((b|0)==1){break R}while(1){z=g&65535;if(z>>>0>=x[s>>1]){break P}v[22440]=0;b=T(278,h|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break $}v[22440]=0;U(192,d+48|0,h|0,b+(b&1)&65535);b=v[22440];v[22440]=0;if((b|0)==1){break S}b=d+48|0;m=cc(d+112|0,b);sb(b);v[d+48>>2]=0;v[d+52>>2]=0;e=0;ca:{while(1){v[22440]=0;b=Q(158,d+112|0,6)|0;f=v[22440];v[22440]=0;if((f|0)==1){break ca}f=v[d+48>>2];if(b&f>>>0<j>>>0){b=Zc(Sb(i,l),f,z);v[22440]=0;R(359,d+16|0,m|0);f=v[22440];v[22440]=0;da:{ea:{if((f|0)!=1){f=d+16|0;k=Ec(f);E=Oe(f);F=Li(f);q=bc(f);n=t[f|0];if((n-1&255)>>>0>95){break ea}t[b|0]=n+13;if(!v[d+52>>2]){break da}t[b+3|0]=19;v[d+32>>2]=15;G=b,H=w[ld(r,d+32|0)|0]|208,t[G+5|0]=H;break da}break T}if((n|0)>=0){break da}if(v[d+52>>2]){t[b+3|0]=19;v[d+32>>2]=15;G=b,H=w[ld(r,d+32|0)|0]|192,t[G+5|0]=H;break da}t[b|0]=254}if(w[k|0]){t[b+2|0]=1;t[d+32|0]=64;G=b,H=w[Tb(k,d+32|0)|0],t[G+4|0]=H}k=w[E|0];if(k){t[b+1|0]=k}k=w[F|0];n=w[q|0];if(k|n){Ef(b,k,n)}k=d+32|0;b=w[f+5|0];if(b&128){v[22440]=0;f=T(208,m|0)|0;n=v[22440];v[22440]=0;if((n|0)==1){break T}b=f|b<<8&32512}e=b+e|0;lB(k,e,v[a+480196>>2]);b=v[d+36>>2];v[d+48>>2]=v[d+32>>2];v[d+52>>2]=b;continue}break}g=g+1|0;sb(d+112|0);continue}break}break T}m=0;b=Zc(Sb(i,l),0,0);fa:while(1){f=0;if((j|0)==(m|0)){break P}while(1){if(x[s>>1]<=(f&65535)>>>0){m=m+1|0;continue fa}v[22440]=0;R(360,d+48|0,h|0);e=v[22440];v[22440]=0;if((e|0)!=1){t[d+16|0]=0;ga:{if(!D){v[d+112>>2]=v[d+48>>2];e=d+112|0;g=Ec(e);l=Oe(e);k=Li(e);e=t[e|0];if((e|0)>0){t[b|0]=(B((e&240)>>>4|0,12)+(e&15)|0)+12}e=w[g|0];if(e>>>0>=4){t[b+2|0]=1;t[b+4|0]=(e>>>2|0)-1;e=w[g|0]}t[b+1|0]=e<<4&48|w[l|0]>>>4;e=w[l|0]&15;t[d+16|0]=e;g=w[k|0];t[b+5|0]=g;break ga}e=v[d+48>>2];v[d+4>>2]=e;v[d>>2]=e;e=d+32|0;_t(e,d,b);g=d+112|0;dB(g,d+16|0,b+5|0);cB(g,e);G=b,H=w[b+1|0]|w[Eb(d+48|0,0)|0]&48,t[G+1|0]=H;g=w[b+5|0];e=w[d+16|0]}Ef(b,e&255,g);e=w[b+3|0];ha:{if(e>>>0>11){break ha}e=1<<e;ia:{if(!(e&2240)){if(!(e&12)){break ha}if(!w[b+5|0]){break ia}break ha}e=w[b+5|0];g=e&240;if(g){t[b+5|0]=g;break ha}if(e){break ha}}t[b+3|0]=0}b=b+6|0;f=f+1|0;continue}break}break}e=P()|0;O()|0;break Q}e=P()|0;O()|0;break Q}v[22440]=0;b=T(282,d+112|0)|0;e=v[22440];v[22440]=0;ja:{ka:{la:{ma:{na:{if((e|0)!=1){if(b){f=Db(d+48|0);b=0;oa:{while(1){pa:{v[22440]=0;e=Q(158,d+112|0,1)|0;h=v[22440];v[22440]=0;if((h|0)==1){break pa}if(!e){break oa}if(Cf(i)>>>0<=b>>>0){break oa}v[22440]=0;U(361,d+112|0,f|0,32);e=v[22440];v[22440]=0;if((e|0)==1){break pa}e=Sb(i,b);v[22440]=0;R(288,e|0,f|0);e=v[22440];v[22440]=0;if((e|0)==1){break pa}b=b+1|0;continue}break}e=P()|0;O()|0;rb(f);break na}rb(f)}b=d+112|0;sb(b);v[22440]=0;U(350,b|0,d+200|0,1414679374);b=v[22440];v[22440]=0;if((b|0)==1){break ma}v[22440]=0;b=T(282,d+112|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break V}if(!b){break ja}f=Db(d+48|0);e=a+480188|0;b=0;while(1){v[22440]=0;h=Q(158,d+112|0,1)|0;g=v[22440];v[22440]=0;if((g|0)==1){break la}if(!h|x[e>>1]<=b>>>0){break ka}v[22440]=0;U(361,d+112|0,f|0,32);h=v[22440];v[22440]=0;if((h|0)==1){break la}Al(((b<<5)+a|0)+480289|0,f);b=b+1|0;continue}}e=P()|0;O()|0}sb(d+112|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;rb(f);break U}rb(f)}b=d+112|0;sb(b);v[22440]=0;U(358,b|0,d+200|0,1145129300);b=v[22440];v[22440]=0;if((b|0)==1){break W}G=d,H=yb(v[d+112>>2]),v[G+48>>2]=H;e=c&2;f=yb(v[d+116>>2]);h=a+480190|0;qa:{ra:{sa:{ta:{ua:{va:{while(1){b=v[d+48>>2];if(!Qb(b,f)){Ic(d+112|0);b=Db(d+48|0);if((o|0)!=841887798){break ua}v[22440]=0;c=Q(1,d+112|0,9519)|0;e=v[22440];v[22440]=0;if((e|0)==1){break va}Cb(b,c);rb(c);break ta}v[22440]=0;c=T(278,b|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break X}wa:{if(!(!e|c>>>0>=x[h>>1])){c=B(c,104)+a|0;g=x[c+484518>>1];g=Nc(d+176|0,g&1?16:8,g&64?2:1,1,0);v[22440]=0;Y(222,g|0,c+484484|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break wa}}Uf(d+48|0);continue}break}break X}e=P()|0;O()|0;break Y}v[22440]=0;U(350,d+112|0,d+200|0,1447383635);c=v[22440];v[22440]=0;xa:{ya:{za:{Aa:{Ba:{if((c|0)!=1){v[22440]=0;c=T(282,d+112|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break sa}if(!c){break ya}v[22440]=0;c=T(286,d+112|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break Ba}v[22440]=0;R(273,d+32|0,4295);e=v[22440];v[22440]=0;if((e|0)==1){break Aa}v[d+16>>2]=c>>>4;v[22440]=0;v[d+8>>2]=c&15;W(362,d+176|0,d+32|0,d+16|0,d+8|0);c=v[22440];v[22440]=0;if((c|0)==1){break za}c=d+176|0;Cb(b,c);rb(c);Ab(d+32|0);break xa}e=P()|0;O()|0;break Y}e=P()|0;O()|0;break Z}e=P()|0;O()|0;break Z}e=P()|0;O()|0;Ab(d+32|0);break Z}v[22440]=0;c=Q(1,d+176|0,8538)|0;e=v[22440];v[22440]=0;if((e|0)==1){break _}Cb(b,c);rb(c)}sb(d+112|0)}v[22440]=0;c=Q(1,d+112|0,8538)|0;e=v[22440];v[22440]=0;if((e|0)==1){break ra}Cb(a+1298344|0,c);rb(c);v[22440]=0;c=Q(1,d+112|0,10152)|0;e=v[22440];v[22440]=0;if((e|0)==1){break qa}Cb(a+1298356|0,c);rb(c);Cb(a+1298368|0,b);v[a+1298404>>2]=2;rb(b);f=1;break o}e=P()|0;O()|0;break Z}e=P()|0;O()|0;break Y}e=P()|0;O()|0;break Y}e=P()|0;O()|0;break Q}e=P()|0;O()|0}sb(d+112|0)}rb(b);break b}e=P()|0;O()|0;Ic(d+112|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}sb(d+112|0);break b}e=P()|0;O()|0;sb(d+112|0);break Q}e=P()|0;O()|0;break Q}e=P()|0;O()|0}Ic(d+176|0);break b}Uf(d+8|0);continue}}f=0}Qd(d+200|0)}cb=d+240|0;return f|0}e=P()|0;O()|0;break b}e=P()|0;O()|0;break f}e=P()|0;O()|0;sb(d+176|0);break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break b}e=P()|0;O()|0}sb(d+48|0);break b}e=P()|0;O()|0;sb(d+112|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;sb(d+176|0)}Qd(d+200|0)}S(e|0);L()}function Kea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,W=0,X=0;e=cb-400|0;cb=e;sc(b);f=cb-16|0;cb=f;g=e+192|0;WP(f+8|0,g);p=b;n=v[f+12>>2];Yb(f,b,v[f+8>>2],n);b=v[f+4>>2];if((b|0)==(n|0)){Ob(p,v[f+12>>2])}cb=f+16|0;b=(b|0)==(n|0);if(!b){VP(g)}a:{if(!b){break a}if(!XP(e+192|0)){break a}if(!c){h=1;break a}ud(a,134217728);b=e+136|0;Xf(b,3956);v[22440]=0;n=e+192|4;U(692,e+8|0,b|0,n|0);b=v[22440];v[22440]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=e+8|0;Cb(a+1298344|0,b);rb(b);Ab(e+136|0);b=jc(b,9003);Cb(a+1298356|0,b);rb(b);v[a+480188>>2]=4;v[a+1298404>>2]=2;W=a,X=wb(w[e+328|0]|w[e+329|0]<<8),v[W+480196>>2]=X;b=w[e+332|0]|w[e+333|0]<<8;v[a+480260>>2]=56;v[a+480264>>2]=13696;W=a,X=UP(wb(b)),v[W+480204>>2]=X;pq(Nb(a+484360|0),e+200|0,w[e+192|6]);E=a+480190|0;j=a+480188|0;z=Rb(e+176|0);G=Rb(e+160|0);h:{i:{j:{k:{while(1){if(wb(w[e+392|0]|w[e+393|0]<<8)>>>0<=(d&65535)>>>0){break k}v[22440]=0;g=T(278,p|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break g}u[e+112>>1]=g;if((g-4e3&65535)>>>0<=61536){break c}h=wb(w[e+394|0]|w[e+395|0]<<8);if((wb(w[n|0]|w[n+1|0]<<8)|0)==2){v[22440]=0;g=T(286,p|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break h}h=g-2|0}v[22440]=0;U(192,e+136|0,p|0,h|0);b=v[22440];v[22440]=0;if((b|0)==1){break i}b=e+136|0;g=cc(e+8|0,b);sb(b);H=x[ie(E,e+112|0)>>1];u[a+480190>>1]=H;v[22440]=0;C=B(x[e+112>>1],104)+a|0;r=C+484380|0;R(284,r|0,1);b=v[22440];v[22440]=0;l:{m:{n:{if((b|0)==1){break n}if(wb(w[n|0]|w[n+1|0]<<8)>>>0>1){break m}v[22440]=0;R(693,g|0,C+484423|0);b=v[22440];v[22440]=0;if((b|0)==1){break n}v[22440]=0;Q(190,e+8|0,1)|0;b=v[22440];v[22440]=0;if((b|0)==1){break n}v[22440]=0;U(334,g|0,((x[e+112>>1]<<5)+a|0)+946304|0,30);b=v[22440];v[22440]=0;if((b|0)!=1){break l}}h=P()|0;O()|0;break f}f=Db(e+136|0);v[22440]=0;U(361,g|0,f|0,257);b=v[22440];v[22440]=0;o:{p:{if((b|0)==1){break p}pe(C+484423|0,f);v[22440]=0;Q(190,e+8|0,1)|0;b=v[22440];v[22440]=0;if((b|0)==1){break p}v[22440]=0;U(361,g|0,f|0,31);b=v[22440];v[22440]=0;if((b|0)==1){break p}uc(((x[e+112>>1]<<5)+a|0)+946304|0,f);if(!(t[e+16|0]&1)){break o}v[22440]=0;Q(190,e+8|0,1)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break o}}h=P()|0;O()|0;rb(f);break f}rb(f)}v[22440]=0;R(694,g|0,e+136|0);b=v[22440];v[22440]=0;q:{if((b|0)==1){break q}f=cb-16|0;cb=f;g=e+136|0;b=Wb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));v[r>>2]=b;t[f+15|0]=w[g+4|0];t[f+14|0]=64;W=r,X=w[Tb(f+15|0,f+14|0)|0]<<2,u[W+30>>1]=X;l=g+6|0;i=Wb(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24));v[r+4>>2]=i;g=g+10|0;g=Wb(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24))+Wb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))|0;v[r+8>>2]=g;if(b>>>0<=i>>>0){i=b-1|0;v[r+4>>2]=i}if(b>>>0<g>>>0){v[r+8>>2]=b;g=b}r:{if(g>>>0<i>>>0){v[r+4>>2]=0;v[r+8>>2]=0;break r}if(g>>>0<=i>>>0){break r}u[r+34>>1]=x[r+34>>1]|2;W=Ib(r+68|0,0),X=i,v[W>>2]=X}cb=f+16|0;s:{h=wb(w[n|0]|w[n+1|0]<<8);if((h|0)==2){t[C+484417|0]=w[e+154|0]<<3;h=wb(w[n|0]|w[n+1|0]<<8)}if(!h){break s}v[22440]=0;R(217,G|0,H|0);b=v[22440];v[22440]=0;if((b|0)==1){break q}v[22440]=0;R(695,z|0,H|0);b=v[22440];v[22440]=0;if((b|0)==1){break q}f=rd(v[z>>2],x[e+112>>1]-1|0);Ac(f);v[22440]=0;l=T(278,p|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break j}v[22440]=0;g=Q(158,p|0,l<<3)|0;b=v[22440];v[22440]=0;if((b|0)==1){break j}if(g){v[22440]=0;R(696,f|0,l|0);b=v[22440];v[22440]=0;if((b|0)==1){break j}h=0;v[e+128>>2]=0;if(!(!(w[C+484414|0]&2)|l)){g=v[C+484384>>2];v[e+120>>2]=g;b=v[C+484388>>2];v[22440]=0;v[e+124>>2]=b-g;R(697,f|0,e+120|0);b=v[22440];v[22440]=0;if((b|0)!=1){break s}h=P()|0;O()|0;break f}while(1){if(l>>>0<=(h&65535)>>>0){break s}v[22440]=0;g=T(286,p|0)|0;b=v[22440];v[22440]=0;t:{if((b|0)==1){break t}v[22440]=0;v[e+120>>2]=g;g=T(286,p|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break t}v[22440]=0;v[e+124>>2]=g;R(697,f|0,e+120|0);b=v[22440];v[22440]=0;if((b|0)==1){break t}h=h+1|0;continue}break}h=P()|0;O()|0;break f}sb(e+8|0);break c}d=d+1|0;sb(e+8|0);continue}break}h=P()|0;O()|0;break f}J=128;u:{if(wb(w[n|0]|w[n+1|0]<<8)){break u}v[22440]=0;J=T(278,p|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break u}h=P()|0;O()|0;break e}I=w[e+192|7];u[e+118>>1]=4;v:{w:{if(wb(w[n|0]|w[n+1|0]<<8)){d=v[p+8>>2];f=0;while(1){x:{if((f&65535)>>>0>=J>>>0){break x}v[22440]=0;g=T(278,p|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break w}if((g|0)==65535){break x}v[22440]=0;I=T(278,p|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break w}v[22440]=0;g=T(278,p|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break w}u[e+118>>1]=g;if(g>>>0>127){break c}W=j,X=x[ie(j,e+118|0)>>1],u[W>>1]=X;v[22440]=0;Q(190,p|0,B(g,I)<<2)|0;b=v[22440];v[22440]=0;if((b|0)==1){break w}f=f+1|0;continue}break}v[22440]=0;Q(157,p|0,d|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break v}}b=x[j>>1];v[22440]=0;K=Q(698,e+136|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){V=a+484344|0;r=c&1;M=wb(w[e+330|0]|w[e+331|0]<<8);g=0;b=0;while(1){y:{z:{A:{B:{if((g&65535)>>>0>=J>>>0){break B}C:{if(!wb(w[n|0]|w[n+1|0]<<8)){h=x[e+118>>1];f=g;break C}v[22440]=0;f=T(278,p|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break y}if((f|0)==65535){break B}v[22440]=0;I=T(278,p|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break y}v[22440]=0;h=T(278,p|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break y}u[e+118>>1]=h}v[22440]=0;s=I&65535;l=s<<2;j=Q(158,p|0,B(l,h&65535)|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break y}if(!j){break B}if(!r){break A}v[22440]=0;C=f&65535;f=Y(229,V|0,C|0,s|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break y}if(!f){break A}F=0;D:while(1){if((s|0)==(F|0)){break z}f=0;m=Gf(Sb(V,C),F);N=0;D=0;E:{F:{G:{switch((M&3)-1|0){case 0:D=!(F&3);break F;case 1:D=!(F&1);break F;case 2:break G;default:break E}}D=(F&3)!=3}}while(1){if(x[e+118>>1]<=f>>>0){F=F+1|0;continue D}j=v[K>>2];v[22440]=0;R(360,e+120|0,p|0);d=v[22440];v[22440]=0;if((d|0)==1){break y}k=B(f,9)+j|0;l=e+120|0;j=Ec(l);d=Oe(l);o=m+B(f,6)|0;t[o+1|0]=w[l|0];j=w[j|0];t[o|0]=j;i=w[Li(l)|0];t[o+5|0]=i;q=o+5|0;if(j){t[o|0]=j+25;t[k+8|0]=0;t[k|0]=0;t[k+1|0]=0;t[k+2|0]=0;t[k+3|0]=0;t[k+4|0]=0;t[k+5|0]=0;t[k+6|0]=0;t[k+7|0]=0;i=w[q|0]}A=i&255;h=w[d|0];H:{if(h>>>0>=240){d=A|(h&15)<<8;if(d){W=q,X=rk(+(UP(d)>>>0)/1e4),t[W|0]=X;t[o+3|0]=17;break H}t[o+3|0]=0;break H}l=A>>>4|0;j=A<<4;d=l|j;I:{switch(h|0){case 0:d=m+B(f,6)|0;if(i&255){t[d+3|0]=1;break H}t[d+3|0]=0;break H;case 1:t[(m+B(f,6)|0)+3|0]=2;break H;case 2:t[(m+B(f,6)|0)+3|0]=3;break H;case 3:t[e+8|0]=15;W=k,X=w[Tb(q,e+8|0)|0]|16,t[W|0]=X;t[k+7|0]=0;t[k+1|0]=0;t[k+2|0]=0;t[(m+B(f,6)|0)+3|0]=0;break H;case 4:t[e+8|0]=15;W=k,X=w[Tb(q,e+8|0)|0]|32,t[W|0]=X;t[k+7|0]=0;t[k+1|0]=0;t[k+2|0]=0;t[(m+B(f,6)|0)+3|0]=0;break H;case 5:t[k+7|0]=0;t[k+2|0]=0;t[k+1|0]=i;t[k|0]=0;t[(m+B(f,6)|0)+3|0]=0;break H;case 6:t[k+7|0]=0;t[k+2|0]=i;t[k|0]=0;t[k+1|0]=0;t[(m+B(f,6)|0)+3|0]=0;break H;case 7:t[(m+B(f,6)|0)+3|0]=23;b=0;break H;case 8:t[(m+B(f,6)|0)+3|0]=0;b=d;break H;case 9:t[(m+B(f,6)|0)+3|0]=19;t[e+8|0]=15;W=q,X=w[Tb(q,e+8|0)|0]|16,t[W|0]=X;break H;case 10:t[(m+B(f,6)|0)+3|0]=19;t[e+8|0]=15;W=q,X=w[Tb(q,e+8|0)|0]|32,t[W|0]=X;break H;case 11:t[k+3|0]=d;t[(m+B(f,6)|0)+3|0]=0;break H;case 12:d=m+B(f,6)|0;t[d+4|0]=i;t[d+2|0]=1;t[k+3|0]=0;t[d+3|0]=0;break H;case 13:d=m+B(f,6)|0;J:{K:{if(A&240){t[(m+B(f,6)|0)+2|0]=4;h=(i&240)>>>4|0;break K}if(!(A&15)){break J}t[(m+B(f,6)|0)+2|0]=3;h=i&15}t[d+4|0]=h}t[k+3|0]=0;t[(m+B(f,6)|0)+3|0]=0;break H;case 14:t[(m+B(f,6)|0)+3|0]=19;t[q|0]=!(i&255);break H;case 15:t[(m+B(f,6)|0)+3|0]=16;t[q|0]=(i&240)>>>4;M=i&15;break H;case 16:t[k+5|0]=0;t[k+4|0]=i;t[(m+B(f,6)|0)+3|0]=0;break H;case 17:t[k+6|0]=A&15?i:0;t[(m+B(f,6)|0)+3|0]=0;break H;case 18:t[(m+B(f,6)|0)+3|0]=14;break H;case 19:t[k+8|0]=0;t[k+7|0]=i;t[k+2|0]=0;t[k|0]=0;t[k+1|0]=0;t[(m+B(f,6)|0)+3|0]=0;break H;case 20:t[(m+B(f,6)|0)+3|0]=12;break H;case 22:j=w[o+1|0];L:{if(!j){break L}d=v[z>>2];if(gd(d,v[z+4>>2])>>>0<j>>>0){break L}l=rd(d,j-1|0);j=i-1|0;t[q|0]=j;v[22440]=0;T(699,e+8|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break y}v[e+112>>2]=9;W=e,X=gd(v[l>>2],v[l+4>>2]),v[W+4>>2]=X;if(y[Bb(e+112|0,e+4|0)>>2]<=(j&255)>>>0){break L}d=m+B(f,6)|0;t[d+2|0]=15;t[d+4|0]=w[q|0]}t[(m+B(f,6)|0)+3|0]=0;break H;case 23:j=w[o+1|0];M:{if(!j){break M}d=v[z>>2];if(gd(d,v[z+4>>2])>>>0<j>>>0){break M}l=i-1|0;t[q|0]=l;d=rd(d,j-1|0);j=v[d>>2];h=gd(j,v[d+4>>2]);d=l&255;if(h>>>0<=d>>>0){break M}d=rd(j,d);i=x[d+8>>1];N:{if(i){break N}i=0;if(!Sh(a)){break N}i=x[E>>1]+1|0;u[E>>1]=i;u[d+8>>1]=i}t[o+1|0]=i}t[(m+B(f,6)|0)+3|0]=0;break H;case 24:j=w[o+1|0];O:{if(!j){break O}d=v[z>>2];if(gd(d,v[z+4>>2])>>>0<j>>>0){break O}l=rd(d,j-1|0);j=i-1|0;t[q|0]=j;v[22440]=0;T(699,e+8|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break y}v[e+112>>2]=9;W=e,X=gd(v[l>>2],v[l+4>>2]),v[W+4>>2]=X;if(y[Bb(e+112|0,e+4|0)>>2]>(j&255)>>>0){d=m+B(f,6)|0;t[d+2|0]=15;t[d+4|0]=w[q|0]}d=Xb(v[G>>2],w[o+1|0]-1|0);i=x[d>>1];P:{if(i){break P}i=0;if(!Sh(a)){break P}i=x[E>>1]+1|0;u[E>>1]=i;u[d>>1]=i}t[o+1|0]=i}t[(m+B(f,6)|0)+3|0]=0;break H;case 25:j=w[o+1|0];Q:{if(!j){break Q}d=v[z>>2];if(gd(d,v[z+4>>2])>>>0<j>>>0){break Q}l=i-1|0;t[q|0]=l;d=rd(d,j-1|0);j=v[d>>2];h=gd(j,v[d+4>>2]);d=l&255;if(h>>>0<=d>>>0){break Q}d=rd(j,d);i=x[d+10>>1];R:{if(i){break R}i=0;if(!Sh(a)){break R}i=x[E>>1]+1|0;u[E>>1]=i;u[d+10>>1]=i}t[o+1|0]=i}t[(m+B(f,6)|0)+3|0]=0;break H;case 29:t[(m+B(f,6)|0)+3|0]=11;t[q|0]=d;if(A&15){t[q|0]=j|15;break H}if((i&255)>>>0<16){break H}t[q|0]=l|240;break H;case 32:if(A&240){t[k+3|0]=l;t[(m+B(f,6)|0)+3|0]=0;break H}t[(m+B(f,6)|0)+3|0]=19;t[q|0]=i&15|192;break H;case 33:t[(m+B(f,6)|0)+3|0]=19;t[e+8|0]=15;W=q,X=w[Tb(q,e+8|0)|0]|208,t[W|0]=X;break H;case 34:t[(m+B(f,6)|0)+3|0]=19;t[e+8|0]=15;W=q,X=w[Tb(q,e+8|0)|0]|144,t[W|0]=X;break H;case 73:t[(m+B(f,6)|0)+3|0]=10;break H;case 78:if((i&112|128)==224){t[(m+B(f,6)|0)+3|0]=19;break H}t[(m+B(f,6)|0)+3|0]=0;break H;case 79:d=m+B(f,6)|0;if((i&255)>>>0<=31){t[d+3|0]=16;M=0;break H}t[d+3|0]=17;break H;default:break I}}t[(m+B(f,6)|0)+3|0]=0}A=0;i=w[k+3|0];if(!(w[o+2|0]|!i)){S:{if(i>>>0>=16){t[o+2|0]=5;i=i>>>4|0;break S}t[o+2|0]=6}t[o+4|0]=i;A=1}T:{if(w[o+3|0]){break T}h=w[k+1|0];U:{if(h){t[o+3|0]=2;break U}h=w[k+2|0];if(h){t[o+3|0]=3;break U}h=w[k|0];if(h){t[o+3|0]=19;break U}h=w[k+7|0];if(h){t[o+3|0]=4;t[k+8|0]=h;break U}h=w[k+4|0];if(h){t[o+3|0]=5;t[k+5|0]=h;break U}d=w[k+3|0];if(!(!d|A)){t[o+3|0]=11;t[q|0]=d;if(d&15){h=d|-16;break U}if(!(d&240)){break T}h=d|15;break U}h=w[k+6|0];if(h){t[o+3|0]=8;break U}if(D){t[o+3|0]=20;D=0;h=97;break U}D=0;if(N){break T}d=b&255;if(!d){break T}t[o+3|0]=24;t[q|0]=b;if(b&15){h=b|-16}else{if(!(d&240)){N=1;break T}h=b|15}N=1}t[q|0]=h}f=f+1|0;continue}}}v[a+480228>>2]=256/x[a+480188>>1];mh(a,1);if(wb(w[n|0]|w[n+1|0]<<8)){V:{while(1){v[22440]=0;g=Q(158,p|0,2)|0;b=v[22440];v[22440]=0;if((b|0)==1){break y}if(!g){break V}v[22440]=0;g=T(278,p|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break y}if((g|0)==65535){break V}v[22440]=0;Q(190,p|0,2)|0;b=v[22440];v[22440]=0;if((b|0)==1){break y}v[22440]=0;g=T(286,p|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){v[22440]=0;Q(190,p|0,g|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){continue}}break}break y}v[22440]=0;Q(190,p|0,34)|0;b=v[22440];v[22440]=0;if((b|0)==1){break y}}W:{if(!(c&2)){break W}A=1;while(1){c=A&65535;if(c>>>0>H>>>0){break W}X:{s=(B(c,104)+a|0)+484380|0;if(!v[s>>2]){break X}b=Nc(e+8|0,8,1,0,0);v[22440]=0;Y(222,b|0,s|0,p|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break y}b=v[z>>2];if(gd(b,v[z+4>>2])>>>0<c>>>0){break X}C=c-1|0;r=rd(b,C);c=0;g=0;l=cb-112|0;cb=l;Y:{if(!Sd(s)){break Y}if(gd(v[r>>2],v[r+4>>2])>>>0<2){break Y}h=Sn(l+8|0,s);v[h+20>>2]=0;v[h>>2]=0;f=v[r>>2];b=gd(f,v[r+4>>2]);j=v[s>>2];Z:{while(1){if((b|0)==(c|0)){break Z}_:{n=rd(f,c);d=v[n>>2];if(d>>>0>=j>>>0){break _}n=v[n+4>>2];if(n>>>0>j-d>>>0|268435456-n>>>0<g>>>0){break _}g=g+n|0;v[h>>2]=g;c=c+1|0;continue}break}b=c}if(!Lg(h)){break Y}d=h+68|0;g=0;c=0;while(1){if((b|0)==(c|0)){pm(s);b=Sn(s,h);v[b+4>>2]=0;v[b+8>>2]=v[s>>2];u[b+34>>1]=x[b+34>>1]|2;break Y}f=v[h+20>>2]+g|0;D=v[s+20>>2];n=rd(v[r>>2],c);ic(f,D+v[n>>2]|0,v[n+4>>2]);v[n>>2]=g;if(c-10>>>0>=4294967287){W=Ib(d,c-1|0),X=g,v[W>>2]=X}c=c+1|0;g=v[n+4>>2]+g|0;continue}}cb=l+112|0;b=x[Xb(v[G>>2],C)>>1];if(b){Ez(s,(B(b,104)+a|0)+484380|0,0,v[s>>2],0)}b=rd(v[z>>2],C);W=e,X=yb(v[b>>2]),v[W+8>>2]=X;c=yb(v[b+4>>2]);while(1){g=v[e+8>>2];if(!Qb(g,c)){break X}b=x[g+8>>1];if(b){Ez(s,(B(b,104)+a|0)+484380|0,v[g>>2],v[g+4>>2],1)}b=x[g+10>>1];if(b){Ez(s,(B(b,104)+a|0)+484380|0,v[g>>2],v[g+4>>2],0)}Vn(e+8|0);continue}}A=A+1|0;continue}}Tp(K);h=1;break b}v[22440]=0;Q(190,p|0,B(l,x[e+118>>1])|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){break z}break y}g=g+1|0;continue}break}h=P()|0;O()|0;Tp(K);break e}h=P()|0;O()|0;break e}h=P()|0;O()|0;break e}h=P()|0;O()|0;break e}h=P()|0;O()|0;break f}h=P()|0;O()|0;break e}h=P()|0;O()|0;break e}h=P()|0;O()|0;Ab(e+136|0);break d}h=P()|0;O()|0;break e}sb(e+8|0)}_c(G);QP(z)}S(h|0);L()}h=0}_c(G);QP(z)}cb=e+400|0;return h|0}function Wea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=cb-272|0;cb=e;sc(b);a:{b:{c:{if(!xt(b,e+176|0)){break c}if(!qQ(e+176|0)){break c}if(!Kb(b,wc(pQ(e+176|0),fb))){break c}if(!c){h=1;break c}ud(a,2);v[a+480260>>2]=64;v[a+480264>>2]=32767;k=Db(e+160|0);d:{e:{f=w[e+216|0]|w[e+217|0]<<8;if((f|0)==20479){l=w[e+230|0]|w[e+231|0]<<8;break e}l=f-16464|0;f:{g:{h:{i:{j:{switch(f>>>12|0){case 0:if((f|0)!=520){break f}v[22440]=0;f=Q(1,e+32|0,12345)|0;g=v[22440];v[22440]=0;if((g|0)!=1){Cb(k,f);rb(f);break f}d=P()|0;O()|0;break a;case 1:k:{if((f|0)!=4896){break k}if(!(w[e+208|0]&15|(w[e+238|0]|w[e+239|0]<<8)|(w[e+228|0]|(w[e+214|0]|w[e+215|0]<<8)&65455))){l:{if(t[e+227|0]<0){v[a+1074308>>2]=18219008;v[22440]=0;d=Q(1,e+32|0,14858)|0;f=v[22440];v[22440]=0;if((f|0)!=1){break l}d=P()|0;O()|0;break a}v[a+1074308>>2]=16777216;v[22440]=0;d=Q(1,e+32|0,13395)|0;f=v[22440];v[22440]=0;if((f|0)==1){break i}}Cb(k,d);rb(d);v[22440]=0;d=1;Y(271,a+1074312|0,81,1)|0;f=v[22440];v[22440]=0;h=1;if((f|0)!=1){break d}break b}if(w[e+228|0]|(w[e+238|0]|w[e+239|0]<<8)|(w[e+229|0]|(w[e+214|0]|w[e+215|0]<<8))){break k}v[22440]=0;f=Q(1,e+32|0,9505)|0;g=v[22440];v[22440]=0;if((g|0)!=1){Cb(k,f);rb(f);break f}d=P()|0;O()|0;break a}v[22440]=0;d=Q(1,e+32|0,8523)|0;f=v[22440];v[22440]=0;g=1;if((f|0)!=1){Cb(k,d);rb(d);break g}d=P()|0;O()|0;break a;case 2:v[22440]=0;d=Q(1,e+32|0,6776)|0;f=v[22440];v[22440]=0;h=1;if((f|0)!=1){Cb(k,d);rb(d);break g}d=P()|0;O()|0;break a;case 3:m:{n:{o:{p:{if(f>>>0<=12820){v[22440]=0;d=Q(1,e+32|0,8586)|0;g=v[22440];v[22440]=0;if((g|0)!=1){Cb(k,d);rb(d);break p}d=P()|0;O()|0;break a}v[22440]=0;R(443,e+144|0,4018);d=v[22440];v[22440]=0;if((d|0)==1){break o}d=w[e+216|0]|w[e+217|0]<<8;v[22440]=0;v[e+128>>2]=d-12820;U(444,e+32|0,e+144|0,e+128|0);d=v[22440];v[22440]=0;if((d|0)==1){break n}d=e+32|0;Cb(k,d);rb(d);Ab(e+144|0)}d=w[e+216|0]|w[e+217|0]<<8;if(d>>>0<12807){break h}g=w[e+232|0]|w[e+233|0]<<8|(w[e+234|0]<<16|w[e+235|0]<<24);if(g){break m}break h}d=P()|0;O()|0;break a}d=P()|0;O()|0;Ab(e+144|0);break a}d=NC(d,g);g=eo(e+32|0);v[g+44>>2]=d;v[22440]=0;R(446,a+1298408|0,g|0);d=v[22440];v[22440]=0;if((d|0)!=1){break h}d=P()|0;O()|0;break a;case 4:if((f|0)!=16640){break e}v[22440]=0;f=Q(1,e+32|0,8369)|0;g=v[22440];v[22440]=0;h=1;if((g|0)!=1){Cb(k,f);rb(f);v[22440]=0;Y(271,a+1074312|0,81,1)|0;f=v[22440];v[22440]=0;g=0;if((f|0)==1){break b}break d}d=P()|0;O()|0;break a;case 5:f=f&4095;d=f<<16;if(f>>>0>=297){d=d|(w[e+230|0]|w[e+231|0]<<8)}v[a+1074308>>2]=d;v[22440]=0;f=Q(1,e+144|0,17645)|0;d=v[22440];v[22440]=0;q:{r:{s:{if((d|0)!=1){d=v[a+1074308>>2];v[22440]=0;R(142,e+128|0,d|0);d=v[22440];v[22440]=0;if((d|0)==1){break s}d=0;v[22440]=0;U(2,e+32|0,f|0,e+128|0);g=v[22440];v[22440]=0;if((g|0)==1){break r}g=e+32|0;Cb(k,g);rb(g);rb(e+128|0);rb(f);break f}d=P()|0;O()|0;break a}d=P()|0;O()|0;break q}d=P()|0;O()|0;rb(e+128|0)}rb(f);break a;case 6:v[22440]=0;f=Q(1,e+32|0,8369)|0;g=v[22440];v[22440]=0;if((g|0)!=1){Cb(k,f);rb(f);v[22440]=0;Y(271,a+1074312|0,81,1)|0;f=v[22440];v[22440]=0;g=0;if((f|0)==1){break b}break d}d=P()|0;O()|0;break a;case 7:v[22440]=0;f=Q(1,e+32|0,8381)|0;g=v[22440];v[22440]=0;if((g|0)!=1){Cb(k,f);rb(f);break f}d=P()|0;O()|0;break a;default:break j}}if((f|0)!=51712){break f}v[22440]=0;f=Q(1,e+32|0,9304)|0;g=v[22440];v[22440]=0;if((g|0)!=1){Cb(k,f);rb(f);break f}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}v[22440]=0;d=Y(271,a+1074312|0,7,1)|0;g=v[22440];v[22440]=0;if((g|0)==1){break b}v[22440]=0;d=Y(271,d|0,23,1)|0;g=v[22440];v[22440]=0;if((g|0)==1){break b}v[22440]=0;d=Y(271,d|0,38,1)|0;g=v[22440];v[22440]=0;if((g|0)==1){break b}v[22440]=0;Y(271,d|0,107,1)|0;d=v[22440];v[22440]=0;if((d|0)==1){break b}h=1;v[a+480260>>2]=1;g=0;if(f>>>0<=12820){break g}d=0;break d}v[22440]=0;Z(684,e+144|0);d=v[22440];v[22440]=0;t:{u:{v:{if((d|0)!=1){d=w[e+216|0]|w[e+217|0]<<8;v[e+16>>2]=d>>>8&15;v[22440]=0;v[e>>2]=d&255;R(445,e+128|0,e|0);d=v[22440];v[22440]=0;if((d|0)==1){break v}d=0;v[22440]=0;ga(685,e+32|0,e+144|0,k|0,e+16|0,e+128|0);f=v[22440];v[22440]=0;if((f|0)==1){break u}f=e+32|0;Cb(k,f);rb(f);rb(e+128|0);Ab(e+144|0);break d}d=P()|0;O()|0;break a}d=P()|0;O()|0;break t}d=P()|0;O()|0;rb(e+128|0)}Ab(e+144|0);break a}g=0;break d}d=w[e+230|0]|w[e+231|0]<<8;v[22440]=0;U(448,e+32|0,f|0,d|0);d=v[22440];v[22440]=0;w:{x:{if((d|0)!=1){d=e+32|0;Cb(k,d);rb(d);v[a+480260>>2]=1;if((l|0)<4201){break x}v[22440]=0;Y(271,a+1074312|0,7,1)|0;d=v[22440];v[22440]=0;if((d|0)==1){break b}break w}d=P()|0;O()|0;break a}if((l|0)>=2386){break w}h=1;d=0;j=1;break d}d=0;v[22440]=0;h=1;Y(271,a+1074312|0,38,1)|0;f=v[22440];v[22440]=0;j=1;if((f|0)==1){break b}}v[22440]=0;f=Q(1,e+32|0,15126)|0;i=v[22440];v[22440]=0;y:{z:{A:{B:{C:{D:{E:{F:{if((i|0)!=1){Cb(a+1298344|0,f);rb(f);v[22440]=0;f=Q(1,e+32|0,10493)|0;i=v[22440];v[22440]=0;if((i|0)==1){break F}Cb(a+1298356|0,f);rb(f);o=Cb(a+1298368|0,k);v[a+1298404>>2]=v[a+1074308>>2]?8:5;if(h){v[22440]=0;f=Q(272,a+1074312|0,77)|0;i=v[22440];v[22440]=0;if((i|0)==1){break b}v[22440]=0;f=Q(272,f|0,78)|0;i=v[22440];v[22440]=0;if((i|0)==1){break b}v[22440]=0;f=Q(272,f|0,79)|0;i=v[22440];v[22440]=0;if((i|0)==1){break b}v[22440]=0;f=Q(272,f|0,80)|0;i=v[22440];v[22440]=0;if((i|0)==1){break b}v[22440]=0;f=Q(272,f|0,82)|0;i=v[22440];v[22440]=0;if((i|0)==1){break b}v[22440]=0;f=Q(272,f|0,96)|0;i=v[22440];v[22440]=0;if((i|0)==1){break b}v[22440]=0;Q(272,f|0,113)|0;f=v[22440];v[22440]=0;if((f|0)==1){break b}}f=w[e+216|0]|w[e+217|0]<<8;i=f&61440;if(i>>>0>=4097){d=(i|0)!=12288|f>>>0>12819|d}v[22440]=0;f=a+901404|0;Z(686,f|0);i=v[22440];v[22440]=0;if((i|0)==1){break b}if(!d){_p(f)}Gi(e+144|0,1,e+176|0);v[22440]=0;W(225,e+32|0,v[e+144>>2],v[e+148>>2],w[e+152|0]);d=v[22440];v[22440]=0;if((d|0)==1){break C}d=e+32|0;tc(a+1298308|0,d);rb(d);d=w[e+214|0]|w[e+215|0]<<8;if(d&16){v[a+480208>>2]=v[a+480208>>2]|65536;d=w[e+214|0]|w[e+215|0]<<8}if(d&1){v[a+480208>>2]=v[a+480208>>2]|131072}if(!(w[e+214|0]&64?0:(w[e+216|0]|w[e+217|0]<<8)!=4864)){v[a+480208>>2]=v[a+480208>>2]|2}d=w[e+225|0];v[a+480196>>2]=d;G:{H:{if(d){if((d|0)!=255){break H}f=0;if(!g){break G}}v[a+480196>>2]=6}f=g}i=f;v[a+480204>>2]=B(w[e+226|0],1e4);if(w[e+226|0]<=32){v[a+480204>>2]=i?125e4:32e4}t[e+32|0]=w[e+224|0];t[e+144|0]=64;d=w[Tb(e+32|0,e+144|0)|0];v[a+480200>>2]=d<<2;if(!((w[e+216|0]|w[e+217|0]<<8)>>>0>4895|d)){v[a+480200>>2]=256}if((w[e+218|0]|w[e+219|0]<<8)!=1){break E}h=e+227|0;d=w[h|0];if(d>>>0>7){break E}v[e+32>>2]=(d<<4)+16;v[e+144>>2]=127;f=v[ld(e+32|0,e+144|0)>>2];break D}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}h=e+227|0;d=w[h|0];f=32;if((d|16)==18){break D}d=d&127;f=48;if(!d){break D}v[e+32>>2]=d;v[e+144>>2]=16;f=v[Ke(e+32|0,e+144|0)>>2]}v[a+480228>>2]=f;d=0;g=1;I:{if(t[h|0]<0){break I}g=1;if(v[a+1074308>>2]){break I}H=a,I=wc(nka(f<<3|5,f>>>29|0,11,0),fb),v[H+480228>>2]=I;g=0}p=a+480188|0;u[p>>1]=4;v[a+480232>>2]=j?(l|0)<3299?64:36:36;h=Rp(e+120|0);while(1){if((d|0)==32){d=a+480188|0;if(!x[d>>1]){u[d>>1]=1}d=Nb(a+484360|0);f=w[e+208|0]|w[e+209|0]<<8;v[22440]=0;ea(351,d|0,b|0,f|0,255,254)|0;d=v[22440];v[22440]=0;if((d|0)!=1){p=Rb(e+144|0);d=w[e+210|0]|w[e+211|0]<<8;v[22440]=0;Y(220,b|0,p|0,d|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){q=Rb(e+128|0);d=w[e+212|0]|w[e+213|0]<<8;v[22440]=0;Y(220,b|0,q|0,d|0)|0;d=v[22440];v[22440]=0;J:{if((d|0)!=1){if(w[e+229|0]!=252){break B}d=0;v[22440]=0;R(687,b|0,e+32|0);f=v[22440];v[22440]=0;if((f|0)==1){break J}while(1){if((d|0)==32){break B}g=(e+32|0)+d|0;f=w[g|0];K:{if(!(f&32)){break K}j=((d<<5)+a|0)+480284|0;if(i){Cc(e+16|0,h,d);if(tb(v[v[e+16>>2]>>2],v[e+20>>2])){break K}f=w[g|0]}u[j>>1]=(((f&15)<<8|8)>>>0)/15}d=d+1|0;continue}}break A}break A}d=P()|0;O()|0;break z}d=P()|0;O()|0;break a}f=(d<<5)+a|0;l=f+480280|0;$e(l);q=e+d|0;j=w[q+240|0];m=j&127;L:{if((j|0)!=255){u[p>>1]=d+1;if(g){u[f+480284>>1]=j&8?204:51}if(t[q+240|0]>=0){break L}}v[l>>2]=1024}if((m-16&255)>>>0<=13){u[f+480284>>1]=128;f=e+32|0;Cc(f,h,d);rm(f)}d=d+1|0;continue}}d=P()|0;O()|0;break a}u[e+32>>1]=w[e+210|0]|w[e+211|0]<<8;u[e+16>>1]=3999;h=x[Kc(e+32|0,e+16|0)>>1];u[a+480190>>1]=h;f=c&2;l=e+80|0;d=0;j=0;g=0;M:{N:{O:{while(1){if((h&65535)>>>0<=d>>>0){if(!i){break N}if(!(!j|g&65535)&(w[e+216|0]|w[e+217|0]<<8)!=4864){break O}v[22440]=0;d=g&65535;f=Y(271,a+1074312|0,79,d>>>0>1|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break A}v[22440]=0;d=d>>>0<2;f=Y(271,f|0,107,d|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break A}v[22440]=0;Y(271,f|0,38,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break A}v[22440]=0;d=g&65535;Q(135,o|0,(d>>>0>1?17206:17213)|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break A}if(d>>>0<2){break N}v[a+480228>>2]=48;break N}h=Xb(v[p>>2],d);h=w[h|0]|w[h+1|0]<<8;v[22440]=0;h=Q(157,b|0,h<<4)|0;m=v[22440];v[22440]=0;if((m|0)==1){break M}P:{Q:{if(!h){break Q}v[22440]=0;h=Q(688,b|0,e+32|0)|0;m=v[22440];v[22440]=0;if((m|0)==1){break M}if(!h){break Q}v[22440]=0;h=d+1|0;m=(B(h,104)+a|0)+484380|0;U(689,e+32|0,m|0,i|0);n=v[22440];v[22440]=0;if((n|0)==1){break M}Gi(e,1,l);v[22440]=0;W(225,e+16|0,v[e>>2],v[e+4>>2],w[e+8|0]);n=v[22440];v[22440]=0;if((n|0)==1){break P}n=((h<<5)+a|0)+946304|0;h=e+16|0;uc(n,h);rb(h);if(w[e+32|0]>1){break Q}h=nQ(e+32|0);R:{if(!f|!(w[e+48|0]|w[e+49|0]<<8|(w[e+50|0]<<16|w[e+51|0]<<24))){break R}v[22440]=0;h=Q(157,b|0,h|0)|0;n=v[22440];v[22440]=0;if((n|0)==1){break A}if(!h){break R}h=e+16|0;mQ(h,e+32|0,(w[e+218|0]|w[e+219|0]<<8)==1);v[22440]=0;Y(222,h|0,m|0,b|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break A}j=1}g=w[e+72|0]|w[e+73|0]<<8|g}d=d+1|0;h=x[a+480190>>1];continue}break}break A}v[22440]=0;d=Q(1,e+32|0,9769)|0;f=v[22440];v[22440]=0;if((f|0)==1){break A}Cb(o,d);rb(d)}h=1;if(!(c&1)){break y}c=w[e+216|0]|w[e+217|0]<<8;u[e+32>>1]=w[e+212|0]|w[e+213|0]<<8;u[e+16>>1]=255;s=x[Kc(e+32|0,e+16|0)>>1];v[22440]=0;j=a+484344|0;R(228,j|0,s|0);d=v[22440];v[22440]=0;if((d|0)==1){break M}y=c>>>0<4896;c=e+32|0;n=c|5;C=c|3;z=c|4;D=c|2;E=c|1;F=a+480188|0;g=0;o=0;m=0;while(1){if((g|0)==(s|0)){if(!y){break y}a=x[a+480188>>1];if((a|0)>(m+o|0)|(a|0)<=(o-m|0)){break y}d=Cf(j)-1&65535;c=0;S:{if(Cf(j)>>>0<=d>>>0){break S}while(1){b=c&65535;if(b>>>0>d>>>0){break S}a=fg(v[j>>2],b);if(Vh(a)){a=Pg(a);f=Og(fg(v[j>>2],b));b=cb-16|0;cb=b;v[b+8>>2]=a;while(1){if(Qb(a,f)){if(w[a+3|0]==31){t[a+3|0]=20;t[a+5|0]=w[a+5|0]|128}Ki(b+8|0);a=v[b+8>>2];continue}break}cb=b+16|0}c=c+1|0;continue}}break y}v[22440]=0;c=Y(229,j|0,g&65535,64)|0;d=v[22440];v[22440]=0;if((d|0)==1){break M}T:{if(!c){break T}c=Xb(v[q>>2],g);c=w[c|0]|w[c+1|0]<<8;if(!c){break T}v[22440]=0;c=Q(157,b|0,c<<4)|0;d=v[22440];v[22440]=0;if((d|0)==1){break M}if(!c){break T}v[22440]=0;Q(190,b|0,2)|0;c=v[22440];v[22440]=0;if((c|0)==1){break M}d=0;A=Gf(Sb(j,g),0);while(1){if(d>>>0>63){break T}f=d;v[22440]=0;l=T(208,b|0)|0;c=v[22440];v[22440]=0;U:{if((c|0)!=1){if(l){break U}d=64;if(f>>>0>62){continue}d=f+1|0;A=Gf(Sb(j,g),d);continue}break A}G=tg(e+32|0);c=l&31;d=c>>>0<x[F>>1];i=B(c,6)+A|0;if(l&32){v[22440]=0;R(267,e+16|0,b|0);c=v[22440];v[22440]=0;V:{W:{X:{if((c|0)!=1){r=Ec(e+16|0);c=w[e+16|0];if(c>>>0>239){break X}c=lQ((B(c>>>4|0,12)+(c&15)|0)+13|0);break W}break A}Y:{switch(c-254|0){case 0:break W;case 1:break Y;default:break V}}c=0}t[(d?i:e+32|0)|0]=c}t[(d?i+1|0:E)|0]=w[r|0]}Z:{if(!(l&64)){break Z}v[22440]=0;r=T(208,b|0)|0;c=v[22440];v[22440]=0;_:{if((c|0)!=1){c=d?i+2|0:D;r=r<<24>>24;t[e+16|0]=r;if((r|0)>-64){break _}t[c|0]=2;t[(d?i+4|0:z)|0]=w[e+16|0]^128;break Z}break A}t[c|0]=1;t[e|0]=64;H=d?i+4|0:z,I=w[Tb(e+16|0,e)|0],t[H|0]=I}$:{if(!(l&128)){break $}v[22440]=0;R(267,e+16|0,b|0);c=v[22440];v[22440]=0;aa:{ba:{if((c|0)!=1){c=e+16|0;EA(d?i:G,w[c|0],w[Ec(c)|0],0);l=d?i+3|0:C;c=w[l|0];if((c|0)==10){break aa}if((c|0)==31){break ba}if((c|0)!=20){break $}c=d?i+5|0:n;d=w[c|0];if((d&240)!=160|(w[e+216|0]|w[e+217|0]<<8)>>>0>4895){break $}t[c|0]=d&15^136;break $}break A}c=w[(d?i+5|0:n)|0];if(c>>>0>15){y=0;break $}if(c>>>0<=7){m=m+1|0;break $}o=((c|0)!=8)+o|0;break $}if(w[(d?i+5|0:n)|0]|(w[e+216|0]|w[e+217|0]<<8)>>>0>4865){break $}t[l|0]=37}d=f;continue}}g=g+1|0;continue}}}d=P()|0;O()|0;_c(q)}_c(p);break a}_c(q);_c(p);rb(k)}cb=e+272|0;return h|0}d=P()|0;O()|0}rb(k);S(d|0);L()}function Qda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=cb-512|0;cb=d;sc(b);a:{if(!FA(b,d+432|0)){break a}if(!$O(d+432|0)){break a}if(!Kb(b,wc(ZO(d+432|0),fb))){break a}b:{if(!c){break b}ud(a,4);eg(a);t[a+1074368|0]=4;j=Db(d+416|0);c:{d:{e:{f:{k=d+470|0;g:{if(!(Mb(k,17828,20)|(w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24))!=276)){if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break g}e=HA(d+449|0,0,20)?1154:34;break e}if(!Mb(k,17807,20)){e=1;break e}Bj(d+16|0,3,k);v[22440]=0;W(225,d+56|0,v[d+16>>2],v[d+20>>2],w[d+24|0]);h=v[22440];v[22440]=0;h:{i:{if((h|0)!=1){v[22440]=0;U(11,d+128|0,5,d+56|0);h=v[22440];v[22440]=0;if((h|0)==1){break i}h=d+128|0;Cb(j,h);rb(h);rb(d+56|0);if(Mb(k,17645,8)){break h}e=1048;break e}f=P()|0;O()|0;break c}f=P()|0;O()|0;rb(d+56|0);break c}if(!Mb(k,17545,12)){e=16;if(!Mb(d+482|0,17849,8)){break e}t[a+1074368|0]=5;break e}if(Mb(k,11693,20)){break f}}e=48;break e}if(!Mb(k,27200,15)){v[22440]=0;h=Q(272,a+1074312|0,54)|0;e=v[22440];v[22440]=0;D=1;if((e|0)==1){break d}v[22440]=0;Q(272,h|0,51)|0;h=v[22440];v[22440]=0;e=16;if((h|0)==1){break d}break e}j:{if(Mb(k,27216,14)){if(Mb(k,27231,14)){break j}}v[22440]=0;h=Q(272,a+1074312|0,57)|0;e=v[22440];v[22440]=0;if((e|0)==1){break d}v[22440]=0;Q(272,h|0,51)|0;h=v[22440];v[22440]=0;e=16;if((h|0)!=1){break e}break d}e=Mb(k,17633,11)?16:256}z=d+449|0;Bj(d+56|0,3,z);v[22440]=0;W(225,d+128|0,v[d+56>>2],v[d+60>>2],w[d+64|0]);h=v[22440];v[22440]=0;k:{l:{m:{n:{o:{p:{q:{if((h|0)!=1){h=d+128|0;tc(a+1298308|0,h);rb(h);v[a+480260>>2]=1;v[a+480264>>2]=31999;q=a+484360|0;Qe(Nb(q),w[d+498|0]|w[d+499|0]<<8);u[a+480188>>1]=w[d+500|0]|w[d+501|0]<<8;u[d+128>>1]=w[d+504|0]|w[d+505|0]<<8;u[d+56>>1]=255;G=a+480192|0,H=x[Kc(h,d+56|0)>>1],u[G>>1]=H;h=w[d+508|0]|w[d+509|0]<<8;if(h){v[a+480196>>2]=h}h=w[d+510|0]|w[d+511|0]<<8;if(h){h=B(h,1e4);h=h>>>0<1e7?h:1e7;v[a+480204>>2]=h>>>0>32e4?h:32e4}v[a+480208>>2]=0;h=(w[d+506|0]|w[d+507|0]<<8)<<4&16;v[a+480208>>2]=h;f=w[d+506|0]|w[d+507|0]<<8;v[a+480208>>2]=h|f<<3&32768;h=Nb(q);m=w[d+496|0]|w[d+497|0]<<8;v[22440]=0;ea(351,h|0,b|0,m|0,65535,65535)|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}f=f>>>12&1?(e|0)==34?146:e:e;if(!(f&1024|(w[d+496|0]|w[d+497|0]<<8))){h=Nb(q);v[22440]=0;U(753,h|0,1,0);h=v[22440];v[22440]=0;if((h|0)==1){break d}}h=w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24);v[22440]=0;Q(157,b|0,h+60|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if((w[d+490|0]|w[d+491|0]<<8)>>>0>=260){v[22440]=0;U(754,b|0,d+432|0,a|0);h=v[22440];v[22440]=0;if((h|0)==1){break d}}t[d+415|0]=0;A=c&2;E=d+74|0;n=d+161|0;m=Rb(d+400|0);F=a+480192|0;h=-1;o=1;while(1){e=o&65535;if(e>>>0>x[F>>1]){if(!(!(f&2)|r&255)){f=HA(z,0,20)?f|16:f}if((w[d+490|0]|w[d+491|0]<<8)>>>0>259){break o}if(c&3){v[22440]=0;U(754,b|0,d+432|0,a|0);c=v[22440];v[22440]=0;if((c|0)==1){break n}}if(!A){break o}n=a+480190|0;e=1;while(1){c=e&65535;if(c>>>0>x[n>>1]){break o}g=v[m>>2];v[22440]=0;Y(222,Ib(g,c-1|0)|0,(B(c,104)+a|0)+484380|0,b|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){e=e+1|0;continue}break}f=P()|0;O()|0;break k}v[22440]=0;g=T(159,b|0)|0;l=v[22440];v[22440]=0;r:{s:{if((l|0)!=1){xg(b,4);v[22440]=0;U(755,b|0,d+128|0,(g?g:263)|0);g=v[22440];v[22440]=0;if((g|0)==1){break p}t:{if((f|0)==1){g=w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24);if((g|0)!=263){f=16;if((g|0)!=245){break t}v[a+1074308>>2]=16777381;v[22440]=0;f=Q(1,d+56|0,13395)|0;g=v[22440];v[22440]=0;if((g|0)!=1){Cb(j,f);rb(f);f=17;break t}f=P()|0;O()|0;break k}v[a+1074308>>2]=16777395;v[22440]=0;f=Q(1,d+56|0,13310)|0;g=v[22440];v[22440]=0;if((g|0)!=1){Cb(j,f);rb(f);f=17;break t}f=P()|0;O()|0;break k}if(w[d+155|0]|w[d+156|0]<<8){break t}g=w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24);if(!(!(f&2)|(w[d+157|0]|w[d+158|0]<<8|(w[d+159|0]<<16|w[d+160|0]<<24))|(g|0)!=263)){f=f|16;break t}if(!(!(f&256)|(g|0)==29)){f=f&-257;break t}if(!(f&160)){break t}f=(g|0)==33?f:0}v[22440]=0;g=Y(257,a|0,e|0,0)|0;l=v[22440];v[22440]=0;if((l|0)==1){break p}if(!g){break r}g=((e<<2)+a|0)+900380|0;e=v[g>>2];v[22440]=0;R(756,d+128|0,e|0);e=v[22440];v[22440]=0;if((e|0)==1){break p}e=w[d+154|0];u:{if((h|0)==-1){h=e;break u}if(!(f&32)|(e|0)==(h|0)){break u}f=f&-161|128}e=w[d+155|0]|w[d+156|0]<<8;if(!e){break r}l=w[d+369|0];i=w[d+370|0];p=w[d+371|0]|w[d+372|0]<<8;s=w[d+375|0];v[22440]=0;U(757,d+112|0,a|0,e|0);e=v[22440];v[22440]=0;if((e|0)==1){break q}f=s|(p|(i|l))?f&-4:f;g=v[g>>2]+236|0;e=12;l=v[d+112>>2];i=Fc(l,v[d+116>>2]);v:{while(1){w:{if((e|0)==108){if((w[d+490|0]|w[d+491|0]<<8)>>>0>259){Ac(m)}g=w[d+155|0]|w[d+156|0]<<8;e=0;v[22440]=0;l=Q(758,d+96|0,g|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){break w}f=P()|0;O()|0;break v}p=Xb(g,e);if(i>>>0>x[p>>1]){G=p,H=x[Xb(l,x[Xb(g,e)>>1])>>1],u[G>>1]=H}e=e+1|0;continue}break}x:{y:{z:{A:{while(1){g=w[d+155|0]|w[d+156|0]<<8;if(g>>>0<=e>>>0){e=0;if((w[d+490|0]|w[d+491|0]<<8)>>>0<=259){break s}B:{while(1){if(e>>>0>=g>>>0){break s}i=w[Ib(v[m>>2],e)+3|0];g=v[Ib(v[d+96>>2],e)>>2];v[22440]=0;U(192,d+16|0,b|0,((i|0)==10?(g+1>>>1|0)+16|0:g)|0);g=v[22440];v[22440]=0;if((g|0)!=1){g=d+16|0;i=cc(d+56|0,g);sb(g);g=v[d+112>>2];if(!(!A|Fc(g,v[d+116>>2])>>>0<=e>>>0)){p=x[Xb(g,e)>>1];g=Ib(v[m>>2],e);g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);v[22440]=0;v[d+12>>2]=g;v[d+8>>2]=g;g=da(759,(B(p,104)+a|0)+484380|0,d+8|0,i|0,d+415|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break B}C=g^1|C}e=e+1|0;sb(d+56|0);g=w[d+155|0]|w[d+156|0]<<8;continue}break}f=P()|0;O()|0;break x}f=P()|0;O()|0;sb(d+56|0);break x}v[22440]=0;R(760,b|0,d+56|0);g=v[22440];v[22440]=0;if((g|0)==1){break y}g=d+16|0;i=d+56|0;C:{if(!(w[i+17|0]!=173|w[i+14|0]&48)){Nc(g,8,1,0,10);break C}i=w[i+14|0];Nc(g,i&16?16:8,i&32?3:1,0,2)}v[22440]=0;R(761,m|0,g|0);g=v[22440];v[22440]=0;if((g|0)!=1){G=Ib(v[d+96>>2],e),H=w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24),v[G>>2]=H;p=w[d+73|0];g=v[d+112>>2];if(Fc(g,v[d+116>>2])>>>0>e>>>0){i=x[Xb(g,e)>>1];v[22440]=0;g=(B(i,104)+a|0)+484380|0;R(762,d+56|0,g|0);s=v[22440];v[22440]=0;if((s|0)==1){break A}t[g+38|0]=w[n+202|0];t[g+39|0]=w[n+203|0];t[g+40|0]=w[n+204|0];t[g+41|0]=w[n+205|0];Bl(d+40|0,3,E);v[22440]=0;W(225,d+16|0,v[d+40>>2],v[d+44>>2],w[d+48|0]);g=v[22440];v[22440]=0;if((g|0)==1){break z}g=d+16|0;uc(((i<<5)+a|0)+946304|0,g);rb(g);f=(w[d+70|0]&3)==3?(f&2)>>>1|0?f|4:f:f}r=p|r;e=e+1|0;continue}break}f=P()|0;O()|0;break x}f=P()|0;O()|0;break x}f=P()|0;O()|0;break x}f=P()|0;O()|0}fc(l)}_c(d+112|0);break k}f=P()|0;O()|0;break k}fc(l);_c(d+112|0)}o=o+1|0;continue}}f=P()|0;O()|0;break c}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}D:{if(!(C&1)){break D}v[22440]=0;c=Q(1,d+128|0,16660)|0;e=v[22440];v[22440]=0;E:{if((e|0)!=1){e=v[a+1298464>>2];v[22440]=0;U(388,e|0,2,c|0);e=v[22440];v[22440]=0;if((e|0)==1){break E}rb(c);break D}f=P()|0;O()|0;break k}f=P()|0;O()|0;rb(c);break k}v[22440]=0;c=Q(414,b|0,5561)|0;e=v[22440];v[22440]=0;if((e|0)==1){break n}if(c){v[22440]=0;c=T(159,b|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break n}v[22440]=0;W(340,a+1298332|0,b|0,c|0,0);c=v[22440];v[22440]=0;if((c|0)==1){break n}f=f|16}v[22440]=0;n=Q(414,b|0,14175)|0;c=v[22440];v[22440]=0;if((c|0)==1){break l}if(n){v[22440]=0;c=T(159,b|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break l}v[22440]=0;e=a+901404|0;U(763,b|0,e|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break l}GA(e);f=f|16}v[22440]=0;c=Q(414,b|0,13937)|0;e=v[22440];v[22440]=0;if((e|0)==1){break l}if(!c){break m}v[22440]=0;c=T(159,b|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){u[d+128>>1]=c>>>5;c=a+484344|0;G=d,H=Cf(c),u[G+56>>1]=H;g=x[Kc(d+128|0,d+56|0)>>1];e=0;while(1){if((e|0)==(g|0)){f=f|16;break m}v[22440]=0;R(578,b|0,d+128|0);o=v[22440];v[22440]=0;F:{if((o|0)==1){break F}o=Sb(c,e);v[22440]=0;Q(579,o|0,d+128|0)|0;o=v[22440];v[22440]=0;if((o|0)==1){break F}e=e+1|0;continue}break}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}v[22440]=0;c=Q(414,b|0,13942)|0;e=v[22440];v[22440]=0;if((e|0)==1){break l}G:{if(!c){break G}v[22440]=0;c=T(159,b|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){u[d+128>>1]=(c>>>0)/20;u[d+56>>1]=x[a+480188>>1];c=x[Kc(d+128|0,d+56|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break G}v[22440]=0;U(425,b|0,((e<<5)+a|0)+480289|0,20);g=v[22440];v[22440]=0;if((g|0)!=1){e=e+1|0;continue}break}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}v[22440]=0;c=Q(158,b|0,8)|0;e=v[22440];v[22440]=0;if((e|0)==1){break l}H:{I:{J:{K:{if(c){c=v[b+8>>2];v[22440]=0;Q(426,a|0,b|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break K}f=(c|0)==v[b+8>>2]?f:f|16}L:{if(!(f&16)){break L}if(f&4){v[a+1074308>>2]=17367040;v[22440]=0;c=Q(1,d+128|0,14782)|0;e=v[22440];v[22440]=0;if((e|0)!=1){Cb(j,c);rb(c);break L}f=P()|0;O()|0;break k}if(!(f&2)){break L}v[a+1074308>>2]=18219008;v[22440]=0;c=Q(1,d+128|0,14945)|0;e=v[22440];v[22440]=0;if((e|0)==1){break J}Cb(j,c);rb(c)}M:{N:{O:{P:{Q:{R:{S:{if(!Mb(k,17645,8)){v[22440]=0;c=Y(395,d+128|0,d+478|0,12)|0;e=v[22440];v[22440]=0;if((e|0)==1){break S}v[22440]=0;U(11,d+56|0,1,c|0);e=v[22440];v[22440]=0;if((e|0)==1){break R}v[22440]=0;e=T(764,d+56|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break Q}v[a+1074308>>2]=e;rb(d+56|0);t[a+1074368|0]=y[a+1074308>>2]<19007257?4:5;rb(c);f=24}if(!(!v[a+1074308>>2]|f&8)){t[a+1074368|0]=0;Rt(a+1074312|0)}c=f&32;T:{if(!c){break T}t[a+1074368|0]=5;if(!n){_p(a+901404|0)}if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break T}v[22440]=0;Y(271,a+1074312|0,4,1)|0;e=v[22440];v[22440]=0;if((e|0)==1){break l}}if(!xd(j)){break M}if(!(f&256)|r&255|h+1>>>0>1){break N}v[22440]=0;c=Q(1,d+128|0,8321)|0;h=v[22440];v[22440]=0;if((h|0)==1){break O}Cb(j,c);rb(c);break M}f=P()|0;O()|0;break k}f=P()|0;O()|0;break P}f=P()|0;O()|0;rb(d+56|0)}rb(c);break k}f=P()|0;O()|0;break k}if(c){v[22440]=0;c=Q(1,d+128|0,12105)|0;h=v[22440];v[22440]=0;if((h|0)!=1){Cb(j,c);rb(c);break M}f=P()|0;O()|0;break k}v[22440]=0;c=Q(1,d+128|0,9769)|0;h=v[22440];v[22440]=0;if((h|0)==1){break I}Cb(j,c);rb(c)}t[d+40|0]=0;U:{if(x[a+480192>>1]){v[22440]=0;c=Q(434,a|0,b|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break U}t[d+40|0]=c}v[22440]=0;W(435,a|0,b|0,1,d+40|0);b=v[22440];v[22440]=0;if((b|0)==1){break U}e=v[a+1074308>>2];V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{if(w[d+40|0]){if(e>>>0>18284543){break ha}v[a+1074308>>2]=18284544;break ha}if(e>>>0<18284544){break ga}}v[22440]=0;b=Q(1,d+56|0,17645)|0;c=v[22440];v[22440]=0;if((c|0)==1){break fa}c=v[a+1074308>>2];v[22440]=0;R(765,d+16|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break ea}v[22440]=0;U(2,d+128|0,b|0,d+16|0);c=v[22440];v[22440]=0;if((c|0)==1){break da}c=d+128|0;Cb(j,c);rb(c);rb(d+16|0);rb(b);e=v[a+1074308>>2]}ia:{if(e-1>>>0>19005952){break ia}b=a+484344|0;if(!ve(b,254)){c=Nb(q);v[22440]=0;R(766,c|0,254);c=v[22440];v[22440]=0;if((c|0)==1){break U}}if(ve(b,255)){break ia}Tz(Nb(q),255,65535)}v[22440]=0;R(767,d+56|0,4105);b=v[22440];v[22440]=0;if((b|0)==1){break ba}b=w[d+490|0]|w[d+491|0]<<8;v[d+112>>2]=b>>>8;v[22440]=0;v[d+96>>2]=b&255;R(445,d+16|0,d+96|0);b=v[22440];v[22440]=0;if((b|0)==1){break aa}v[22440]=0;W(431,d+128|0,d+56|0,d+112|0,d+16|0);b=v[22440];v[22440]=0;if((b|0)==1){break $}c=d+128|0;b=Cb(a+1298344|0,c);rb(c);rb(d+16|0);Ab(d+56|0);Cb(a+1298368|0,j);v[a+1298404>>2]=D?8:v[a+1074308>>2]?8:5;if(!w[d+415|0]){break W}Cb(a+1298380|0,b);v[22440]=0;c=Q(1,d+128|0,15316)|0;h=v[22440];v[22440]=0;if((h|0)==1){break Z}Cb(b,c);rb(c);v[22440]=0;b=Q(1,d+128|0,10120)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Y}Cb(a+1298356|0,b);rb(b);v[22440]=0;b=Q(1,d+128|0,10121)|0;c=v[22440];v[22440]=0;if((c|0)==1){break X}Cb(a+1298392|0,b);break V}f=P()|0;O()|0;break k}f=P()|0;O()|0;break ca}f=P()|0;O()|0;rb(d+16|0)}rb(b);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break _}f=P()|0;O()|0;rb(d+16|0)}Ab(d+56|0);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}v[22440]=0;b=Q(1,d+128|0,10121)|0;c=v[22440];v[22440]=0;if((c|0)==1){break H}Cb(a+1298356|0,b)}rb(b);fc(m);rb(j);break b}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0}fc(m);break c}f=P()|0;O()|0}rb(j);S(f|0);L()}e=1}cb=d+512|0;return e|0}function Hd(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=cb-16|0;cb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(a>>>0<=244){f=v[114925];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=f>>>c|0;if(b&3){d=c+((b^-1)&1)|0;b=d<<3;e=v[b+459748>>2];a=e+8|0;c=v[e+8>>2];b=b+459740|0;l:{if((c|0)==(b|0)){m=459700,n=oka(-2,d)&f,v[m>>2]=n;break l}v[c+12>>2]=b;v[b+8>>2]=c}b=d<<3;v[e+4>>2]=b|3;b=b+e|0;v[b+4>>2]=v[b+4>>2]|1;break a}k=v[114927];if(k>>>0>=h>>>0){break k}if(b){a=2<<c;a=(0-a|a)&b<<c;b=(0-a&a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;c=(c|a)+(b>>>a|0)|0;a=c<<3;g=v[a+459748>>2];b=v[g+8>>2];a=a+459740|0;m:{if((b|0)==(a|0)){f=oka(-2,c)&f;v[114925]=f;break m}v[b+12>>2]=a;v[a+8>>2]=b}a=g+8|0;v[g+4>>2]=h|3;d=g+h|0;b=c<<3;e=b-h|0;v[d+4>>2]=e|1;v[b+g>>2]=e;if(k){b=k>>>3|0;c=(b<<3)+459740|0;g=v[114930];b=1<<b;n:{if(!(b&f)){v[114925]=b|f;b=c;break n}b=v[c+8>>2]}v[c+8>>2]=g;v[b+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=b}v[114930]=d;v[114927]=e;break a}j=v[114926];if(!j){break k}b=(0-j&j)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;b=v[((c|a)+(b>>>a|0)<<2)+460004>>2];d=(v[b+4>>2]&-8)-h|0;c=b;while(1){o:{a=v[c+16>>2];if(!a){a=v[c+20>>2];if(!a){break o}}c=(v[a+4>>2]&-8)-h|0;e=c>>>0<d>>>0;d=e?c:d;b=e?a:b;c=a;continue}break}i=v[b+24>>2];e=v[b+12>>2];if((e|0)!=(b|0)){a=v[b+8>>2];v[a+12>>2]=e;v[e+8>>2]=a;break b}c=b+20|0;a=v[c>>2];if(!a){a=v[b+16>>2];if(!a){break j}c=b+16|0}while(1){g=c;e=a;c=a+20|0;a=v[c>>2];if(a){continue}c=e+16|0;a=v[e+16>>2];if(a){continue}break}v[g>>2]=0;break b}h=-1;if(a>>>0>4294967231){break k}a=a+11|0;h=a&-8;j=v[114926];if(!j){break k}d=0-h|0;f=0;p:{if(h>>>0<256){break p}f=31;if(h>>>0>16777215){break p}a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;f=(a<<1|h>>>a+21&1)+28|0}c=v[(f<<2)+460004>>2];q:{r:{s:{if(!c){a=0;break s}a=0;b=h<<((f|0)==31?0:25-(f>>>1|0)|0);while(1){t:{g=(v[c+4>>2]&-8)-h|0;if(g>>>0>=d>>>0){break t}e=c;d=g;if(d){break t}d=0;a=c;break r}g=v[c+20>>2];c=v[((b>>>29&4)+c|0)+16>>2];a=g?(g|0)==(c|0)?a:g:a;b=b<<1;if(c){continue}break}}if(!(a|e)){e=0;a=2<<f;a=(0-a|a)&j;if(!a){break k}b=(a&0-a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=v[((c|a)+(b>>>a|0)<<2)+460004>>2]}if(!a){break q}}while(1){b=(v[a+4>>2]&-8)-h|0;c=b>>>0<d>>>0;d=c?b:d;e=c?a:e;b=v[a+16>>2];if(b){a=b}else{a=v[a+20>>2]}if(a){continue}break}}if(!e|v[114927]-h>>>0<=d>>>0){break k}f=v[e+24>>2];b=v[e+12>>2];if((e|0)!=(b|0)){a=v[e+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break c}c=e+20|0;a=v[c>>2];if(!a){a=v[e+16>>2];if(!a){break i}c=e+16|0}while(1){g=c;b=a;c=a+20|0;a=v[c>>2];if(a){continue}c=b+16|0;a=v[b+16>>2];if(a){continue}break}v[g>>2]=0;break c}c=v[114927];if(c>>>0>=h>>>0){d=v[114930];b=c-h|0;u:{if(b>>>0>=16){v[114927]=b;a=d+h|0;v[114930]=a;v[a+4>>2]=b|1;v[c+d>>2]=b;v[d+4>>2]=h|3;break u}v[114930]=0;v[114927]=0;v[d+4>>2]=c|3;a=c+d|0;v[a+4>>2]=v[a+4>>2]|1}a=d+8|0;break a}i=v[114928];if(i>>>0>h>>>0){b=i-h|0;v[114928]=b;c=v[114931];a=c+h|0;v[114931]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;if(v[115043]){c=v[115045]}else{v[115046]=-1;v[115047]=-1;v[115044]=4096;v[115045]=4096;v[115043]=l+12&-16^1431655768;v[115048]=0;v[115036]=0;c=4096}g=j+c|0;e=0-c|0;c=g&e;if(c>>>0<=h>>>0){break a}d=v[115035];if(d){b=v[115033];f=b+c|0;if(d>>>0<f>>>0|b>>>0>=f>>>0){break a}}if(w[460144]&4){break f}v:{w:{d=v[114931];if(d){a=460148;while(1){b=v[a>>2];if(b>>>0<=d>>>0&d>>>0<b+v[a+4>>2]>>>0){break w}a=v[a+8>>2];if(a){continue}break}}b=Wo(0);if((b|0)==-1){break g}f=c;d=v[115044];a=d-1|0;if(a&b){f=(c-b|0)+(a+b&0-d)|0}if(f>>>0<=h>>>0|f>>>0>2147483646){break g}d=v[115035];if(d){a=v[115033];e=a+f|0;if(e>>>0>d>>>0|a>>>0>=e>>>0){break g}}a=Wo(f);if((b|0)!=(a|0)){break v}break e}f=e&g-i;if(f>>>0>2147483646){break g}b=Wo(f);if((b|0)==(v[a>>2]+v[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|h+48>>>0<=f>>>0)){b=v[115045];b=b+(j-f|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((Wo(b)|0)!=-1){f=b+f|0;b=a;break e}Wo(0-f|0);break g}b=a;if((a|0)!=-1){break e}break g}e=0;break b}b=0;break c}if((b|0)!=-1){break e}}v[115036]=v[115036]|4}if(c>>>0>2147483646){break d}b=v[22359];c=c+3&-4;a=b+c|0;x:{y:{if(!c|a>>>0>b>>>0){if(Bw()>>>0>=a>>>0){break y}if(ta(a|0)|0){break y}a=v[22359]}else{a=b}v[114922]=48;b=-1;break x}v[22359]=a}if(Bw()>>>0<a>>>0){if(!(ta(a|0)|0)){break d}}v[22359]=a;if((b|0)==-1|(a|0)==-1|a>>>0<=b>>>0){break d}f=a-b|0;if(f>>>0<=h+40>>>0){break d}}a=v[115033]+f|0;v[115033]=a;if(a>>>0>y[115034]){v[115034]=a}z:{A:{B:{g=v[114931];if(g){a=460148;while(1){d=v[a>>2];c=v[a+4>>2];if((d+c|0)==(b|0)){break B}a=v[a+8>>2];if(a){continue}break}break A}a=v[114929];if(!(a>>>0<=b>>>0?a:0)){v[114929]=b}a=0;v[115038]=f;v[115037]=b;v[114933]=-1;v[114934]=v[115043];v[115040]=0;while(1){d=a<<3;c=d+459740|0;v[d+459748>>2]=c;v[d+459752>>2]=c;a=a+1|0;if((a|0)!=32){continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[114928]=c;a=a+b|0;v[114931]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[114932]=v[115047];break z}if(w[a+12|0]&8|d>>>0>g>>>0|b>>>0<=g>>>0){break A}v[a+4>>2]=c+f;a=g+8&7?-8-g&7:0;c=a+g|0;v[114931]=c;b=v[114928]+f|0;a=b-a|0;v[114928]=a;v[c+4>>2]=a|1;v[(b+g|0)+4>>2]=40;v[114932]=v[115047];break z}if(y[114929]>b>>>0){v[114929]=b}d=b+f|0;c=460148;C:{while(1){if((d|0)!=v[c>>2]){a=460148;c=v[c+8>>2];if(c){continue}break C}break}a=460148;if(w[c+12|0]&8){break C}v[c>>2]=b;v[c+4>>2]=v[c+4>>2]+f;j=(b+8&7?-8-b&7:0)+b|0;v[j+4>>2]=h|3;e=d+(d+8&7?-8-d&7:0)|0;i=h+j|0;c=e-i|0;D:{if((e|0)==(g|0)){v[114931]=i;a=v[114928]+c|0;v[114928]=a;v[i+4>>2]=a|1;break D}if(v[114930]==(e|0)){v[114930]=i;a=v[114927]+c|0;v[114927]=a;v[i+4>>2]=a|1;v[a+i>>2]=a;break D}a=v[e+4>>2];if((a&3)==1){f=a&-8;E:{if(a>>>0<=255){d=v[e+8>>2];a=a>>>3|0;b=v[e+12>>2];if((b|0)==(d|0)){m=459700,n=v[114925]&oka(-2,a),v[m>>2]=n;break E}v[d+12>>2]=b;v[b+8>>2]=d;break E}h=v[e+24>>2];b=v[e+12>>2];F:{if((e|0)!=(b|0)){a=v[e+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break F}G:{a=e+20|0;d=v[a>>2];if(d){break G}a=e+16|0;d=v[a>>2];if(d){break G}b=0;break F}while(1){g=a;b=d;a=b+20|0;d=v[a>>2];if(d){continue}a=b+16|0;d=v[b+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break E}d=v[e+28>>2];a=(d<<2)+460004|0;H:{if(v[a>>2]==(e|0)){v[a>>2]=b;if(b){break H}m=459704,n=v[114926]&oka(-2,d),v[m>>2]=n;break E}v[h+(v[h+16>>2]==(e|0)?16:20)>>2]=b;if(!b){break E}}v[b+24>>2]=h;a=v[e+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[e+20>>2];if(!a){break E}v[b+20>>2]=a;v[a+24>>2]=b}e=e+f|0;c=c+f|0}v[e+4>>2]=v[e+4>>2]&-2;v[i+4>>2]=c|1;v[c+i>>2]=c;if(c>>>0<=255){a=c>>>3|0;b=(a<<3)+459740|0;c=v[114925];a=1<<a;I:{if(!(c&a)){v[114925]=a|c;a=b;break I}a=v[b+8>>2]}v[b+8>>2]=i;v[a+12>>2]=i;v[i+12>>2]=b;v[i+8>>2]=a;break D}a=31;if(c>>>0<=16777215){a=c>>>8|0;e=a+1048320>>>16&8;a=a<<e;d=a+520192>>>16&4;a=a<<d;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(e|d))|0;a=(a<<1|c>>>a+21&1)+28|0}v[i+28>>2]=a;v[i+16>>2]=0;v[i+20>>2]=0;e=(a<<2)+460004|0;J:{d=v[114926];b=1<<a;K:{if(!(d&b)){v[114926]=b|d;v[e>>2]=i;v[i+24>>2]=e;break K}a=c<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[e>>2];while(1){d=b;if((v[b+4>>2]&-8)==(c|0)){break J}b=a>>>29|0;a=a<<1;e=d+(b&4)|0;b=v[e+16>>2];if(b){continue}break}v[e+16>>2]=i;v[i+24>>2]=d}v[i+12>>2]=i;v[i+8>>2]=i;break D}a=v[d+8>>2];v[a+12>>2]=i;v[d+8>>2]=i;v[i+24>>2]=0;v[i+12>>2]=d;v[i+8>>2]=a}a=j+8|0;break a}while(1){L:{c=v[a>>2];if(c>>>0<=g>>>0){e=c+v[a+4>>2]|0;if(e>>>0>g>>>0){break L}}a=v[a+8>>2];continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[114928]=c;a=a+b|0;v[114931]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[114932]=v[115047];a=(e+(e-39&7?39-e&7:0)|0)-47|0;c=a>>>0<g+16>>>0?g:a;v[c+4>>2]=27;a=v[115040];v[c+16>>2]=v[115039];v[c+20>>2]=a;a=v[115038];v[c+8>>2]=v[115037];v[c+12>>2]=a;v[115039]=c+8;v[115038]=f;v[115037]=b;v[115040]=0;a=c+24|0;while(1){v[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<e>>>0){continue}break}if((c|0)==(g|0)){break z}v[c+4>>2]=v[c+4>>2]&-2;e=c-g|0;v[g+4>>2]=e|1;v[c>>2]=e;if(e>>>0<=255){a=e>>>3|0;b=(a<<3)+459740|0;c=v[114925];a=1<<a;M:{if(!(c&a)){v[114925]=a|c;a=b;break M}a=v[b+8>>2]}v[b+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=b;v[g+8>>2]=a;break z}a=31;v[g+16>>2]=0;v[g+20>>2]=0;if(e>>>0<=16777215){a=e>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|e>>>a+21&1)+28|0}v[g+28>>2]=a;d=(a<<2)+460004|0;N:{c=v[114926];b=1<<a;O:{if(!(c&b)){v[114926]=b|c;v[d>>2]=g;v[g+24>>2]=d;break O}a=e<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[d>>2];while(1){c=b;if((e|0)==(v[b+4>>2]&-8)){break N}b=a>>>29|0;a=a<<1;d=c+(b&4)|0;b=v[d+16>>2];if(b){continue}break}v[d+16>>2]=g;v[g+24>>2]=c}v[g+12>>2]=g;v[g+8>>2]=g;break z}a=v[c+8>>2];v[a+12>>2]=g;v[c+8>>2]=g;v[g+24>>2]=0;v[g+12>>2]=c;v[g+8>>2]=a}a=v[114928];if(a>>>0<=h>>>0){break d}b=a-h|0;v[114928]=b;c=v[114931];a=c+h|0;v[114931]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}a=0;v[114922]=48;break a}P:{if(!f){break P}c=v[e+28>>2];a=(c<<2)+460004|0;Q:{if(v[a>>2]==(e|0)){v[a>>2]=b;if(b){break Q}j=oka(-2,c)&j;v[114926]=j;break P}v[f+(v[f+16>>2]==(e|0)?16:20)>>2]=b;if(!b){break P}}v[b+24>>2]=f;a=v[e+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[e+20>>2];if(!a){break P}v[b+20>>2]=a;v[a+24>>2]=b}R:{if(d>>>0<=15){a=d+h|0;v[e+4>>2]=a|3;a=a+e|0;v[a+4>>2]=v[a+4>>2]|1;break R}v[e+4>>2]=h|3;f=e+h|0;v[f+4>>2]=d|1;v[d+f>>2]=d;if(d>>>0<=255){a=d>>>3|0;b=(a<<3)+459740|0;c=v[114925];a=1<<a;S:{if(!(c&a)){v[114925]=a|c;a=b;break S}a=v[b+8>>2]}v[b+8>>2]=f;v[a+12>>2]=f;v[f+12>>2]=b;v[f+8>>2]=a;break R}a=31;if(d>>>0<=16777215){a=d>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|d>>>a+21&1)+28|0}v[f+28>>2]=a;v[f+16>>2]=0;v[f+20>>2]=0;b=(a<<2)+460004|0;T:{c=1<<a;U:{if(!(c&j)){v[114926]=c|j;v[b>>2]=f;break U}a=d<<((a|0)==31?0:25-(a>>>1|0)|0);h=v[b>>2];while(1){b=h;if((v[b+4>>2]&-8)==(d|0)){break T}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=v[c+16>>2];if(h){continue}break}v[c+16>>2]=f}v[f+24>>2]=b;v[f+12>>2]=f;v[f+8>>2]=f;break R}a=v[b+8>>2];v[a+12>>2]=f;v[b+8>>2]=f;v[f+24>>2]=0;v[f+12>>2]=b;v[f+8>>2]=a}a=e+8|0;break a}V:{if(!i){break V}c=v[b+28>>2];a=(c<<2)+460004|0;W:{if(v[a>>2]==(b|0)){v[a>>2]=e;if(e){break W}m=459704,n=oka(-2,c)&j,v[m>>2]=n;break V}v[i+(v[i+16>>2]==(b|0)?16:20)>>2]=e;if(!e){break V}}v[e+24>>2]=i;a=v[b+16>>2];if(a){v[e+16>>2]=a;v[a+24>>2]=e}a=v[b+20>>2];if(!a){break V}v[e+20>>2]=a;v[a+24>>2]=e}X:{if(d>>>0<=15){a=d+h|0;v[b+4>>2]=a|3;a=a+b|0;v[a+4>>2]=v[a+4>>2]|1;break X}v[b+4>>2]=h|3;e=b+h|0;v[e+4>>2]=d|1;v[e+d>>2]=d;if(k){a=k>>>3|0;c=(a<<3)+459740|0;g=v[114930];a=1<<a;Y:{if(!(a&f)){v[114925]=a|f;a=c;break Y}a=v[c+8>>2]}v[c+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=a}v[114930]=e;v[114927]=d}a=b+8|0}cb=l+16|0;return a|0}function f6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=cb-32|0;cb=g;a:{b:{c:{d:{e:{if(ue(b,21685)){Db(a);break e}if(ue(b,9912)){b=cb-96|0;cb=b;f=Db(a);v[22440]=0;Z(136,b- -64|0);a=v[22440];v[22440]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[22440]=0;v[b+32>>2]=0;R(1072,b+48|0,b+32|0);a=v[22440];v[22440]=0;if((a|0)==1){break p}v[22440]=0;a=Q(824,f|0,b+48|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break o}rb(b+48|0);v[22440]=0;a=Q(960,a|0,16802)|0;c=v[22440];v[22440]=0;q:{if((c|0)==1){break q}v[22440]=0;v[b+32>>2]=7;R(1072,b+48|0,b+32|0);c=v[22440];v[22440]=0;if((c|0)==1){break n}v[22440]=0;a=Q(824,a|0,b+48|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break m}rb(b+48|0);v[22440]=0;a=Q(960,a|0,16802)|0;c=v[22440];v[22440]=0;if((c|0)==1){break q}v[22440]=0;v[b+32>>2]=0;R(1072,b+48|0,b+32|0);c=v[22440];v[22440]=0;if((c|0)==1){break l}v[22440]=0;a=Q(824,a|0,b+48|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break k}c=b+48|0;rb(c);v[22440]=0;c=Q(56,c|0,15115)|0;d=v[22440];v[22440]=0;if((d|0)==1){break j}d=vb(c);rb(c);if(!d){break i}v[22440]=0;Q(960,a|0,15115)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break i}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break g}a=P()|0;O()|0;break h}a=P()|0;O()|0;rb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;rb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;rb(b+48|0);break h}a=P()|0;O()|0;break h}c=Rb(b+48|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=v[b+76>>2];if(d){v[22440]=0;v[b+12>>2]=d;R(1072,b+16|0,b+12|0);d=v[22440];v[22440]=0;if((d|0)==1){break D}v[22440]=0;U(986,b+32|0,8993,b+16|0);d=v[22440];v[22440]=0;if((d|0)==1){break C}v[22440]=0;R(185,c|0,b+32|0);d=v[22440];v[22440]=0;if((d|0)==1){break B}rb(b+32|0);rb(b+16|0)}if(!Ed(w[b+80|0])){break x}v[22440]=0;d=Q(56,b+32|0,12806)|0;e=v[22440];v[22440]=0;if((e|0)==1){break z}v[22440]=0;R(185,c|0,d|0);e=v[22440];v[22440]=0;if((e|0)==1){break y}rb(d);break w}a=P()|0;O()|0;break r}a=P()|0;O()|0;break A}a=P()|0;O()|0;rb(b+32|0)}rb(b+16|0);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;rb(d);break r}if(!Ed(w[b+81|0])){break w}v[22440]=0;d=Q(56,b+32|0,12577)|0;e=v[22440];v[22440]=0;if((e|0)==1){break v}v[22440]=0;R(185,c|0,d|0);e=v[22440];v[22440]=0;if((e|0)==1){break u}rb(d)}if(Ed(w[b+82|0])){break t}break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;rb(d);break r}v[22440]=0;d=Q(56,b+32|0,11102)|0;e=v[22440];v[22440]=0;E:{if((e|0)!=1){v[22440]=0;R(185,c|0,d|0);e=v[22440];v[22440]=0;if((e|0)==1){break E}rb(d);break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;rb(d);break r}if(hc(v[c>>2],v[c+4>>2])){break f}v[22440]=0;a=Q(960,a|0,16832)|0;d=v[22440];v[22440]=0;if((d|0)!=1){v[22440]=0;d=Q(56,b+16|0,16802)|0;e=v[22440];v[22440]=0;F:{G:{H:{if((e|0)!=1){v[22440]=0;U(1073,b+32|0,c|0,d|0);e=v[22440];v[22440]=0;if((e|0)==1){break H}v[22440]=0;Q(824,a|0,b+32|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break G}rb(b+32|0);rb(d);break f}a=P()|0;O()|0;break r}a=P()|0;O()|0;break F}a=P()|0;O()|0;rb(b+32|0)}rb(d);break r}a=P()|0;O()|0}ad(c)}Jf(b- -64|0)}rb(f);break a}ad(c);Jf(b- -64|0);cb=b+96|0;break e}if(ue(b,8161)){v[g>>2]=0;hp(a,g);break e}if(ue(b,8139)){v[g>>2]=7;hp(a,g);break e}if(ue(b,10822)){v[g>>2]=0;hp(a,g);break e}if(ue(b,10615)){Bc(a,15115);break e}if(ue(b,11439)){b=Bc(g,15115);c=vb(b);v[22440]=0;Q(56,a|0,(c?15837:15507)|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break d}rb(b);break e}if(ue(b,7372)){b=cb-48|0;cb=b;YD(b+16|0);v[22440]=0;Z(153,b|0);c=v[22440];v[22440]=0;I:{J:{K:{L:{if((c|0)!=1){v[22440]=0;U(154,b+32|0,b+16|0,b|0);c=v[22440];v[22440]=0;if((c|0)==1){break L}v[22440]=0;R(1033,a|0,b+32|0);a=v[22440];v[22440]=0;if((a|0)==1){break K}rb(b+32|0);rb(b);rb(b+16|0);cb=b+48|0;break e}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;rb(b+32|0)}rb(b)}rb(b+16|0);break a}if(ue(b,9928)){b=cb-16|0;cb=b;e=cb-16|0;cb=e;v[e+8>>2]=101;c=cb-112|0;cb=c;f=Rb(c+96|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{d=v[e+8>>2];if(d&1){v[22440]=0;R(142,c- -64|0,19988487);d=v[22440];v[22440]=0;if((d|0)==1){break $}v[22440]=0;R(126,f|0,c- -64|0);d=v[22440];v[22440]=0;if((d|0)==1){break _}rb(c- -64|0);d=v[e+8>>2]}if(!(d&4)){break Y}v[22440]=0;d=ha(143)|0;h=v[22440];v[22440]=0;if((h|0)==1){break X}if(!d){break Z}break Y}d=P()|0;O()|0;break N}d=P()|0;O()|0;rb(c- -64|0);break N}v[22440]=0;Z(144,c- -64|0);d=v[22440];v[22440]=0;aa:{if((d|0)!=1){v[22440]=0;R(126,f|0,c- -64|0);d=v[22440];v[22440]=0;if((d|0)==1){break aa}rb(c- -64|0);break Y}d=P()|0;O()|0;break N}d=P()|0;O()|0;rb(c- -64|0);break N}ba:{d=v[e+8>>2];if(!(d&32)){break ba}v[22440]=0;Z(136,c- -64|0);d=v[22440];v[22440]=0;ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((d|0)!=1){v[22440]=0;R(145,c+48|0,c- -64|0);d=v[22440];v[22440]=0;if((d|0)==1){break da}d=c+48|0;h=xd(d);rb(d);if(!h){v[22440]=0;Z(146,c+32|0);d=v[22440];v[22440]=0;if((d|0)==1){break ua}v[22440]=0;R(145,c+16|0,c- -64|0);d=v[22440];v[22440]=0;if((d|0)==1){break ta}v[22440]=0;U(147,c+48|0,c+32|0,c+16|0);d=v[22440];v[22440]=0;if((d|0)==1){break sa}v[22440]=0;R(126,f|0,c+48|0);d=v[22440];v[22440]=0;if((d|0)==1){break ra}rb(c+48|0);rb(c+16|0);Ab(c+32|0)}d=Go(c- -64|0);if(!xd(d)){v[22440]=0;Z(148,c+32|0);h=v[22440];v[22440]=0;if((h|0)==1){break oa}v[22440]=0;U(149,c+48|0,c+32|0,d|0);d=v[22440];v[22440]=0;if((d|0)==1){break na}v[22440]=0;R(126,f|0,c+48|0);d=v[22440];v[22440]=0;if((d|0)==1){break ma}rb(c+48|0);Ab(c+32|0)}v[22440]=0;R(150,c+48|0,c- -64|0);d=v[22440];v[22440]=0;if((d|0)==1){break ka}d=c+48|0;h=xd(d);rb(d);if(!h){v[22440]=0;Z(146,c+32|0);d=v[22440];v[22440]=0;if((d|0)==1){break ja}v[22440]=0;R(150,c+16|0,c- -64|0);d=v[22440];v[22440]=0;if((d|0)==1){break ia}v[22440]=0;U(147,c+48|0,c+32|0,c+16|0);d=v[22440];v[22440]=0;if((d|0)==1){break ha}v[22440]=0;R(126,f|0,c+48|0);d=v[22440];v[22440]=0;if((d|0)==1){break ga}rb(c+48|0);rb(c+16|0);Ab(c+32|0)}Jf(c- -64|0);d=v[e+8>>2];break ba}d=P()|0;O()|0;break N}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break pa}d=P()|0;O()|0;break qa}d=P()|0;O()|0;rb(c+48|0)}rb(c+16|0)}Ab(c+32|0);break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break la}d=P()|0;O()|0;rb(c+48|0)}Ab(c+32|0);break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break ea}d=P()|0;O()|0;break fa}d=P()|0;O()|0;rb(c+48|0)}rb(c+16|0)}Ab(c+32|0);break ca}d=P()|0;O()|0}Jf(c- -64|0);break N}va:{if(!(d&64)){break va}v[22440]=0;d=ha(143)|0;h=v[22440];v[22440]=0;if((h|0)==1){break X}if(d){break va}d=c- -64|0;Db(d);v[22440]=0;R(126,f|0,d|0);d=v[22440];v[22440]=0;if((d|0)==1){break O}rb(c- -64|0)}if(w[e+8|0]&128){v[22440]=0;Z(151,c- -64|0);d=v[22440];v[22440]=0;if((d|0)==1){break W}v[22440]=0;R(126,f|0,c- -64|0);d=v[22440];v[22440]=0;if((d|0)==1){break V}rb(c- -64|0)}v[22440]=0;h=Q(1,c- -64|0,21685)|0;d=v[22440];v[22440]=0;if((d|0)==1){break U}v[22440]=0;U(152,c|0,f|0,h|0);d=v[22440];v[22440]=0;if((d|0)==1){break T}v[22440]=0;Z(153,c+48|0);d=v[22440];v[22440]=0;if((d|0)==1){break S}v[22440]=0;U(154,b|0,c|0,c+48|0);d=v[22440];v[22440]=0;if((d|0)==1){break R}rb(c+48|0);rb(c);rb(h);ad(f);cb=c+112|0;break M}d=P()|0;O()|0;break N}d=P()|0;O()|0;break N}d=P()|0;O()|0;rb(c- -64|0);break N}d=P()|0;O()|0;break N}d=P()|0;O()|0;break P}d=P()|0;O()|0;break Q}d=P()|0;O()|0;rb(c+48|0)}rb(c)}rb(h);break N}d=P()|0;O()|0;rb(c- -64|0)}ad(f);S(d|0);L()}cb=e+16|0;v[22440]=0;R(1033,a|0,b|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(b);cb=b+16|0;break e}break b}if(ue(b,10544)){b=cb-48|0;cb=b;ar(b);v[22440]=0;R(145,b+32|0,b|0);c=v[22440];v[22440]=0;wa:{xa:{if((c|0)!=1){v[22440]=0;R(1033,a|0,b+32|0);a=v[22440];v[22440]=0;if((a|0)==1){break xa}rb(b+32|0);Jf(b);cb=b+48|0;break e}a=P()|0;O()|0;break wa}a=P()|0;O()|0;rb(b+32|0)}Jf(b);break a}if(ue(b,11402)){b=cb-32|0;cb=b;ar(b);v[22440]=0;R(1033,a|0,Go(b)|0);a=v[22440];v[22440]=0;if((a|0)!=1){Jf(b);cb=b+32|0;break e}a=P()|0;O()|0;Jf(b);break a}if(ue(b,9941)){b=cb-48|0;cb=b;ar(b+16|0);c=v[b+28>>2];ya:{if(c){v[22440]=0;v[b+12>>2]=c;R(1072,a|0,b+12|0);a=v[22440];v[22440]=0;if((a|0)!=1){break ya}a=P()|0;O()|0;Jf(b+16|0);break a}Db(a)}Jf(b+16|0);cb=b+48|0;break e}if(ue(b,12796)){ar(g);b=w[g+16|0];v[22440]=0;Q(56,a|0,(Ed(b)?15507:15837)|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){Jf(g);break e}a=P()|0;O()|0;Jf(g);break a}if(ue(b,9957)){ar(g);b=w[g+17|0];v[22440]=0;Q(56,a|0,(Ed(b)?15507:15837)|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){Jf(g);break e}a=P()|0;O()|0;Jf(g);break a}if(ue(b,12249)){ar(g);b=w[g+18|0];v[22440]=0;Q(56,a|0,(Ed(b)?15507:15837)|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){Jf(g);break e}a=P()|0;O()|0;Jf(g);break a}if(ue(b,12551)){b=cb-16|0;cb=b;c=cb-32|0;cb=c;d=Db(b);v[22440]=0;Z(136,c|0);f=v[22440];v[22440]=0;za:{Aa:{Ba:{if((f|0)!=1){v[22440]=0;R(137,d|0,Go(c)|0);f=v[22440];v[22440]=0;if((f|0)==1){break Ba}Jf(c);cb=c+32|0;break za}a=P()|0;O()|0;break Aa}a=P()|0;O()|0;Jf(c)}rb(d);break a}v[22440]=0;R(1033,a|0,b|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(b);cb=b+16|0;break e}break b}if(ue(b,8282)){b=cb-16|0;cb=b;c=cb-48|0;cb=c;d=Db(b);v[22440]=0;R(139,c+16|0,4138);f=v[22440];v[22440]=0;Ca:{Da:{Ea:{Fa:{Ga:{if((f|0)!=1){v[c+12>>2]=14;v[c+8>>2]=0;v[22440]=0;v[c+4>>2]=0;ga(140,c+32|0,c+16|0,c+12|0,c+8|0,c+4|0);f=v[22440];v[22440]=0;if((f|0)==1){break Ga}v[22440]=0;Q(100,d|0,c+32|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break Fa}rb(c+32|0);Ab(c+16|0);cb=c+48|0;break Ca}a=P()|0;O()|0;break Da}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;rb(c+32|0)}Ab(c+16|0)}rb(d);S(a|0);L()}v[22440]=0;R(1033,a|0,b|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(b);cb=b+16|0;break e}break b}if(ue(b,6825)){b=cb-16|0;cb=b;Wm(b,0,19631);v[22440]=0;R(1033,a|0,b|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(b);cb=b+16|0;break e}break b}if(ue(b,6458)){b=cb-48|0;cb=b;c=jc(b+16|0,17692);v[22440]=0;R(1074,b|0,2);d=v[22440];v[22440]=0;Ha:{Ia:{Ja:{Ka:{if((d|0)!=1){v[22440]=0;U(2,b+32|0,c|0,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break Ka}v[22440]=0;R(1033,a|0,b+32|0);a=v[22440];v[22440]=0;if((a|0)==1){break Ja}rb(b+32|0);rb(b);rb(c);cb=b+48|0;break e}a=P()|0;O()|0;break Ha}a=P()|0;O()|0;break Ia}a=P()|0;O()|0;rb(b+32|0)}rb(b)}rb(c);break a}if(ue(b,11425)){b=cb-16|0;cb=b;Wm(b,0,18031);v[22440]=0;R(1033,a|0,b|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(b);cb=b+16|0;break e}break b}if(ue(b,10551)){b=cb-16|0;cb=b;Zq(b,0);v[22440]=0;R(1033,a|0,b|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(b);cb=b+16|0;break e}break b}if(ue(b,10526)){b=cb-16|0;cb=b;Zq(b,2);v[22440]=0;R(1033,a|0,b|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(b);cb=b+16|0;break e}break b}if(ue(b,10511)){b=cb-16|0;cb=b;Zq(b,3);v[22440]=0;R(1033,a|0,b|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(b);cb=b+16|0;break e}break b}Db(a)}cb=g+32|0;break c}a=P()|0;O()|0;rb(b);break a}return}a=P()|0;O()|0;rb(b)}S(a|0);L()}function raa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;f=cb-48|0;cb=f;b=v[a+1074308>>2];if(!(b>>>0>18285125|(b|0)==18284544)){Vf(a+1074312|0,0)}h=a+1074312|0;ub(f+32|0,h,0);if(tb(v[v[f+32>>2]>>2],v[f+36>>2])){o=(v[a+480180>>2]&16777248)!=0}ub(f+32|0,h,0);if(tb(v[v[f+32>>2]>>2],v[f+36>>2])){C=v[a+480180>>2]==4}a:{i=a+1074308|0;b=v[i>>2];if(b>>>0>18874367){break a}c=a+480192|0;g=a+480180|0;d=1;while(1){b:{e=d&65535;if(e>>>0<=x[c>>1]){e=v[((e<<2)+a|0)+900380>>2];if(!e){break b}v[f+32>>2]=B(w[e+20|0],100)>>>6;v[f+16>>2]=100;E=e,F=v[Bb(f+32|0,f+16|0)>>2],t[E+20|0]=F;c:{d:{e:{if(o){if(b>>>0>18350079){break b}j=t[e+26|0];t[e+26|0]=((j>>31|1)+j|0)/2;if(b>>>0<18285314){break e}break d}b=t[e+26|0];t[e+26|0]=((b>>31|1)+b|0)/2}IA(Bh(e,2),v[g>>2]);b=v[a+1074308>>2];if(b>>>0<18284544){break c}if(b>>>0>18285135){break b}if(!w[e+34|0]){break c}if(!sj(w[e+31|0])){break c}Gb(h,2,1);b=v[i>>2]}if(b>>>0>18285135){break b}}if(!(w[e+24|0]|(w[e+23|0]|(w[e+19|0]|w[e+20|0])))){break b}Gb(h,1,1)}f:{if(!(v[a+480180>>2]&16777248)|y[i>>2]>18285313&o){break f}e=x[a+480190>>1];c=1;while(1){b=c&65535;if(b>>>0>e>>>0){break f}b=B(b,104)+a|0;d=b+484419|0;if(!(w[d|0]|!(w[b+484421|0]|w[b+484420|0]))){t[d|0]=255}c=c+1|0;continue}}e=a+901404|0;g=oz(e);while(1){if((e|0)!=(g|0)){b=e;j=Pp(b);while(1){if((b|0)!=(j|0)){c=w[b|0];g:{h:{if((c-97&255)>>>0<=5){d=c-32|0;break h}if(!(c-88>>>0<2|c-120>>>0<2)){d=99;if((c|0)==75|(c|0)==107){break h}break g}d=122}t[b|0]=d}b=b+1|0;continue}break}e=e+32|0;continue}break}b=v[a+1074308>>2];break a}d=d+1|0;continue}}i:{j:{k:{if((b|0)==18874368|b>>>0>18874895){break k}if(!(v[a+480180>>2]&16777252)){break j}e=0;g=x[a+480192>>1];c=1;while(1){d=c&65535;if(d>>>0>g>>>0){if(!e){break k}Gb(h,3,1);b=v[i>>2]}else{d=v[((d<<2)+a|0)+900380>>2];if(!(!d|!w[d+31|0])){t[d+33|0]=13;e=1}c=c+1|0;continue}break}}if((b|0)==19005440|b>>>0>19006225){break i}}if(!(v[a+480180>>2]&16777248)){break i}ub(f+32|0,h,0);if(!tb(v[v[f+32>>2]>>2],v[f+36>>2])){ub(f+16|0,h,1);if(!tb(v[v[f+16>>2]>>2],v[f+20>>2])){break i}}e=x[a+480192>>1];c=1;while(1){b=c&65535;if(b>>>0>e>>>0){break i}b=v[((b<<2)+a|0)+900380>>2];if(!(!b|!w[b+19|0]|!(t[b+80|0]&1))){t[b+19|0]=0}c=c+1|0;continue}}l:{m:{n:{o:{p:{if(y[i>>2]>19007232){break p}b=a+946300|0;c=a+906300|0;while(1){if((b|0)==(c|0)){break p}e=f+16|0;d=c+80|0;CL(e,d);v[22440]=0;W(241,f+32|0,0,8,e|0);e=v[22440];v[22440]=0;if((e|0)==1){break o}rb(f+16|0);e=f+32|0;ou(d,e);c=c+160|0;rb(e);continue}}q:{r:{s:{if(v[a+480180>>2]!=4){break s}e=v[i>>2];if(e>>>0<19007257){break q}if(e>>>0>19071235){break r}if(w[a+1074368|0]!=4){break s}ly(a,5)}e=v[i>>2]}if(e>>>0>19202054){break n}b=19202048;if((e|0)==19202048){break m}}g=x[a+480192>>1];d=1;while(1){b=d&65535;if(b>>>0>g>>>0){break n}b=v[((b<<2)+a|0)+900380>>2];t:{if(!b|!w[b+20|0]|!w[b+31|0]){break t}c=b+236|0;j=et(c);while(1){if((c|0)!=(j|0)){k=x[c>>1];c=c+2|0;if(!k){continue}break t}break}t[b+20|0]=0}d=d+1|0;continue}}a=P()|0;O()|0;rb(f+16|0);S(a|0);L()}b=e;if(b>>>0>19267583){break l}}d=x[a+480192>>1];g=b>>>0>18350079;c=1;while(1){e=c&65535;if(e>>>0>d>>>0){break l}e=v[((e<<2)+a|0)+900380>>2];u:{if(!e){break u}j=t[e+26|0];t[e+26|0]=((j>>31|1)+j|0)/2;if(g&o){break u}t[e+19|0]=w[e+19|0]+3>>>2}c=c+1|0;continue}}v:{if(b>>>0>19398673){break v}e=x[a+480192>>1];c=1;while(1){d=c&65535;if(d>>>0>e>>>0){break v}d=v[((d<<2)+a|0)+900380>>2];if(!d|w[d+65|0]==255){c=c+1|0;continue}else{Gb(h,94,1);b=v[i>>2]}break}}w:{if(b>>>0>19399427){break w}e=x[a+480192>>1];c=1;while(1){d=c&65535;if(d>>>0>e>>>0){break w}d=v[((d<<2)+a|0)+900380>>2];if(!d|w[d+36|0]>1){c=c+1|0;continue}else{Gb(h,101,1);b=v[i>>2]}break}}x:{if(b>>>0>19923027){break x}b=x[a+480190>>1];c=1;while(1){e=c&65535;if(e>>>0>b>>>0){break x}e=B(e,104)+a|0;if(!Sd(e+484380|0)|!(w[e+484414|0]&20)){c=c+1|0;continue}else{Gb(h,116,1)}break}}b=cb-16|0;cb=b;u[f+12>>1]=0;v[f+8>>2]=a;ub(b+8|0,a+1074312|0,0);E=f,F=tb(v[v[b+8>>2]>>2],v[b+12>>2]),t[E+14|0]=F;cb=b+16|0;b=v[f+12>>2];v[f>>2]=v[f+8>>2];v[f+4>>2]=b;j=cb-16|0;cb=j;p=a+484344|0;c=Cf(p);b=v[f+4>>2];e=v[f>>2];v[j>>2]=e;v[j+4>>2]=b;v[j+8>>2]=e;v[j+12>>2]=b;e=cb-32|0;cb=e;z=c-1&65535;y:{if(Cf(p)>>>0>z>>>0){q=v[j>>2];r=v[j+4>>2];while(1){b=A&65535;if(b>>>0>z>>>0){v[f+32>>2]=q;v[f+36>>2]=r;break y}c=fg(v[p>>2],b);if(Vh(c)){d=Pg(c);D=Og(fg(v[p>>2],b));v[e+24>>2]=q;v[e+28>>2]=r;v[e+8>>2]=q;v[e+12>>2]=r;k=cb-16|0;cb=k;v[k+8>>2]=d;while(1){if(Qb(d,D)){m=cb-16|0;cb=m;s=x[e+12>>1];b=s+1|0;u[e+12>>1]=b;g=v[e+8>>2];u[e+12>>1]=x[g+480188>>1]>(b&65535)>>>0?b:0;z:{if(eh(w[d|0])){break z}c=v[g+1074308>>2];A:{n=v[g+480180>>2];B:{C:{if((n|0)==2){if(c>>>0>18415615){break C}if(w[d+3|0]!=23){break B}yf(d+5|0,64);break B}if(n&16777248){D:{E:{if(c>>>0>=18285314){if(w[e+14|0]){break E}g=0;b=0;if(c>>>0>18874367){break D}}F:{switch(w[d+3|0]-20|0){case 3:yf(d+5|0,128);break E;case 0:break F;default:break E}}b=w[d+5|0];if((b|0)!=208){if((b|0)!=192){break E}t[d|0]=254;t[d+3|0]=0;break E}t[d+3|0]=0}G:{H:{I:{if(c>>>0>=18350080){if(w[e+14|0]){break I}g=0;b=0;if(c>>>0>18874367){break D}}b=w[d+3|0];if(b>>>0>29){break H}g=1;if(!(1<<b&536873152)){break H}break G}g=0;b=0;if(c>>>0>18874367){break D}b=w[d+3|0]}g=0}b=(b|0)==24|(b|0)==22}J:{if(!(b?1:g)){break J}g=w[d+5|0];b=g&15;if(!b|(b|0)==15){break J}g=g&240;if(!g|(g|0)==240){break J}t[d+5|0]=w[d+3|0]==24?g:b}K:{if((c|0)==19005440|c>>>0>19005699){break K}b=x[v[e+8>>2]+480192>>1];if(w[e+14|0]|(!b|b>>>0>=w[d+1|0])){break K}t[d+4|0]=0;t[d+2|0]=1}if(w[d+3|0]!=18|w[d+5|0]!=17){break C}if(c>>>0>19468801){break A}ub(m+8|0,v[e+8>>2]+1074312|0,22);if(!tb(v[v[m+8>>2]>>2],v[m+12>>2])|v[v[e+8>>2]+480208>>2]&4){break C}t[d+5|0]=0;break C}if((n|0)!=4){break C}L:{M:{N:{O:{P:{Q:{if(c>>>0<18285314){break Q}b=w[e+14|0];if(!(!b&c>>>0<18874368|c>>>0>19137025|w[d+3|0]!=23|w[d+5|0]<65)){t[d+3|0]=0}if(c>>>0<18415616){break Q}if(b|c>>>0>18874367){break P}}g=w[d+3|0];b=w[d+2|0];if((g|0)!=10|(b|0)!=11){break O}g=0;t[d+3|0]=0;break L}if(c>>>0>18874639){break N}g=w[d+3|0];b=w[d+2|0]}if((b|0)!=11|(g|0)!=4){break L}b=w[d+4|0];if(!(w[e+14|0]?1:b)){break M}l=w[d+5|0];if(!l){break M}t[d+2|0]=0;g=4;E=d,F=au(l+(b<<4)|0),t[E+5|0]=F;break L}if(c>>>0>19007240){break A}g=w[d+3|0];break L}g=4}if(w[d+5|0]|(g|0)!=16){break C}t[d+3|0]=0}if(c>>>0>18874367){break A}}g=w[d+3|0];l=w[d+5|0]&240;R:{S:{if((g|0)!=28|(l|0)!=96){b=0}else{if(!w[e+14|0]|(n|0)!=4){break S}b=c>>>0<18350080}if(!(b|(g|0)==20&(l|0)==96)){break R}}b=B(s,-6)+d|0;while(1){if(b>>>0<d>>>0){if(!((w[b+3|0]|8)!=28|(w[b+5|0]&240)!=96)){t[b+3|0]=0}b=b+6|0;continue}break}g=w[d+3|0]}if((g|0)!=20|(l|0)!=224){break A}b=B(s,-6)+d|0;while(1){if(b>>>0>=d>>>0){break A}if(!(w[b+3|0]!=20|(w[b+5|0]&240)!=224)){t[b+3|0]=0}b=b+6|0;continue}}b=w[d+2|0];if(!((b|0)!=8|c>>>0>19333174|(c|0)==19333120)){c=w[d+4|0];b=w[d+3|0];if(!(!c|(b|0)!=7)){t[d+3|0]=11;break z}T:{U:{switch(b-5|0){default:if((b|0)!=26){break z}break;case 2:break T;case 0:break U;case 1:break z}}g=w[d+5|0];if(!(g&15)){t[d+2|0]=0;t[d+3|0]=5;t[d+5|0]=g|c&15;break z}V:{switch(b-5|0){case 0:case 2:break T;case 1:break z;default:break V}}if((b|0)!=26){break z}}t[d+2|0]=0;break z}if(!(w[d+3|0]|((n|0)==16777216|(b|0)!=15))){t[d+2|0]=0;t[d+3|0]=10;t[d+5|0]=w[d+4|0]<<3;break z}if(w[d+3|0]!=10|c>>>0>19922963|(b|0)!=15){break z}if(w[d+4|0]?w[d+5|0]:1){t[d+2|0]=0;break z}t[d+3|0]=0}cb=m+16|0;Ki(k+8|0);d=v[k+8>>2];continue}break}b=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=b;cb=k+16|0}A=A+1|0;continue}}b=v[j+4>>2];v[f+32>>2]=v[j>>2];v[f+36>>2]=b}cb=e+32|0;cb=j+16|0;W:{if(!(!o|y[i>>2]>19267583)){c=41984;while(1){if((c|0)==42328){break W}b=v[i>>2];e=v[c+4>>2];Gb(h,v[c>>2],b>>>0>=e>>>0|(b|0)==(e&-65536));c=c+8|0;continue}}if(!C|y[i>>2]>19267583){break W}c=42336;while(1){if((c|0)==42576){break W}Gb(h,v[c>>2],y[i>>2]>=y[c+4>>2]);c=c+8|0;continue}}X:{Y:{b=v[a+480180>>2];if(b&16777248){c=42576;while(1){if((c|0)==42632){break Y}b=v[i>>2];e=v[c+4>>2];d=e&-65536;if(!(b>>>0>=d>>>0&(b>>>0<=d>>>0|b>>>0>=e>>>0))){Vf(h,v[c>>2])}c=c+8|0;continue}}c=42704;d=42640;Z:{switch(b-2|0){case 2:while(1){if((d|0)==42704){break Y}if(y[i>>2]<y[d+4>>2]){Vf(h,v[d>>2])}d=d+8|0;continue};case 0:break Z;default:break X}}while(1){if((c|0)==42792){break Y}if(y[i>>2]<y[c+4>>2]){Vf(h,v[c>>2])}c=c+8|0;continue}}b=v[a+480180>>2]}_:{if((b|0)==4){c=v[i>>2];if(c>>>0>18415615){break _}Gb(h,98,1)}c=v[i>>2]}d=8;if(c-19333159>>>0<=33){c=0;while(1){if((c|0)!=5){b=c+77|0;ub(f+32|0,h,b);Vf(Gb(h,c+86|0,tb(v[v[f+32>>2]>>2],v[f+36>>2])),b);c=c+1|0;continue}break}c=v[i>>2]}$:{if(c>>>0>=18284544){if(c>>>0>18874627){break $}d=6;if((c|0)==18874368){break $}}Gb(h,d,1)}b=v[a+1074308>>2];aa:{if(w[a+480208|0]&16){if(b>>>0<=19136511){Vf(h,7);break aa}if(!(v[a+480180>>2]&16777248)|b>>>0>19267583){break aa}Gb(h,7,1);break aa}if((b|0)==19922944|b>>>0>19922997){break aa}Vf(h,7)}ub(f+32|0,h,31);ba:{if(!tb(v[v[f+32>>2]>>2],v[f+36>>2])){break ba}b=v[i>>2];if(b>>>0<19071234|b>>>0>19398722){break ba}e=x[a+480192>>1];c=1;while(1){b=c&65535;if(b>>>0>e>>>0){break ba}ca:{b=v[((b<<2)+a|0)+900380>>2];if(!b){break ca}d=w[b+65|0];if(!(w[b+60|0]&4)|(d|0)==255|d>>>0<=w[b- -64|0]){break ca}Gb(h,97,1);break ba}c=c+1|0;continue}}b=v[a+480180>>2];da:{if(!(b&16777218)){break da}e=x[a+480190>>1];c=1;while(1){d=c&65535;if(d>>>0>e>>>0){break da}c=c+1|0;if(!(w[(B(d,104)+a|0)+484415|0]&2)){continue}break}ea:{fa:{ga:{if(!(!x[a+480192>>1]|(b|0)!=16777216)){c=v[i>>2];if(c>>>0<19398688){break fa}if(c>>>0>19464277){break ga}Gb(h,109,1)}c=v[i>>2]}if((c|0)==19922944|c>>>0>19922996){break ea}}Vf(h,111)}if(v[a+480180>>2]==2){if(y[i>>2]>19464191){break da}Gb(h,108,1);break da}Vf(h,108)}ha:{if(!(v[a+480180>>2]&16777252)|v[i>>2]-19333186>>>0>589827){break ha}b=a+946300|0;c=a+906300|0;while(1){if((b|0)==(c|0)){break ha}ia:{if((w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24))!=1146637647|(w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24))!=-271958638){break ia}if((Uc(v[c+4>>2],v[c+8>>2])|0)!=32){break ia}a=Bc(f+32|0,16883);ou(c+80|0,a);rb(a)}c=c+160|0;continue}}cb=f+48|0}function hV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=cb-272|0;cb=e;sc(b);if(yq(b,17858)){p=Db(e+256|0);v[22440]=0;f=Q(236,b|0,p|0)|0;g=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{if((g|0)!=1){if(!f){break a}v[22440]=0;f=Q(251,b|0,e+248|0)|0;g=v[22440];v[22440]=0;g:{if((g|0)==1){break g}if(!f){break a}if(!QB(e+248|0)){break a}f=wc(PB(e+248|0),fb);v[22440]=0;f=Q(158,b|0,f|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break g}if(!f){break a}if(!c){break b}v[22440]=0;R(252,a|0,4096);d=v[22440];v[22440]=0;if((d|0)==1){break g}v[22440]=0;R(253,a+1298308|0,p|0);d=v[22440];v[22440]=0;if((d|0)==1){break g}d=w[e+248|2];u[a+480188>>1]=32;u[a+480192>>1]=d;mh(a,1);v[22440]=0;d=Q(1,e+96|0,9505)|0;f=v[22440];v[22440]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{if((f|0)!=1){Cb(a+1298344|0,d);rb(d);v[22440]=0;d=Q(1,e+96|0,7053)|0;f=v[22440];v[22440]=0;if((f|0)==1){break p}Cb(a+1298356|0,d);rb(d);v[22440]=0;Z(254,e+48|0);d=v[22440];v[22440]=0;if((d|0)==1){break o}t[e+216|0]=w[e+248|1];d=w[e+248|0];v[22440]=0;t[e+8|0]=d;R(255,e+232|0,e+8|0);d=v[22440];v[22440]=0;if((d|0)==1){break n}v[22440]=0;W(256,e+96|0,e+48|0,e+216|0,e+232|0);d=v[22440];v[22440]=0;if((d|0)==1){break m}d=e+96|0;Cb(a+1298368|0,d);rb(d);rb(e+232|0);Ab(e+48|0);v[a+1298404>>2]=5;if(w[e+248|0]<2){break i}u[e+96>>1]=8192;v[22440]=0;d=T(196,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break k}u[e+48>>1]=d;s=a,y=B(x[ie(e+96|0,e+48|0)>>1],1e4)>>>8|0,v[s+480204>>2]=y;v[22440]=0;t[e+96|0]=1;d=T(208,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break j}t[e+48|0]=d;s=a,y=w[ff(e+96|0,e+48|0)|0],v[s+480196>>2]=y;v[22440]=0;Q(190,b|0,3)|0;d=v[22440];v[22440]=0;if((d|0)!=1){v[22440]=0;d=T(196,b|0)|0;f=v[22440];v[22440]=0;if((f|0)!=1){break h}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break l}b=P()|0;O()|0;rb(e+232|0)}Ab(e+48|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}t[e+96|0]=32;v[22440]=0;d=T(208,b|0)|0;f=v[22440];v[22440]=0;q:{if((f|0)!=1){t[e+48|0]=d;s=a,y=B(w[ff(e+96|0,e+48|0)|0],1e4),v[s+480204>>2]=y;v[22440]=0;t[e+96|0]=1;d=T(208,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break q}t[e+48|0]=d;s=a,y=w[ff(e+96|0,e+48|0)|0],v[s+480196>>2]=y;v[22440]=0;d=T(208,b|0)|0;f=v[22440];v[22440]=0;if((f|0)!=1){break h}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}v[a+480208>>2]=d>>>2&16|12;n=Rb(e+232|0);i=e+72|1;q=e+96|12;o=Rb(e+216|0);j=a+480190|0;h=1;while(1){r:{s:{d=h&65535;if(d>>>0>x[a+480192>>1]){break s}v[22440]=0;f=Y(257,a|0,d|0,0)|0;d=v[22440];v[22440]=0;t:{if((d|0)==1){break t}if(!f){break s}v[22440]=0;d=Q(246,b|0,f+492|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break t}if(!d){break s}v[22440]=0;m=T(208,b|0)|0;d=v[22440];v[22440]=0;u:{v:{w:{if((d|0)!=1){Hb(e+96|0,0,120);if(!m){break r}x:{if(w[e+248|0]){v[22440]=0;d=Q(258,b|0,e+96|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break w}if(!d){break r}if(w[e+248|0]){break x}}$b(e+88|0,q,96);v[22440]=0;W(167,e+48|0,b|0,v[e+88>>2],v[e+92>>2]);d=v[22440];v[22440]=0;if((d|0)==1){break v}if(!v[e+52>>2]){break r}}g=f+236|0;d=0;break u}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}while(1){if((d|0)!=120){s=Xb(g,d),y=(w[(e+96|0)+d|0]+x[j>>1]|0)+1|0,u[s>>1]=y;d=d+1|0;continue}break}v[22440]=0;d=f+48|0;U(259,e+8|0,d|0,b|0);g=v[22440];v[22440]=0;if((g|0)==1){break e}v[22440]=0;g=f+68|0;U(259,e+32|0,g|0,b|0);l=v[22440];v[22440]=0;if((l|0)==1){break e}v[22440]=0;l=f+88|0;U(259,e+80|0,l|0,b|0);k=v[22440];v[22440]=0;if((k|0)==1){break e}v[22440]=0;R(260,b|0,e+72|0);k=v[22440];v[22440]=0;if((k|0)==1){break f}v[f>>2]=(w[i|0]|w[i+1|0]<<8)&4095;r=w[i|0]|w[i+1|0]<<8;k=e+72|0;vu(k,d,0);vu(k,g,1);vu(k,l,2);s=e,y=yb(v[d>>2]),v[s+48>>2]=y;k=r>>>12&3;r=yb(v[f+52>>2]);while(1){d=v[e+48>>2];if(Qb(d,r)){t[e+44|0]=64;t[e+70|0]=((w[d+2|0]<<6)- -64>>>0)/127;s=d,y=w[Tb(e+44|0,e+70|0)|0],t[s+2|0]=y;Ge(e+48|0);continue}else{s=e,y=yb(v[g>>2]),v[s+48>>2]=y;d=yb(v[f+72>>2])}break}while(1){g=v[e+48>>2];if(Qb(g,d)){t[e+44|0]=64;t[e+70|0]=((w[g+2|0]<<6)+128>>>0)/255;s=g,y=w[Tb(e+44|0,e+70|0)|0],t[s+2|0]=y;Ge(e+48|0);continue}break}s=e,y=yb(v[l>>2]),v[s+48>>2]=y;l=1<<k;k=yb(v[f+92>>2]);while(1){d=v[e+48>>2];if(Qb(d,k)){g=d;d=t[d+2|0];d=kka(d^-128,d>>31^-1,l,0);f=fb;y:{if((f|0)>=-1&d>>>0>=4294967292|(f|0)>=0){d=d+4|0;f=d>>>0<4?f+1|0:f;d=((f&7)<<29|d>>>3)&536870911;f=0;break y}f=0-((d>>>0>3)+f|0)|0;d=3-d|0;f=((f&7)<<29|d>>>3)&536870911;d=0-f|0;f=0-((f|0)!=0)|0}s=g,y=yc(d,f)^128,t[s+2|0]=y;Ge(e+48|0);continue}else{f=x[j>>1]+1|0;u[e+70>>1]=f;d=0;f=f&65535;g=4e3-f|0;g=g>>>0>4e3?0:g;z:{A:{B:{while(1){if((d|0)==(m|0)){break A}if((d|0)==(g|0)){v[22440]=0;Q(190,b|0,20)|0;d=v[22440];v[22440]=0;if((d|0)!=1){break A}b=P()|0;O()|0;break d}v[22440]=0;l=d+f|0;Q(246,b|0,((l<<5)+a|0)+946304|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break z}v[22440]=0;R(261,b|0,e+48|0);k=v[22440];v[22440]=0;C:{if((k|0)==1){break C}v[22440]=0;R(262,e+48|0,(B(l,104)+a|0)+484380|0);l=v[22440];v[22440]=0;if((l|0)==1){break C}l=w[e+72|0];k=w[e+67|0];v[22440]=0;u[e+44>>1]=l|d<<8&32512|((k&3)!=0)<<15;R(263,o|0,e+44|0);l=v[22440];v[22440]=0;if((l|0)==1){break B}d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[22440]=0;R(263,n|0,e+70|0);d=v[22440];v[22440]=0;if((d|0)!=1){v[e+48>>2]=3999;v[e+44>>2]=m+x[j>>1];s=j,y=v[ld(e+48|0,e+44|0)>>2],u[s>>1]=y;break r}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}}}b=P()|0;O()|0;break d}d=Db(e+96|0);v[22440]=0;f=Q(236,b|0,d|0)|0;g=v[22440];v[22440]=0;D:{E:{F:{G:{H:{if((g|0)!=1){I:{if(f){v[22440]=0;U(11,e+48|0,7,d|0);f=v[22440];v[22440]=0;if((f|0)==1){break I}f=e+48|0;Cb(a+1298320|0,f);rb(f)}rb(d);d=0;J:{while(1){if((d|0)==32){v[22440]=0;d=Q(264,b|0,e+32|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break G}if(!d){break F}d=w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24);if(d>>>0<12){break H}v[22440]=0;d=Q(158,b|0,d-11|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break G}if(d){break J}break H}f=(d<<5)+a|0;$e(f+480280|0);v[22440]=0;R(237,b|0,f+480289|0);f=v[22440];v[22440]=0;if((f|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}v[e+80>>2]=(w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24))-11;i=Rb(e+96|0);v[22440]=0;U(240,b|0,i|0,v[e+80>>2]);d=v[22440];v[22440]=0;K:{if((d|0)!=1){v[e+48>>2]=50529027;d=e+48|0;s=e,y=B(v[Bb(e+80|0,d)>>2],85),v[s+72>>2]=y;g=Db(d);d=e+32|4;v[e+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=v[Bb(e+72|0,e+8|0)>>2];v[22440]=0;R(47,g|0,d|0);d=v[22440];v[22440]=0;L:{if((d|0)==1){break L}d=0;M:{while(1){f=v[e+80>>2];if(f>>>0<=d>>>0){break M}j=v[i>>2];h=w[Eb(j,d)|0];q=f;f=d+1|0;if(!((h|0)!=255|q-f>>>0<2)){f=t[Eb(j,f)|0];j=w[Eb(j,d+2|0)|0];s=e,y=gf(g),v[s+8>>2]=y;kj(e+24|0,e+8|0);v[22440]=0;W(243,g|0,v[e+24>>2],j|0,f|0);f=v[22440];v[22440]=0;if((f|0)!=1){d=d+3|0;continue}break L}v[22440]=0;R(48,g|0,h<<24>>24);j=v[22440];v[22440]=0;d=f;if((j|0)!=1){continue}break}break L}v[22440]=0;W(241,e+8|0,5,7,g|0);d=v[22440];v[22440]=0;if((d|0)!=1){N:{f=e+8|0;d=tc(g,f);rb(f);f=Fb(d);j=vb(d);v[22440]=0;ga(242,a+1298332|0,f|0,j|0,74,0);f=v[22440];v[22440]=0;if((f|0)==1){break N}rb(d);_b(i);break H}}}b=P()|0;O()|0;rb(g);break K}b=P()|0;O()|0}_b(i);break d}}b=P()|0;O()|0;rb(d);break d}d=Nb(a+484360|0);f=e+248|5;f=w[f|0]|w[f+1|0]<<8;v[22440]=0;ea(244,d|0,b|0,f|0,65535,65535)|0;d=v[22440];v[22440]=0;if((d|0)==1){break G}j=c&1;if(j){d=e+248|3;d=w[d|0]|w[d+1|0]<<8;v[22440]=0;R(228,a+484344|0,d|0);d=v[22440];v[22440]=0;if((d|0)==1){break G}}f=a+484344|0;i=e+248|3;d=0;while(1){O:{if((w[i|0]|w[i+1|0]<<8)>>>0>d>>>0){v[22440]=0;g=Q(158,b|0,4)|0;h=v[22440];v[22440]=0;if((h|0)==1){break D}if(g){break O}}if(!(c&2)){break F}f=a+480190|0;d=0;while(1){c=x[f>>1];if(d>>>0>=c>>>0){d=0;g=a+480190|0;while(1){if(c>>>0<=d>>>0){break F}b=x[Xb(v[o>>2],d)>>1];f=b&255;P:{if(!f){break P}i=v[n>>2];f=f-1&65535;if(Fc(i,v[n+4>>2])>>>0<=f>>>0){break P}b=x[Xb(i,f)>>1]+(b>>>8&127)&65535;if(b>>>0>c>>>0){break P}f=B(b,104);c=(f+a|0)+484380|0;if(!Sd(c)){break P}i=a+484380|0;b=i+B(d+1|0,104)|0;f=f+i|0;u[b+34>>1]=x[b+34>>1]&65534|u[f+34>>1]&1;v[b>>2]=v[c>>2];if(!Lg(b)){break P}ic(v[b+20>>2],v[f+20>>2],Fj(v[c>>2],x[f+34>>1]))}d=d+1|0;c=x[g>>1];continue}}c=x[Xb(v[o>>2],d)>>1];if(c&255){d=d+1|0;continue}d=d+1|0;g=B(d,104)+a|0;c=Nc(e+96|0,u[g+484414>>1]&1?16:8,1,0,c<<16>>16>=0?0:6);v[22440]=0;Y(222,c|0,g+484380|0,b|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){continue}break}b=P()|0;O()|0;break d}v[22440]=0;g=T(159,b|0)|0;h=v[22440];v[22440]=0;Q:{R:{S:{T:{if((h|0)!=1){v[22440]=0;U(192,e+48|0,b|0,g|0);g=v[22440];v[22440]=0;if((g|0)==1){break T}h=e+48|0;g=cc(e+96|0,h);sb(h);if(!j){break R}v[22440]=0;h=T(208,g|0)|0;m=v[22440];v[22440]=0;if((m|0)==1){break Q}v[22440]=0;Q(190,e+96|0,1)|0;m=v[22440];v[22440]=0;if((m|0)==1){break Q}v[22440]=0;h=Y(229,f|0,d&65535,h+1|0)|0;m=v[22440];v[22440]=0;if((m|0)==1){break Q}if(!h){break R}v[22440]=0;h=Q(238,g|0,e+48|0)|0;m=v[22440];v[22440]=0;if((m|0)==1){break E}if(!h){break S}h=Sb(f,d);v[22440]=0;R(239,h|0,e+48|0);h=v[22440];v[22440]=0;if((h|0)!=1){break S}break E}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}h=Sb(f,d);v[22440]=0;U(245,h|0,1,g|0);g=v[22440];v[22440]=0;if((g|0)==1){break E}}d=d+1|0;sb(e+96|0);continue}break}break E}b=P()|0;O()|0;break d}_c(o);_c(n);break b}b=P()|0;O()|0;sb(e+96|0);break d}b=P()|0;O()|0;break d}h=h+1|0;continue}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0}_c(o);_c(n)}rb(p);S(b|0);L()}d=1}rb(p)}cb=e+272|0;return d|0}function Dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;e=cb-288|0;cb=e;sc(b);f=e+264|0;g=TB(b,f);if(!g){zu(f)}a:{b:{c:{d:{e:{if(!g){break e}if(!RT(e+264|0)){break e}if(!Kb(b,wc(72,0))){break e}if(!c){d=1;break e}ud(a,1);v[a+480208>>2]=v[a+480208>>2]&-25231361|16842752;i=w[e+273|0];u[a+480190>>1]=63;u[a+480188>>1]=i;f:{g:{while(1){if((i&65535)>>>0<=d>>>0){h:{d=1;i:{while(1){j:{f=d&65535;if(f>>>0>x[a+480190>>1]){YB(b,a+1298308|0);f=e+184|0;d=cb-16|0;cb=d;k:{if(!Kb(b,8)){t[d|0]=0;_h(f,8,d);break k}Qm(d+8|0,f);md(d,b,v[d+8>>2],v[d+12>>2])}cb=d+16|0;n=Rb(e+168|0);f=w[e+274|0]|w[e+275|0]<<8;if(!f){break i}g=w[e+273|0];d=0;v[22440]=0;f=Y(330,b|0,n|0,B(f,g)<<1)|0;g=v[22440];v[22440]=0;if((g|0)!=1){break j}a=P()|0;O()|0;break a}g=(B(f,104)+a|0)+484380|0;ed(g,1);j=f+(e+192|0)|0;f=He(b);t[j|0]=f;if(f<<24>>24>=0){A=g,C=PT(b)<<1,v[A>>2]=C}d=d+1|0;continue}break}if(!f){break f}}d=v[n>>2];Ub(e+160|0,d,Uc(d,v[n+4>>2])>>>1|0);m=Rb(e+144|0);d=w[e+276|0]|w[e+277|0]<<8;v[22440]=0;R(331,m|0,d<<8);d=v[22440];v[22440]=0;if((d|0)==1){break h}d=0;l:{m:{n:{while(1){f=d&65535;d=w[e+276|0]|w[e+277|0]<<8;if(f>>>0>=d>>>0){break m}v[e+72>>2]=d-f;v[e+96>>2]=2e3;d=e+72|0;g=v[ld(d,e+96|0)>>2];d=Rb(d);v[22440]=0;g=Y(330,b|0,d|0,g<<8)|0;i=v[22440];v[22440]=0;if((i|0)==1){break l}if(!g){break n}ac(e+136|0,yb(v[m+4>>2]));g=yb(v[e+72>>2]);i=yb(v[e+76>>2]);v[22440]=0;W(332,m|0,v[e+136>>2],g|0,i|0);g=v[22440];v[22440]=0;if((g|0)!=1){_b(d);d=f+2e3|0;continue}break}break c}_b(d);d=0;break g}qe(e+120|0,v[m>>2],v[m+4>>2]);_g(e+128|0,v[e+120>>2],v[e+124>>2]);p=a+484360|0;d=Nb(p);f=w[e+274|0]|w[e+275|0]<<8;v[22440]=0;R(333,d|0,f|0);d=v[22440];v[22440]=0;if((d|0)==1){break d}q=a+484344|0;s=c&1;while(1){if((w[e+274|0]|w[e+275|0]<<8)>>>0<=h>>>0){g=c&2;i=1;o:{p:{q:{r:{s:{t:{u:{v:{while(1){c=i&65535;if(c>>>0<=x[a+480190>>1]){v[22440]=0;d=w[c+(e+192|0)|0];U(334,b|0,((c<<5)+a|0)+946304|0,d&63);f=v[22440];v[22440]=0;if((f|0)==1){break u}w:{if(d<<24>>24<0){break w}v[22440]=0;d=T(335,b|0)|0;f=v[22440];v[22440]=0;x:{y:{z:{A:{B:{C:{D:{E:{if((f|0)==1){break E}c=B(c,104)+a|0;f=c+484392|0;v[f>>2]=d<<1;v[22440]=0;d=T(335,b|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break D}d=d<<1;if(d>>>0>=3){v[c+484396>>2]=d+v[f>>2];d=c+484414|0;u[d>>1]=x[d>>1]|8}v[22440]=0;d=T(208,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break t}t[e+72|0]=d;t[e+96|0]=64;A=c+484410|0,C=w[Tb(e+72|0,e+96|0)|0]<<2,u[A>>1]=C;v[22440]=0;d=T(208,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break E}t[c+484417|0]=d<<4;c=c+484380|0;_n(c);if(!v[c>>2]){break w}v[22440]=0;f=T(208,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break p}d=0;switch(f|0){case 4:case 5:break z;case 2:case 3:break A;case 1:break B;case 0:break C;default:break g}}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}if(!g){break x}f=Rb(e+96|0);h=v[c>>2];v[22440]=0;h=Q(158,b|0,h|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break s}if(!h){break y}d=v[c>>2];v[22440]=0;U(336,b|0,f|0,d|0);d=v[22440];v[22440]=0;if((d|0)==1){break s}A=e,C=yb(v[e+96>>2]),v[A+72>>2]=C;h=yb(v[e+100>>2]);while(1){d=v[e+72>>2];if(Qb(d,h)){j=d;d=w[d|0];t[j|0]=d<<7|(d^-1)<<24>>>25;Fe(e+72|0);continue}break}qe(e- -64|0,v[e+96>>2],v[e+100>>2]);ee(e+56|0);v[22440]=0;d=ea(337,e+72|0,v[e+64>>2],v[e+68>>2],v[e+56>>2],v[e+60>>2])|0;h=v[22440];v[22440]=0;F:{if((h|0)!=1){h=Nc(e+112|0,16,1,0,16);v[22440]=0;Y(222,h|0,c|0,d|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break F}sb(e+72|0);_b(f);break w}a=P()|0;O()|0;break o}a=P()|0;O()|0;sb(e+72|0);break o}f=Rb(e+96|0);d=v[c>>2];v[22440]=0;U(338,e+72|0,b|0,d|0);d=v[22440];v[22440]=0;G:{H:{I:{if((d|0)!=1){d=e+72|0;h=xm(f,d);_b(d);if(g){qe(e+48|0,v[e+96>>2],v[e+100>>2]);ee(e+40|0);v[22440]=0;d=ea(337,e+72|0,v[e+48>>2],v[e+52>>2],v[e+40>>2],v[e+44>>2])|0;k=v[22440];v[22440]=0;if((k|0)==1){break I}k=Nc(e+112|0,8,1,0,2);v[22440]=0;Y(222,k|0,c|0,d|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break H}sb(e+72|0)}_b(h);break w}a=V(30592)|0;if((O()|0)!=(fa(30592)|0)){break G}_(a|0)|0;d=0;v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)!=1){break v}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;sb(e+72|0)}_b(f);break b}if(g){d=Nc(e+72|0,(f|0)==2?8:16,1,0,0);v[22440]=0;Y(222,d|0,c|0,b|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break w}a=P()|0;O()|0;break b}c=v[c>>2];v[22440]=0;Q(190,b|0,B(c,f-1|0)|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break w}break p}h=Rb(e+96|0);d=v[c>>2];v[22440]=0;U(339,e+72|0,b|0,d|0);d=v[22440];v[22440]=0;J:{K:{L:{M:{N:{O:{if((d|0)!=1){d=e+72|0;k=xm(h,d);_b(d);if(!g){break N}if((f|0)!=5){break O}A=e,C=yb(v[e+96>>2]),v[A+72>>2]=C;l=yb(v[e+100>>2]);while(1){d=v[e+72>>2];if(!Qb(d,l)){break O}j=d;d=w[d|0];t[j|0]=w[(d>>>7|0)+26465|0]^d;Fe(e+72|0);continue}}a=V(30592)|0;if((O()|0)!=(fa(30592)|0)){break J}_(a|0)|0;d=0;v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)!=1){break M}a=P()|0;O()|0;break J}qe(e+32|0,v[e+96>>2],v[e+100>>2]);ee(e+24|0);v[22440]=0;d=ea(337,e+72|0,v[e+32>>2],v[e+36>>2],v[e+24>>2],v[e+28>>2])|0;l=v[22440];v[22440]=0;if((l|0)==1){break L}f=(f|0)==5;f=Nc(e+112|0,f?16:8,1,0,f?16:1);v[22440]=0;Y(222,f|0,c|0,d|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break K}sb(e+72|0)}_b(k);break w}_b(h);break g}a=P()|0;O()|0;break J}a=P()|0;O()|0;sb(e+72|0)}_b(h);break b}_b(f);break g}c=v[c>>2];v[22440]=0;Q(190,b|0,c|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break p}}i=i+1|0;continue}break}P:{Q:{R:{S:{T:{U:{V:{d=w[e+278|0]|w[e+279|0]<<8|w[e+280|0]<<16;if(d){c=Rb(e+96|0);v[22440]=0;b=Y(330,b|0,c|0,d|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break r}if(!b){break T}qe(e+16|0,v[c>>2],v[c+4>>2]);b=ee(e+8|0);f=v[b+4>>2];b=v[b>>2];v[22440]=0;b=ea(337,e+72|0,v[e+16>>2],v[e+20>>2],b|0,f|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break V}v[22440]=0;W(340,a+1298332|0,b|0,d|0,1);d=v[22440];v[22440]=0;if((d|0)==1){break U}sb(b);_b(c)}v[22440]=0;Z(341,e+96|0);b=v[22440];v[22440]=0;if((b|0)==1){break S}v[22440]=0;U(216,e+72|0,e+96|0,e+272|0);b=v[22440];v[22440]=0;if((b|0)==1){break R}b=e+72|0;Cb(a+1298344|0,b);rb(b);Ab(e+96|0);v[22440]=0;b=Q(1,b|0,10115)|0;c=v[22440];v[22440]=0;if((c|0)==1){break Q}Cb(a+1298356|0,b);rb(b);v[22440]=0;b=Q(1,e+72|0,5104)|0;c=v[22440];v[22440]=0;if((c|0)==1){break P}Cb(a+1298368|0,b);rb(b);v[a+1298404>>2]=2;d=1;break g}a=P()|0;O()|0;break q}a=P()|0;O()|0;sb(b);break q}_b(c);d=0;break g}a=P()|0;O()|0;break b}a=P()|0;O()|0;Ab(e+96|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}_b(f);break g}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break o}a=P()|0;O()|0}_b(c);break b}a=P()|0;O()|0;break b}_b(f);break b}A=Xb(v[Nb(p)>>2],h),C=h,u[A>>1]=C;W:{X:{if(!s){break X}v[22440]=0;r=h&65535;d=Y(229,q|0,r|0,64)|0;f=v[22440];v[22440]=0;if((f|0)==1){break W}if(!d){break X}f=x[a+480188>>1];k=0;while(1){d=f&65535;if(d>>>0<=k>>>0){break X}d=Xb(v[e+160>>2],B(d,h)+k|0);d=w[d|0]|w[d+1|0]<<8;Y:{if(d>>>0>=(w[e+276|0]|w[e+277|0]<<8)>>>0){break Y}i=0;y=0-k|0;z=d<<8;d=Zc(Sb(q,h),0,k&65535);while(1){if((i|0)==64){break Y}jq(e+72|0,v[e+128>>2],v[e+132>>2],(i<<2)+z|0,4);f=v[e+72>>2];g=Eb(f,0);o=w[g|0]&63;t[d|0]=o?o+48|0:0;l=Eb(f,1);t[d+1|0]=w[l|0]<<2&60|w[g|0]>>>6;g=w[l|0];j=Eb(f,2);l=w[Eb(f,3)|0];j=w[j|0];f=l<<4|j>>>4;u[e+118>>1]=f;g=j<<2&60|g>>>6;Z:{if(!(w[Eb(e+184|0,g>>>3|0)|0]>>>(g&7)&1)|!(f?1:g)){break Z}t[d+5|0]=f;j=l>>>4|0;t[d+4|0]=j;_:{$:{switch(g|0){case 0:case 1:case 2:case 32:case 33:case 34:Ef(d,g&15,f&255);if(!w[d+4|0]){break Z}t[d+2|0]=g>>>0<32?3:4;break Z;case 3:case 4:case 5:case 6:case 7:case 12:Ef(d,g,f&255);break Z;case 9:t[d+3|0]=10;t[d+5|0]=f>>>1;if(f>>>0<512){break Z}t[d+2|0]=15;t[d+4|0]=l>>>5;break Z;case 10:case 42:if(f>>>0<=254){Ef(d,g&15,f&255);break Z}t[d+3|0]=19;t[d+5|0]=j|(g>>>0<32?16:32);if(l&15){t[d+2|0]=3;t[d+4|0]=(f&240)>>>4;break Z}t[d+2|0]=4;t[d+4|0]=f&15;break Z;case 11:case 15:t[d+3|0]=(g|0)==11?12:16;A=d,C=au(f),t[A+5|0]=C;break Z;case 13:t[d+3|0]=14;if((f&255)>>>0<64){break Z}t[d+5|0]=0;break Z;case 16:case 19:case 20:case 21:case 23:case 31:t[d+3|0]=19;t[d+5|0]=f&15|g<<4;break Z;case 22:case 25:case 28:case 29:case 30:t[d+3|0]=19;u[e+96>>1]=15;A=d,C=w[Kc(e+118|0,e+96|0)|0]|g<<4,t[A+5|0]=C;break Z;case 17:case 18:case 26:case 27:t[d+3|0]=19;if(f&255){t[d+5|0]=f&15|((g|0)==17?16:(g|0)==26?16:32);if(!(l&240)){break Z}t[d+2|0]=g>>>0>25?6:5;break Z}t[d+5|0]=j|(g>>>0>25?-80:-96);break Z;case 47:if(!f){break _}t[d+3|0]=17;v[e+96>>2]=8;v[e+112>>2]=f+4;A=d,C=rg(v[Ke(e+96|0,e+112|0)>>2]/8|0),t[A+5|0]=C;break Z;case 43:t[d+3|0]=14;l=B(y,6)+d|0;o=x[a+480188>>1];f=0;while(1){if((f|0)==(o|0)){break Z}g=l+B(f,6)|0;if(!w[g+3|0]){t[g+3|0]=12;A=g,C=au(r),t[A+5|0]=C}f=f+1|0;continue};case 48:t[d+3|0]=9;g=f&7;if(g){t[d+5|0]=w[g+26457|0];break Z}g=f>>>4|0;if((g|0)==128){break _}t[d+5|0]=g;if(!(f&2048)){t[d+5|0]=g^128;break Z}t[d+5|0]=g^-1;break Z;case 50:break $;default:break _}}t[d+5|0]=0;t[d+3|0]=0;if(!o){t[d|0]=255;break Z}t[d+3|0]=25;break Z}t[d+3|0]=0}i=i+1|0;f=x[a+480188>>1];d=B(f,6)+d|0;continue}}k=k+1|0;continue}}h=h+1|0;continue}break}a=P()|0;O()|0;break b}break c}}else{fB(a,d&65535);u[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;i=x[a+480188>>1];continue}break}a=P()|0;O()|0;break b}_b(m)}_b(n)}cb=e+288|0;return d|0}a=P()|0;O()|0;break b}a=P()|0;O()|0;_b(d)}_b(m)}_b(n);S(a|0);L()}function z4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=cb-32|0;cb=g;d=Bc(g+16|0,11636);h=dh(c,d);rb(d);a:{b:{c:{d:{e:{if(h){_k(a,v[b+24>>2]+1298356|0);break e}d=Bc(g+16|0,10974);h=dh(c,d);rb(d);if(h){_k(a,v[b+24>>2]+1298344|0);break e}d=Bc(g+16|0,11466);h=dh(c,d);rb(d);if(h){_k(a,v[b+24>>2]+1298392|0);break e}d=Bc(g+16|0,10966);h=dh(c,d);rb(d);if(h){_k(a,v[b+24>>2]+1298380|0);break e}d=Bc(g+16|0,8272);h=dh(c,d);rb(d);if(h){c=g+16|0;d=v[v[b+24>>2]+480184>>2];b=32736;f:{while(1){if((b|0)!=32784){if((d|0)==v[b>>2]){Wm(c,0,v[b+8>>2]);break f}else{b=b+12|0;continue}}break}Db(c)}v[22440]=0;R(1033,a|0,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break d}rb(g+16|0);break e}d=Bc(g+16|0,10951);h=dh(c,d);rb(d);if(h){f=v[v[b+24>>2]+480184>>2];c=cb-48|0;cb=c;b=32736;e=Jg(c+32|0);j=g+16|0;d=Db(j);while(1){if((b|0)!=32784){if((f|0)==v[b>>2]){h=v[b+4>>2];v[22440]=0;h=Q(1,c+16|0,h|0)|0;i=v[22440];v[22440]=0;g:{h:{i:{j:{k:{l:{if((i|0)!=1){v[22440]=0;U(869,c|0,e|0,h|0);i=v[22440];v[22440]=0;if((i|0)==1){break j}if(!w[c+4|0]){break g}if(!xd(d)){v[22440]=0;i=Q(1,c|0,17803)|0;k=v[22440];v[22440]=0;if((k|0)==1){break l}v[22440]=0;Q(100,d|0,i|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break k}rb(i)}v[22440]=0;Q(100,d|0,h|0)|0;i=v[22440];v[22440]=0;if((i|0)!=1){break g}b=P()|0;O()|0;break i}b=P()|0;O()|0;break h}b=P()|0;O()|0;break i}b=P()|0;O()|0;rb(i);break i}b=P()|0;O()|0}rb(h)}rb(d);fL(e);S(b|0);L()}rb(h)}b=b+12|0;continue}break}fL(e);cb=c+48|0;v[22440]=0;R(1033,a|0,j|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(g+16|0);break e}c=P()|0;O()|0;rb(g+16|0);break a}d=Bc(g+16|0,8338);h=dh(c,d);rb(d);if(h){_k(a,v[b+24>>2]+1298368|0);break e}d=Bc(g+16|0,5623);h=dh(c,d);rb(d);if(h){_k(a,v[b+24>>2]+1298320|0);break e}d=Bc(g+16|0,12040);h=dh(c,d);rb(d);if(h){c=g+16|0;qf(c,v[b+24>>2]+1298308|0);v[22440]=0;U(1027,a|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(g+16|0);break e}c=P()|0;O()|0;rb(g+16|0);break a}d=Bc(g+16|0,11409);h=dh(c,d);rb(d);if(h){m:{b=b+24|0;c=Ww(v[b>>2]);if(!hc(v[c>>2],v[c+4>>2])){if(OC(v[XH(v[Ww(v[b>>2])+4>>2])+12>>2])){break m}}Db(a);break e}o=g+16|0;b=XH(v[Ww(v[b>>2])+4>>2]);j=cb-144|0;cb=j;ic(j+96|0,b,44);e=v[b+44>>2];if(e){ic(j+44|0,b,44);h=cb-16|0;cb=h;b=Tw(v[j+64>>2]+1900|0,v[j+60>>2]+1|0,v[j+56>>2])-Tw(1970,1,1)|0;b=kka(b,b>>31,86400,0);c=B(v[j+52>>2],3600);b=b+c|0;d=fb+(c>>31)|0;d=b>>>0<c>>>0?d+1|0:d;c=B(v[j+48>>2],60);i=c;b=c+b|0;c=(c>>31)+d|0;c=b>>>0<i>>>0?c+1|0:c;d=v[j+44>>2];i=d;b=d+b|0;d=(d>>31)+c|0;c=Zl(h+8|0,b,b>>>0<i>>>0?d+1|0:d);b=v[c>>2];i=v[c+4>>2];cb=h+16|0;h=j+88|0;d=2147483647;m=ne(+(e>>>0)/18.2);c=-1;n:{if(m>=0x8000000000000000){break n}d=-2147483648;c=0;if(m<=-0x8000000000000000){break n}if(D(m)<0x8000000000000000){d=D(m)>=1?~~(m>0?F(H(m*2.3283064365386963e-10),4294967295):I((m-+(~~m>>>0>>>0))*2.3283064365386963e-10))>>>0:0;c=~~m>>>0;break n}c=0}d=d+i|0;c=b+c|0;d=c>>>0<b>>>0?d+1|0:d;b=Zl(h,c,d);i=v[b+4>>2];h=v[b>>2];k=cb-16|0;cb=k;v[k+12>>2]=0;v[k+8>>2]=0;v[k+4>>2]=0;b=Tw(1970,1,1)+lka(h,i,86400,0)|0;f=b>>31;d=kka(b,f,1e4,0)+14780|0;c=fb;e=d;c=d>>>0<14780?c+1|0:c;l=lka(d,c,-14609700,-1)+b|0;d=f+fb|0;d=b>>>0>l>>>0?d+1|0:d;n=lka(e,c,365242500,0);l=n+l|0;d=fb+d|0;d=l>>>0<n>>>0?d+1|0:d;n=lka(e,c,-146097e4,-1);l=n+l|0;d=fb+d|0;d=l>>>0<n>>>0?d+1|0:d;c=lka(e,c,3652425,0);e=fb;n=e;p=l;l=kka(c,e,-365,-1);e=p+l|0;d=fb+d|0;d=e>>>0<l>>>0?d+1|0:d;if(!((d|0)>0|(d|0)>=0)){d=n-!c|0;c=c-1|0;e=kka(c,d,-365,-1)+b|0;d=f+fb|0;d=b>>>0>e>>>0?d+1|0:d;b=e;e=(c|0)/-4|0;b=b+e|0;d=(e>>31)+d|0;d=b>>>0<e>>>0?d+1|0:d;e=b;b=(c|0)/100|0;f=b;e=e+b|0;b=(b>>31)+d|0;b=e>>>0<f>>>0?b+1|0:b;d=(c|0)/-400|0;f=d;e=d+e|0;d=(d>>31)+b|0;d=e>>>0<f>>>0?d+1|0:d}f=c;b=kka(e,d,100,0)+52|0;c=fb;b=lka(b,b>>>0<52?c+1|0:c,3060,0);c=b+2|0;d=(c|0)/12|0;v[k+12>>2]=f+d;v[k+8>>2]=(c+B(d,-12)|0)+1;b=kka(b,fb,306,0)+5|0;d=fb;b=lka(b,b>>>0<5?d+1|0:d,-10,-1)+e|0;v[k+4>>2]=b+1;v[j+136>>2]=0;v[j+128>>2]=0;v[j+132>>2]=0;v[j+120>>2]=0;v[j+124>>2]=0;v[j+116>>2]=v[k+12>>2]-1900;v[j+112>>2]=v[k+8>>2]-1;b=v[k+4>>2];q=j,r=mka(lka(h,i,3600,0),fb,24),v[q+104>>2]=r;v[j+108>>2]=b;b=lka(h,i,60,0);c=fb;q=j,r=mka(b,c,60),v[q+100>>2]=r;b=kka(b,c,-60,-1)+h|0;v[j+96>>2]=b;cb=k+16|0}c=ic(j,j+96|0,44);b=cb-112|0;cb=b;h=Db(b+96|0);v[22440]=0;d=Q(1,b+80|0,13511)|0;e=v[22440];v[22440]=0;o:{p:{q:{r:{s:{if((e|0)!=1){e=v[c+20>>2];if(!e){break p}v[22440]=0;v[b+48>>2]=e+1900;R(99,b- -64|0,b+48|0);e=v[22440];v[22440]=0;if((e|0)!=1){v[22440]=0;i=Q(100,h|0,b- -64|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break s}rb(b- -64|0);f=v[c+16>>2];if(f>>>0>11){break p}v[22440]=0;e=Q(1,b+48|0,16830)|0;j=v[22440];v[22440]=0;t:{u:{v:{w:{x:{y:{if((j|0)!=1){v[22440]=0;v[b+16>>2]=f+1;R(101,b+32|0,b+16|0);f=v[22440];v[22440]=0;if((f|0)==1){break y}v[22440]=0;U(2,b- -64|0,e|0,b+32|0);f=v[22440];v[22440]=0;if((f|0)==1){break x}v[22440]=0;i=Q(100,i|0,b- -64|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break w}rb(b- -64|0);rb(b+32|0);rb(e);if(v[c+12>>2]-32>>>0>=4294967265){break t}break p}a=P()|0;O()|0;break r}a=P()|0;O()|0;break u}a=P()|0;O()|0;break v}a=P()|0;O()|0;rb(b- -64|0)}rb(b+32|0)}rb(e);break r}v[22440]=0;e=Q(1,b+48|0,16830)|0;f=v[22440];v[22440]=0;z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{if((f|0)!=1){v[22440]=0;R(101,b+32|0,c+12|0);f=v[22440];v[22440]=0;if((f|0)==1){break Y}v[22440]=0;U(2,b- -64|0,e|0,b+32|0);f=v[22440];v[22440]=0;if((f|0)==1){break X}v[22440]=0;i=Q(100,i|0,b- -64|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break W}rb(b- -64|0);rb(b+32|0);rb(e);j=v[c>>2];e=v[c+8>>2];f=v[c+4>>2];if(!(j|(e|f))|e>>>0>23|f>>>0>59){break p}v[22440]=0;e=Q(1,b- -64|0,13723)|0;f=v[22440];v[22440]=0;if((f|0)==1){break T}v[22440]=0;i=Q(100,i|0,e|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break S}rb(e);if(v[c+32>>2]>0){v[22440]=0;e=Q(1,b- -64|0,15620)|0;f=v[22440];v[22440]=0;if((f|0)==1){break R}Cb(d,e);rb(e)}v[22440]=0;R(101,b+32|0,c+8|0);e=v[22440];v[22440]=0;if((e|0)==1){break Q}v[22440]=0;e=Q(1,b+16|0,14732)|0;f=v[22440];v[22440]=0;if((f|0)==1){break P}v[22440]=0;U(2,b+48|0,b+32|0,e|0);f=v[22440];v[22440]=0;if((f|0)==1){break O}v[22440]=0;R(101,b|0,c+4|0);f=v[22440];v[22440]=0;if((f|0)==1){break N}v[22440]=0;U(2,b- -64|0,b+48|0,b|0);f=v[22440];v[22440]=0;if((f|0)==1){break M}v[22440]=0;i=Q(100,i|0,b- -64|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break L}rb(b- -64|0);rb(b);rb(b+48|0);rb(e);rb(b+32|0);if(j>>>0<62){break G}v[22440]=0;U(102,o|0,i|0,d|0);e=v[22440];v[22440]=0;if((e|0)==1){break F}break o}a=P()|0;O()|0;break r}a=P()|0;O()|0;break U}a=P()|0;O()|0;break V}a=P()|0;O()|0;rb(b- -64|0)}rb(b+32|0)}rb(e);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;rb(e);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;break H}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;break K}a=P()|0;O()|0;rb(b- -64|0)}rb(b)}rb(b+48|0)}rb(e)}rb(b+32|0);break r}v[22440]=0;e=Q(1,b+48|0,14732)|0;f=v[22440];v[22440]=0;if((f|0)==1){break E}v[22440]=0;R(101,b+32|0,c|0);f=v[22440];v[22440]=0;if((f|0)==1){break D}v[22440]=0;U(2,b- -64|0,e|0,b+32|0);f=v[22440];v[22440]=0;if((f|0)==1){break C}v[22440]=0;i=Q(100,i|0,b- -64|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break B}rb(b- -64|0);rb(b+32|0);rb(e);v[22440]=0;Q(100,i|0,d|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){break p}}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;break z}a=P()|0;O()|0;break A}a=P()|0;O()|0;rb(b- -64|0)}rb(b+32|0)}rb(e);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;break q}a=P()|0;O()|0;rb(b- -64|0)}rb(d)}rb(h);S(a|0);L()}zc(o,h)}rb(d);rb(h);cb=b+112|0;cb=c+144|0;v[22440]=0;R(1033,a|0,o|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(g+16|0);break e}c=P()|0;O()|0;rb(g+16|0);break a}d=Bc(g+16|0,12241);h=dh(c,d);rb(d);if(h){c=g+16|0;d=b+24|0;OO(c,v[d>>2]+1298332|0);Z:{if(!xd(c)){break Z}d=v[v[d>>2]+480180>>2];_:{$:{if((d|0)==33554432){break $}c=1;if((d|0)==32){break _}if((d|0)==16384){break $}if((d|0)==16777216){break _}}c=2}aa:{switch(c-1|0){case 0:v[22440]=0;R(1034,g|0,b|0);c=v[22440];v[22440]=0;if((c|0)!=1){tc(g+16|0,g);rb(g);break Z}break b;case 1:break aa;default:break Z}}v[22440]=0;R(1035,g|0,b|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=tc(g+16|0,g);rb(g);if(!xd(c)){break Z}v[22440]=0;R(1034,g|0,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break b}tc(c,g);rb(g)}v[22440]=0;U(1027,a|0,b|0,g+16|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(g+16|0);break e}break b}d=Bc(g+16|0,5475);h=dh(c,d);rb(d);if(h){c=g+16|0;OO(c,v[b+24>>2]+1298332|0);v[22440]=0;U(1027,a|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(g+16|0);break e}c=P()|0;O()|0;rb(g+16|0);break a}e=c;c=Bc(g+16|0,7295);d=dh(e,c);rb(c);if(d){a=Db(a);q=g,r=yb(v[b+68>>2]),v[q+16>>2]=r;b=yb(v[b+72>>2]);c=1;while(1){d=v[g+16>>2];if(!Qb(d,b)){break e}if(!(c&1)){v[22440]=0;Q(960,a|0,21655)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}}v[22440]=0;Q(824,a|0,d|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}Vn(g+16|0);c=0;continue}}Bc(a,21685)}cb=g+32|0;return}c=P()|0;O()|0;rb(g+16|0);break a}c=P()|0;O()|0;rb(a);break a}c=P()|0;O()|0;rb(g+16|0)}S(c|0);L()}function TF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,D=0,E=0,F=0,G=0,H=C(0),I=0;f=cb-144|0;cb=f;d=Hb(f,0,144);v[d+76>>2]=-1;v[d+44>>2]=a;v[d+32>>2]=1140;v[d+84>>2]=a;y=c;h=cb-304|0;cb=h;a:{b:{c:{d:{if(v[d+4>>2]){break d}yw(d);if(v[d+4>>2]){break d}break c}c=w[b|0];if(!c){break a}e:{f:{g:{h:{i:{while(1){j:{a=c&255;k:{if(Pk(a)){while(1){c=b;b=b+1|0;if(Pk(w[c+1|0])){continue}break}hi(d,0,0);while(1){a=v[d+4>>2];l:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break l}a=id(d)}if(Pk(a)){continue}break}b=v[d+4>>2];a=v[d+116>>2];if((a|0)>0|(a|0)>=0){b=b-1|0;v[d+4>>2]=b}a=b-v[d+44>>2]|0;e=a>>31;g=a;a=o+v[d+124>>2]|0;b=n+v[d+120>>2]|0;a=b>>>0<n>>>0?a+1|0:a;f=b;b=g+b|0;g=a+e|0;n=b;o=b>>>0<f>>>0?g+1|0:g;break k}m:{n:{o:{if((a|0)==37){a=w[b+1|0];if((a|0)==42){break o}if((a|0)!=37){break n}}hi(d,0,0);p:{if(w[b|0]==37){while(1){a=v[d+4>>2];q:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;c=w[a|0];break q}c=id(d)}if(Pk(c)){continue}break}b=b+1|0;break p}a=v[d+4>>2];if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;c=w[a|0];break p}c=id(d)}if(w[b|0]!=(c|0)){a=v[d+116>>2];if((a|0)>0|(a|0)>=0){v[d+4>>2]=v[d+4>>2]-1}if((c|0)>=0){break a}e=0;if(D){break a}break c}a=v[d+4>>2]-v[d+44>>2]|0;e=a>>31;f=a;a=o+v[d+124>>2]|0;c=n+v[d+120>>2]|0;a=c>>>0<n>>>0?a+1|0:a;g=c;c=f+c|0;f=a+e|0;n=c;o=c>>>0<g>>>0?f+1|0:f;c=b;break k}k=0;b=b+2|0;break m}if(!(!Yj(a)|w[b+2|0]!=36)){c=cb-16|0;v[c+12>>2]=y;a=a-48|0;a=(a>>>0>1?(a<<2)-4|0:0)+y|0;v[c+8>>2]=a+4;k=v[a>>2];b=b+3|0;break m}k=v[y>>2];y=y+4|0;b=b+1|0}f=0;while(1){i=w[b|0];if(Yj(i)){b=b+1|0;f=(B(f,10)+i|0)-48|0;continue}break}s=0;if((i|0)==109){m=0;s=(k|0)!=0;i=w[b+1|0];r=0;b=b+1|0}c=b+1|0;a=3;e=s;r:{s:{switch((i&255)-65|0){case 39:a=w[b+1|0]==104;c=a?b+2|0:c;a=a?-2:-1;break r;case 43:a=w[b+1|0]==108;c=a?b+2|0:c;a=a?3:1;break r;case 51:case 57:a=1;break r;case 11:a=2;break r;case 41:break r;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break s;default:break e}}a=0;c=b}e=a;a=w[c|0];b=(a&47)==3;x=b?1:e;p=b?a|32:a;t:{if((p|0)==91){break t}u:{if((p|0)!=110){if((p|0)!=99){break u}f=(f|0)>1?f:1;break t}UF(k,x,n,o);break k}hi(d,0,0);while(1){a=v[d+4>>2];v:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break v}a=id(d)}if(Pk(a)){continue}break}b=v[d+4>>2];a=v[d+116>>2];if((a|0)>0|(a|0)>=0){b=b-1|0;v[d+4>>2]=b}a=b-v[d+44>>2]|0;e=a>>31;j=a;a=o+v[d+124>>2]|0;b=n+v[d+120>>2]|0;a=b>>>0<n>>>0?a+1|0:a;g=b;b=j+b|0;o=a+e|0;o=b>>>0<g>>>0?o+1|0:o;n=b}j=f;l=f>>31;hi(d,f,l);a=v[d+4>>2];w:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;break w}if((id(d)|0)<0){break f}}a=v[d+116>>2];if((a|0)>0|(a|0)>=0){v[d+4>>2]=v[d+4>>2]-1}b=16;x:{y:{z:{A:{B:{switch(p-88|0){default:a=p-65|0;if(a>>>0>6|!(1<<a&113)){break x}case 9:case 13:case 14:case 15:WF(h+8|0,d,x,0);a=v[d+4>>2]-v[d+44>>2]|0;if(v[d+120>>2]!=(0-a|0)|v[d+124>>2]!=(0-((a>>31)+((a|0)!=0)|0)|0)){break z}break g;case 3:case 11:case 27:if((p&239)==99){Hb(h+32|0,-1,257);t[h+32|0]=0;if((p|0)!=115){break y}t[h+65|0]=0;t[h+46|0]=0;u[h+42>>1]=0;u[h+44>>1]=0;break y}a=w[c+1|0];e=(a|0)==94;Hb(h+32|0,e,257);t[h+32|0]=0;b=e?c+2|0:c+1|0;C:{D:{E:{c=w[(e?2:1)+c|0];if((c|0)!=45){if((c|0)==93){break E}a=(a|0)!=94;break C}a=(a|0)!=94;t[h+78|0]=a;break D}a=(a|0)!=94;t[h+126|0]=a}b=b+1|0}c=b;while(1){i=w[c|0];F:{if((i|0)!=45){if(!i){break f}if((i|0)!=93){break F}break y}i=45;e=w[c+1|0];if(!e|(e|0)==93){break F}g=c+1|0;b=w[c-1|0];G:{if(e>>>0<=b>>>0){i=e;break G}while(1){b=b+1|0;t[b+(h+32|0)|0]=a;i=w[g|0];if(i>>>0>b>>>0){continue}break}}c=g}t[(h+i|0)+33|0]=a;c=c+1|0;continue};case 23:b=8;break A;case 12:case 29:b=10;break A;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break x;case 0:case 24:case 32:break A;case 17:break B}}b=0}j=0;g=0;e=0;f=0;i=0;E=cb-16|0;cb=E;H:{if((b|0)==1){v[114922]=28;break H}while(1){a=v[d+4>>2];I:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break I}a=id(d)}if(Pk(a)){continue}break}J:{K:{switch(a-43|0){case 0:case 2:break K;default:break J}}i=(a|0)==45?-1:0;a=v[d+4>>2];if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break J}a=id(d)}L:{M:{N:{O:{if(!(b&-17|(a|0)!=48)){a=v[d+4>>2];P:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break P}a=id(d)}if((a&-33)==88){b=16;a=v[d+4>>2];Q:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break Q}a=id(d)}if(w[a+75153|0]<16){break N}a=v[d+116>>2];if((a|0)>0|(a|0)>=0){v[d+4>>2]=v[d+4>>2]-1}hi(d,0,0);break H}if(b){break O}b=8;break N}b=b?b:10;if(b>>>0>w[a+75153|0]){break O}a=v[d+116>>2];if((a|0)>0|(a|0)>=0){v[d+4>>2]=v[d+4>>2]-1}hi(d,0,0);v[114922]=28;break H}if((b|0)!=10){break N}e=a-48|0;if(e>>>0<=9){b=0;while(1){b=B(b,10)+e|0;f=b>>>0<429496729;a=v[d+4>>2];R:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break R}a=id(d)}e=a-48|0;if(f&e>>>0<=9){continue}break}j=b}S:{if(e>>>0>9){break S}l=kka(j,0,10,0);f=fb;b=e;while(1){a=v[d+4>>2];T:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break T}a=id(d)}e=a-48|0;q=e>>>0>9;j=b+l|0;g=j>>>0<b>>>0?f+1|0:f;if((g|0)==429496729&j>>>0>=2576980378|g>>>0>429496729|q){break S}l=kka(j,g,10,0);f=fb;b=e;if((f|0)==-1&l>>>0<=(b^-1)>>>0|(f|0)!=-1){continue}break}b=10;break M}b=10;if(e>>>0<=9){break M}break L}if(b-1&b){f=w[a+75153|0];if(f>>>0<b>>>0){while(1){e=B(b,e)+f|0;j=e>>>0<119304647;a=v[d+4>>2];U:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break U}a=id(d)}f=w[a+75153|0];if(j&f>>>0<b>>>0){continue}break}j=e}if(b>>>0<=f>>>0){break M}while(1){l=kka(j,g,b,0);e=fb;f=f&255;if((e|0)==-1&(f^-1)>>>0<l>>>0){break M}a=e;g=f+l|0;a=g>>>0<f>>>0?a+1|0:a;j=g;g=a;a=v[d+4>>2];V:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break V}a=id(d)}f=w[a+75153|0];if(b>>>0<=f>>>0){break M}xf(E,b,0,0,0,j,g,0,0);if(!(v[E+8>>2]|v[E+12>>2])){continue}break}break M}l=t[(B(b,23)>>>5&7)+75409|0];e=w[a+75153|0];if(e>>>0<b>>>0){while(1){f=f<<l|e;j=f>>>0<134217728;a=v[d+4>>2];W:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break W}a=id(d)}e=w[a+75153|0];if(j&e>>>0<b>>>0){continue}break}j=f}if(b>>>0<=e>>>0){break M}f=l;q=f&31;if((f&63)>>>0>=32){f=0;q=-1>>>q|0}else{f=-1>>>q|0;q=f|(1<<q)-1<<32-q}if(!f&j>>>0>q>>>0){break M}while(1){F=e&255;e=l&31;if((l&63)>>>0>=32){a=j<<e;e=0}else{a=(1<<e)-1&j>>>32-e|g<<e;e=j<<e}j=F|e;g=a;a=v[d+4>>2];X:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break X}a=id(d)}e=w[a+75153|0];if(b>>>0<=e>>>0){break M}if((f|0)==(g|0)&j>>>0<=q>>>0|f>>>0>g>>>0){continue}break}}if(w[a+75153|0]>=b>>>0){break L}while(1){a=v[d+4>>2];Y:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break Y}a=id(d)}if(w[a+75153|0]<b>>>0){continue}break}v[114922]=68;j=-1;g=-1;i=0}a=v[d+116>>2];if((a|0)>0|(a|0)>=0){v[d+4>>2]=v[d+4>>2]-1}a=i^j;j=a-i|0;b=i>>31;g=(b^g)-((a>>>0<i>>>0)+b|0)|0}cb=E+16|0;a=v[d+4>>2]-v[d+44>>2]|0;if(v[d+120>>2]==(0-a|0)&v[d+124>>2]==(0-((a>>31)+((a|0)!=0)|0)|0)){break g}if(!(!k|(p|0)!=112)){v[k>>2]=j;break x}UF(k,x,j,g);break x}if(!k){break x}a=v[h+16>>2];b=v[h+20>>2];e=v[h+8>>2];f=v[h+12>>2];Z:{switch(x|0){case 0:G=k,H=kF(e,f,a,b),z[G>>2]=H;break x;case 1:G=k,I=Sw(e,f,a,b),A[G>>3]=I;break x;case 2:break Z;default:break x}}v[k>>2]=e;v[k+4>>2]=f;v[k+8>>2]=a;v[k+12>>2]=b;break x}g=(p|0)==99;f=g?f+1|0:31;x=(x|0)!=1;_:{if(!x){a=k;if(s){a=Hd(f<<2);if(!a){break h}}v[h+296>>2]=0;v[h+300>>2]=0;b=0;while(1){e=v[d+4>>2];$:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break $}e=id(d)}if(w[(e+h|0)+33|0]){t[h+27|0]=e;e=sr(h+28|0,h+27|0,1,h+296|0);if((e|0)==-2){continue}m=0;if((e|0)==-1){break i}if(a){v[(b<<2)+a>>2]=v[h+28>>2];b=b+1|0}if(!((b|0)==(f|0)&s)){continue}e=1;r=a;b=f;f=b<<1|1;a=Ir(a,f<<2);if(a){continue}break e}break}m=0;if(h+296|0?v[h+296>>2]:0){break i}break _}if(s){b=0;i=Hd(f);if(!i){break h}while(1){m=i;while(1){a=v[d+4>>2];aa:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break aa}a=id(d)}if(!w[(a+h|0)+33|0]){a=0;break _}t[b+m|0]=a;b=b+1|0;if((f|0)!=(b|0)){continue}break}e=1;r=0;b=f;a=b<<1|1;f=a;i=Ir(m,a);if(i){continue}break}break e}b=0;if(k){while(1){a=v[d+4>>2];ba:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break ba}a=id(d)}if(w[(a+h|0)+33|0]){t[b+k|0]=a;b=b+1|0;continue}else{a=0;m=k;break _}}}while(1){a=v[d+4>>2];ca:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break ca}a=id(d)}if(w[(a+h|0)+33|0]){continue}break}m=0;a=0}i=v[d+4>>2];e=v[d+116>>2];if((e|0)>0|(e|0)>=0){i=i-1|0;v[d+4>>2]=i}f=i-v[d+44>>2]|0;r=f;e=f+v[d+120>>2]|0;f=v[d+124>>2]+(f>>31)|0;f=e>>>0<r>>>0?f+1|0:f;if(!(f|e)|((e|0)!=(j|0)|(f|0)!=(l|0))&(p|0)==99){break j}da:{if(!s){break da}if(!x){v[k>>2]=a;break da}v[k>>2]=m}ea:{if(g){break ea}if(a){v[(b<<2)+a>>2]=0}if(!m){m=0;break ea}t[b+m|0]=0}r=a}a=v[d+4>>2]-v[d+44>>2]|0;e=a>>31;g=a;a=o+v[d+124>>2]|0;b=n+v[d+120>>2]|0;a=b>>>0<n>>>0?a+1|0:a;f=b;b=g+b|0;a=a+e|0;n=b;o=b>>>0<f>>>0?a+1|0:a;D=((k|0)!=0)+D|0}b=c+1|0;c=w[c+1|0];if(c){continue}break a}break}r=a;break g}r=a;break f}e=1;m=0;r=0;break e}e=s;break b}e=s}if(D){break b}}D=-1}if(!e){break a}zb(m);zb(r)}cb=h+304|0;cb=d+144|0;return D}function QV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a:{n=Ah(b,13911);if(!n){break a}o=a+480192|0;b:while(1){if(!Kb(b,6)){break a}c:{f=Ag(b);d:{if((f|0)==(Hm(13730)|0)){break d}c=w[21661]|w[21662]<<8|(w[21663]<<16|w[21664]<<24);if(!(f&1616928864)|f&-2139062144){break d}if((c|0)!=(f|0)){break c}}xg(b,4);break a}l=1;c=Sg(b);while(1){d=l&65535;if(d>>>0>x[o>>1]){continue b}d=v[((d<<2)+a|0)+900380>>2];if(d){e:{g=0;if((Hm(16786)|0)==(f|0)){Ob(b,c);break e}e=cb-48|0;cb=e;f:{if(!d){break f}g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{switch(f-1349079874|0){default:if((f|0)==1095062094){break v}if((f|0)==1095126087){break s}if((f|0)==1129524782){break B}if((f|0)==1145263150){break Y}if((f|0)==1145979182){break X}if((f|0)==1179463214){break z}if((f|0)==1851469358){break F}if((f|0)==1179931728){break n}$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{if((f|0)!=1196830254){if((f|0)==1229341486){break U}if((f|0)==1229345326){break T}if((f|0)==1264266798){break G}if((f|0)==1296182830){break S}if((f|0)==1296248366){break Q}if((f|0)==1297100334){break R}if((f|0)==1297110852){break q}if((f|0)==1298747438){break D}if((f|0)==1313692462){break H}if((f|0)==1313751342){break Z}if((f|0)==1345203758){break ja}if((f|0)==1346711086){break l}if((f|0)==1346720334){break w}if((f|0)==1346722606){break J}if((f|0)==1346784327){break t}if((f|0)==1347175726){break da}if((f|0)==1347179310){break ea}if((f|0)==1347437358){break O}if((f|0)==1347441454){break P}if((f|0)==1347443502){break M}if((f|0)==1347628590){break W}if((f|0)==1347633710){break ca}if((f|0)==1347634478){break ba}if((f|0)==1347703884){break o}if((f|0)==1347831112){break y}if((f|0)==1347833672){break x}if((f|0)==1349076270){break k}if((f|0)==1349076315){break I}if((f|0)==1349078085){break $}if((f|0)==1349078099){break aa}if((f|0)==1349079131){break L}if((f|0)==1378758190){break p}if((f|0)==1381183022){break A}if((f|0)==1447374382){break m}if((f|0)==1447383630){break u}if((f|0)==1447385902){break K}if((f|0)==1447447623){break r}if((f|0)==1447839022){break ha}if((f|0)==1447842606){break ia}if((f|0)==1448106798){break N}if((f|0)==1448226350){break C}if((f|0)==1448291886){break V}if((f|0)==1448297006){break ga}if((f|0)==1448297774){break fa}if((f|0)!=1682320942){if((f|0)==1718508334){break E}if((f|0)!=1179594286|c>>>0>4){break f}if(!Kb(b,c)){break f}p=d,q=Tu(b,c),v[p>>2]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+15|0]=q;break g}if(c>>>0>4){break f}if(!Kb(b,c)){break f}p=d,q=Tu(b,c),v[p+4>>2]=q;break g}if(c>>>0>4){break f}if(!Kb(b,c)){break f}p=d,q=Tu(b,c),v[p+8>>2]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+61|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+62|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+63|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d- -64|0,q=vd(b,c),t[p|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+81|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+82|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+83|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+84|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+101|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+102|0]=q;break g;case 0:if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+103|0]=q;break g;case 3:break _;case 1:case 2:break f}}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+104|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+16|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+17|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+18|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+19|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+20|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+21|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+22|0]=q;break g}if(c>>>0>2){break f}if(!Kb(b,c)){break f}p=d,q=LC(b,c),u[p+28>>1]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+30|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+31|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=KC(b,c),t[p+26|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+27|0]=q;break g}Td(e,b,c);h=cc(e+24|0,e);sb(e);i=Bh(d,0);while(1){if(Dd(i)>>>0<=g>>>0){sb(h);break g}v[22440]=0;k=T(199,h|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break j}p=Ib(v[i>>2],g),q=k,u[p>>1]=q;g=g+1|0;continue}}Td(e,b,c);h=cc(e+24|0,e);sb(e);i=Bh(d,1);while(1){if(Dd(i)>>>0<=g>>>0){sb(h);break g}v[22440]=0;k=T(199,h|0)|0;j=v[22440];v[22440]=0;if((j|0)!=1){p=Ib(v[i>>2],g),q=k,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Td(e,b,c);h=cc(e+24|0,e);sb(e);i=Bh(d,2);while(1){if(Dd(i)>>>0<=g>>>0){sb(h);break g}v[22440]=0;k=T(199,h|0)|0;j=v[22440];v[22440]=0;if((j|0)!=1){p=Ib(v[i>>2],g),q=k,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Td(e,b,c);h=cc(e+24|0,e);sb(e);i=Bh(d,0);while(1){if(Dd(i)>>>0<=g>>>0){sb(h);break g}v[22440]=0;k=T(200,h|0)|0;j=v[22440];v[22440]=0;if((j|0)!=1){p=Ib(v[i>>2],g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Td(e,b,c);h=cc(e+24|0,e);sb(e);i=Bh(d,1);while(1){if(Dd(i)>>>0<=g>>>0){sb(h);break g}v[22440]=0;k=T(200,h|0)|0;j=v[22440];v[22440]=0;if((j|0)!=1){p=Ib(v[i>>2],g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Td(e,b,c);h=cc(e+24|0,e);sb(e);i=Bh(d,2);while(1){if(Dd(i)>>>0<=g>>>0){sb(h);break g}v[22440]=0;k=T(200,h|0)|0;j=v[22440];v[22440]=0;if((j|0)!=1){p=Ib(v[i>>2],g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>128){break f}i=d+108|0;Td(e,b,c);h=cc(e+24|0,e);sb(e);while(1){if((g|0)==128){sb(h);break g}v[22440]=0;k=T(200,h|0)|0;j=v[22440];v[22440]=0;if((j|0)!=1){p=Eb(i,g),q=k,t[p|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>256){break f}i=d+236|0;Td(e,b,c);h=cc(e+24|0,e);sb(e);while(1){if((g|0)==128){sb(h);break g}v[22440]=0;k=T(199,h|0)|0;j=v[22440];v[22440]=0;if((j|0)!=1){p=Xb(i,g),q=k,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>32){break f}k=d+492|0;Td(e,b,c);h=cc(e+24|0,e);sb(e);i=Db(e);while(1){if((c|0)==(g|0)){break h}v[22440]=0;j=T(201,h|0)|0;m=v[22440];v[22440]=0;ka:{if((m|0)==1){break ka}v[22440]=0;Q(202,i|0,j|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break ka}g=g+1|0;continue}break}g=P()|0;O()|0;rb(i);break i}if(c>>>0>32){break f}k=d+524|0;Td(e,b,c);h=cc(e+24|0,e);sb(e);i=Db(e);la:{while(1){if((c|0)!=(g|0)){v[22440]=0;j=T(201,h|0)|0;m=v[22440];v[22440]=0;if((m|0)==1){break la}v[22440]=0;Q(202,i|0,j|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break la}g=g+1|0;continue}break}uc(k,i);rb(i);sb(h);break g}g=P()|0;O()|0;rb(i);break i}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+34|0]=q;break g}if(c>>>0>2){break f}if(!Kb(b,c)){break f}p=d,q=LC(b,c),u[p+12>>1]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+23|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+24|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+25|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+35|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+36|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+105|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+85|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+65|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+100|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+80|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=vd(b,c),t[p+60|0]=q;break g}if(c>>>0>1){break f}if(!Kb(b,c)){break f}p=d,q=KC(b,c),t[p+33|0]=q;break g}g=1;h=ro(b,c);if(!qo(h)){break f}t[d+14|0]=h;break f}p=d,q=B(Ru(b,c),1e4)+(y[d+40>>2]%1e4|0)|0,v[p+40>>2]=q;break g}g=Ru(b,c);h=v[d+40>>2];v[d+40>>2]=h-((h>>>0)%1e4|0)+(g>>>0)%1e4;break g}v[e+24>>2]=240;p=e,q=ro(b,c),v[p>>2]=q;Qg(d+48|0,v[Bb(e+24|0,e)>>2]);break g}v[e+24>>2]=240;p=e,q=ro(b,c),v[p>>2]=q;Qg(d+68|0,v[Bb(e+24|0,e)>>2]);break g}v[e+24>>2]=240;p=e,q=ro(b,c),v[p>>2]=q;Qg(d+88|0,v[Bb(e+24|0,e)>>2]);break g}g=P()|0;O()|0}sb(h);S(g|0);L()}uc(k,i);rb(i);sb(h)}g=1}cb=e+48|0;if(!g){Ob(b,c);break e}if((Hm(16791)|0)==(f|0)){e=w[d+15|0];t[d+15|0]=0;t[d+100|0]=w[d+100|0]&224|(e>>>5&4|e>>>6&1);t[d+60|0]=e>>>1&2|(e<<1&4|(w[d+60|0]&240|e&1));t[d+80|0]=w[d+80|0]&240|(e>>>4&2|(e>>>2&4|e>>>3&1))}}}l=l+1|0;continue}}}return n|0}function U9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=cb-768|0;cb=d;sc(b);a:{b:{c:{d:{e:{f:{if(!$h(b,d+760|0)){break f}if(!YK(d+760|0)){break f}if(!fA(b,d+752|0)){break f}if(!XK(d+752|0)){break f}h=1313423693;j=w[d+752|0]|w[d+753|0]<<8|(w[d+754|0]<<16|w[d+755|0]<<24);if((j|0)!=1179012417){h=1414090313;if((j|0)!=538987841){break f}}m=be(d+728|0,b);k=bf(d+712|0);g:{h:{i:{j:{k:{l:{m:{if(!c){v[22440]=0;W(876,d+136|0,m|0,((j|0)==1179012417?1:2)|0,h|0);b=v[22440];v[22440]=0;if((b|0)!=1){break m}b=P()|0;O()|0;break a}v[22440]=0;U(877,d+136|0,m|0,((j|0)==1179012417?1:2)|0);b=v[22440];v[22440]=0;if((b|0)==1){break l}}b=d+136|0;wt(k,b);Qd(b);v[22440]=0;U(878,d+688|0,k|0,h|0);b=v[22440];v[22440]=0;if((b|0)!=1){v[22440]=0;b=T(180,d+688|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break k}e=0;if(!b){break g}v[22440]=0;b=Q(879,d+688|0,d+608|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break k}if(!b){break g}b=w[d+673|0];if(!b){break g}v[22440]=0;e=Q(158,d+688|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break k}if(!c|e^1){break g}v[22440]=0;R(252,a|0,8388608);b=v[22440];v[22440]=0;if((b|0)==1){break k}v[a+480208>>2]=12;v[a+480208>>2]=w[d+672|0]<<4&16^28;u[d+136>>1]=w[d+673|0];u[d+496>>1]=127;o=a,p=x[Kc(d+136|0,d+496|0)>>1],u[o+480188>>1]=p;v[a+480196>>2]=w[d+674|0];v[a+480204>>2]=B(w[d+675|0],1e4);v[a+480200>>2]=w[d+680|0]<<1;v[22440]=0;Q(138,a+1298344|0,((j|0)==1179012417?17001:16967)|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break k}v[22440]=0;b=Q(1,d+136|0,13295)|0;e=v[22440];v[22440]=0;if((e|0)==1){break i}Cb(a+1298356|0,b);rb(b);v[a+1298404>>2]=5;Nz(d+496|0,2,d+608|0);v[22440]=0;W(225,d+136|0,v[d+496>>2],v[d+500>>2],w[d+504|0]);b=v[22440];v[22440]=0;if((b|0)==1){break j}l=(j|0)!=1179012417;b=d+136|0;tc(a+1298308|0,b);rb(b);i=(j|0)==1179012417;b=0;while(1){n:{o:{p:{if(x[a+480188>>1]<=b>>>0){e=yb(v[k>>2]);h=yb(v[k+4>>2]);b=cb-16|0;cb=b;v[b>>2]=1380209231;v[b+8>>2]=e;while(1){q:{r:{if(Qb(e,h)){if(!fU(b,e)){break r}e=v[b+8>>2]}cb=b+16|0;break q}zm(b+8|0);e=v[b+8>>2];continue}break}if(Qb(e,yb(v[k+4>>2]))){break p}break h}h=(b<<5)+a|0;f=h+480280|0;$e(f);v[22440]=0;e=T(208,d+688|0)|0;g=v[22440];v[22440]=0;s:{t:{if((g|0)!=1){if(i){break s}if(e>>>0<129){break t}break o}b=P()|0;O()|0;break b}u[h+480284>>1]=e<<1;break n}if(e<<24>>24<0){break o}v[d+136>>2]=e<<2;v[d+496>>2]=256;o=h+480284|0,p=v[ld(d+136|0,d+496|0)>>2],u[o>>1]=p;break n}v[22440]=0;U(878,d+136|0,k|0,1380209231);b=v[22440];v[22440]=0;u:{if((b|0)!=1){v[22440]=0;b=T(208,d+136|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break u}e=Nb(a+484360|0);v[22440]=0;ea(351,e|0,d+136|0,b+1&255,255,254)|0;b=v[22440];v[22440]=0;if((b|0)==1){break u}sb(d+136|0);break h}b=P()|0;O()|0;break b}b=P()|0;O()|0;sb(d+136|0);break b}v[f>>2]=1024}b=b+1|0;continue}}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}v:{if(!(c&1)){break v}u[d+56>>1]=0;v[22440]=0;U(880,d+560|0,k|0,1414807888);b=v[22440];v[22440]=0;if((b|0)==1){break c}b=v[d+564>>2];h=v[d+560>>2];v[22440]=0;e=a+484344|0;R(228,e|0,Df(h,b)&65535);b=v[22440];v[22440]=0;w:{if((b|0)!=1){o=d,p=yb(v[d+560>>2]),v[o+88>>2]=p;h=yb(v[d+564>>2]);x:{y:{z:{A:{B:{while(1){b=v[d+88>>2];if(!Qb(b,h)){b=0;break x}b=be(d+136|0,b);v[22440]=0;i=T(208,b|0)|0;f=v[22440];v[22440]=0;if((f|0)!=1){v[22440]=0;u[d+480>>1]=i;b=T(159,b|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break B}v[22440]=0;U(192,d+496|0,d+136|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break A}b=cc(d+584|0,d+496|0);v[22440]=0;i=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=i;v[d+16>>2]=v[b+16>>2];i=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=i;W(881,d|0,x[d+480>>1],l|0,a|0);b=v[22440];v[22440]=0;if((b|0)==1){break z}sb(d+496|0);o=d,p=x[ie(d+56|0,d+480|0)>>1],u[o+56>>1]=p;sb(d+136|0);Uf(d+88|0);continue}break}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;sb(d+496|0)}sb(d+136|0);break w}while(1){h=b&65535;if(h>>>0>=x[d+56>>1]){Ic(d+560|0);break v}C:{if(!ve(e,h)){v[22440]=0;Y(229,e|0,h|0,64)|0;h=v[22440];v[22440]=0;if((h|0)==1){break C}}b=b+1|0;continue}break}b=P()|0;O()|0;break w}b=P()|0;O()|0}Ic(d+560|0);break b}D:{if((j|0)==1179012417){v[22440]=0;U(880,d+88|0,k|0,1414745673);b=v[22440];v[22440]=0;if((b|0)==1){break d}o=d,p=yb(v[d+88>>2]),v[o+120>>2]=p;j=c&2;h=d+504|0;l=d+136|1;i=yb(v[d+92>>2]);while(1){b=v[d+120>>2];if(!Qb(b,i)){Ic(d+88|0);break D}c=be(d+560|0,b);v[22440]=0;b=Q(882,c|0,d+136|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){E:{if(!b){break E}b=w[l|0];if((b|0)==255){break E}v[22440]=0;b=Y(257,a|0,b+1|0,0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break e}if(!b){break E}e=x[a+480190>>1];v[22440]=0;U(883,d+136|0,b|0,e|0);b=v[22440];v[22440]=0;if((b|0)==1){break e}b=0;while(1){if(w[d+166|0]<=b>>>0){break E}F:{if(!Sh(a)){break F}v[22440]=0;e=Q(884,c|0,d+496|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break e}if(!e){break F}e=x[a+480190>>1]+1|0;u[a+480190>>1]=e;if((w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24))!=1347240275){break F}Gi(d+480|0,2,h);v[22440]=0;W(225,d+56|0,v[d+480>>2],v[d+484>>2],w[d+488|0]);f=v[22440];v[22440]=0;G:{if((f|0)!=1){e=e&65535;f=d+56|0;uc(((e<<5)+a|0)+946304|0,f);rb(f);v[22440]=0;f=B(e,104)+a|0;e=f+484380|0;U(885,d+496|0,d+136|0,e|0);g=v[22440];v[22440]=0;if((g|0)==1){break e}if(!j){break G}f=d+56|0;g=d+534|0;Nc(f,(w[g|0]|w[g+1|0]<<8)&4?16:8,1,0,0);v[22440]=0;Y(222,f|0,e|0,c|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){break F}break e}break e}f=x[f+484414>>1];e=v[e>>2];v[22440]=0;Q(190,d+560|0,Fj(e,f)|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break e}}b=b+1|0;continue}}sb(d+560|0);Uf(d+120|0);continue}break}break e}v[22440]=0;U(880,d+480|0,k|0,1179011410);b=v[22440];v[22440]=0;if((b|0)!=1){o=d,p=yb(v[d+480>>2]),v[o+472>>2]=p;j=c&2;h=d+496|4;b=d+80|4;l=d+136|5;i=yb(v[d+484>>2]);H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{while(1){c=v[d+472>>2];if(!Qb(c,i)){Ic(d+480|0);break D}c=be(d+560|0,c);v[22440]=0;e=T(159,c|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break Q}R:{S:{if((e|0)!=538986817){break S}v[22440]=0;e=Q(886,c|0,d+464|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break P}if(!e|(w[d+464|0]|w[d+465|0]<<8|(w[d+466|0]<<16|w[d+467|0]<<24))!=1414745673){break S}v[22440]=0;e=Q(887,c|0,d+136|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break O}if(!e){break S}e=w[l|0];if((e|0)==255){break S}v[22440]=0;e=Y(257,a|0,e+1|0,0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break N}if(!e){break S}f=x[a+480190>>1];v[22440]=0;U(888,d+136|0,e|0,f|0);e=v[22440];v[22440]=0;if((e|0)==1){break N}v[22440]=0;U(877,d+496|0,c|0,2);c=v[22440];v[22440]=0;if((c|0)==1){break R}v[22440]=0;U(880,d+120|0,d+496|0,1179011410);c=v[22440];v[22440]=0;if((c|0)==1){break M}Qd(d+496|0);o=d,p=yb(v[d+120>>2]),v[o+112>>2]=p;f=yb(v[d+124>>2]);T:{U:{while(1){c=v[d+112>>2];if(!Qb(c,f)){break T}c=be(d+88|0,c);v[22440]=0;e=T(159,c|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break L}V:{W:{if((e|0)!=538989377){break W}if(!Sh(a)){break W}e=w[d+460|0]|w[d+461|0]<<8;g=e-1|0;t[d+460|0]=g;t[d+461|0]=g>>>8;if(!e){sb(d+88|0);break T}g=x[a+480190>>1]+1|0;u[a+480190>>1]=g;v[22440]=0;c=Q(886,c|0,d+80|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break K}if(!c|(w[d+80|0]|w[d+81|0]<<8|(w[d+82|0]<<16|w[d+83|0]<<24))!=1347240275){break U}c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[22440]=0;U(192,d+496|0,d+88|0,c|0);c=v[22440];v[22440]=0;X:{if((c|0)!=1){c=d+496|0;e=cc(d+56|0,c);sb(c);v[22440]=0;c=Q(889,e|0,c|0)|0;n=v[22440];v[22440]=0;if((n|0)==1){break V}if(c){break X}sb(d+56|0);sb(d+88|0);break T}b=P()|0;O()|0;break I}Ie(d+24|0,2,h);v[22440]=0;W(225,d+40|0,v[d+24>>2],v[d+28>>2],w[d+32|0]);c=v[22440];v[22440]=0;if((c|0)==1){break J}c=g&65535;g=d+40|0;uc(((c<<5)+a|0)+946304|0,g);rb(g);v[22440]=0;c=(B(c,104)+a|0)+484380|0;U(890,d+496|0,d+136|0,c|0);g=v[22440];v[22440]=0;if((g|0)==1){break V}Y:{if(!j){break Y}g=w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24);v[22440]=0;Q(157,d+56|0,g+4|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break V}g=d+40|0;n=d+536|0;Nc(g,(w[n|0]|w[n+1|0]<<8)&4?16:8,1,0,0);v[22440]=0;Y(222,g|0,c|0,e|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break Y}break J}sb(d+56|0)}sb(d+88|0);Uf(d+112|0);continue}break}break J}sb(d+88|0)}Ic(d+120|0)}sb(d+560|0);Uf(d+472|0);continue}break}b=P()|0;O()|0;break H}b=P()|0;O()|0;break H}b=P()|0;O()|0;break H}b=P()|0;O()|0;break H}b=P()|0;O()|0;break H}b=P()|0;O()|0;Qd(d+496|0);break H}b=P()|0;O()|0;break I}b=P()|0;O()|0;break I}b=P()|0;O()|0;sb(d+56|0)}sb(d+88|0);Ic(d+120|0)}sb(d+560|0);Ic(d+480|0);break b}b=P()|0;O()|0;break b}e=1}sb(d+688|0);Qd(k);sb(m)}cb=d+768|0;return e|0}b=P()|0;O()|0;sb(d+560|0);Ic(d+88|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}sb(d+688|0)}Qd(k);sb(m);S(b|0);L()}function sea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;k=cb-208|0;cb=k;if(!ot(a)){e=k+48|0;ic(e,a,128);pf(k+176|0,e,128,2);e=k+192|0;xc(e,v[k+176>>2],v[k+180>>2],w[k+184|0]);uc(b+492|0,e);rb(e)}u[c+34>>1]=x[c+34>>1]&65489;p=k+192|0;f=cb-32|0;cb=f;a:{b:{switch(w[a+128|0]-4|0){default:v[f+28>>2]=0;On(p,0,f+28|0);break a;case 0:case 4:break b}}t[f+28|0]=w[a+129|0];t[f+24|0]=100;e=f+24|0;h=w[Tb(f+28|0,e)|0];t[f+24|0]=w[a+130|0];t[f+20|0]=100;e=w[Tb(e,f+20|0)|0];v[f+28>>2]=e;c:{if(w[a+140|0]&16){g=wb(w[a+150|0]|w[a+151|0]<<8);j=wb(w[a+152|0]|w[a+153|0]<<8);n=v[c>>2];s=+(n>>>0)/6553600;h=hq(s*+((g|h<<16)>>>0));v[f+24>>2]=n-h;y=f,z=hq(s*+((j|e<<16)>>>0)),v[y+20>>2]=z;y=f,z=v[Bb(f+24|0,f+20|0)>>2],v[y+28>>2]=z;break c}if(!Sd(c)){break c}g=v[c>>2];j=g>>>7|0;h=B(j,(h<<7>>>0)/100|0);v[f+24>>2]=g-h;v[f+20>>2]=B(j,(e<<7>>>0)/100|0);e=v[Bb(f+24|0,f+20|0)>>2];j=x[c+34>>1];d:{if(j&1){Ub(f+8|0,v[c+20>>2],B(zd(j),g));g=v[f+8>>2];n=zd(x[c+34>>1]);j=g+(B(n,e+h|0)<<1)|0;o=u[g+(B(h,n)<<1)>>1];n=0-n<<1;while(1){e:{f:{if(e){m=u[j>>1]-o|0;g=m>>31;if((g^g+m)>>>0>=1536){break f}}else{e=0}break e}e=e-1|0;j=j+n|0;continue}break}break d}Ub(f,v[c+20>>2],B(zd(j),g));g=v[f>>2];n=zd(x[c+34>>1]);o=0-n|0;j=g+B(n,e+h|0)|0;n=t[g+B(h,n)|0];while(1){g:{h:{if(e){m=t[j|0]-n|0;g=m>>31;if((g^g+m)>>>0>=6){break h}}else{e=0}break g}e=e-1|0;j=j+o|0;continue}break}}v[f+28>>2]=e}On(p,h,f+28|0)}cb=f+32|0;n=bc(p);if(!(!v[n>>2]|w[a+128|0]!=4)){u[c+34>>1]=x[c+34>>1]|2;v[c+4>>2]=v[p>>2];v[c+8>>2]=v[n>>2]+v[p>>2]}e=w[a+134|0];if((e-1&255)>>>0<=198){t[k+48|0]=e;t[k+176|0]=100;e=(w[Tb(k+48|0,k+176|0)|0]<<7>>>0)/100|0}else{e=128}t[k+47|0]=e;t[k+48|0]=64;e=k+47|0;f=k+48|0;y=c,z=w[ff(e,f)|0]>>>1|0,u[y+32>>1]=z;t[k+48|0]=64;y=b,z=w[Tb(e,f)|0],v[y+4>>2]=z;v[c+24>>2]=40460;vl(c,+t[a+139|0]/12+ +(0-w[a+143|0]|0)+ +t[a+138|0]/1536);t[b+34|0]=w[a+142|0]&2?2:1;if(w[a+142|0]&2){Jj(b,127,1);Ij(b,0,1)}i:{if(!Sd(c)){break i}b=w[a+140|0];if(b&1){j:{if(!Sd(c)){break j}b=v[c>>2];if(b>>>0<2){break j}k:{l:{switch(Ak(x[c+34>>1])-1|0){case 3:f=v[c+20>>2];e=0;g=b>>>1|0;while(1){if((e|0)!=(g|0)){ec(f+(e<<2)|0,f+(b+(e^-1)<<2)|0);e=e+1|0;continue}break};break k;case 1:f=v[c+20>>2];e=0;g=b>>>1|0;while(1){if((e|0)!=(g|0)){ay(f+(e<<1)|0,f+(b+(e^-1)<<1)|0);e=e+1|0;continue}break};break k;case 0:break l;default:break j}}f=v[c+20>>2];e=0;g=b>>>1|0;while(1){if((e|0)!=(g|0)){xh(e+f|0,f+(b+(e^-1)|0)|0);e=e+1|0;continue}break}}Ai(c,d)}b=w[a+140|0]}if(b&4){m:{if(!Sd(c)){break m}e=x[c+34>>1];b=B(v[c>>2],zd(e));n:{o:{switch(Nm(e)-1|0){case 1:f=v[c+20>>2];e=0;while(1){if((b|0)!=(e|0)){g=f+(e<<1)|0;u[g>>1]=x[g>>1]^-1;e=e+1|0;continue}break};break n;case 0:break o;default:break m}}f=v[c+20>>2];e=0;while(1){if((b|0)!=(e|0)){g=e+f|0;t[g|0]=w[g|0]^-1;e=e+1|0;continue}break}}Ai(c,d)}}i=w[a+170|0]!=2|w[a+171|0]>100?i:w[a+172|0]<101;b=x[c+34>>1];if(!(!(w[a+141|0]?1:i|w[a+160|0]!=0)|b&1)){e=nt(v[c>>2],zd(b)<<1&254);if(!e){break i}b=e;f=v[c>>2];g=x[c+34>>1];h=B(zd(g),f);j=v[c+20>>2];f=Fj(f,g);g=cb-16|0;cb=g;v[g+12>>2]=h;qc(g+12|0,f);f=v[g+12>>2];while(1){if(f){u[b>>1]=t[j|0]<<8;j=j+1|0;b=b+2|0;f=f-1|0;continue}break}cb=g+16|0;u[c+34>>1]=x[c+34>>1]|1;CP(c,e,v[c>>2],d)}p:{if(t[a+141|0]>=0){break p}Ub(k+48|0,v[c+20>>2],B(v[c>>2],zd(x[c+34>>1])));f=v[k+52>>2];e=v[k+48>>2];q:while(1){if((0-t[a+141|0]|0)<=(l|0)){break p}h=u[e>>1];g=Xb(e,f);b=e;while(1)if((b|0)==(g|0)){l=l+1|0;continue q}else{h=bd(u[b>>1]-bd(h,1)|0,1);u[b>>1]=h;b=b+2|0;continue}}}r:{if(!i){break r}Ub(k+48|0,v[c+20>>2],B(v[c>>2],zd(x[c+34>>1])));i=v[k+52>>2];b=(i|0)/2|0;g=b>>31;m=b;b=w[a+172|0];h=w[a+171|0];e=h;f=0-(b>>>0<e>>>0)|0;b=b-e|0;e=f<<24|b>>>8;j=b<<24;f=m+j|0;b=e+g|0;b=yc(lka(f,f>>>0<j>>>0?b+1|0:b,i,i>>31),fb);f=b;j=b>>31;b=h<<24;h=b;e=b>>31;b=v[k+48>>2];l=Xb(b,i);while(1){if((b|0)==(l|0)){break r}i=u[b>>1];i=kka(h,e,i,i>>31)+838860800|0;g=fb;y=b,z=yc(lka(i,i>>>0<838860800?g+1|0:g,1677721600,0),fb),u[y>>1]=z;b=b+2|0;e=e+j|0;i=f+h|0;e=i>>>0<f>>>0?e+1|0:e;h=i;continue}}s:{if(!w[a+160|0]){break s}Ub(k+176|0,v[c+20>>2],B(v[c>>2],zd(x[c+34>>1])));b=w[a+162|0];i=w[a+163|0];t:{if(w[a+161|0]<=1){f=0;e=v[k+180>>2];g=0;break t}f=v[k+180>>2];e=(f|0)/2|0;j=e>>31;h=e;e=w[a+164|0];g=0-(b>>>0>e>>>0)|0;e=e-b|0;l=e<<23;h=h+l|0;e=(g<<23|e>>>9)+j|0;f=yc(lka(h,h>>>0<l>>>0?e+1|0:e,f,f>>31),fb);e=v[k+180>>2];g=(e|0)/2|0;j=g>>31;m=g;g=w[a+165|0];l=0-(i>>>0>g>>>0)|0;h=g-i|0;g=l<<23|h>>>9;l=h<<23;h=m+l|0;g=g+j|0;g=yc(lka(h,h>>>0<l>>>0?g+1|0:g,e,e>>31),fb)}h=b<<23;i=i<<23;j=(k+48|0)+((w[a+160|0]&2)<<2)|0;l=0;b=v[k+176>>2];o=Xb(b,e);e=0;while(1){if((b|0)==(o|0)){break s}m=(u[b>>1]>>1)-e|0;v[k+56>>2]=m;q=m;m=(h|0)/8388608|0;l=bd(B(q,m),8)+l|0;v[k+52>>2]=l;e=bd(B(l,m),6)+e|0;e=bd(bd(B(e,(i|0)/8388608|0),6)+e|0,2);v[k+48>>2]=e;y=b,z=Wc(v[j>>2]),u[y>>1]=z;b=b+2|0;i=g+i|0;h=f+h|0;continue}}u:{if(t[a+141|0]<=0){break u}Ub(k+48|0,v[c+20>>2],B(v[c>>2],zd(x[c+34>>1])));l=0;f=v[k+52>>2];e=v[k+48>>2];v:while(1){if(t[a+141|0]<=(l|0)){break u}h=u[e>>1];i=Xb(e,f);b=e;while(1)if((b|0)==(i|0)){l=l+1|0;continue v}else{h=((u[b>>1]<<1)+h|0)/3|0;u[b>>1]=h;b=b+2|0;continue}}}b=x[c+34>>1];w:{if(b&1){Ub(k+32|0,v[c+20>>2],B(v[c>>2],zd(b)));j=cb-16|0;cb=j;b=v[k+32>>2];l=Xb(b,v[k+36>>2]);o=cb-16|0;cb=o;v[o+12>>2]=b;m=j+8|0;f=On(m,b,o+12|0);x:{if((b|0)==(l|0)){break x}e=b+2|0;if((l|0)==(e|0)){break x}y=(wj(x[e>>1],x[v[f>>2]>>1])?0:4)+f|0,z=e,v[y>>2]=z;g=f+4|0;while(1){h=e;i=e+2|0;if((l|0)!=(i|0)){e=h+4|0;if((l|0)==(e|0)){v[o+12>>2]=l;e=x[h+2>>1];if(!wj(e,x[v[f>>2]>>1])){f=g;if(wj(e,x[v[f>>2]>>1])){break x}}v[f>>2]=i;break x}r=x[v[f>>2]>>1];q=x[e>>1];h=x[h+2>>1];y:{if(wj(q,h)){if(wj(q,r)){v[f>>2]=e}if(wj(h,x[v[g>>2]>>1])){continue}break y}if(wj(h,r)){v[f>>2]=i}i=e;if(wj(q,x[v[g>>2]>>1])){continue}}v[g>>2]=i;continue}break}v[o+12>>2]=h}cb=o+16|0;v[j+4>>2]=0-u[v[m>>2]>>1];y=j,z=u[v[bc(m)>>2]>>1],v[y>>2]=z;z:{e=v[Ke(j+4|0,j)>>2];if((e|0)>32766|!e){break z}while(1){if((b|0)==(l|0)){break z}u[b>>1]=(B(u[b>>1],32767)|0)/(e|0);b=b+2|0;continue}}break w}Ub(k+24|0,v[c+20>>2],B(v[c>>2],zd(b)));j=cb-16|0;cb=j;b=v[k+24>>2];l=Eb(b,v[k+28>>2]);o=cb-16|0;cb=o;v[o+12>>2]=b;m=j+8|0;f=On(m,b,o+12|0);A:{if((b|0)==(l|0)){break A}e=b+1|0;if((l|0)==(e|0)){break A}y=(ll(w[e|0],w[v[f>>2]])?0:4)+f|0,z=e,v[y>>2]=z;g=f+4|0;while(1){h=e;i=e+1|0;if((l|0)!=(i|0)){e=h+2|0;if((l|0)==(e|0)){v[o+12>>2]=l;e=w[h+1|0];if(!ll(e,w[v[f>>2]])){f=g;if(ll(e,w[v[f>>2]])){break A}}v[f>>2]=i;break A}r=w[v[f>>2]];q=w[e|0];h=w[h+1|0];B:{if(ll(q,h)){if(ll(q,r)){v[f>>2]=e}if(ll(h,w[v[g>>2]])){continue}break B}if(ll(h,r)){v[f>>2]=i}i=e;if(ll(q,w[v[g>>2]])){continue}}v[g>>2]=i;continue}break}v[o+12>>2]=h}cb=o+16|0;v[j+4>>2]=0-t[v[m>>2]];y=j,z=t[v[bc(m)>>2]],v[y>>2]=z;C:{e=v[Ke(j+4|0,j)>>2];if((e|0)>126|!e){break C}while(1){if((b|0)==(l|0)){break C}t[b|0]=(B(t[b|0],127)|0)/(e|0);b=b+1|0;continue}}}cb=j+16|0;D:{if((w[a+134|0]-101&255)>>>0>98){break D}e=x[c+34>>1];b=B(v[c>>2],zd(e));if(e&1){e=v[c+20>>2];v[k+16>>2]=e;y=k,z=jt(e,e+(b<<1)|0),v[y+20>>2]=z;b=(3276800-(w[a+134|0]<<14)|0)/100|0;g=0-b|0;f=32768-b|0;e=v[k+16>>2];h=Xb(e,v[k+20>>2]);while(1){if((e|0)!=(h|0)){i=u[e>>1];E:{if((i|0)>(b|0)){m=f+((B(b,i-b|0)|0)/(f|0)|0)|0;break E}m=((B(b,b+i|0)|0)/(f|0)|0)-f|0;if((g|0)>(i|0)){break E}m=(B(f,i)|0)/(b|0)|0}y=e,z=Wc(m),u[y>>1]=z;e=e+2|0;continue}break}break D}e=v[c+20>>2];i=hn(k+8|0,e,b+e|0);e=v[i>>2];b=(3276800-(w[a+134|0]<<14)|0)/100|0;g=0-b|0;f=32768-b|0;h=Eb(e,v[i+4>>2]);while(1){if((e|0)!=(h|0)){i=t[e|0]<<8;F:{if((i|0)>(b|0)){m=f+((B(b,i-b|0)|0)/(f|0)|0)|0;break F}m=((B(b,b+i|0)|0)/(f|0)|0)-f|0;if((g|0)>(i|0)){break F}m=(B(f,i)|0)/(b|0)|0}y=e,z=xR((m|0)/256|0),t[y|0]=z;e=e+1|0;continue}break}}if(!v[n>>2]|(!w[a+131|0]|w[a+128|0]!=8)){break i}v[c+12>>2]=v[p>>2];v[c+16>>2]=v[n>>2]+v[p>>2];i=v[n>>2];f=w[a+131|0];if(i>>>0>268435456/(f>>>0)>>>0){break i}e=v[c>>2];b=B(f,i);if(e>>>0>268435456-b>>>0){break i}g=v[p>>2];e=b+e|0;b=Ak(x[c+34>>1]);h=nt(e,b);if(!h){break i}i=g+B(i,f+1|0)|0;v[c>>2]=e;g=v[c+20>>2];f=ic(h,g,B(b,v[n>>2]+v[p>>2]|0));h=0;while(1){if(w[a+131|0]<=h>>>0){ic(f+B(b,i)|0,g+B(b,v[n>>2]+v[p>>2]|0)|0,B(b,e-i|0));CP(c,f,e,d)}else{l=v[p>>2];h=h+1|0;j=v[n>>2];ic(f+B(b,l+B(h,j)|0)|0,g+B(b,l)|0,B(b,j));continue}break}}cb=k+208|0}function _P(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;k=cb-336|0;cb=k;n=h;o=i&65535;p=d;m=e&65535;r=(e^i)&-2147483648;u=i>>>16&32767;I=e>>>16&32767;a:{b:{if(u-32767>>>0>4294934529&I-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){z=d;r=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){z=h;r=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;r=2147450880;break a}r=r|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));z=b?0:z;r=b?2147450880:r;b=0;c=0;break a}if(!(f|h|(e|g))){r=r|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){i=b;d=!(m|p);h=d<<6;j=E(d?b:p)+32|0;b=E(d?c:m);b=h+((b|0)==32?j:b)|0;Tf(k+320|0,i,c,p,m,b-15|0);l=16-b|0;p=v[k+328>>2];m=v[k+332>>2];c=v[k+324>>2];b=v[k+320>>2]}if(e>>>0>65535){break b}d=!(n|o);e=d<<6;h=E(d?f:n)+32|0;d=E(d?g:o);d=e+((d|0)==32?h:d)|0;Tf(k+304|0,f,g,n,o,d-15|0);l=(d+l|0)-16|0;n=v[k+312>>2];o=v[k+316>>2];f=v[k+304>>2];g=v[k+308>>2]}e=o|65536;F=e;G=n;d=n;j=e<<15|d>>>17;e=d<<15|g>>>17;d=0-e|0;h=j;i=1963258675-(j+((e|0)!=0)|0)|0;xf(k+288|0,e,j,0,0,d,i,0,0);j=v[k+296>>2];xf(k+272|0,0-j|0,0-(v[k+300>>2]+((j|0)!=0)|0)|0,0,0,d,i,0,0);d=v[k+280>>2];i=d<<1|v[k+276>>2]>>>31;d=v[k+284>>2]<<1|d>>>31;xf(k+256|0,i,d,0,0,e,h,0,0);j=d;d=v[k+264>>2];xf(k+240|0,i,j,0,0,0-d|0,0-(v[k+268>>2]+((d|0)!=0)|0)|0,0,0);i=v[k+248>>2];j=i<<1|v[k+244>>2]>>>31;d=v[k+252>>2]<<1|i>>>31;xf(k+224|0,j,d,0,0,e,h,0,0);i=d;d=v[k+232>>2];xf(k+208|0,j,i,0,0,0-d|0,0-(v[k+236>>2]+((d|0)!=0)|0)|0,0,0);d=v[k+216>>2];i=d<<1|v[k+212>>2]>>>31;d=v[k+220>>2]<<1|d>>>31;xf(k+192|0,i,d,0,0,e,h,0,0);j=d;d=v[k+200>>2];xf(k+176|0,i,j,0,0,0-d|0,0-(v[k+204>>2]+((d|0)!=0)|0)|0,0,0);d=e;i=v[k+184>>2];e=i<<1|v[k+180>>2]>>>31;s=e-1|0;i=(v[k+188>>2]<<1|i>>>31)-!e|0;xf(k+160|0,d,h,0,0,s,i,0,0);d=f;j=g<<15|d>>>17;xf(k+144|0,d<<15,j,0,0,s,i,0,0);h=v[k+172>>2];o=v[k+160>>2];e=v[k+152>>2];d=o+e|0;n=v[k+164>>2];j=n+v[k+156>>2]|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=j;n=(n|0)==(d|0)&e>>>0<o>>>0|d>>>0<n>>>0;j=n+v[k+168>>2]|0;h=j>>>0<n>>>0?h+1|0:h;o=!d&e>>>0>1|(d|0)!=0;n=o+j|0;j=h;h=n;xf(k+112|0,s,i,0,0,0-h|0,0-(((h|0)!=0)+(h>>>0<o>>>0?j+1|0:j)|0)|0,0,0);xf(k+128|0,1-e|0,0-((e>>>0>1)+d|0)|0,0,0,s,i,0,0);N=(I-u|0)+l|0;e=v[k+116>>2];A=e;d=v[k+112>>2];j=e<<1|d>>>31;D=d<<1;q=j;d=j;h=v[k+140>>2];B=h;e=v[k+136>>2];j=h<<1|e>>>31;i=e<<1|v[k+132>>2]>>>31;h=i+D|0;d=d+j|0;d=h>>>0<i>>>0?d+1|0:d;e=d;d=d-(h>>>0<13927)|0;w=d;J=d;l=0;d=m|65536;I=d;K=p;C=(d&2147483647)<<1|p>>>31;x=kka(w,l,C,0);d=fb;t=d;j=b;d=c<<1|j>>>31;u=j<<1;s=d;n=d;j=0;o=j;i=h-13927|0;l=(e|0)==(w|0)&i>>>0<h>>>0|e>>>0>w>>>0;m=(e|0)==(q|0)&h>>>0<D>>>0|e>>>0<q>>>0;d=v[k+120>>2];h=v[k+124>>2]<<1|d>>>31;e=B>>>31|0;d=e+(d<<1|A>>>31)|0;j=h;j=d>>>0<e>>>0?j+1|0:j;e=d;d=m+d|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=l+d|0;l=d>>>0<e>>>0?j+1|0:j;e=d;d=d-1|0;H=l-!e|0;D=0;j=kka(n,o,H,D);e=j+x|0;h=fb+t|0;h=e>>>0<j>>>0?h+1|0:h;l=(h|0)==(t|0)&e>>>0<x>>>0|h>>>0<t>>>0;j=0;x=l;q=d;d=p;O=c>>>31|0;t=O|d<<1;B=0;l=kka(q,j,t,B);d=l+e|0;j=fb+h|0;j=d>>>0<l>>>0?j+1|0:j;p=d;m=j;e=(j|0)==(h|0)&d>>>0<e>>>0|h>>>0>j>>>0;d=x+e|0;l=0;l=d>>>0<e>>>0?1:l;e=kka(C,o,H,D);d=e+d|0;j=fb+l|0;x=d;d=d>>>0<e>>>0?j+1|0:j;l=kka(C,o,q,B);h=fb;w=kka(t,B,H,D);e=w+l|0;j=fb+h|0;j=e>>>0<w>>>0?j+1|0:j;w=e;e=j;j=(h|0)==(j|0)&l>>>0>w>>>0|h>>>0>j>>>0;l=x+e|0;d=d+j|0;h=l;l=h>>>0<e>>>0?d+1|0:d;e=0;d=e+p|0;j=m+w|0;j=d>>>0<e>>>0?j+1|0:j;e=j;m=(j|0)==(m|0)&d>>>0<p>>>0|j>>>0<m>>>0;h=m+h|0;j=l;x=h;l=h>>>0<m>>>0?j+1|0:j;p=d;m=e;w=i;h=kka(i,0,t,B);e=fb;i=kka(J,o,n,o);d=i+h|0;j=fb+e|0;j=d>>>0<i>>>0?j+1|0:j;e=(e|0)==(j|0)&d>>>0<h>>>0|e>>>0>j>>>0;h=j;L=x;A=e;M=u&-2;i=kka(q,B,M,0);e=i+d|0;j=fb+j|0;j=e>>>0<i>>>0?j+1|0:j;x=e;i=e;e=j;i=(j|0)==(h|0)&d>>>0>i>>>0|h>>>0>j>>>0;d=A+i|0;h=0;h=d>>>0<i>>>0?1:h;j=d;i=d+p|0;d=h+m|0;A=i;h=i;d=h>>>0<j>>>0?d+1|0:d;i=d;h=(d|0)==(m|0)&h>>>0<p>>>0|d>>>0<m>>>0;d=L+h|0;j=l;L=d;p=d>>>0<h>>>0?j+1|0:j;P=kka(C,o,w,z);C=fb;h=kka(H,D,M,z);d=h+P|0;j=fb+C|0;H=d;m=kka(J,o,t,B);l=d+m|0;h=d>>>0<h>>>0?j+1|0:j;d=h+fb|0;d=l>>>0<m>>>0?d+1|0:d;t=l;m=kka(n,o,q,B);j=l+m|0;l=fb+d|0;D=j;l=j>>>0<m>>>0?l+1|0:l;m=0;q=(d|0)==(l|0)&t>>>0>j>>>0|d>>>0>l>>>0;j=(d|0)==(h|0)&t>>>0<H>>>0|d>>>0<h>>>0;d=j+((h|0)==(C|0)&H>>>0<P>>>0|h>>>0<C>>>0)|0;h=0;d=q+d|0;q=l|0;h=q+A|0;j=(d|m)+i|0;j=h>>>0<q>>>0?j+1|0:j;q=h;d=h;m=j;h=(i|0)==(j|0)&d>>>0<A>>>0|i>>>0>j>>>0;d=h+L|0;j=p;C=d;i=d>>>0<h>>>0?j+1|0:j;t=kka(J,o,M,z);A=fb;h=kka(n,o,w,z);d=h+t|0;j=fb+A|0;j=d>>>0<h>>>0?j+1|0:j;p=0;h=(j|0)==(A|0)&d>>>0<t>>>0|j>>>0<A>>>0;n=j;d=j+x|0;j=(h|p)+e|0;h=d;j=d>>>0<n>>>0?j+1|0:j;n=(e|0)==(j|0)&d>>>0<x>>>0|e>>>0>j>>>0;e=0+d|0;d=j;l=D+d|0;l=e>>>0<p>>>0?l+1|0:l;e=(d|0)==(l|0)&e>>>0<h>>>0|d>>>0>l>>>0;d=n+e|0;j=0;j=d>>>0<e>>>0?1:j;e=d;d=d+q|0;j=j+m|0;j=d>>>0<e>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&d>>>0<q>>>0|j>>>0<m>>>0;h=j+C|0;l=h>>>0<j>>>0?i+1|0:i;i=l;c:{if((i|0)==131071|i>>>0<131071){j=K;l=I<<1|j>>>31;K=O|j<<1;I=l|B;xf(k+80|0,d,e,h,i,f,g,G,F);l=b<<17;b=0;c=v[k+88>>2];m=b-c|0;j=v[k+80>>2];o=v[k+84>>2];n=(j|o)!=0;p=m-n|0;m=(l-(v[k+92>>2]+(b>>>0<c>>>0)|0)|0)-(m>>>0<n>>>0)|0;n=0-j|0;o=0-(((j|0)!=0)+o|0)|0;b=N+16382|0;break c}d=(e&1)<<31|d>>>1;e=h<<31|e>>>1;h=(i&1)<<31|h>>>1;i=i>>>1|0;xf(k+96|0,d,e,h,i,f,g,G,F);m=0;n=v[k+104>>2];o=m-n|0;j=v[k+96>>2];s=v[k+100>>2];u=(j|s)!=0;p=o-u|0;m=((b<<16)-(v[k+108>>2]+(m>>>0<n>>>0)|0)|0)-(o>>>0<u>>>0)|0;n=0-j|0;o=0-(((j|0)!=0)+s|0)|0;u=b;s=c;b=N+16383|0}if((b|0)>=32767){r=r|2147418112;b=0;c=0;break a}d:{if((b|0)>0){c=p;j=m<<1|c>>>31;p=c<<1|o>>>31;m=j;u=h;s=i&65535|b<<16;b=n;j=o<<1|b>>>31;b=b<<1;break d}if((b|0)<=-113){b=0;c=0;break a}qm(k- -64|0,d,e,h,i,1-b|0);Tf(k+48|0,u,s,K,I,b+112|0);d=v[k+64>>2];e=v[k+68>>2];u=v[k+72>>2];s=v[k+76>>2];xf(k+32|0,f,g,G,F,d,e,u,s);c=v[k+40>>2];i=c<<1;c=v[k+44>>2]<<1|c>>>31;b=v[k+56>>2];h=v[k+36>>2];p=h>>>31|i;i=b-p|0;l=v[k+60>>2]-((b>>>0<p>>>0)+c|0)|0;c=v[k+32>>2];h=h<<1|c>>>31;c=c<<1;j=v[k+52>>2];b=v[k+48>>2];m=(h|0)==(j|0)&c>>>0>b>>>0|h>>>0>j>>>0;p=i-m|0;m=l-(i>>>0<m>>>0)|0;i=b;b=i-c|0;j=j-((c>>>0>i>>>0)+h|0)|0}xf(k+16|0,f,g,G,F,3,0,0,0);xf(k,f,g,G,F,5,0,0,0);i=d;n=d&1;c=b+n|0;d=0;h=j+d|0;h=b>>>0>c>>>0?h+1|0:h;l=c;b=l;g=(g|0)==(h|0)&b>>>0>f>>>0|g>>>0<h>>>0;c=(d|0)==(h|0)&b>>>0<n>>>0|d>>>0>h>>>0;b=c+p|0;j=m;j=b>>>0<c>>>0?j+1|0:j;f=b;c=j;d=(b|0)==(G|0)&(j|0)==(F|0)?g:(F|0)==(j|0)&b>>>0>G>>>0|j>>>0>F>>>0;b=i+d|0;j=e;j=b>>>0<d>>>0?j+1|0:j;d=b;b=j;g=(j|0)==(e|0)&d>>>0<i>>>0|e>>>0>j>>>0;e=g+u|0;j=s;j=e>>>0<g>>>0?j+1|0:j;g=e;e=d;n=g;d=v[k+20>>2];i=(d|0)==(h|0)&y[k+16>>2]<l>>>0|d>>>0<h>>>0;d=v[k+28>>2];g=v[k+24>>2];i=j>>>0<2147418112&((f|0)==(g|0)&(c|0)==(d|0)?i:(d|0)==(c|0)&g>>>0<f>>>0|c>>>0>d>>>0);g=e+i|0;d=b;d=g>>>0<i>>>0?d+1|0:d;e=(b|0)==(d|0)&e>>>0>g>>>0|b>>>0>d>>>0;b=n+e|0;j=b>>>0<e>>>0?j+1|0:j;e=j;i=b;b=v[k+4>>2];l=(b|0)==(h|0)&y[k>>2]<l>>>0|b>>>0<h>>>0;b=v[k+12>>2];h=v[k+8>>2];c=j>>>0<2147418112&((f|0)==(h|0)&(b|0)==(c|0)?l:(b|0)==(c|0)&h>>>0<f>>>0|b>>>0<c>>>0);b=c+g|0;j=b>>>0<c>>>0?d+1|0:d;c=j;g=(d|0)==(j|0)&b>>>0<g>>>0|d>>>0>j>>>0;f=i+g|0;d=e;z=f|z;r=r|(f>>>0<g>>>0?d+1|0:d)}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=z;v[a+12>>2]=r;cb=k+336|0}function UH(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=cb-128|0;cb=h;a:{b:{if(g){Me(h+112|0,f,32);v[22440]=0;Y(540,h+96|0,f|0,32)|0;k=v[22440];v[22440]=0;if((k|0)!=1){break b}f=P()|0;O()|0;break a}Db(h+112|0);Db(h+96|0)}c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if(Qr(c)){m=b+24|0;b=v[m>>2]+484344|0;if(ve(b,c&65535)){break t}}v[22440]=0;U(1112,a|0,h+112|0,h+96|0);a=v[22440];v[22440]=0;if((a|0)!=1){break s}f=P()|0;O()|0;break c}b=Sb(b,c);if(!(v[b+12>>2]>(d|0)&(d|0)>=0)){v[22440]=0;U(1112,a|0,h+112|0,h+96|0);a=v[22440];v[22440]=0;if((a|0)!=1){break s}break d}if(!(x[v[m>>2]+480188>>1]>e>>>0&(e|0)>=0)){v[22440]=0;U(1112,a|0,h+112|0,h+96|0);a=v[22440];v[22440]=0;if((a|0)==1){break d}break s}c=Zc(b,d,e&65535);dg(h+112|0);dg(h+96|0);u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{b=w[c|0];if(!Rc(b)){if(!pp(b)){break I}}d=v[m>>2];e=w[c+1|0];v[22440]=0;W(1113,h- -64|0,d|0,b|0,e|0);b=v[22440];v[22440]=0;d=1;if((b|0)==1){break G}v[22440]=0;R(1033,h+80|0,h- -64|0);b=v[22440];v[22440]=0;if((b|0)!=1){break H}f=P()|0;O()|0;break D}d=0;v[22440]=0;Q(56,h+80|0,16796)|0;b=v[22440];v[22440]=0;if((b|0)==1){break F}}v[22440]=0;k=Q(824,h+112|0,h+80|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break E}rb(h+80|0);if(d){rb(h- -64|0)}b=w[c|0];J:{if(Rc(b)){v[22440]=0;Q(56,h+80|0,9987)|0;b=v[22440];v[22440]=0;if((b|0)==1){break e}break J}if(pp(b)){v[22440]=0;Q(56,h+80|0,10297)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break J}break e}v[22440]=0;Q(56,h+80|0,16796)|0;b=v[22440];v[22440]=0;if((b|0)==1){break e}}v[22440]=0;d=Q(824,h+96|0,h+80|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break C}rb(h+80|0);if(f-6>>>0>4294967290){break v}v[22440]=0;b=Q(56,h+80|0,17856)|0;e=v[22440];v[22440]=0;if((e|0)==1){break B}v[22440]=0;e=Q(824,k|0,b|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break A}rb(b);v[22440]=0;b=Q(56,h+80|0,17856)|0;j=v[22440];v[22440]=0;if((j|0)==1){break z}v[22440]=0;j=Q(824,d|0,b|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break y}rb(b);b=c+1|0;K:{if(w[c+1|0]){v[22440]=0;R(557,h+80|0,b|0);i=v[22440];v[22440]=0;if((i|0)!=1){break K}break f}v[22440]=0;Q(56,h+80|0,16801)|0;i=v[22440];v[22440]=0;if((i|0)==1){break f}}v[22440]=0;i=Q(824,e|0,h+80|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break x}rb(h+80|0);L:{if(w[b|0]){v[22440]=0;Q(56,h+80|0,10791)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break L}break g}v[22440]=0;Q(56,h+80|0,16801)|0;b=v[22440];v[22440]=0;if((b|0)==1){break g}}v[22440]=0;j=Q(824,j|0,h+80|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break w}f=P()|0;O()|0;rb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;rb(h+80|0);if(!d){break c}}rb(h- -64|0);break c}f=P()|0;O()|0;rb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;rb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;rb(b);break c}f=P()|0;O()|0;rb(h+80|0);break c}rb(h+80|0);if(f-9>>>0>4294967287){break v}M:{N:{O:{P:{Q:{R:{S:{if(eh(w[c|0])){v[22440]=0;e=Q(56,h+48|0,17856)|0;b=v[22440];v[22440]=0;if((b|0)==1){break R}b=w[c+4|0];l=w[c+2|0];v[22440]=0;n=h,o=ek(l,b)&255,v[n+16>>2]=o;R(556,h+32|0,h+16|0);b=v[22440];v[22440]=0;if((b|0)==1){break Q}b=0;v[22440]=0;U(990,h+80|0,e|0,h+32|0);l=v[22440];v[22440]=0;e=1;if((l|0)!=1){break S}f=P()|0;O()|0;break i}b=w[c+2|0];if(b){b=UK(v[v[v[m>>2]+8>>2]+88>>2],b);v[22440]=0;b=Y(540,h+48|0,1,b|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break N}v[22440]=0;R(557,h+32|0,c+4|0);e=v[22440];v[22440]=0;if((e|0)==1){break P}e=0;v[22440]=0;U(990,h+80|0,b|0,h+32|0);l=v[22440];v[22440]=0;b=1;if((l|0)!=1){break S}f=P()|0;O()|0;break l}e=0;v[22440]=0;Q(56,h+80|0,16800)|0;l=v[22440];v[22440]=0;b=0;if((l|0)==1){break o}}v[22440]=0;i=Q(824,i|0,h+80|0)|0;l=v[22440];v[22440]=0;if((l|0)==1){break O}rb(h+80|0);if(b){rb(h+32|0);rb(h+48|0)}if(e){rb(h+32|0);rb(h+48|0)}T:{if(eh(w[c|0])){v[22440]=0;Q(56,h+80|0,5491)|0;b=v[22440];v[22440]=0;if((b|0)==1){break m}break T}if(w[c+2|0]){v[22440]=0;Q(56,h+80|0,5487)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break T}break m}v[22440]=0;Q(56,h+80|0,16800)|0;b=v[22440];v[22440]=0;if((b|0)==1){break m}}v[22440]=0;e=Q(824,j|0,h+80|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break M}f=P()|0;O()|0;rb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break h}f=P()|0;e=0;O()|0;break k}f=P()|0;O()|0;rb(h+80|0);if(b){break l}break j}f=P()|0;O()|0;break c}rb(h+80|0);if(f-13>>>0>4294967283){break v}v[22440]=0;b=Q(56,h+80|0,17856)|0;j=v[22440];v[22440]=0;U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{if((j|0)!=1){v[22440]=0;j=Q(824,i|0,b|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break ba}rb(b);v[22440]=0;b=Q(56,h+80|0,17856)|0;i=v[22440];v[22440]=0;if((i|0)==1){break aa}v[22440]=0;i=Q(824,e|0,b|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break $}rb(b);b=w[c+3|0];ca:{if(eh(w[c|0])){m=w[c+5|0];e=0;v[22440]=0;n=h,o=ek(b,m)&4095,v[n+28>>2]=o;R(1114,h+80|0,h+28|0);b=v[22440];v[22440]=0;if((b|0)!=1){break ca}f=P()|0;O()|0;break c}if(b){b=TK(v[v[v[m>>2]+8>>2]+84>>2],b);v[22440]=0;b=Y(540,h+16|0,1,b|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break _}v[22440]=0;R(557,h|0,c+5|0);e=v[22440];v[22440]=0;if((e|0)==1){break Z}v[22440]=0;U(990,h+80|0,b|0,h|0);b=v[22440];v[22440]=0;e=1;if((b|0)!=1){break ca}f=P()|0;O()|0;break W}e=0;v[22440]=0;Q(56,h+80|0,16796)|0;b=v[22440];v[22440]=0;if((b|0)==1){break Y}}v[22440]=0;Q(824,j|0,h+80|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break X}rb(h+80|0);if(e){rb(h);rb(h+16|0)}da:{if(eh(w[c|0])){v[22440]=0;Q(56,h+80|0,11134)|0;b=v[22440];v[22440]=0;if((b|0)==1){break n}break da}if(w[c+3|0]){v[22440]=0;Q(56,h+80|0,11134)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break da}break n}v[22440]=0;Q(56,h+80|0,16796)|0;b=v[22440];v[22440]=0;if((b|0)==1){break n}}v[22440]=0;Q(824,i|0,h+80|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break U}f=P()|0;O()|0;rb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;rb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;rb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break V}f=P()|0;O()|0;break c}f=P()|0;O()|0;rb(h+80|0);if(!e){break c}}rb(h)}rb(h+16|0);break c}rb(h+80|0);if(!f){break u}}ea:{fa:{ga:{ha:{ia:{if(vb(k)>>>0>f>>>0){v[22440]=0;W(132,h+80|0,k|0,0,f|0);b=v[22440];v[22440]=0;if((b|0)!=1){b=h+80|0;tc(k,b);rb(b);break ia}f=P()|0;O()|0;break c}if(!g){break ia}b=vb(k);v[22440]=0;b=Y(540,h+80|0,f-b|0,32)|0;c=v[22440];v[22440]=0;if((c|0)==1){break ha}v[22440]=0;Q(824,k|0,b|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break ga}rb(b)}if(vb(d)>>>0<=f>>>0){break ea}v[22440]=0;W(132,h+80|0,d|0,0,f|0);b=v[22440];v[22440]=0;if((b|0)==1){break fa}b=h+80|0;tc(d,b);rb(b);break u}f=P()|0;O()|0;break c}f=P()|0;O()|0;rb(b);break c}f=P()|0;O()|0;break c}if(!g){break u}b=vb(d);v[22440]=0;b=Y(540,h+80|0,f-b|0,32)|0;c=v[22440];v[22440]=0;if((c|0)==1){break r}v[22440]=0;Q(824,d|0,b|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break q}rb(b)}v[22440]=0;U(1112,a|0,k|0,d|0);a=v[22440];v[22440]=0;if((a|0)==1){break p}}rb(h+96|0);rb(h+112|0);cb=h+128|0;return}f=P()|0;O()|0;break c}f=P()|0;O()|0;rb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}rb(h+32|0)}rb(h+48|0)}if(!e){break c}}rb(h+32|0)}rb(h+48|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}rb(h+96|0)}rb(h+112|0);S(f|0);L()}function OW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=cb-1456|0;cb=e;sc(b);Fo(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!Yq(b,e+1432|0)){break n}if(!VD(e+1432|0)){break n}if(!c){i=1;break n}p=e+1450|0;c=p;if(!Xq(b,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break n}C=e+1444|0;if(!Xq(b,(w[p|0]|w[p+1|0]<<8|(w[p+2|0]<<16|w[p+3|0]<<24))+((w[C|0]|w[C+1|0]<<8)<<2)|0)){break n}tv(a);H=e,I=sv(),v[H+56>>2]=I;d=e+56|0;rv(Sj(v[a+4>>2])+32|0,d);Wq(d);n=v[Sj(v[a+4>>2])+32>>2];c=e+1446|0;v[e+1428>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);H=e,I=Ck(b),v[H+1168>>2]=I;v[e+1128>>2]=214748364;c=e+1168|0;i=e+1128|0;H=e,I=B(v[Bb(c,i)>>2],20),v[H+56>>2]=I;dn(n,v[Bb(e+1428|0,d)>>2]);Hb(c,0,256);k=i|4;l=e+1144|0;D=e+1146|0;z=e+1142|0;m=e+1140|0;E=Rb(e+1152|0);o:{while(1){if((w[C|0]|w[C+1|0]<<8)>>>0>F>>>0){c=w[p|0]|w[p+1|0]<<8|(w[p+2|0]<<16|w[p+3|0]<<24);v[22440]=0;c=Q(157,b|0,c+(F<<2)|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break m}i=0;if(!c){break o}v[22440]=0;c=Q(158,b|0,4)|0;d=v[22440];v[22440]=0;if((d|0)==1){break m}if(!c){break o}v[22440]=0;c=T(159,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break l}v[22440]=0;d=Q(157,b|0,c|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break l}if(!d){break o}v[22440]=0;d=Q(160,b|0,e+1128|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break k}if(!d){break o}d=w[m|0]|w[m+1|0]<<8;v[22440]=0;d=Y(161,b|0,E|0,d|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break k}if(!d){break o}f=v[E>>2];d=w[m|0]|w[m+1|0]<<8;v[22440]=0;g=T(162,b|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break j}j=c+20|0;if(g>>>0<=j+(d<<3)>>>0){break o}c=d?f:0;f=w[m|0]|w[m+1|0]<<8;g=j+(f<<3)|0;d=0;j=w[z|0]|w[z+1|0]<<8;p:{if(!(j&1)){while(1){if(d>>>0>=f>>>0){break p}if(!c){break o}v[22440]=0;f=Y(163,c|0,n|0,v[e+1428>>2])|0;j=v[22440];v[22440]=0;if((j|0)==1){break i}if(!f){break o}v[22440]=0;f=Q(157,b|0,g|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break i}if(!f){break o}f=c+4|0;$b(e+1120|0,Eb(v[n>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));v[22440]=0;W(164,e+56|0,b|0,v[e+1120>>2],v[e+1124>>2]);f=v[22440];v[22440]=0;if((f|0)==1){break h}if(v[e+60>>2]!=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))){break o}d=d+1|0;c=c+8|0;f=w[m|0]|w[m+1|0]<<8;continue}}q:{r:{s:{t:{u:{if(j&4){if(!c){break o}v[22440]=0;d=Y(163,c|0,n|0,v[e+1428>>2])|0;f=v[22440];v[22440]=0;if((f|0)==1){break g}if(!d){break o}u=Eb(v[n>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));o=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&-2;if(!o){break o}f=w[D|0]|w[D+1|0]<<8;d=w[l|0]|w[l+1|0]<<8;v[22440]=0;d=Q(157,b|0,d+g|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break f}if(!d){break o}d=w[l|0]|w[l+1|0]<<8;g=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);v[22440]=0;d=Q(158,b|0,g-d|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break f}if(!d){break o}d=w[l|0]|w[l+1|0]<<8;g=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);v[22440]=0;U(165,e+32|0,b|0,g-d|0);d=v[22440];v[22440]=0;if((d|0)==1){break b}d=e+32|0;q=Vq(e+56|0,d);sb(d);A=0;j=0;v:{w:{x:{while(1){g=0;y:{while(1){if((j&65535)>>>0>=(w[m|0]|w[m+1|0]<<8)>>>0){break x}v[22440]=0;d=Q(166,q|0,f+1|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break y}h=f&15;r=x[(h<<1)+26080>>1];z:{A:{if(r>>>0<=d>>>0){v[22440]=0;h=w[h+26128|0];s=Q(166,q|0,h|0)|0;G=v[22440];v[22440]=0;if((G|0)==1){break y}d=s+(d-r<<h)|0;if((d|0)!=(f|0)){f=d&15;break z}v[22440]=0;d=Q(166,q|0,4)|0;h=v[22440];v[22440]=0;if((h|0)==1){break y}if((d|0)==15){v[22440]=0;h=Q(166,q|0,1)|0;d=v[22440];v[22440]=0;if((d|0)==1){break y}d=65535;if(!h){break A}sb(e+56|0);break p}d=d+65520|0}if(d>>>0>65535){break z}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;s=g+u|0;h=w[z|0]|w[z+1|0]<<8;B:{if(h&2){A=d+A|0;d=A;break B}d=h&512?d:d^32768}r=d>>>8|0;h=h&1024;t[s+1|0]=h?d:r;t[s|0]=h?r:d;g=g+2|0}if(g>>>0<o>>>0){continue}break}j=j+1|0;if(j>>>0>=(w[m|0]|w[m+1|0]<<8)>>>0){break r}v[22440]=0;d=(j<<3)+c|0;g=Y(163,d|0,n|0,v[e+1428>>2])|0;o=v[22440];v[22440]=0;if((o|0)==1){break y}if(!g){break t}o=(w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))&-2;if(!o){break u}u=Eb(v[n>>2],w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));continue}break}i=V(30592)|0;if((O()|0)!=(fa(30592)|0)){break v}_(i|0)|0;v[22440]=0;X(18);c=v[22440];v[22440]=0;if((c|0)==1){break w}}sb(e+56|0);break p}i=P()|0;O()|0}sb(e+56|0);break a}if(!c){break o}v[22440]=0;d=Y(163,c|0,n|0,v[e+1428>>2])|0;f=v[22440];v[22440]=0;if((f|0)==1){break e}if(!d){break o}A=Eb(v[n>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));u=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[D|0]|w[D+1|0]<<8;if((w[l|0]|w[l+1|0]<<8)>>>0>256){break o}v[22440]=0;d=Q(157,b|0,g|0)|0;g=v[22440];v[22440]=0;C:{D:{if((g|0)!=1){if(!d){break o}$b(e+24|0,e+1168|0,w[l|0]|w[l+1|0]<<8);v[22440]=0;W(167,e+56|0,b|0,v[e+24>>2],v[e+28>>2]);d=v[22440];v[22440]=0;if((d|0)==1){break D}if(y[e+60>>2]<(w[l|0]|w[l+1|0]<<8)>>>0){break o}d=w[l|0]|w[l+1|0]<<8;g=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);v[22440]=0;d=Q(158,b|0,g-d|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){break C}}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}if(!d){break o}d=w[l|0]|w[l+1|0]<<8;g=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);v[22440]=0;U(165,e+32|0,b|0,g-d|0);d=v[22440];v[22440]=0;if((d|0)==1){break c}d=e+32|0;q=Vq(e+56|0,d);sb(d);o=0;j=0;E:{F:{G:{while(1){g=0;H:{while(1){if((o&65535)>>>0>=(w[m|0]|w[m+1|0]<<8)>>>0){break G}v[22440]=0;d=Q(166,q|0,f+1|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break H}h=f&7;r=w[h+26112|0];I:{J:{if(r>>>0<=d>>>0){v[22440]=0;h=w[h+26120|0];s=Q(166,q|0,h|0)|0;G=v[22440];v[22440]=0;if((G|0)==1){break H}d=s+(d-r<<h)|0;if((d|0)!=(f|0)){f=d&7;break I}v[22440]=0;d=Q(166,q|0,3)|0;h=v[22440];v[22440]=0;if((h|0)==1){break H}if((d|0)==7){v[22440]=0;h=Q(166,q|0,1)|0;d=v[22440];v[22440]=0;if((d|0)==1){break H}d=255;if(!h){break J}sb(e+56|0);break p}d=d+248|0}if(d>>>0>255){break I}}d=w[(e+1168|0)+d|0];h=d+j|0;s=d;d=(w[z|0]|w[z+1|0]<<8)&2;t[g+A|0]=d?h:s;j=d?h:j;g=g+1|0}if(g>>>0<u>>>0){continue}break}o=o+1|0;if(o>>>0>=(w[m|0]|w[m+1|0]<<8)>>>0){break q}v[22440]=0;d=(o<<3)+c|0;g=Y(163,d|0,n|0,v[e+1428>>2])|0;u=v[22440];v[22440]=0;if((u|0)==1){break H}if(!g){break s}u=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);A=Eb(v[n>>2],w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));continue}break}i=V(30592)|0;if((O()|0)!=(fa(30592)|0)){break E}_(i|0)|0;v[22440]=0;X(18);c=v[22440];v[22440]=0;if((c|0)==1){break F}}sb(e+56|0);break p}i=P()|0;O()|0}sb(e+56|0);break a}sb(e+56|0);break o}sb(e+56|0);break o}sb(e+56|0);break o}sb(e+56|0);break p}sb(e+56|0)}F=F+1|0;continue}break}qe(e+8|0,v[n>>2],v[n+4>>2]);_g(e+16|0,v[e+8>>2],v[e+12>>2]);b=ee(e);c=v[b+4>>2];b=v[b>>2];v[22440]=0;b=ea(168,e+56|0,v[e+16>>2],v[e+20>>2],b|0,c|0)|0;c=v[22440];v[22440]=0;i=1;if((c|0)==1){break d}Sc(Sj(v[a+4>>2])+12|0,b);sb(b)}de(E)}cb=e+1456|0;return i|0}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0}de(E);S(i|0);L()}function Qs(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=cb-32|0;cb=h;v[h+28>>2]=c;a:{if((c|0)<=0){break a}k=v[b+656>>2];if(!(!k|v[a+480180>>2]!=16777216)){m=v[k+44>>2]!=0}i=v[b+104>>2];b:{c:{d:{if(!k){j=c;break d}if((c|0)>128){break c}j=c-1|0;l=x[Xb(k+236|0,j)>>1];e:{if((l-1&65535)>>>0<=3998){i=(B(l,104)+a|0)+484380|0;break e}ub(h+16|0,a+1074312|0,43);if(!tb(v[v[h+16>>2]>>2],v[h+20>>2])){break e}if(!dk(v[b+656>>2])){break a}}j=w[Eb(k+108|0,j)|0];v[h+28>>2]=j}if(j>>>0<121){break b}c=j}f:{if(!(v[a+480180>>2]&16777248?(c|0)!=255:0)){Bn(a,b);if(d){break f}ub(h+16|0,a+1074312|0,100);if(!tb(v[v[h+16>>2]>>2],v[h+20>>2])|!(w[a+480208|0]&4)|!w[b+789|0]){break f}v[b+88>>2]=v[b+88>>2]&-6145;break f}if(!x[a+480192>>1]){break f}v[b+88>>2]=v[b+88>>2]|4096}g:{if((c|0)!=254){break g}c=v[b+88>>2];if(!(!(c&512)|v[a+480180>>2]!=2)){v[b+88>>2]=c|2048;break g}v[b+88>>2]=c|2101248;h:{if(v[a+480180>>2]&16777248){if(!x[a+480192>>1]){break h}ub(h+16|0,a+1074312|0,50);if(tb(v[v[h+16>>2]>>2],v[h+20>>2])){break h}}v[b+688>>2]=0}ub(h+16|0,a+1074312|0,50);if(tb(v[v[h+16>>2]>>2],v[h+20>>2])){v[b+8>>2]=0;v[b+12>>2]=0}v[b+696>>2]=0}ub(h+16|0,a+1074312|0,20);if(!tb(v[v[h+16>>2]>>2],v[h+20>>2])){break a}t[b+797|0]=0;t[b+802|0]=0;break a}i:{j:{k:{if(m){if(d){l=w[b+797|0];if(l){break k}}v[b+708>>2]=0}if(d){break j}if(!(!(v[a+480180>>2]&1048588)|!i)){u[b+770>>1]=t[i+36|0];u[b+772>>1]=t[i+37|0]}if(i){ub(h+16|0,a+1074312|0,24);l=0;o=1;if(!tb(v[v[h+16>>2]>>2],v[h+20>>2])){break i}v[b+704>>2]=v[i+24>>2];break i}i=0;l=0;break i}l=B((v[v[k+44>>2]+36>>2]<<16>>16)+1|0,(j<<16>>16)-l|0)-v[b+852>>2]|0;v[b+708>>2]=l;v[b+852>>2]=0-l}o=(i|0)!=0;l=1;if(zi(v[b+8>>2],v[b+12>>2])){break i}l=a+1074312|0;ub(h+16|0,l,54);if(tb(v[v[h+16>>2]>>2],v[h+20>>2])){v[b+700>>2]=0;break a}ub(h+16|0,l,39);l=(tb(v[v[h+16>>2]>>2],v[h+20>>2])^-1)&d}l:{if(vm(v[a+480180>>2])){v[h+28>>2]=u[b+770>>1]+j;oe(h+28|0,12,131);break l}XQ(h+28|0)}j=a+1074312|0;ub(h+16|0,j,34);m:{if(tb(v[v[h+16>>2]>>2],v[h+20>>2])){d=wl(c);break m}d=v[h+28>>2]}t[b+797|0]=d;t[b+851|0]=w[b+851|0]&183|64;if(!(v[a+480180>>2]&16777250?0:l)){t[b+803|0]=0}d=ch(a,v[h+28>>2],u[b+772>>1],v[b+704>>2]);t[b+831|0]=0;ub(h+16|0,j,48);if(tb(v[v[h+16>>2]>>2],v[h+20>>2])){FM(a,b,k,i)}ub(h+16|0,j,115);if(!(!tb(v[v[h+16>>2]>>2],v[h+20>>2])|!k|!w[k+26|0])){if(!x[b+784>>1]){u[b+784>>1]=x[b+692>>1]+1}EM(b+692|0,c,k)}n:{if(e^1|l){break n}v[b+776>>2]=0;v[b+780>>2]=0;if(!k){break n}ub(h+16|0,j,29);if(tb(v[v[h+16>>2]>>2],v[h+20>>2])){t[b+798|0]=w[k+16|0]}if(!(w[k+60|0]&8)){mj(b+724|0)}if(!(w[k+80|0]&8)){mj(b+732|0)}if(!(w[k+100|0]&8)){mj(b+740|0)}if(w[k+20|0]){c=Os(An(a));n=w[k+20|0];ub(h+16|0,j,28);n=((B(c,n)<<16>>16)/64<<16)+65536>>16;o:{if(tb(v[v[h+16>>2]>>2],v[h+20>>2])){c=v[b+752>>2];break o}c=(v[b+688>>2]+1|0)/2|0}u[b+776>>1]=(B(c,n)|0)/199}p:{if(!w[k+19|0]){break p}q=b,r=(B(Os(An(a)),w[k+19|0])<<16>>16)/32|0,u[q+778>>1]=r;ub(h+16|0,j,28);if(tb(v[v[h+16>>2]>>2],v[h+20>>2])|x[b+784>>1]){break p}u[b+784>>1]=x[b+692>>1]+1}c=w[k+23|0];if(c){n=Os(An(a));p=w[b+837|0];t[b+796|0]=p+1;u[b+780>>1]=(B(p,(B(c,n+1|0)<<16>>16)/128<<16>>16)+1|0)/128}c=w[k+24|0];if(!c){break n}n=Os(An(a));p=w[b+838|0];t[b+795|0]=p+1;u[b+782>>1]=(B(p,(B(c,n+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!o){break a}c=0;q:{r:{if(!d){break r}if(!(v[b+700>>2]?l:0)){v[b+700>>2]=d}s:{t:{if(!m){if(!l){ub(h+16|0,j,69);if(tb(v[v[h+16>>2]>>2],v[h+20>>2])){break t}ub(h+8|0,j,46);if(tb(v[v[h+8>>2]>>2],v[h+12>>2])|v[a+480180>>2]==1){break t}}v[b+708>>2]=d;t[b+851|0]=w[b+851|0]&239}if(!l){break t}if(v[b+76>>2]|w[a+480180|0]&2){break s}}v[b+104>>2]=i;d=v[i>>2];v[b+84>>2]=d;v[b+76>>2]=d;v[b+80>>2]=0;v[b>>2]=0;v[b+4>>2]=0;u:{v:{if(!(v[a+480208>>2]&2097152)){ub(h+16|0,j,96);if(!tb(v[v[h+16>>2]>>2],v[h+20>>2])){break v}}if(w[b+789|0]){break v}v[h+16>>2]=v[b+76>>2]-1;q=b,r=v[Bb(b+660|0,h+16|0)>>2],v[q+4>>2]=r;break u}v[b+660>>2]=0}m=x[i+34>>1];d=m&1023;o=d|v[b+88>>2]&-525056;v[b+88>>2]=o;w:{x:{if(m&8){v[b+80>>2]=v[i+12>>2];m=v[i+16>>2];v[b+88>>2]=(d&16?o|4:o&-524295)|2;v[b+84>>2]=m;if(y[b+76>>2]>m>>>0){break x}break w}if(!(d&2)){break w}v[b+80>>2]=v[i+4>>2];m=v[i+8>>2];v[b+84>>2]=m;if(y[b+76>>2]<=m>>>0){break w}}v[b+76>>2]=m}ub(h+16|0,j,83);if(!(!tb(v[v[h+16>>2]>>2],v[h+20>>2])|v[b+80>>2])){d=v[i>>2];v[b+84>>2]=d;v[b+76>>2]=d}d=v[b+88>>2];y:{if(!(d&128)){break y}i=v[b+76>>2];if(!i){break y}v[b+88>>2]=d|128;v[b+4>>2]=i-1}z:{if(w[b+822|0]>3){break z}ub(h+16|0,j,21);A:{B:{C:{if(!tb(v[v[h+16>>2]>>2],v[h+20>>2])){i=v[a+480180>>2];if(!(i&16777248)){break C}m=16;if(v[a+480208>>2]&4){break B}break A}i=v[a+480180>>2]}m=32;if((i|0)==16){break A}}if(i&67633152){break z}m=0}t[b+819|0]=m}ub(h+16|0,j,21);if(tb(v[v[h+16>>2]>>2],v[h+20>>2])|w[b+825|0]>3){break s}t[b+820|0]=0}i=v[b>>2];if(y[b+76>>2]<=y[b+4>>2]){d=v[b+80>>2];v[b>>2]=i;v[b+4>>2]=d}if(!l){break r}c=1;if(!(v[a+480180>>2]&17301536)|(v[b+696>>2]?0:w[b+89|0]&16)){break r}d=1;if(!(w[a+480208|0]&8)){break q}d=1;if(!w[b+789|0]){break q}}if(!(v[b+696>>2]|(!(v[a+480180>>2]&17301536)|!(w[b+89|0]&16)))){hm(b);ub(h+16|0,j,21);if(!tb(v[v[h+16>>2]>>2],v[h+20>>2])){t[b+818|0]=0;v[b+756>>2]=0}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}D:{if(!c){i=w[b+789|0];break D}i=w[b+789|0];if(!(w[a+480208|0]&8)){break D}d=1;if(!(i&255)){break q}}if(!(i&255?0:v[a+480180>>2]&1048580)){v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}d=c}ub(h+16|0,j,40);E:{F:{if(tb(v[v[h+16>>2]>>2],v[h+20>>2])){if(d){if(!(!(w[a+480208|0]&8)|!w[b+789|0])){v[b+88>>2]=v[b+88>>2]&-4196353;i=1;break E}v[b+88>>2]=v[b+88>>2]&-4194305;i=1;break E}c=v[b+88>>2]&-4196353;break F}c=v[b+88>>2]&-4196353;v[b+88>>2]=c;i=1;if(d){break E}}u[b+842>>1]=65535;v[b+88>>2]=c&-6326273|2097152;ub(h+16|0,j,23);G:{if(tb(v[v[h+16>>2]>>2],v[h+20>>2])){break G}ub(h+8|0,j,22);if(tb(v[v[h+8>>2]>>2],v[h+12>>2])){break G}ub(h+16|0,j,52);if(tb(v[v[h+16>>2]>>2],v[h+20>>2])){break G}ub(h+8|0,j,71);if(tb(v[v[h+8>>2]>>2],v[h+12>>2])){break G}t[b+839|0]=0;t[b+808|0]=0}if(e){t[b+818|0]=0;v[b+756>>2]=0}v[b+20>>2]=0;v[b+24>>2]=0;c=v[a+480208>>2]&8192;H:{I:{if(k){i=1;d=w[k+22|0];J:{if(!Eq(d)){i=!(c>>>13|0);break J}q=b,r=Fq(d),t[q+838|0]=r}c=w[k+21|0];if(Eq(c)){q=b,r=Fq(c),t[q+837|0]=r;break I}if(i){break I}c=(i|0)!=0;break H}v[b+776>>2]=0;v[b+780>>2]=0;c=!c;break H}c=1;d=w[k+25|0];if((d|0)==255){break H}t[b+845|0]=d}K:{if(w[b+837|0]>=127){ub(h+16|0,j,36);if(!tb(v[v[h+16>>2]>>2],v[h+20>>2])){break K}}if(!c){break K}if((Cp(a,b,1,256)|0)<0|!(w[b+89|0]&2)){break K}c=a+1298300|0;if(!Bd(c)|(g|0)==65535){break K}Ip(v[c>>2],g,w[b+837|0]>>>1|0,1)}i=0;if(!(w[b+89|0]&2)){break E}c=a+1298300|0;if(!Bd(c)|(g|0)==65535){break E}ub(h+16|0,j,111);if(tb(v[v[h+16>>2]>>2],v[h+20>>2])){fk(v[c>>2],g);break E}ub(h+16|0,j,110);if(!tb(v[v[h+16>>2]>>2],v[h+20>>2])){break E}az(v[c>>2],g,0,1,0)}c=v[b+88>>2];if(f){c=c&-1025;v[b+88>>2]=c}L:{M:{if(w[a+24618|0]&16?c&1024:0){break M}a=v[b+104>>2];if(!(f?1:!a|!(w[a+35|0]&4))){break M}a=v[b+656>>2];if(!a|!(w[a+15|0]&2)){break L}}if(f){break L}v[b+700>>2]=0}if(i){break a}u[b+136>>1]=0;v[b+132>>2]=4194304;v[b+112>>2]=0;v[b+116>>2]=0}cb=h+32|0}function Nja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;e=cb+-64|0;cb=e;sc(a);a:{b:{if(b>>>0<=2){b=e+56|0;G=b,H=He(a),t[G|0]=H;Ob(a,2);f=b|2;g=Sg(a);t[f|0]=g;t[f+1|0]=g>>>8;b=b|4;f=Ag(a);t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;break b}co(a,e+56|0);if(b>>>0>5){break a}}t[e+56|1]=0}c:{m=d+484344|0;b=e+56|2;A=wd(w[b|0]|w[b+1|0]<<8,1,1024);l=mB(m,A,0);if((l|0)==65535){break c}g=Gf(Sb(m,l),0);f=x[d+480188>>1];u[e>>1]=f-1;u[e+40>>1]=w[e+56|0];C=x[Kc(e,e+40|0)>>1];j=C+1|0;b=j&65535;f=b>>>0<f>>>0?f:b;while(1)if((b|0)==(f|0)){t[c+13|0]=w[e+56|1]>>>4;b=w[c+12|0];t[e|0]=0;b=(b|0)!=0;p=hu(e+40|0,j,e);D=d+480188|0;d:while(1){if((k|0)==(A|0)){_b(p);break c}e:{d=Eb(v[p>>2],0);f=w[d|0];f:{g:{if(!f){v[22440]=0;d=T(208,a|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break e}d=d<<24>>24;if((d|0)<0){v[22440]=0;f=T(208,a|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break e}G=Eb(v[p>>2],0),H=f,t[G|0]=H}t[e|0]=0;h:{i:{d=d&63;if(!d){break i}v[22440]=0;j=T(208,a|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break h}t[e|0]=j;j:{k:{switch(d-1|0){case 0:t[c+12|0]=0;t[e+36|0]=1;G=c,H=w[ff(e+36|0,e)|0],t[G+14|0]=H;t[c+15|0]=0;break j;case 1:if(!j){break i}t[c+15|0]=j;t[c+12|0]=1;b=w[c+13|0];if(!b){break j}t[c+14|0]=B(B(b,j),15);break j;case 2:t[c+13|0]=j>>>4;if(j>>>0>=16){b=w[c+12|0];j=0;v[e+36>>2]=0;v[e+32>>2]=0;n=0;if(!b){break f}break g}j=0;t[c+12|0]=0;v[e+36>>2]=0;v[e+32>>2]=0;n=0;if(!(b&1)){break f}break g;case 3:n=0;v[e+36>>2]=0;v[e+32>>2]=0;if(b&1){break g}break f;case 5:if(!j){break i}d=(w[c+12|0]?15:14)+c|0;b=w[d|0];t[d|0]=b>>>0<256-j>>>0?b+j|0:-1;break j;case 6:break k;default:break i}}if(!j){break i}d=(w[c+12|0]?15:14)+c|0;b=w[d|0];t[d|0]=b>>>0>j+1>>>0?b-j|0:1}j=0;v[e+36>>2]=0;v[e+32>>2]=0;break g}j=0;v[e+36>>2]=0;v[e+32>>2]=0;n=0;if(!(b&1)){break f}break g}break e}t[d|0]=f-1;j=0;v[e+36>>2]=0;v[e+32>>2]=0;n=0;if(!(b&1)){break f}}b=w[c+13|0];d=w[c+12|0];if(d){n=0;if(!b){break f}}l:{if(d){v[e>>2]=1;v[e+24>>2]=B(b,w[c+15|0])<<1;d=v[Ke(e,e+24|0)>>2];break l}d=B(w[c+14|0],30)+30|0}b=255;h=0;while(1){m:{if(!b){b=0;break m}f=B(b,d);h=(f|0)/48|0;if(f-1536>>>0<10752){break m}b=b-1|0;continue}break}v[e+36>>2]=b;v[e+32>>2]=h;oe(e+32|0,32,255);n=1;v[e>>2]=1;G=c,H=v[Ke(e,e+36|0)>>2],t[G+16|0]=H}s=k-1|0;y=1;b=Zc(Sb(m,l),k,1);while(1){g=y&65535;if(g>>>0>C>>>0){if(n){xe(Sb(m,l),yh(bo(Pe(Je(e,17,w[e+32|0]),k),0)));xe(Sb(m,l),yh(Pe(Je(e,16,w[e+36|0]),k)))}if(j&240){xe(Sb(m,l),mU(Pe(Je(e,20,j>>>4|224),k)))}b=j&15;if(b){xe(Sb(m,l),mU(Pe(Je(e,20,wd((B(b,w[c+16|0])>>>0)/15&255,1,15)|96),k)))}k=k+1|0;b=0;continue d}n:{o:{p:{q:{d=Eb(v[p>>2],g);f=w[d|0];if(!f){v[22440]=0;h=T(208,a|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break e}if(h&128){v[22440]=0;d=T(208,a|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break e}G=Eb(v[p>>2],g),H=d,t[G|0]=H}E=1;if(h&64){v[22440]=0;d=T(208,a|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break e}t[b+1|0]=d;E=!d}if(!(h&32)){f=w[b|0];break q}v[22440]=0;f=T(208,a|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break e}t[b|0]=f;if((f-1&255)>>>0<=107){f=wl(f+24|0);t[b|0]=f;G=Cd(v[c>>2],g),H=f,t[G+1|0]=H;break q}if((f+127&255)>>>0<=107){d=wl((f&127)+24|0);G=Cd(v[c>>2],g),H=d,t[G|0]=H;t[b|0]=0;break p}if((f|0)!=255){break q}t[b|0]=254;break o}t[d|0]=f-1;break n}if(f&255){break o}}if(!w[b+1|0]){break o}d=w[Cd(v[c>>2],g)+1|0];t[b+1|0]=0;t[b|0]=d}if(Rc(w[b|0])){G=Cd(v[c>>2],g),H=0,t[G+5|0]=H}t[e+23|0]=0;t[e+22|0]=0;if(h&16){t[b+2|0]=1;v[22440]=0;d=T(208,a|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break e}t[b+4|0]=d+2>>>2}f=0;q=0;o=0;r:{if(!(h&8)){break r}v[22440]=0;d=T(208,a|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break e}v[22440]=0;o=T(208,a|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break e}s:{switch(d-1|0){case 0:t[b|0]=254;break r;case 1:t[b|0]=255;break r;case 2:d=Cd(v[c>>2],g);t[b|0]=w[d+1|0];t[d+5|0]=0;break r;case 3:d=gu(o,w[c+16|0]);o=d?d|-48:0;q=d?20:0;if(w[b|0]){break r}d=Cd(v[c>>2],g);t[b|0]=w[d+1|0];t[d+5|0]=0;break r;case 4:t[e|0]=1;G=e,H=gu(o,w[c+16|0]),t[G+24|0]=H;o=w[ff(e,e+24|0)|0];G=Cd(v[c>>2],g),H=0,t[G+5|0]=H;q=15;break r;case 5:case 6:case 7:case 8:t:{if(!k){break t}if((d|0)==w[Cd(v[c>>2],g)+4|0]){break t}if(!xe(Sb(m,l),ym(bo(Pe(Je(e,20,(d+122|160)&255),s),g)))){break t}G=Cd(v[c>>2],g),H=d,t[G+4|0]=H}d=Cd(v[c>>2],g);if(!w[b|0]){t[b|0]=w[d+1|0]}t[d+5|0]=0;q=10;break r;case 9:break s;default:break r}}i=Cd(v[c>>2],g);d=w[i+5|0];t[i+5|0]=d^1;o=d?-98:-97;q=20}u:{v:{w:{if(!(h&4)){break w}v[22440]=0;i=T(208,a|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break e}v[22440]=0;d=T(208,a|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break e}t[e+23|0]=d;F=1;f=1;x:{switch(i-1|0){case 0:lB(e,d<<24>>24<<3,128);d=w[b|0];if(Rc(d)){G=b,H=wl(d+v[e>>2]|0),t[G|0]=H}t[e+23|0]=w[e+4|0]^128;f=35;break w;case 1:d=gu(d,w[c+16|0]);t[e+23|0]=d;if(!d){break v}t[e+23|0]=d|208;f=20;break u;case 3:case 4:G=e,H=lU(d,w[c+16|0],1),t[G+23|0]=H;f=(i|0)==4?2:3;break u;case 5:if(!w[b|0]){G=b,H=w[Cd(v[c>>2],g)|0],t[G|0]=H;d=w[e+23|0]}G=e,H=lU(d&255,w[c+16|0],0),t[G+23|0]=H;f=4;break u;case 6:G=b,H=wl(d+25|0),t[G|0]=H;t[e+23|0]=255;f=4;break u;case 7:case 8:case 9:y:{if(!k){break y}if((i|0)==w[Cd(v[c>>2],g)+2|0]){break y}if(!xe(Sb(m,l),ym(bo(Pe(Je(e,20,(i-8|48)&255),s),g)))){break y}G=Cd(v[c>>2],g),H=i,t[G+2|0]=H}G=e,H=kB(w[e+23|0],w[c+16|0]),t[G+23|0]=H;f=5;break u;case 10:G=e,H=kU(d,w[c+16|0]),t[G+23|0]=H;f=18;break u;case 11:d=gu(d,w[c+16|0]);t[e+23|0]=d;if(d){t[e+23|0]=d|192;f=20;break u}t[b|0]=254;break v;case 2:break u;default:break x}}f=0}F=0;break u}f=0}i=0;z=1;z:{if(h&2){v[22440]=0;d=T(208,a|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break e}v[22440]=0;r=T(208,a|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break e}t[e+22|0]=r;i=9;z=0;h=0;A:{switch(d-1|0){case 0:case 1:h=1;G=e,H=jU(r,w[c+16|0],(d|0)==1),t[G+22|0]=H;i=11;break z;case 2:G=e,H=kU(r,w[c+16|0]),t[G+22|0]=H;h=1;i=18;break z;case 3:case 4:case 5:B:{if(!k){break B}if((d|0)==w[Cd(v[c>>2],g)+3|0]){break B}if(!xe(Sb(m,l),ym(bo(Pe(Je(e,20,(d-4|64)&255),s),g)))){break B}G=Cd(v[c>>2],g),H=d,t[G+3|0]=H}G=e,H=kB(r,w[c+16|0]),t[G+22|0]=H;h=1;i=8;break z;case 7:case 8:G=e,H=jU(r,w[c+16|0],(d|0)==8),t[G+22|0]=H;h=1;i=29;break z;case 9:G=e,H=kB(r,w[c+16|0]),t[G+22|0]=H;h=1;i=27;break z;case 6:break z;default:break A}}z=1;i=0}h=0}if(F){iU(b,k,x[D>>1],f,e+23|0)}if(h){iU(b,k,x[D>>1],i,e+22|0)}C:{D:{E:{F:{G:{if(!E){break G}if(!Rc(w[b|0])){break G}if(!f){break F}if(!z|(f|0)==4){break G}t[e+22|0]=255;i=4}d=b+2|0;if(w[b+2|0]!=1){break C}if(f){break E}t[e+23|0]=w[b+4|0];f=13;break D}t[e+23|0]=255;d=b+2|0;f=4;if(w[b+2|0]!=1){break C}}if(i){break C}t[e+22|0]=w[b+4|0];i=13}t[d|0]=0}g=tg(e);io(e+24|0,g,f,w[e+23|0],i,w[e+22|0]);H:{if(w[d|0]){break H}f=w[e+2|0];if(!f){break H}t[b+2|0]=f;t[b+4|0]=w[e+4|0]}h=w[e+3|0];I:{if(q){io(e+24|0,g,h&255,w[e+5|0],q,o&255);J:{if(w[d|0]){break J}d=w[e+2|0];if(!d){break J}t[b+2|0]=d;t[b+4|0]=w[e+4|0]}h=w[e+3|0];break I}if(!(h&255)){break n}}t[b+3|0]=h;t[b+5|0]=w[e+5|0]}b=b+6|0;y=y+1|0;continue}}break}a=P()|0;O()|0;_b(p);S(a|0);L()}else{t[g+B(b,6)|0]=254;b=b+1|0;continue}}cb=e- -64|0;return l|0}function lea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;j=cb-288|0;cb=j;f=cb-128|0;cb=f;g=j+104|0;i=be(g,c);v[22440]=0;m=T(176,g+20|0)|0;c=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{if((c|0)!=1){v[22440]=0;o=T(176,g+40|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break C}v[22440]=0;p=T(176,g+60|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break B}v[22440]=0;q=T(176,g+80|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break A}v[22440]=0;n=T(176,g+100|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break z}v[22440]=0;r=T(176,g+120|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break y}s=bf(g+140|0);sc(g);v[g+172>>2]=1873739776;u[g+176>>1]=0;v[22440]=0;c=Q(793,i|0,f+112|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break x}if(!c){break m}c=f+112|0;h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);if((h|0)!=1414744396&(h|0)!=1179011410){break m}c=f+120|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);if((c|0)!=1163280727&(c|0)!=1702257015){break m}t[g+176|0]=(h|0)==1414744396;v[22440]=0;U(794,f+96|0,i|0,2);c=v[22440];v[22440]=0;if((c|0)==1){break w}h=v[f+96>>2];D:{if(qq(h,v[f+100>>2])>>>0<4){break D}c=f+40|0;Uh(c,ws(h,1));if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1635017060){break D}c=f- -64|0;Uh(c,ws(v[f+96>>2],1));if(!(om(c)&1)){break D}c=f+24|0;Uh(c,ws(v[f+96>>2],2));if(om(c)){break D}c=f+88|0;Uh(c,ws(v[f+96>>2],3));if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){break D}v[22440]=0;Q(157,g|0,12)|0;c=v[22440];v[22440]=0;if((c|0)==1){break v}v[22440]=0;U(794,f+40|0,i|0,1);c=v[22440];v[22440]=0;if((c|0)==1){break u}c=f+40|0;wt(f+96|0,c);Qd(c)}v[22440]=0;U(795,f- -64|0,f+96|0,544501094);c=v[22440];v[22440]=0;if((c|0)==1){break t}v[22440]=0;i=g+156|0;c=Q(796,f- -64|0,i|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break k}if(!c){break n}c=w[i|0]|w[i+1|0]<<8;if((c|0)!=1){break r}v[22440]=0;c=T(204,f- -64|0)|0;h=v[22440];v[22440]=0;if((h|0)!=1){break s}break k}c=P()|0;O()|0;break b}c=P()|0;O()|0;break c}c=P()|0;O()|0;break d}c=P()|0;O()|0;break e}c=P()|0;O()|0;break f}c=P()|0;O()|0;break g}c=P()|0;O()|0;break h}c=P()|0;O()|0;break h}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}if((c|0)==4){break q}c=w[i|0]|w[i+1|0]<<8}if((c&65535)!=65534){break o}v[22440]=0;c=Q(797,f- -64|0,f+40|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break p}if(!c){break n}c=v[f+60>>2];v[f+16>>2]=v[f+56>>2];v[f+20>>2]=c;c=v[f+52>>2];v[f+8>>2]=v[f+48>>2];v[f+12>>2]=c;h=f+24|0;c=f+8|0;v[h>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);u[h+4>>1]=w[c+4|0]|w[c+5|0]<<8;u[h+6>>1]=w[c+6|0]|w[c+7|0]<<8;y=h,z=lA(w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24),w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24)),v[y+8>>2]=z;v[h+12>>2]=fb;u[g+172>>1]=v[h>>2];break o}v[22440]=0;c=T(199,f- -64|0)|0;h=v[22440];v[22440]=0;E:{if((h|0)!=1){v[22440]=0;h=T(199,f- -64|0)|0;l=v[22440];v[22440]=0;if((l|0)==1){break E}if((c|0)!=2|(h|0)!=1){break o}t[g+177|0]=1;break o}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}v[22440]=0;U(795,f+40|0,f+96|0,1635017060);c=v[22440];v[22440]=0;F:{G:{H:{I:{J:{K:{if((c|0)!=1){h=f+40|0;c=Sc(m,h);sb(h);v[22440]=0;h=T(180,c|0)|0;l=v[22440];v[22440]=0;if((l|0)==1){break k}if(!h){v[22440]=0;U(795,f+40|0,f+96|0,544039792);h=v[22440];v[22440]=0;if((h|0)==1){break K}h=f+40|0;Sc(c,h);sb(h)}v[22440]=0;U(795,f+40|0,f+96|0,1952670054);h=v[22440];v[22440]=0;if((h|0)==1){break J}v[22440]=0;h=T(159,f+40|0)|0;l=v[22440];v[22440]=0;if((l|0)==1){break I}v[g+152>>2]=h;sb(f+40|0);if(v[g+152>>2]?(w[i|0]|w[i+1|0]<<8)==17:0){break F}i=aL(g);if(!i){break F}h=Ep(g);if(h){if((h>>>0)/(jk(g)>>>0)>>>0<i<<1>>>0){break H}}v[22440]=0;c=T(162,c|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break k}i=aL(g);break G}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;sb(f+40|0);break j}v[22440]=0;c=T(162,c|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break k}i=Ep(g)}v[g+152>>2]=(c>>>0)/(i>>>0)}v[22440]=0;c=Q(798,g|0,f+96|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break k}u[g+174>>1]=c;v[22440]=0;R(799,g|0,f+96|0);c=v[22440];v[22440]=0;if((c|0)==1){break k}v[22440]=0;U(795,f+40|0,f+96|0,1886221175);c=v[22440];v[22440]=0;if((c|0)==1){break l}c=f+40|0;Sc(n,c);sb(c)}sb(f- -64|0);Qd(f+96|0)}cb=f+128|0;break a}c=P()|0;O()|0;break j}c=P()|0;O()|0}sb(f- -64|0)}Qd(f+96|0)}Qd(s);sb(r)}sb(n)}sb(q)}sb(p)}sb(o)}sb(m)}sb(g);S(c|0);L()}v[22440]=0;c=T(734,g|0)|0;f=v[22440];v[22440]=0;L:{M:{if((f|0)!=1){N:{if(!c){break N}if((jk(g)-3&65535)>>>0<65534){break N}O:{P:{c=Mn(g);Q:{if(!c){if((ik(g)|0)==85){break Q}break N}if(c>>>0>31){break P}}if((ik(g)|0)!=3){break O}break N}if(c>>>0>64){break N}}f=ik(g);c=30352;while(1){R:{S:{if((c|0)!=30376){if((f|0)!=v[c>>2]){break S}}else{c=30376}break R}c=c+4|0;continue}break}if((c|0)==30376){break N}Ts(a,b);v[22440]=0;c=Q(56,j+80|0,21685)|0;f=v[22440];v[22440]=0;T:{U:{V:{W:{X:{Y:{Z:{if((f|0)!=1){i=uc(((b<<5)+a|0)+946304|0,c);rb(c);v[22440]=0;c=B(b,104)+a|0;f=c+484380|0;R(284,f|0,0);k=v[22440];v[22440]=0;if((k|0)==1){break Z}v[f>>2]=v[g+152>>2];k=c+484404|0;c=g+160|0;v[k>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=v[a+1298404>>2];v[22440]=0;W(735,g|0,f|0,c|0,i|0);c=v[22440];v[22440]=0;if((c|0)==1){break Z}be(j+80|0,g+20|0);c=Nc(j+72|0,8,jk(g)>>>0>1?2:1,0,0);i=ik(g);if((i|0)==85){break W}if((i|0)!=17){break V}if(jk(g)>>>0>2){break X}qc(f,268435456);d=B(b,104)+a|0;b=d+484414|0;c=x[b>>1]|1;u[b>>1]=c;y=b,z=c&65471|((jk(g)|0)==2)<<6,u[y>>1]=z;if(Lg(f)){break Y}k=0;break T}k=P()|0;O()|0;break L}k=P()|0;O()|0;break L}c=v[d+484400>>2];d=v[f>>2];b=be(j+48|0,j+80|0);i=Ep(g);k=jk(g);v[22440]=0;h=v[b+12>>2];v[j+8>>2]=v[b+8>>2];v[j+12>>2]=h;v[j+16>>2]=v[b+16>>2];h=v[b+4>>2];v[j>>2]=v[b>>2];v[j+4>>2]=h;ga(736,c|0,d|0,j|0,i|0,k|0);b=v[22440];v[22440]=0;if((b|0)==1){break M}Ai(f,a);break U}if((i|0)!=85){break V}}v[22440]=0;b=ea(572,a|0,b|0,j+80|0,0,1)|0;c=v[22440];v[22440]=0;if((c|0)==1){break M}if(b){break U}k=0;break T}_:{if(qz(g)){break _}if(!Ed(w[g+177|0])){break _}if((ik(g)|0)!=1){break _}if((Mn(g)|0)!=32){break _}if((Ep(g)|0)!=jk(g)<<2){break _}kd(c,32);Hf(c,12);v[22440]=0;Y(222,c|0,f|0,j+80|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break U}break M}$:{if(qz(g)){break $}if((ik(g)|0)!=1){break $}if((Mn(g)|0)!=24){break $}if((Ep(g)|0)!=jk(g)<<2){break $}kd(c,32);Hf(c,13);v[22440]=0;Y(222,c|0,f|0,j+80|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break M}break U}if((ik(g)&65534)==6){kd(c,16);Hf(c,(ik(g)|0)==6?17:16);v[22440]=0;Y(222,c|0,f|0,j+80|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break M}break U}i=(Mn(g)-1>>>3|0)-1|0;k=i<<3;b=k&31;kd(c,(i>>>0<7?(k&63)>>>0>=32?4196360>>>b|0:((1<<b)-1&4196360)<<32-b|136321040>>>b:8)&255);if(Mn(g)>>>0<9){Hf(c,1)}if((ik(g)|0)==3){Hf(c,3)}if(d){qN(c)}v[22440]=0;Y(222,c|0,f|0,j+80|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break M}}if(e){b=j+24|0;be(b,g+100|0);Sc(e,b);sb(b)}bt(f,v[a+480180>>2]);Ai(f,a);k=1}sb(j+80|0)}bP(g);cb=j+288|0;return k|0}k=P()|0;O()|0;break L}k=P()|0;O()|0;sb(j+80|0)}bP(g);S(k|0);L()}function Sja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=cb-272|0;cb=d;sc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if(!pU(b,d+200|0)){break o}if(!qU(d+200|0)){break o}if(!c){f=1;break o}ud(a,131072);e=cb-16|0;cb=e;f=d+104|0;k=jc(e,3913);zc(f,k);rb(k);cb=e+16|0;v[22440]=0;U(312,d+152|0,f|0,d+200|4);e=v[22440];v[22440]=0;p:{if((e|0)!=1){e=d+152|0;Cb(a+1298344|0,e);rb(e);f=d+104|0;Ab(f);k=jc(e,11114);Cb(a+1298356|0,k);rb(k);v[a+1298404>>2]=5;pu(f,3,d+213|0);xc(e,v[d+104>>2],v[d+108>>2],w[d+112|0]);tc(a+1298308|0,e);rb(e);Bj(d+80|0,3,d+243|0);xc(f,v[d+80>>2],v[d+84>>2],w[d+88|0]);v[22440]=0;U(11,e|0,5,f|0);e=v[22440];v[22440]=0;if((e|0)==1){break b}e=d+152|0;Cb(a+1298320|0,e);rb(e);rb(d+104|0);e=eo(e);q=e,r=wd(w[d+263|0],1,31),v[q+12>>2]=r;q=e,r=wd(w[d+264|0],1,12)-1|0,v[q+16>>2]=r;v[e+20>>2]=w[d+265|0];f=a+1298408|0;Ac(f);pB(f,e);h=d+112|0;j=d+48|4;k=bf(d+136|0);q:{r:{s:{while(1){v[22440]=0;e=Q(158,b|0,8)|0;f=v[22440];v[22440]=0;t:{u:{v:{w:{x:{if((f|0)!=1){if(!e){break q}v[22440]=0;R(313,b|0,d+48|0);e=v[22440];v[22440]=0;if((e|0)==1){break x}f=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);y:{n=w[d+204|0];switch(n-3|0){case 1:break w;case 0:break y;default:break v}}e=2;if((w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))!=1431389523){break u}break t}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}e=4;if((w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))!=1431389523){break u}break t}e=0;if(n>>>0>7){break t}}f=(w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))==1146113363?-1:f;e=0}n=v[d+52>>2];v[d+104>>2]=v[d+48>>2];v[d+108>>2]=n;v[22440]=0;U(192,d+80|0,b|0,f|0);f=v[22440];v[22440]=0;if((f|0)==1){break s}cc(h,d+80|0);v[22440]=0;R(314,k|0,d+104|0);f=v[22440];v[22440]=0;if((f|0)==1){break r}Xc(d+104|0);sb(d+80|0);v[22440]=0;Q(190,b|0,e|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){continue}break}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;Xc(d+104|0);sb(d+80|0);break c}v[22440]=0;n=T(176,d+104|0)|0;b=v[22440];v[22440]=0;z:{A:{B:{if((b|0)!=1){v[22440]=0;U(315,d+80|0,k|0,1431389523);b=v[22440];v[22440]=0;if((b|0)==1){break B}e=d+80|0;b=Sc(n,e);sb(e);u[d+78>>1]=0;u[d+76>>1]=65534;if(w[d+204|0]<3){break z}v[22440]=0;e=T(196,b|0)|0;f=v[22440];v[22440]=0;if((f|0)!=1){break A}break e}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}u[d+78>>1]=e;if(w[d+204|0]<4){break z}v[22440]=0;e=T(196,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break e}u[d+76>>1]=w[d+204|0]==4?e?e:-2:e}e=a+484360|0;f=Nb(e);v[22440]=0;j=T(204,b|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break e}v[22440]=0;ea(244,f|0,b|0,j>>>1|0,65535,65535)|0;f=v[22440];v[22440]=0;if((f|0)==1){break e}Kf(d+78|0,iu(Nb(e)));Kf(d+76|0,iu(Nb(e)));v[22440]=0;U(315,d+80|0,k|0,1414807888);f=v[22440];v[22440]=0;if((f|0)==1){break h}f=d+80|0;j=Sc(b,f);sb(f);v[22440]=0;f=T(180,b|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break e}if(!(c&1)|f^1){break p}v[22440]=0;R(316,j|0,d+72|0);f=v[22440];v[22440]=0;if((f|0)==1){break i}q=a+480188|0,r=wd(w[d+72|2],1,32)+1|0,u[q>>1]=r;f=w[d+72|0]|w[d+73|0]<<8;v[22440]=0;f=Q(221,d+8|0,f|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break j}q=d,r=yb(v[f>>2]),v[q+32>>2]=r;m=yb(v[f+4>>2]);C:{D:{while(1){g=v[d+32>>2];if(!Qb(g,m)){h=x[a+480188>>1];v[22440]=0;h=Q(317,d+80|0,h|0)|0;m=v[22440];v[22440]=0;if((m|0)!=1){g=yl(Nb(e));v[22440]=0;m=a+484344|0;R(228,m|0,g|0);g=v[22440];v[22440]=0;if((g|0)==1){break g}g=Nb(e);q=d,r=yb(v[g>>2]),v[q+48>>2]=r;i=yb(v[g+4>>2]);E:{while(1){F:{g=v[d+48>>2];if(!Qb(g,i)){g=Nb(e);v[22440]=0;i=g;g=x[d+76>>1];i=Q(318,i|0,g|0)|0;l=v[22440];v[22440]=0;if((l|0)!=1){break F}break g}l=v[f>>2];p=Df(l,v[f+4>>2]);o=x[g>>1];if(p>>>0>o>>>0){v[22440]=0;l=da(319,Ng(l,o)|0,w[d+204|0],h|0,a|0)|0;o=v[22440];v[22440]=0;if((o|0)==1){break E}u[g>>1]=l}Ne(d+48|0);continue}break}G:{if(!i){break G}i=x[d+78>>1];if(!i){if(iu(Nb(e))>>>0<=g>>>0){break G}}e=x[Xb(v[Nb(e)>>2],g)>>1];xe(Sb(m,e),ym(Pe(Je(d+48|0,12,i&255),v[Sb(m,e)+12>>2]-1|0)))}Th(h);Ic(f);break p}break g}b=P()|0;O()|0;break f}v[22440]=0;h=w[d+204|0]<3?9:8;Q(190,b|0,h-4|0)|0;i=v[22440];v[22440]=0;if((i|0)!=1){v[22440]=0;i=T(159,j|0)|0;l=v[22440];v[22440]=0;if((l|0)==1){break D}xg(b,h);v[22440]=0;U(192,d+48|0,b|0,h+i|0);h=v[22440];v[22440]=0;if((h|0)==1){break C}i=g;h=d+80|0;g=d+48|0;Sc(i,cc(h,g));sb(h);sb(g);Uf(d+32|0);continue}break}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;Ab(d+104|0);break a}v[22440]=0;U(315,d+80|0,k|0,1196641603);e=v[22440];v[22440]=0;if((e|0)==1){break n}f=d+80|0;e=Sc(j,f);sb(f);v[22440]=0;f=T(180,b|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break e}if(f){v[22440]=0;Q(190,b|0,1)|0;f=v[22440];v[22440]=0;if((f|0)==1){break e}v[22440]=0;f=T(204,b|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break e}v[22440]=0;ga(320,a+1298332|0,e|0,f|0,40,0);f=v[22440];v[22440]=0;if((f|0)==1){break e}}v[22440]=0;U(315,d+80|0,k|0,1146113363);f=v[22440];v[22440]=0;if((f|0)==1){break m}v[22440]=0;U(315,d+48|0,k|0,1229999443);f=v[22440];v[22440]=0;H:{if((f|0)!=1){g=e;e=d+48|0;j=Sc(g,e);sb(e);v[22440]=0;e=T(208,j|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break l}h=a+480190|0;u[h>>1]=e;m=!(c&2);f=1;while(1){I:{c=f&65535;if(c>>>0>(e&65535)>>>0){eg(a);v[a+480204>>2]=12e5;v[a+480208>>2]=24;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+480228>>2]=48;v[a+480232>>2]=48;v[22440]=0;f=1;Y(271,a+1074312|0,114,1)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break H}break l}e=30;J:{K:{L:{if(w[d+204|0]>=2){v[22440]=0;e=T(208,j|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break L}}v[22440]=0;U(321,j|0,((c<<5)+a|0)+946304|0,e|0);e=v[22440];v[22440]=0;if((e|0)==1){break L}v[22440]=0;R(322,j|0,d+32|0);e=v[22440];v[22440]=0;if((e|0)==1){break K}v[22440]=0;c=B(c,104)+a|0;g=c+484380|0;R(323,d+32|0,g|0);e=v[22440];v[22440]=0;if((e|0)==1){break K}e=w[d+204|0];if(e>>>0>=8){v[22440]=0;R(324,j|0,c+484423|0);e=v[22440];v[22440]=0;if((e|0)==1){break K}e=w[d+204|0]}v[22440]=0;Q(190,b|0,(e>>>0>1?6:2)|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break K}v[22440]=0;e=T(159,d+80|0)|0;i=v[22440];v[22440]=0;if((i|0)!=1){v[22440]=0;U(192,d+8|0,d+80|0,e|0);e=v[22440];v[22440]=0;if((e|0)!=1){break J}}b=P()|0;O()|0;break k}b=P()|0;O()|0;break k}b=P()|0;O()|0;break k}e=d+48|0;i=d+8|0;l=cc(e,i);sb(i);v[22440]=0;e=T(180,e|0)|0;i=v[22440];v[22440]=0;if((i|0)!=1){M:{if(m|e^1){break M}c=Nc(d+8|0,u[c+484414>>1]&1?16:8,1,0,(w[d+47|0]&12)==4?7:0);v[22440]=0;Y(222,c|0,g|0,l|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break M}break I}f=f+1|0;sb(d+48|0);e=x[h>>1];continue}}break}b=P()|0;O()|0;sb(d+48|0);break k}b=P()|0;O()|0;break k}sb(d+80|0);sb(b);Qd(k)}cb=d+272|0;return f|0}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0}sb(d+80|0);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;Th(h)}Ic(f);break d}b=P()|0;O()|0}sb(n)}Qd(k);break a}b=P()|0;O()|0;rb(d+104|0)}S(b|0);L()}function Ffa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=cb-1328|0;cb=d;sc(b);e=cb-16|0;cb=e;RQ(e+8|0,d+216|0);m=v[e+12>>2];Yb(e,b,v[e+8>>2],m);j=v[e+4>>2];if((j|0)==(m|0)){Ob(b,v[e+12>>2])}cb=e+16|0;a:{if((j|0)!=(m|0)){break a}if(!TQ(d+216|0)){break a}if(!Kb(b,wc(SQ(d+216|0),fb))){break a}if(!c){q=1;break a}sc(b);j=be(d+216|0,b);v[22440]=0;R(635,d+200|0,j|0);b=v[22440];v[22440]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){sb(j);v[22440]=0;U(636,d+184|0,d+200|0,1196314451);b=v[22440];v[22440]=0;if((b|0)==1){break i}v[22440]=0;U(636,d+168|0,d+200|0,1280331091);b=v[22440];v[22440]=0;if((b|0)==1){break h}if(hc(v[d+184>>2],v[d+188>>2])){break b}if(!hc(v[d+168>>2],v[d+172>>2])){break g}break b}c=P()|0;O()|0;sb(j);break d}c=P()|0;O()|0;break e}c=P()|0;O()|0;break f}v[22440]=0;R(252,a|0,1);b=v[22440];v[22440]=0;j:{k:{l:{m:{if((b|0)!=1){eg(a);v[a+480188>>2]=4;v[a+480208>>2]=25231360;G=d,H=yb(v[d+168>>2]),v[G+16>>2]=H;e=c&2;m=yb(v[d+172>>2]);n:{o:{while(1){g=v[d+16>>2];if(!Qb(g,m)){break o}if(!Sh(a)){break o}b=x[a+480190>>1]+1|0;u[a+480190>>1]=b;v[22440]=0;l=B(b&65535,104)+a|0;i=l+484380|0;R(284,i|0,1);b=v[22440];v[22440]=0;p:{q:{if((b|0)!=1){v[22440]=0;j=Q(637,g|0,d+216|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break q}if(!j){break c}if(yt(d+216|0)){break p}break c}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}v[22440]=0;j=Q(56,d+48|0,d+216|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break n}uc(((x[a+480190>>1]<<5)+a|0)+946304|0,j);rb(j);b=w[d+252|0]|w[d+253|0]<<8|(w[d+254|0]<<16|w[d+255|0]<<24);v[i>>2]=b;v[l+484388>>2]=b;v[l+484384>>2]=w[d+248|0]|w[d+249|0]<<8|(w[d+250|0]<<16|w[d+251|0]<<24);u[l+484410>>1]=255;b=l+484414|0;u[b>>1]=x[b>>1]|2;r:{if(e){b=Nc(d+48|0,8,1,0,0);v[22440]=0;Y(222,b|0,i|0,g|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break r}}Uf(d+16|0);continue}break}c=P()|0;O()|0;break j}G=d,H=yb(v[d+184>>2]),v[G+160>>2]=H;s=a+484344|0;A=c&1;o=a+484360|0;m=d+1308|0;j=d+1312|0;p=d+1304|0;C=d+1302|0;F=yb(v[d+188>>2]);D=a+484380|0;E=a+946304|0;c=1;q=1;while(1){s:{t:{u:{v:{w:{x:{e=v[d+160>>2];if(!Qb(e,F)){break x}if(!(c&1)){v[22440]=0;c=T(279,o|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break w}if(!c){break x}}Ac(Nb(o));v[22440]=0;c=Q(638,e|0,d+216|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break v}if(!c|(w[C|0]|w[C+1|0]<<8)|(w[p|0]|w[p+1|0]<<8|(w[p+2|0]<<16|w[p+3|0]<<24))-5>>>0<4294967292){break c}c=Nb(o);v[22440]=0;U(5,d+48|0,5,d+216|0);b=v[22440];v[22440]=0;if((b|0)==1){break k}v[22440]=0;R(280,c|0,d+48|0);b=v[22440];v[22440]=0;if((b|0)==1){break l}rb(d+48|0);y:{if(A){b=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);v[22440]=0;U(192,d+48|0,e|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break y}c=P()|0;O()|0;break j}v[22440]=0;T(176,d+112|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break m}FD(d+48|0,d+112|0)}b=d+48|0;y=cc(d+136|0,b);sb(b);if(!A){sb(d+112|0)}Hb(d+48|0,0,64);c=1;z:{A:{B:{while(1){if((c|0)==32){break B}b=(B(c,34)+d|0)+182|0;i=b+32|0;Im(d,i);C:{D:{if(!w[v[d>>2]]){break D}e=w[b- -64|0];if(e>>>0>15){break A}b=w[b+65|0];if(b>>>0>64){break A}if(!yt(i)){break A}z=b<<2;h=e<<4;l=0;b=1;E:{while(1){r=b&65535;e=x[a+480190>>1];if(r>>>0>e>>>0){break E}v[22440]=0;U(537,d+16|0,v[d>>2],v[d+4>>2]);e=v[22440];v[22440]=0;if((e|0)==1){break C}n=cb-16|0;cb=n;k=d+16|0;se(n+8|0,k);PQ(n,((r<<5)+a|0)+946304|0);f=v[n+8>>2];g=v[n>>2];i=v[n+12>>2];e=v[n+4>>2];if((i|0)==(e|0)){e=(uS(f,i,g,e)|0)!=0}else{e=1}cb=n+16|0;rb(k);F:{G:{if(e){break G}G=Xb(d+48|0,c),H=b,u[G>>1]=H;g=B(r,104)+a|0;i=g+484410|0;e=x[i>>1];if((e|0)==255){break F}l=b;if(w[g+484417|0]!=(h&255)){break G}if((e|0)==(z|0)){break F}}b=b+1|0;continue}break}t[g+484417|0]=h;u[i>>1]=z;break D}i=l&65535;if(!i){break D}if(!Sh(a)){break D}b=e+1|0;u[a+480190>>1]=b;G=Xb(d+48|0,c),H=b,u[G>>1]=H;g=B(x[a+480190>>1],104)+D|0;pm(g);e=B(i,104)+D|0;b=Sn(g,e);u[g+30>>1]=z;t[g+37|0]=h;HR(b,e);e=(i<<5)+E|0;b=v[e+4>>2];g=(x[a+480190>>1]<<5)+E|0;v[g>>2]=v[e>>2];v[g+4>>2]=b;b=v[e+28>>2];v[g+24>>2]=v[e+24>>2];v[g+28>>2]=b;b=v[e+20>>2];v[g+16>>2]=v[e+16>>2];v[g+20>>2]=b;b=v[e+12>>2];v[g+8>>2]=v[e+8>>2];v[g+12>>2]=b}c=c+1|0;continue}break}break u}e=0;v[d+40>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;r=w[p|0]|w[p+1|0]<<8;g=64;i=65535;l=0;H:while(1){I:{if(l){break I}v[22440]=0;c=Q(158,d+136|0,1)|0;b=v[22440];v[22440]=0;if((b|0)==1){break z}if(c){break I}b=i;break t}g=g+1|0;if(g>>>0>=64){v[22440]=0;i=Y(370,s|0,64,0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break z}b=65535;if((i|0)==65535){break t}g=0;b=Nb(o);v[22440]=0;R(535,b|0,i|0);b=v[22440];v[22440]=0;if((b|0)==1){break z}}b=0;c=Zc(Sb(s,i&65535),g,0);while(1){if((b|0)==(r|0)){continue H}h=(d+16|0)+B(b,7)|0;f=w[h+6|0];J:{if(f){t[h+6|0]=f-1;f=w[h+4|0]|w[h+5|0]<<8;t[c+4|0]=f;t[c+5|0]=f>>>8;f=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[c|0]=f;t[c+1|0]=f>>>8;t[c+2|0]=f>>>16;t[c+3|0]=f>>>24;l=l-1|0;break J}v[22440]=0;k=Q(158,d+136|0,1)|0;f=v[22440];v[22440]=0;if((f|0)==1){break u}if(!k){break J}if(v[d+144>>2]==(w[m|0]|w[m+1|0]<<8|(w[m+2|0]<<16|w[m+3|0]<<24))){e=Nb(o);Qe(e,iu(e));e=g}v[22440]=0;k=T(208,y|0)|0;f=v[22440];v[22440]=0;K:{if((f|0)!=1){f=k<<24>>24;if((f|0)>=0){break K}k=f&127;t[h+6|0]=k;f=w[h+4|0]|w[h+5|0]<<8;t[c+4|0]=f;t[c+5|0]=f>>>8;f=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[c|0]=f;t[c+1|0]=f>>>8;t[c+2|0]=f>>>16;t[c+3|0]=f>>>24;l=l+k|0;break J}break u}if((f-1&255)>>>0<=35){t[c|0]=f+48}v[22440]=0;k=T(208,y|0)|0;f=v[22440];v[22440]=0;L:{M:{if((f|0)!=1){G=c,H=w[Xb(d+48|0,k&31)|0],t[G+1|0]=H;if(!(k&128)){break M}t[c+3|0]=w[h+3|0];t[c+5|0]=w[h+5|0];break L}break u}v[22440]=0;R(267,d|0,y|0);f=v[22440];v[22440]=0;N:{if((f|0)!=1){f=w[d|0];if(f>>>0>19){break L}t[c+3|0]=w[(f<<1)+27056|0];k=w[Ec(d)|0];t[c+5|0]=k;if((f|0)!=18|k>>>0<32){break N}t[c+3|0]=17;break L}break u}f=w[d|0];if(819137>>>f&1){break L}t[c+5|0]=w[(f<<1)+27057|0]|k&15}f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[h|0]=f;t[h+1|0]=f>>>8;t[h+2|0]=f>>>16;t[h+3|0]=f>>>24;f=w[c+4|0]|w[c+5|0]<<8;t[h+4|0]=f;t[h+5|0]=f>>>8}c=c+6|0;b=b+1|0;continue}}}q=0;break s}break u}Hi(o,0);v[22440]=0;c=Q(1,d+216|0,6470)|0;b=v[22440];v[22440]=0;O:{if((b|0)!=1){Cb(a+1298344|0,c);rb(c);v[22440]=0;c=Q(1,d+216|0,6772)|0;b=v[22440];v[22440]=0;if((b|0)==1){break O}Cb(a+1298356|0,c);rb(c);v[a+1298404>>2]=5;q=1;break b}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;sb(d+136|0);break j}P:{if(!e&g>>>0>62){break P}b=b&65535;if((b|0)==65535){break P}xe(Sb(s,b),yh(Pe(Je(d,14,e&255),g)))}c=32}sb(d+136|0);if(c>>>0<32){break b}Uf(d+160|0);c=0;continue}}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;rb(d+48|0);break j}c=P()|0;O()|0}Ic(d+168|0)}Ic(d+184|0)}Qd(d+200|0)}S(c|0);L()}q=0}Ic(d+168|0);Ic(d+184|0);Qd(d+200|0)}cb=d+1328|0;return q|0}function G6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=0,l=0,m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=C(0),A=C(0),B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=C(0),R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=C(0),_=0,$=0,aa=C(0);a:{if(!w[a+5046|0]){break a}g=z[a+4268>>2];GJ(a);if(g==z[a+4268>>2]){break a}nx(a)}b:{if(!w[a+5045|0]){break b}o=a+44|0;if(!Yh(o)){break b}p=Ud(o,0);s=Ud(o,1);l=jd(o,0);m=jd(o,1);c:{if(!(!w[a+5044|0]|(!d|w[a+4264|0]&2))){z[l>>2]=z[a+5036>>2];z[m>>2]=z[a+5040>>2];t[a+5044|0]=0;s=s+4|0;p=p+4|0;m=m+4|0;l=l+4|0;q=d-1|0;break c}q=d}r=q;d:{if(!r){break d}V=a+4960|0;W=a+4504|0;u=a+4888|0;x=a+4864|0;X=a+4868|0;Y=a+4892|0;E=a+4628|0;F=a+4604|0;R=a+4916|0;G=a+4532|0;H=a+4508|0;I=a+4772|0;J=a+4748|0;S=a+4940|0;K=a+4676|0;L=a+4652|0;M=a+4724|0;N=a+4700|0;T=a+4844|0;O=a+4580|0;P=a+4556|0;U=a+4820|0;while(1){g=z[p>>2];g=C(C(C(z[a+5008>>2]-g)*z[a+4276>>2])+g);z[a+5008>>2]=g;$=Gc(v[a+4864>>2],v[X>>2],v[a+4880>>2]),aa=g,z[$>>2]=aa;g=z[s>>2];g=C(C(C(z[a+5012>>2]-g)*z[a+4276>>2])+g);z[a+5012>>2]=g;$=Gc(v[a+4888>>2],v[Y>>2],v[a+4904>>2]),aa=g,z[$>>2]=aa;g=C(C(C(C(C(Mh(x,v[a+4356>>2])*C(.6800000071525574))+C(Mh(x,v[a+4360>>2])*C(-.5)))-C(Mh(x,v[a+4364>>2])*C(.6200000047683716)))+C(Mh(x,v[a+4368>>2])*C(-.5)))-C(Mh(x,v[a+4372>>2])*C(.6200000047683716)));if(t[a+4264|0]&1){e=g;g=C(z[Gc(v[a+4816>>2],v[U>>2],v[a+4836>>2])>>2]+C(e*C(.6180340051651001)));$=Gc(v[a+4816>>2],v[U>>2],v[a+4832>>2]),aa=C(e-C(g*C(.6180340051651001))),z[$>>2]=aa}y=z[a+4280>>2];$=a,aa=C(Mh(x,v[a+4352>>2])+z[a+5020>>2]),z[$+5020>>2]=aa;e=C(Mh(u,v[a+4376>>2])+z[a+5024>>2]);z[a+5024>>2]=e;f=z[a+5020>>2];h=C(C(C(z[a+4980>>2]-z[Gc(v[a+4624>>2],v[E>>2],v[a+4644>>2])>>2])*z[a+4444>>2])+z[Gc(v[a+4624>>2],v[E>>2],v[a+4644>>2])>>2]);z[a+4980>>2]=h;Q=C(h*z[a+4440>>2]);j=C(e*C(.7070000171661377));i=C(f*C(-.7070000171661377));f=C(j+i);h=z[a+4272>>2];e=C(Q+C(f*h));$=Gc(v[a+4624>>2],v[E>>2],v[a+4640>>2]),aa=C(f-C(h*e)),z[$>>2]=aa;f=C(C(C(z[a+4976>>2]-z[Gc(v[a+4600>>2],v[F>>2],v[a+4620>>2])>>2])*z[a+4436>>2])+z[Gc(v[a+4600>>2],v[F>>2],v[a+4620>>2])>>2]);z[a+4976>>2]=f;h=z[a+4272>>2];f=C(C(f*z[a+4432>>2])+C(e*h));$=Gc(v[a+4600>>2],v[F>>2],v[a+4616>>2]),aa=C(e-C(h*f)),z[$>>2]=aa;A=C(C(e*C(-.15000000596046448))+C(f*C(-.20000000298023224)));if(t[a+4264|0]&1){e=C(C(C(z[a+4972>>2]-z[Gc(v[a+4576>>2],v[O>>2],v[a+4596>>2])>>2])*z[a+4428>>2])+z[Gc(v[a+4576>>2],v[O>>2],v[a+4596>>2])>>2]);z[a+4972>>2]=e;h=z[a+4272>>2];e=C(C(e*z[a+4424>>2])+C(f*h));$=Gc(v[a+4576>>2],v[O>>2],v[a+4592>>2]),aa=C(f-C(h*e)),z[$>>2]=aa;f=C(C(C(z[a+4968>>2]-z[Gc(v[a+4552>>2],v[P>>2],v[a+4572>>2])>>2])*z[a+4420>>2])+z[Gc(v[a+4552>>2],v[P>>2],v[a+4572>>2])>>2]);z[a+4968>>2]=f;h=z[a+4272>>2];f=C(C(f*z[a+4416>>2])+C(e*h));$=Gc(v[a+4552>>2],v[P>>2],v[a+4568>>2]),aa=C(e-C(h*f)),z[$>>2]=aa;A=C(C(C(e*C(.3499999940395355))+A)+C(f*C(-.3799999952316284)))}$=Gc(v[a+4912>>2],v[R>>2],v[a+4928>>2]),aa=f,z[$>>2]=aa;e=C(z[Gc(v[a+4912>>2],v[R>>2],v[a+4932>>2])>>2]*z[a+4496>>2]);z[a+5028>>2]=C(C(z[a+5028>>2]-e)*z[a+4500>>2])+e;e=C(C(C(z[a+4964>>2]-z[Gc(v[a+4528>>2],v[G>>2],v[a+4548>>2])>>2])*z[a+4412>>2])+z[Gc(v[a+4528>>2],v[G>>2],v[a+4548>>2])>>2]);z[a+4964>>2]=e;f=z[a+5028>>2];n=z[a+4272>>2];h=C(C(f*n)+C(e*z[a+4408>>2]));$=Gc(v[a+4528>>2],v[G>>2],v[a+4544>>2]),aa=C(f-C(n*h)),z[$>>2]=aa;e=C(C(C(z[a+4960>>2]-z[Gc(v[a+4504>>2],v[H>>2],v[a+4524>>2])>>2])*z[a+4404>>2])+z[Gc(v[a+4504>>2],v[H>>2],v[a+4524>>2])>>2]);z[a+4960>>2]=e;f=C(e*z[a+4400>>2]);e=z[a+4272>>2];n=C(f+C(h*e));$=Gc(v[a+4504>>2],v[H>>2],v[a+4520>>2]),aa=C(h-C(e*n)),z[$>>2]=aa;z[a+5020>>2]=n;e=C(C(C(C(C(Mh(u,v[a+4380>>2])*C(.7070000171661377))+C(Mh(u,v[a+4384>>2])*C(-.6000000238418579)))-C(Mh(u,v[a+4388>>2])*C(.5)))+C(Mh(u,v[a+4392>>2])*C(-.6000000238418579)))-C(Mh(u,v[a+4396>>2])*C(.5)));if(t[a+4264|0]&1){f=e;e=C(z[Gc(v[a+4840>>2],v[T>>2],v[a+4860>>2])>>2]+C(e*C(.6180340051651001)));$=Gc(v[a+4840>>2],v[T>>2],v[a+4856>>2]),aa=C(f-C(e*C(.6180340051651001))),z[$>>2]=aa}Z=z[a+4280>>2];f=C(C(C(z[a+5004>>2]-z[Gc(v[a+4768>>2],v[I>>2],v[a+4788>>2])>>2])*z[a+4492>>2])+z[Gc(v[a+4768>>2],v[I>>2],v[a+4788>>2])>>2]);z[a+5004>>2]=f;Q=C(f*z[a+4488>>2]);f=C(i-j);i=z[a+4272>>2];j=C(Q+C(f*i));$=Gc(v[a+4768>>2],v[I>>2],v[a+4784>>2]),aa=C(f-C(i*j)),z[$>>2]=aa;f=C(C(C(z[a+5e3>>2]-z[Gc(v[a+4744>>2],v[J>>2],v[a+4764>>2])>>2])*z[a+4484>>2])+z[Gc(v[a+4744>>2],v[J>>2],v[a+4764>>2])>>2]);z[a+5e3>>2]=f;i=z[a+4272>>2];f=C(C(f*z[a+4480>>2])+C(j*i));$=Gc(v[a+4744>>2],v[J>>2],v[a+4760>>2]),aa=C(j-C(i*f)),z[$>>2]=aa;j=C(C(C(h*C(.3799999952316284))+C(j*C(-.15000000596046448)))+C(f*C(-.20000000298023224)));if(t[a+4264|0]&1){h=C(C(C(z[a+4996>>2]-z[Gc(v[a+4720>>2],v[M>>2],v[a+4740>>2])>>2])*z[a+4476>>2])+z[Gc(v[a+4720>>2],v[M>>2],v[a+4740>>2])>>2]);z[a+4996>>2]=h;i=z[a+4272>>2];h=C(C(h*z[a+4472>>2])+C(f*i));$=Gc(v[a+4720>>2],v[M>>2],v[a+4736>>2]),aa=C(f-C(i*h)),z[$>>2]=aa;f=C(C(C(z[a+4992>>2]-z[Gc(v[a+4696>>2],v[N>>2],v[a+4716>>2])>>2])*z[a+4468>>2])+z[Gc(v[a+4696>>2],v[N>>2],v[a+4716>>2])>>2]);z[a+4992>>2]=f;i=z[a+4272>>2];f=C(C(f*z[a+4464>>2])+C(h*i));$=Gc(v[a+4696>>2],v[N>>2],v[a+4712>>2]),aa=C(h-C(i*f)),z[$>>2]=aa;j=C(C(C(h*C(.3499999940395355))+j)+C(f*C(-.3799999952316284)))}_=s+4|0;q=p+4|0;h=C(g*y);A=C(A-C(n*C(.3799999952316284)));n=C(e*Z);$=Gc(v[a+4936>>2],v[S>>2],v[a+4952>>2]),aa=f,z[$>>2]=aa;g=C(z[Gc(v[a+4936>>2],v[S>>2],v[a+4956>>2])>>2]*z[a+4496>>2]);z[a+5032>>2]=C(C(z[a+5032>>2]-g)*z[a+4500>>2])+g;g=C(C(C(z[a+4988>>2]-z[Gc(v[a+4672>>2],v[K>>2],v[a+4692>>2])>>2])*z[a+4460>>2])+z[Gc(v[a+4672>>2],v[K>>2],v[a+4692>>2])>>2]);z[a+4988>>2]=g;e=z[a+5032>>2];f=z[a+4272>>2];g=C(C(e*f)+C(g*z[a+4456>>2]));$=Gc(v[a+4672>>2],v[K>>2],v[a+4688>>2]),aa=C(e-C(f*g)),z[$>>2]=aa;f=z[a+4284>>2];e=C(C(C(z[a+4984>>2]-z[Gc(v[a+4648>>2],v[L>>2],v[a+4668>>2])>>2])*z[a+4452>>2])+z[Gc(v[a+4648>>2],v[L>>2],v[a+4668>>2])>>2]);z[a+4984>>2]=e;y=z[a+4272>>2];e=C(C(e*z[a+4448>>2])+C(g*y));$=Gc(v[a+4648>>2],v[L>>2],v[a+4664>>2]),aa=C(g-C(y*e)),z[$>>2]=aa;z[a+5024>>2]=e;e=C(-e);y=z[a+4288>>2];k=W;e:{f:{while(1){if((k|0)==(V|0)){g:{e=C(n+C(C(C(e*C(.3799999952316284))+j)*y));g=C(h+C(C(C(g*C(.3799999952316284))+A)*f));if(!(w[a+4264|0]&2)){break g}p=q;q=_;break f}}else{B=v[k+16>>2];D=B-1|0;v[k+16>>2]=D;if((B|0)<=0){v[k+16>>2]=D+v[k+12>>2]}B=v[k+20>>2];D=B-1|0;v[k+20>>2]=D;if((B|0)<=0){v[k+20>>2]=D+v[k+12>>2]}k=k+24|0;continue}break}z[l>>2]=C(g+z[a+5036>>2])*C(.5);z[m>>2]=C(e+z[a+5040>>2])*C(.5);z[a+5040>>2]=e;z[a+5036>>2]=g;if((r|0)==1){break e}r=r-1|0;p=p+8|0;m=m+4|0;l=l+4|0;q=s+8|0}s=q;z[l>>2]=g;z[m>>2]=e;m=m+4|0;l=l+4|0;r=r-1|0;if(r){continue}break d}break}t[a+5044|0]=1}ti(a,b,c,jd(o,0),jd(o,1),d)}}function r_(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;l=cb-560|0;cb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+96>>2]=1181;k=l+96|0;r=re(l+136|0,l+144|0,k);b=v[r>>2];v[l+132>>2]=b;v[l+128>>2]=b+400;x=Db(k);n=Db(l+80|0);o=Db(l- -64|0);p=Db(l+48|0);s=Db(l+32|0);v[22440]=0;na(1190,c|0,d|0,l+120|0,l+116|0,l+112|0,x|0,n|0,o|0,p|0,l+28|0);c=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{if((c|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;u=v[l+28>>2];while(1){g:{h:{i:{j:{k:{if((q|0)==4){break k}v[22440]=0;c=Q(1164,a|0,l+552|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}if(!c){break k}l:{m:{n:{o:{p:{q:{switch(t[(l+120|0)+q|0]){case 1:if((q|0)==3){break h}c=v[a>>2];v[22440]=0;c=T(1166,c|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}v[22440]=0;c=Y(1191,h|0,8192,c|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}if(c){v[22440]=0;R(1192,l+16|0,a|0);c=v[22440];v[22440]=0;if((c|0)!=1){v[22440]=0;R(50,s|0,v[l+16>>2]);c=v[22440];v[22440]=0;if((c|0)!=1){break p}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break g;case 4:break m;case 2:break n;case 3:break o;case 0:break q;default:break h}}if((q|0)==3){break h}}while(1){v[22440]=0;c=Q(1164,a|0,l+552|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break b}if(!c){break h}c=v[a>>2];v[22440]=0;c=T(1166,c|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break b}v[22440]=0;c=Y(1191,h|0,8192,c|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break b}if(!c){break h}v[22440]=0;R(1192,l+16|0,a|0);c=v[22440];v[22440]=0;if((c|0)!=1){v[22440]=0;R(50,s|0,v[l+16>>2]);c=v[22440];v[22440]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}c=vb(o);e=vb(p);if((c|0)==(0-e|0)){break h}d=v[a>>2];if(!(e?c:0)){if(c){v[22440]=0;c=T(1166,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}if((c|0)!=v[Fb(o)>>2]){break l}v[22440]=0;T(1168,a|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}m=vb(o)>>>0>1?o:m;break h}v[22440]=0;c=T(1166,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}if((c|0)!=v[Fb(p)>>2]){break h}v[22440]=0;T(1168,a|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}t[g|0]=1;m=vb(p)>>>0>1?p:m;break h}v[22440]=0;c=T(1166,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}if((c|0)==v[Fb(o)>>2]){v[22440]=0;T(1168,a|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}m=vb(o)>>>0>1?o:m;break h}c=v[a>>2];v[22440]=0;c=T(1166,c|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}if((c|0)==v[Fb(p)>>2]){v[22440]=0;T(1168,a|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}t[g|0]=1;m=vb(p)>>>0>1?p:m;break h}v[f>>2]=v[f>>2]|4;a=0;break g}if(!(q>>>0<2|m|((q|0)==2&w[l+123|0]!=0|z))){m=0;break h}c=ac(l+16|0,fd(n));r:{s:{if(!q|w[(l+q|0)+119|0]>1){break s}while(1){t:{d=Mk(n);e=v[l+16>>2];if(!Qb(e,d)){break t}d=v[e>>2];v[22440]=0;d=Y(1191,h|0,8192,d|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break r}if(!d){break t}Ge(c);continue}break}c=fd(n);c=It(v[l+16>>2],c);if(vb(s)>>>0>=c>>>0){B=l,C=Mk(s),v[B+8>>2]=C;d=nl(l+8|0,0-c|0);e=Mk(s);k=fd(n);c=cb-16|0;cb=c;v[c>>2]=k;v[c+8>>2]=d;while(1){u:{k=Qb(d,e);if(!k){break u}if(!hc(v[d>>2],v[v[c>>2]>>2])){break u}Ge(c+8|0);Ge(c);d=v[c+8>>2];continue}break}cb=c+16|0;if(k^1){break s}}ac(l+8|0,fd(n));v[l+16>>2]=v[l+8>>2]}v[l+8>>2]=v[l+16>>2];v:{while(1){c=Mk(n);if(!Qb(v[l+8>>2],c)){break v}v[22440]=0;c=Q(1164,a|0,l+552|0)|0;d=v[22440];v[22440]=0;w:{if((d|0)==1){break w}if(!c){break v}c=v[a>>2];v[22440]=0;c=T(1166,c|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break w}if((c|0)!=v[v[l+8>>2]>>2]){break v}v[22440]=0;T(1168,a|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break d}Ge(l+8|0);continue}break}break d}if(!y){break h}c=Mk(n);if(!Qb(v[l+8>>2],c)){break h}v[f>>2]=v[f>>2]|4;a=0;break g}break d}d=0;e=v[l+112>>2];x:{while(1){y:{v[22440]=0;c=Q(1164,a|0,l+552|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break y}if(!c){break x}c=v[a>>2];v[22440]=0;c=T(1166,c|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break f}v[22440]=0;k=Y(1191,h|0,2048,c|0)|0;A=v[22440];v[22440]=0;if((A|0)==1){break f}z:{if(k){k=v[j>>2];if((k|0)==v[l+548>>2]){v[22440]=0;U(1193,i|0,j|0,l+548|0);k=v[22440];v[22440]=0;if((k|0)==1){break f}k=v[j>>2]}v[j>>2]=k+4;v[k>>2]=c;d=d+1|0;break z}if(!vb(x)|!d|(c|0)!=(e|0)){break x}if(v[l+128>>2]==(b|0)){v[22440]=0;U(1187,r|0,l+132|0,l+128|0);b=v[22440];v[22440]=0;if((b|0)==1){break f}b=v[l+132>>2]}c=b+4|0;v[l+132>>2]=c;v[b>>2]=d;b=c;d=0}v[22440]=0;T(1168,a|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!d|v[r>>2]==(b|0)){break j}if(v[l+128>>2]==(b|0)){v[22440]=0;U(1187,r|0,l+132|0,l+128|0);b=v[22440];v[22440]=0;if((b|0)==1){break e}b=v[l+132>>2]}e=b+4|0;v[l+132>>2]=e;v[b>>2]=d;break i}t[g|0]=1;break h}v[l+28>>2]=u;A:{if(!m){break A}c=1;while(1){if(vb(m)>>>0<=c>>>0){break A}v[22440]=0;d=Q(1165,a|0,l+552|0)|0;e=v[22440];v[22440]=0;B:{if((e|0)==1){break B}C:{if(!d){d=v[a>>2];v[22440]=0;d=T(1166,d|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break B}if((d|0)==v[hk(m,c)>>2]){break C}}v[f>>2]=v[f>>2]|4;a=0;break g}v[22440]=0;T(1168,a|0)|0;d=v[22440];v[22440]=0;c=c+1|0;if((d|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;c=v[r>>2];if((c|0)==(b|0)){break g}a=0;v[l+16>>2]=0;Mf(x,c,b,l+16|0);if(v[l+16>>2]){v[f>>2]=v[f>>2]|4;break g}a=1;break g}e=b}D:{if((u|0)<=0){break D}v[22440]=0;b=Q(1165,a|0,l+552|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break e}E:{if(!b){b=v[a>>2];v[22440]=0;b=T(1166,b|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break e}if((b|0)==v[l+116>>2]){break E}}v[l+28>>2]=u;v[f>>2]=v[f>>2]|4;a=0;break g}v[22440]=0;b=T(1168,a|0)|0;d=v[22440];v[22440]=0;c=u;if((d|0)==1){break e}while(1){if((c|0)<=0){u=0;break D}v[22440]=0;d=Q(1165,b|0,l+552|0)|0;k=v[22440];v[22440]=0;F:{if((k|0)==1){break F}G:{if(!d){d=v[a>>2];v[22440]=0;d=T(1166,d|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break F}v[22440]=0;d=Y(1191,h|0,2048,d|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break F}if(d){break G}}v[l+28>>2]=c;v[f>>2]=v[f>>2]|4;a=0;break g}if(v[j>>2]==v[l+548>>2]){v[22440]=0;U(1193,i|0,j|0,l+548|0);d=v[22440];v[22440]=0;if((d|0)==1){break F}}d=v[a>>2];v[22440]=0;d=T(1166,d|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break F}k=v[j>>2];v[j>>2]=k+4;v[k>>2]=d;v[22440]=0;T(1168,b|0)|0;d=v[22440];v[22440]=0;c=c-1|0;if((d|0)!=1){continue}}break}break d}if(v[i>>2]!=v[j>>2]){b=e;break h}v[l+28>>2]=u;v[f>>2]=v[f>>2]|4;a=0;break g}q=q+1|0;continue}break}Vc(s);Vc(p);Vc(o);Vc(n);rb(x);Lc(r);cb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;v[l+28>>2]=u;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Vc(s);Vc(p);Vc(o);Vc(n);rb(x);Lc(r);S(a|0);L()}function dga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,T=0,V=0,W=0,X=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;e=cb-320|0;cb=e;a:{if(!Tc(b,1080)){break a}if(!Wn(b,e+316|0)){break a}ud(a,1);l=vR(e+296|0);if(!uR(e+316|0,l)){break a}d=x[l+10>>1];if(!d|d>>>0>127){break a}if(!c){g=1;break a}p=a+480188|0;u[p>>1]=d;r=w[l+14|0];s=w[l+13|0];d=w[l+12|0];F=1;if(!me(e+316|0,26986)){F=me(e+316|0,26991)}if(w[l+15|0]){Gb(a+1074312|0,5,1)}y=s?x[p>>1]==8:0;f=e+316|0;q=me(f,16758);k=1;if(!me(f,17522)){k=me(e+316|0,13625)}Tc(b,0);BA(b,a+1298308|0,20);u[a+480190>>1]=31;n=(d|0)!=0;o=a+480188|0;g=1;f=q;while(1)if((g|0)==32){b:{c:{d:{e:{f:{g:{M=v[l+4>>2];if(M>>>0>=G>>>0){g=e+160|0;qR(b,g);Tc(b,x[l+8>>1]);z=g|1;i=w[z|0];d=128;k=a+484360|0;pq(Nb(k),g|2,128);D=j;j=!i&f;i=j?D:0;f=w[g|0];h:{if(f>>>0>128){break h}d=f;if(d){break h}f=v[Nb(k)>>2];g=128;while(1){d=g;if(d>>>0<2){d=1;break h}g=d-1|0;if(!x[Xb(f,g)>>1]){continue}break}}H=(r|0)!=0;o=pR(b,Nb(k),d&65535,h,p,i,0);if(!(!j|x[p>>1]!=8)){v[l>>2]=11299;H=1}i:{if(!y){break i}f=Nb(k);da=e,ea=yb(v[f>>2]),v[da+144>>2]=ea;g=yb(v[f+4>>2]);while(1){f=v[e+144>>2];if(!Qb(f,g)){break i}u[f>>1]=x[f>>1]>>>1;Ne(e+144|0);continue}}Qe(Nb(k),w[z|0]);N=d-1|0;d=w[z|0];if(!((N&65535)>>>0>=d>>>0&((d|0)!=120|x[p>>1]!=4))){Qe(Nb(k),0)}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;d=x[a+480188>>1];g=0;v[a+480208>>2]=0;da=a,ea=Vb(256/(d>>>0)|0,32,128),v[da+480228>>2]=ea;mh(a,0);t[e+159|0]=0;r=1;Q=1;if(!(n&1)){n=0;k=0;j=0;d=q;j:while(1){if(o>>>0>(j&65535)>>>0){m=0;g=0;while(1)if((g|0)==256){j=j+1|0;continue j}else{f=e+128|0;lu(f,b,tg(e+144|0));i=Ec(f);C=UA(w[e+144|0]);k:{l:{m:{n:{h=w[f|0];if((h-7&255)>>>0<3){d=0;break n}f=w[i|0];if(!((h|0)!=14|f>>>0<=1)){d=0;break m}if(!((h|0)==15&(f&255)>>>0>31)){d=C?d:0;if((h|0)!=13){break n}m=m+1|0;if((m&65535)>>>0<2){break k}}d=0;break k}if((h|0)==8){break l}if((h|0)!=14){break k}f=w[i|0]}if((f&240)!=128){break k}t[e+64|0]=f<<4;da=e,ea=w[ff(e+159|0,e- -64|0)|0],t[da+159|0]=ea;break k}da=e,ea=w[ff(e+159|0,i)|0],t[da+159|0]=ea;f=t[i|0];if((f|0)>=0){n=1;break k}k=(f|0)!=-92&f>>>0>4294967183|k}r=r&C;g=g+1|0;continue}}break}g=0;g=(n^-1|k)&1?g:w[e+159|0]>47;Q=d&1}Tc(b,x[l+8>>1]);n=4;n=y?n:x[p>>1];m=a+484344|0;I=o+y&65535;wg(m,I);o=a+1074312|0;ba=g^1;ca=c&1;R=(s|0)!=0;i=0;s=0;C=0;o:{p:{q:{r:{while(1){s:{t:{if((i|0)==(I|0)){break t}u:{if(y){d=(i&65534)>>>1|0;f=i&1;if(!f){if(!nh(m,d,64)){break t}}k=Zc(Sb(m,d),0,f<<2);break u}if(!nh(m,i&65535,64)){break t}k=Zc(Sb(m,i),0,0)}if(ca){break s}s=0;C=0;J=0}if((r^-1|T)&1){break q}v:{if(me(e+316|0,16758)){break v}if(me(e+316|0,17527)){break v}if(!me(e+316|0,13615)){break q}}v[a+480208>>2]=v[a+480208>>2]|2162688;d=Gb(Gb(Gb(o,85,1),91,1),92,1);w:{if(w[e+159|0]>47){break w}d=Gb(d,84,1);if(w[z|0]==127){break w}Gb(d,83,1)}if(!(r&1)){break o}break p}d=x[p>>1];t[e+128|0]=0;f=d;d=e+128|0;V=hu(e+144|0,f,d);f=x[p>>1];v[22440]=0;t[e+64|0]=0;W=Y(593,d|0,f|0,e- -64|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){K=0;x:{y:while(1){z:{if((K|0)==64){break x}g=0;f=0;X=0;while(1){if((g|0)==(n|0)){K=K+1|0;C=f&X|C;k=B(x[p>>1],6)+k|0;continue y}v[22440]=0;j=B(g,6)+k|0;U(594,e- -64|0,b|0,j|0);d=v[22440];v[22440]=0;if((d|0)!=1){h=e- -64|0;D=h;d=w[h|0];E=Ec(h);h=w[E|0];if(d|h){Z=d&255;A:{if((Z|0)==14&R){d=0;t[E|0]=0;t[D|0]=0;h=w[E|0];break A}if(!((Z|0)==15&R)|(h&255)>>>0<32){break A}h=31;t[E|0]=31;d=w[D|0]}Ef(j,d&255,h&255)}d=1;B:{C:{D:{E:{F:{h=w[j+3|0];switch(h-14|0){case 2:break B;case 0:break E;case 3:break F;default:break D}}s=w[j+5|0]<100|s;X=1;break C}if(!Q){break C}t[j+5|0]=0;break C}if(!((h|0)!=9|ba)){d=w[j+5|0];if((d|0)==164){t[j+3|0]=20;t[j+5|0]=145;break C}da=j,ea=rg(d<<1),t[da+5|0]=ea;break C}if((h|0)!=19){break C}d=w[j+5|0];if(d>>>0>15){break C}h=d&1;d=!h;D=!h;h=_&1;_=(h|0)==(d|0)?_:D;J=((d|0)!=(h|0))+J|0}d=f}G:{if(!w[j|0]){f=w[j+1|0];if(!f|y){break G}h=w[Eb(v[e+144>>2],g)|0];if(!h|(f|0)==(h|0)){break G}h=Eb(v[e+128>>2],g);f=w[h|0]+1|0;t[h|0]=f;if((f&255)>>>0<4){break G}v[22440]=0;Y(271,o|0,85,1)|0;f=v[22440];v[22440]=0;if((f|0)!=1){break G}break z}da=Eb(v[e+128>>2],g),ea=0,t[da|0]=ea}f=w[j+1|0];if(f){da=Eb(v[e+144>>2],g),ea=f,t[da|0]=ea}g=g+1|0;f=d;continue}break}}break}f=P()|0;O()|0;_b(W);break r}_b(W);_b(V);i=i+1|0;continue}break}f=P()|0;O()|0}_b(V);break b}if(r&1){break p}if(q^1|w[z|0]!=127|(N&65535)>>>0>128){break o}v[l>>2]=8523;break o}if((J|0)>6|H){break o}v[a+480208>>2]=v[a+480208>>2]|8388608}if((q|H)==1){Gb(o,89,1)}if(F){Gb(o,84,1)}H:{if(!(c&2)){break H}Tc(b,x[l+8>>1]+(B(n,I)<<8)|0);f=(r&q^1|$)&1;g=1;while(1){if((g|0)==32){break H}k=B(g,104)+a|0;c=k+484380|0;if(v[c>>2]){h=e+144|0;if(F){d=2}else{d=oR(b,13931)?10:0}d=Nc(h,8,1,0,d);y=DA(d,v[c>>2])+v[b+8>>2]|0;if(!f){da=c,ea=v[Pc(c,k+484388|0)>>2],v[da>>2]=ea}vg(d,c,b);Tc(b,y)}g=g+1|0;continue}}I:{if((q&s^-1|C)&1){break I}b=nR(e+104|0,0);c=v[b+20>>2];v[e+40>>2]=v[b+16>>2];v[e+44>>2]=c;c=v[b+12>>2];v[e+32>>2]=v[b+8>>2];v[e+36>>2]=c;c=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=c;b=e+144|0;Ct(b,a,0,e+24|0);aa=A[v[e+144>>2]>>3];Di(b);if(!(aa>=480)){break I}c=Gb(o,5,1);b=mR(e+80|0,aa);d=v[b+20>>2];v[e+16>>2]=v[b+16>>2];v[e+20>>2]=d;d=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=d;d=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=d;b=e+144|0;Ct(b,a,0,e);d=w[v[e+144>>2]+26|0];Di(b);if(d){Vf(c,5);break I}v[l>>2]=17110}b=e+316|0;f=b;d=b;c=bc(d);while(1){if((c|0)!=(d|0)){q=w[d|0];t[b|0]=q>>>0>32?q:32;b=b+1|0;d=d+1|0;continue}break}Xf(e+128|0,16863);v[22440]=0;b=Y(595,e+48|0,f|0,c|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break g}v[22440]=0;U(11,e- -64|0,1,b|0);c=v[22440];v[22440]=0;if((c|0)==1){break f}v[22440]=0;U(147,e+144|0,e+128|0,e- -64|0);c=v[22440];v[22440]=0;if((c|0)==1){break e}c=e+144|0;Cb(a+1298344|0,c);rb(c);rb(e- -64|0);rb(b);Ab(e+128|0);b=jc(c,12354);Cb(a+1298356|0,b);rb(b);b=v[l>>2];if(b){Kl(a+1298368|0,b)}v[a+1298404>>2]=2}g=G>>>0<=M>>>0;break a}f=P()|0;O()|0;break c}f=P()|0;O()|0;break d}f=P()|0;O()|0;rb(e- -64|0)}rb(b)}Ab(e+128|0)}S(f|0);L()}else{i=B(g,104)+a|0;d=i+484380|0;z=Vz(b,e+160|0,d,((g<<5)+a|0)+946304|0,x[o>>1]==4);d=v[d>>2];J:{if(k){t[i+484417|0]=0-(w[e+184|0]<<3);break J}n=d>>>0<65536&n}i=wb(w[e+182|0]|w[e+183|0]<<8);K:{if(i){T=!wb(w[e+188|0]|w[e+189|0]<<8)|T;break K}$=w[e+185|0]==64|$}m=f&1;f=0;L:{if(!m){break L}j=(i<<1)+j|0;m=w[e+184|0];f=!m;if(m|!i){break L}f=w[e+185|0]==64}G=z+G|0;h=d+h|0;g=g+1|0;continue}}cb=e+320|0;return g|0}function y_(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0;l=cb-560|0;cb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+104>>2]=1181;k=l+104|0;s=re(l+136|0,l+144|0,k);b=v[s>>2];v[l+132>>2]=b;v[l+128>>2]=b+400;x=Db(k);o=Db(l+88|0);p=Db(l+72|0);q=Db(l+56|0);u=Db(l+40|0);v[22440]=0;na(1184,c|0,d|0,l+120|0,l+119|0,l+118|0,x|0,o|0,p|0,q|0,l+36|0);c=v[22440];v[22440]=0;a:{b:{c:{d:{e:{if((c|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;r=v[l+36>>2];e=0;while(1){f:{g:{h:{i:{j:{if((e|0)==4){break j}v[22440]=0;c=Q(1148,a|0,l+552|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}if(!c){break j}k:{l:{m:{n:{o:{p:{switch(t[(l+120|0)+e|0]){case 1:if((e|0)==3){break g}c=v[a>>2];v[22440]=0;c=T(1150,c|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}if(qh(h,8192,c)){v[22440]=0;R(1185,l+24|0,a|0);c=v[22440];v[22440]=0;if((c|0)!=1){v[22440]=0;R(48,u|0,t[l+24|0]);c=v[22440];v[22440]=0;if((c|0)!=1){break o}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break f;case 4:break l;case 2:break m;case 3:break n;case 0:break p;default:break g}}if((e|0)==3){break g}}while(1){v[22440]=0;c=Q(1148,a|0,l+552|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break b}if(!c){break g}c=v[a>>2];v[22440]=0;c=T(1150,c|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break b}if(!qh(h,8192,c)){break g}v[22440]=0;R(1185,l+24|0,a|0);c=v[22440];v[22440]=0;if((c|0)!=1){v[22440]=0;R(48,u|0,t[l+24|0]);c=v[22440];v[22440]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}c=vb(p);k=vb(q);if((c|0)==(0-k|0)){break g}d=v[a>>2];if(!(k?c:0)){if(c){v[22440]=0;c=T(1150,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}if(w[rc(p,0)|0]!=(c&255)){break k}v[22440]=0;T(1152,a|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}m=vb(p)>>>0>1?p:m;break g}v[22440]=0;c=T(1150,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}if(w[rc(q,0)|0]!=(c&255)){break g}v[22440]=0;T(1152,a|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}t[g|0]=1;m=vb(q)>>>0>1?q:m;break g}v[22440]=0;c=T(1150,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}if(w[rc(p,0)|0]==(c&255)){v[22440]=0;T(1152,a|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}m=vb(p)>>>0>1?p:m;break g}c=v[a>>2];v[22440]=0;c=T(1150,c|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}if(w[rc(q,0)|0]==(c&255)){v[22440]=0;T(1152,a|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}t[g|0]=1;m=vb(q)>>>0>1?q:m;break g}v[f>>2]=v[f>>2]|4;a=0;break f}if(!(e>>>0<2|m|((e|0)==2&w[l+123|0]!=0|z))){m=0;break g}A=l,B=fd(o),v[A+16>>2]=B;c=kj(l+24|0,l+16|0);q:{if(!e|w[(e+l|0)+119|0]>1){break q}while(1){r:{A=l,B=gf(o),v[A+16>>2]=B;if(!oj(c,l+16|0)){break r}if(!qh(h,8192,t[v[c>>2]])){break r}Fe(c);continue}break}A=l,B=fd(o),v[A+16>>2]=B;c=xn(c,l+16|0);if(vb(u)>>>0>=c>>>0){A=l,B=gf(u),v[A+16>>2]=B;d=_z(l+16|0,c);k=gf(u);n=fd(o);c=cb-32|0;cb=c;v[c+16>>2]=k;v[c+24>>2]=d;v[c+8>>2]=n;while(1){d=oj(c+24|0,c+16|0);if(!(!d|w[v[c+24>>2]]!=w[v[c+8>>2]])){Fe(c+24|0);Fe(c+8|0);continue}break}cb=c+32|0;if(d^1){break q}}A=l,B=fd(o),v[A+8>>2]=B;kj(l+16|0,l+8|0);v[l+24>>2]=v[l+16>>2]}v[l+16>>2]=v[l+24>>2];s:{t:{while(1){A=l,B=gf(o),v[A+8>>2]=B;if(!oj(l+16|0,l+8|0)){break s}v[22440]=0;c=Q(1148,a|0,l+552|0)|0;d=v[22440];v[22440]=0;u:{if((d|0)==1){break u}if(!c){break s}c=v[a>>2];v[22440]=0;c=T(1150,c|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break u}if(w[v[l+16>>2]]!=(c&255)){break s}v[22440]=0;T(1152,a|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break t}Fe(l+16|0);continue}break}a=P()|0;O()|0;v[l+36>>2]=r;break a}a=P()|0;O()|0;v[l+36>>2]=r;break a}if(!y){break g}A=l,B=gf(o),v[A+8>>2]=B;if(!oj(l+16|0,l+8|0)){break g}v[f>>2]=v[f>>2]|4;a=0;break f}d=0;n=w[l+118|0];v:{while(1){w:{v[22440]=0;c=Q(1148,a|0,l+552|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break w}if(!c){break v}c=v[a>>2];v[22440]=0;c=T(1150,c|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break e}x:{if(qh(h,2048,c)){k=v[j>>2];if((k|0)==v[l+548>>2]){v[22440]=0;U(1186,i|0,j|0,l+548|0);k=v[22440];v[22440]=0;if((k|0)==1){break e}k=v[j>>2]}v[j>>2]=k+1;t[k|0]=c;d=d+1|0;break x}if(!vb(x)|!d|(n|0)!=(c&255)){break v}if(v[l+128>>2]==(b|0)){v[22440]=0;U(1187,s|0,l+132|0,l+128|0);b=v[22440];v[22440]=0;if((b|0)==1){break e}b=v[l+132>>2]}c=b+4|0;v[l+132>>2]=c;v[b>>2]=d;b=c;d=0}v[22440]=0;T(1152,a|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!d|v[s>>2]==(b|0)){break i}if(v[l+128>>2]==(b|0)){v[22440]=0;U(1187,s|0,l+132|0,l+128|0);b=v[22440];v[22440]=0;if((b|0)==1){break d}b=v[l+132>>2]}k=b+4|0;v[l+132>>2]=k;v[b>>2]=d;break h}t[g|0]=1;break g}v[l+36>>2]=r;y:{if(!m){break y}c=1;while(1){if(vb(m)>>>0<=c>>>0){break y}v[22440]=0;d=Q(1149,a|0,l+552|0)|0;e=v[22440];v[22440]=0;z:{if((e|0)==1){break z}A:{if(!d){d=v[a>>2];v[22440]=0;d=T(1150,d|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break z}if(w[rc(m,c)|0]==(d&255)){break A}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22440]=0;T(1152,a|0)|0;d=v[22440];v[22440]=0;c=c+1|0;if((d|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;c=v[s>>2];if((c|0)==(b|0)){break f}a=0;v[l+24>>2]=0;Mf(x,c,b,l+24|0);if(v[l+24>>2]){v[f>>2]=v[f>>2]|4;break f}a=1;break f}k=b}B:{if((r|0)<=0){break B}v[22440]=0;b=Q(1149,a|0,l+552|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break d}C:{if(!b){b=v[a>>2];v[22440]=0;b=T(1150,b|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break d}if(w[l+119|0]==(b&255)){break C}}v[l+36>>2]=r;v[f>>2]=v[f>>2]|4;a=0;break f}v[22440]=0;b=T(1152,a|0)|0;d=v[22440];v[22440]=0;c=r;if((d|0)==1){break d}while(1){if((c|0)<=0){r=0;break B}v[22440]=0;d=Q(1149,b|0,l+552|0)|0;n=v[22440];v[22440]=0;D:{if((n|0)==1){break D}E:{if(!d){d=v[a>>2];v[22440]=0;d=T(1150,d|0)|0;n=v[22440];v[22440]=0;if((n|0)==1){break D}if(qh(h,2048,d)){break E}}v[l+36>>2]=c;v[f>>2]=v[f>>2]|4;a=0;break f}if(v[j>>2]==v[l+548>>2]){v[22440]=0;U(1186,i|0,j|0,l+548|0);d=v[22440];v[22440]=0;if((d|0)==1){break D}}d=v[a>>2];v[22440]=0;d=T(1150,d|0)|0;n=v[22440];v[22440]=0;if((n|0)==1){break D}n=v[j>>2];v[j>>2]=n+1;t[n|0]=d;v[22440]=0;T(1152,b|0)|0;d=v[22440];v[22440]=0;c=c-1|0;if((d|0)!=1){continue}}break}a=P()|0;O()|0;v[l+36>>2]=r;break a}if(v[i>>2]!=v[j>>2]){b=k;break g}v[l+36>>2]=r;v[f>>2]=v[f>>2]|4;a=0;break f}e=e+1|0;continue}break}rb(u);rb(q);rb(p);rb(o);rb(x);Lc(s);cb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}rb(u);rb(q);rb(p);rb(o);rb(x);Lc(s);S(a|0);L()}function JM(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=C(0),D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=C(0),S=C(0),T=0,U=0,V=0,W=C(0),X=0;p=cb-48|0;cb=p;t[p+40|0]=0;h=b+223848|0;l=p+40|0;Si(h,Oh(e,yi(e,Pp(e),l))+1|0);qe(l,v[h>>2],v[b+223852>>2]);h=cb-16|0;cb=h;t[h+15|0]=0;$b(p+32|0,e,Oh(e,yi(e,Pp(e),h+15|0)));cb=h+16|0;H=v[p+32>>2];I=v[p+36>>2];h=0;o=cb-16|0;cb=o;F=a+1074312|0;k=B(c,872)+b|0;J=k+1415|0;K=k+1304|0;L=k+1392|0;r=k+1368|0;D=k+1364|0;M=k+1336|0;N=k+1308|0;O=k+1300|0;P=k+1280|0;Q=k+1402|0;G=k+616|0;m=k+1466|0;R=C(w[m|0]);S=C(f>>>0);q=v[k+1272>>2];T=a+480188|0;i=1;n=255;while(1){if((s|0)!=(I|0)&y[l+4>>2]>h>>>0){j=w[Eb(H,s)|0];e=j-48|0;a:{b:{c:{if((e&255)>>>0<=9){break c}if((j-65&255)>>>0<=5){e=j-55|0;break c}d:{e:{f:{switch(j-97|0){case 2:e=g;if(!e){e=Il(a,b,c,3,0)}g:{if((e-1&255)>>>0>249){break g}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break g}e=Ey(e,47552,44652);if(!e){break g}e=gb[v[v[e>>2]+188>>2]](e,G,c)|0;j=(e|0)!=255;e=j?e:0;if(j|!q){break c}break d}if(q){break d}e=0;break c;case 21:ub(o+8|0,F,28);h:{if(!tb(v[v[o+8>>2]>>2],v[o+12>>2])){ub(o,F,1);e=0;if(!tb(v[v[o>>2]>>2],v[o+4>>2])){break h}}e=u[L>>1]}j=B(v[r>>2],v[D>>2]);e=B(v[a+1074456>>2],e+v[K>>2]|0);j=Vb((yc(lka(kka(j,j>>31,e,e>>31),fb,1048576,0),fb)|0)/2|0,1,127);break e;case 20:e=B(v[r>>2],v[D>>2]);j=e;E=e>>31;e=B(v[a+1074456>>2],v[M>>2]);j=Vb((yc(lka(kka(j,E,e,e>>31),fb,67108864,0),fb)|0)/2|0,1,127);break e;case 23:v[o+8>>2]=v[N>>2]/2;v[o>>2]=127;j=v[ld(o+8|0,o)>>2];break e;case 24:v[o+8>>2]=v[O>>2]/2;v[o>>2]=127;j=v[ld(o+8|0,o)>>2];break e;case 0:j=0;if(!q){break e}e=x[q+28>>1];if(!e){break e}j=e-1>>>7&127;break e;case 1:j=0;if(!q){break e}e=x[q+28>>1];if(!e){break e}j=e-1&127;break e;case 14:j=v[P>>2]>>>8|0;break e;case 7:j=(x[T>>1]<=c>>>0?w[Q|0]-1|0:c)&127;break e;case 12:j=w[k+704|0]>>>7|0;break e;case 15:j=0;if(!q){break e}e=w[q+30|0];if(!e){break e}j=e-1&127;break e;case 25:i:{if(!d|t[m|0]<0){break i}j:{if(h>>>0<3){break j}e=v[l>>2];if(w[Eb(e,h-3|0)|0]!=240){break j}if(w[Eb(e,h-2|0)|0]>239){break i}}A=vp(b,R,S);k:{if(A<C(4294967296)&A>=C(0)){j=~~A>>>0;break k}j=0}t[m|0]=j;n=128;break e}n=(n&255)==255?f:n;j=f;break e;case 18:l:{if(!h){e=0;break l}j=v[l>>2];e=h;while(1){e=e-1|0;E=Eb(j,e);if(!e){break l}if(w[E|0]!=240){continue}break}}if(h-e>>>0<5){break a}E=v[l>>2];if(w[Eb(E,e)|0]!=240){break a}e=e+5|0;j=0;while(1){if((e|0)!=(h|0)){j=w[Eb(E,e)|0]+j|0;e=e+1|0;continue}break};j=0-j&127;break e;case 13:break f;default:break a}}e=w[J|0];j=Rc(e)?e-1|0:0}e=((i^-1)&1)+h|0;U=Eb(v[l>>2],e),V=j,t[U|0]=V;h=e+1|0;i=1;break b}e=w[q+31|0];m:{if((e|0)==17){e=x[G+786>>1];e=(e?e-1|0:c)&15;break m}e=sj(e)?e-1&15:0}}j=Eb(v[l>>2],h);n:{if(i){t[j|0]=e;break n}t[j|0]=w[j|0]<<4|e;h=h+1|0}i=(i^-1)&1}}s=s+1|0;continue}else{if(n<<24>>24>=0){t[m|0]=n}Ub(o+8|0,v[l>>2],((i^-1)&1)+h|0);e=v[o+12>>2];v[l>>2]=v[o+8>>2];v[l+4>>2]=e;cb=o+16|0}break}o=v[p+44>>2];j=0;o:while(1){f=0;while(1){e=j;p:{q:{r:{s:{while(1){if(y[p+44>>2]<=e>>>0){break p}m=v[p+40>>2];i=Eb(m,e);h=t[i|0];if((h|0)==-16){h=e;if(o-h>>>0>=4){j=4;if((w[Eb(m,e+1|0)|0]&254)==240){break q}}t:{while(1){h=h+1|0;if(o>>>0<=h>>>0){break t}if(w[Eb(m,h)|0]!=247){continue}break}h=h-e|0;j=h+1|0;if(j>>>0>=h>>>0){break q}}U=Eb(m,o),V=247,t[U|0]=V;o=o+1|0;j=o-e|0;break r}if((h|0)<0){break s}if(f&255){e=e-1|0;U=Eb(m,e),V=f,t[U|0]=V;continue}break}j=j+1|0;continue o}U=p,V=QO(h&255),v[U+16>>2]=V;v[p+28>>2]=o-e;j=v[Bb(p+16|0,p+28|0)>>2]}if(!j){break p}m=v[p+40>>2];i=Eb(m,e)}F=w[i|0];jq(p+16|0,m,v[p+44>>2],e,j);$b(p+8|0,v[p+16>>2],v[p+20>>2]);k=v[p+8>>2];h=g;i=0;m=cb-32|0;cb=m;n=v[p+12>>2];u:{if(!n){break u}q=Ed(w[b+223884|0]);v:{s=Eb(k,0);l=w[s|0]-250|0;if(l>>>0>5|!(1<<l&37)){break v}l=x[a+480188>>1];while(1){if((i|0)==(l|0)){break v}r=(B(i,872)+b|0)+1453|0;t[r|0]=127;t[r+1|0]=0;i=i+1|0;continue}}w:{if((n|0)!=4|w[s|0]!=240){break w}l=w[Eb(k,1)|0];if((l&254)!=240){break w}s=b+223860|0;n=(B(c,872)+b|0)+616|0;r=Eb(k,2);D=w[Eb(k,3)|0];i=D<<24>>24;x:{y:{z:{A:{B:{C:{k=w[r|0];switch(k|0){case 3:break z;case 2:break A;case 1:break B;case 0:break C;default:break y}}if((l|0)==241|(i|0)<0){break y}h=B(c,872)+b|0;k=h+1453|0;if(d){i=gh(vp(b,C(w[k|0]),C((i&255)>>>0)))}t[k|0]=i;t[h+1412|0]=0;i=Cp(a,n,!(v[h+704>>2]&32768),256);if((i|0)<0|!(w[h+705|0]&2)){break u}h=a+1298300|0;if(q|Bd(h)^1){break u}Ip(v[h>>2],c,i>>>2&255,1);break u}if((l|0)==241|(i|0)<0){break y}h=B(c,872)+b|0;k=h+1454|0;if(d){i=gh(vp(b,C(w[k|0]),C((i&255)>>>0)))}t[k|0]=i;t[h+1411|0]=0;Cp(a,n,!(v[h+704>>2]&32768),256);break u}if((l|0)==241){break x}if(i>>>0>31){break u}h=B(c,872)+b|0;t[h+1461|0]=(i&240)>>>4;Cp(a,n,!(v[h+704>>2]&32768),256);break u}if((l|0)==241){break x}i=(i|0)<0;if(!h){h=Il(a,b,c,3,0)}h=h-1|0;if((h&255)>>>0>249|i){break u}t[m+24|0]=h;A=C(C(127-D|0)/C(127));if(q){i=0;k=cb-16|0;cb=k;U=k,V=yj(m+24|0),v[U>>2]=V;h=cb-16|0;cb=h;r=Cy(s,h+12|0,w[m+24|0]);n=v[r>>2];if(!n){l=cb-16|0;cb=l;i=bc(s);n=kh(h,lc(24),lh(l+8|0,i));q=v[n>>2]+16|0;i=cb-16|0;cb=i;v[i+8>>2]=v[k>>2];D=w[v[i+8>>2]];v[q+4>>2]=0;t[q|0]=D;cb=i+16|0;U=bc(n),V=1,t[U+4|0]=V;cb=l+16|0;Ig(s,v[h+12>>2],r,v[h>>2]);n=Vd(h);pk(h);i=1}l=k+8|0;Hg(l,ac(h,n),i);cb=h+16|0;h=od(l);cb=k+16|0;z[h+4>>2]=A;break u}h=(B(h&255,160)+a|0)+906444|0;if(!d){z[h>>2]=A;break u}U=h,W=vp(b,z[h>>2],A),z[U>>2]=W;break u}if(k&128){break x}if((l|0)!=241){break u}}n=(i|0)<0;if(!h){h=Il(a,b,c,3,0)}r=n;n=h-1|0;if(r|(n&255)>>>0>249){break u}h=v[(B(n&255,160)+a|0)+906300>>2];if(!h){break u}k=(l|0)==241?k+128|0:k&127;A=C(C((i&255)>>>0)/C(127));if(q){U=XM(s+12|0,rM(m+24|0,n,k)),W=A,z[U>>2]=W;break u}if(!d){gb[v[v[h>>2]+44>>2]](h,k,A);break u}V=h,X=k,W=vp(b,C(gb[v[v[h>>2]+48>>2]](h,k)),A),U=v[v[h>>2]+44>>2],gb[U](V|0,X|0,C(W));break u}if(q){break u}l=x[a+480188>>1];D:{if(l>>>0>c>>>0){i=c+1|0;break D}i=x[(B(c,872)+b|0)+1402>>1];if(!i){break u}}if(w[(B(c,872)+b|0)+707|0]&4|l>>>0<(i&65535)>>>0){break u}if(!h){h=Il(a,b,c,3,0)}if((h-1&255)>>>0>249){break u}h=v[(B(h,160)+a|0)+906140>>2];if(!h){break u}i=w[s|0];if((i|0)==240){_g(m+16|0,k,n);i=v[v[h>>2]+72>>2];k=v[m+20>>2];v[m>>2]=v[m+16>>2];v[m+4>>2]=k;gb[i|0](h,m)|0;break u}U=m,X=QO(i),v[U+24>>2]=X;v[m+12>>2]=n;i=m+24|0;l=v[Bb(i,m+12|0)>>2];v[m+24>>2]=0;ic(i,k,l);gb[v[v[h>>2]+68>>2]](h,v[m+24>>2])|0}cb=m+32|0;f=F>>>0<240?F:f;j=e+j|0;continue}break}break}cb=p+48|0}function $ia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;e=cb-272|0;cb=e;sc(b);d=cb-16|0;cb=d;h=e+112|0;vT(d+8|0,h);g=v[d+12>>2];Yb(d,b,v[d+8>>2],g);i=v[d+4>>2];if((i|0)==(g|0)){Ob(b,v[d+12>>2])}cb=d+16|0;d=(g|0)==(i|0);if(!d){uT(h)}a:{if(!d){break a}if(!wT(e+112|0)){break a}if(!c){f=1;break a}ud(a,v[((w[e+228|0]|w[e+229|0]<<8)<<2)+26496>>2]);v[a+480208>>2]=v[a+480208>>2]|16777216;d=e+48|0;f=jc(d,13139);Cb(a+1298344|0,f);rb(f);f=jc(d,10332);Cb(a+1298356|0,f);rb(f);f=cb-16|0;cb=f;g=e+8|0;h=jc(f,4392);zc(g,h);rb(h);cb=f+16|0;v[22440]=0;W(235,d|0,g|0,e+191|0,e+188|0);d=v[22440];v[22440]=0;b:{if((d|0)!=1){d=e+48|0;Cb(a+1298368|0,d);rb(d);f=e+8|0;Ab(f);Kl(a+1298392|0,((w[e+228|0]|w[e+229|0]<<8)<<2)+26544|0);Kl(a+1298380|0,v[((w[e+228|0]|w[e+229|0]<<8)<<2)+26592>>2]);v[a+1298404>>2]=5;Ie(f,2,e+112|4);xc(d,v[e+8>>2],v[e+12>>2],w[e+16|0]);tc(a+1298308|0,d);rb(d);Ie(f,2,e+148|0);xc(d,v[e+8>>2],v[e+12>>2],w[e+16|0]);c:{if(gq(d,9769)){v[22440]=0;U(11,e+8|0,5,e+48|0);d=v[22440];v[22440]=0;if((d|0)==1){break c}d=e+8|0;Cb(a+1298320|0,d);rb(d)}rb(e+48|0);u[a+480188>>1]=32;d=0;d:{while(1){if((d|0)!=32){g=(d<<5)+a|0;h=g+480280|0;$e(h);f=w[(e+d|0)+193|0];e:{if(f>>>0<=15){v[e+48>>2]=f<<4|8;v[e+8>>2]=256;z=g+480284|0,A=v[ld(e+48|0,e+8|0)>>2],u[z>>1]=A;break e}if((f|0)!=16){if((f|0)!=255){break e}u[a+480188>>1]=d;break d}u[g+480284>>1]=128;v[h>>2]=256}d=d+1|0;continue}break}d=x[a+480188>>1]}f=0;if(!(d&65535)){break a}v[e+48>>2]=w[e+225|0]<<2;v[e+8>>2]=256;z=a,A=v[Bb(e+48|0,e+8|0)>>2],v[z+480200>>2]=A;v[a+480196>>2]=w[e+226|0];v[a+480204>>2]=B(w[e+227|0],1e4);if(Tc(b,w[e+230|0]|w[e+231|0]<<8|(w[e+232|0]<<16|w[e+233|0]<<24))){Zn(Nb(a+484360|0),b,w[e+234|0]+1|0,255,254)}if(!Tc(b,w[e+240|0]|w[e+241|0]<<8|(w[e+242|0]<<16|w[e+243|0]<<24))){break a}k=a+480190|0;d=w[e+248|0]+1|0;u[k>>1]=d;m=e+80|0;n=a+480180|0;h=1;while(1){f:{g:{i=h&65535;if(i>>>0>(d&65535)>>>0){break g}d=cb-16|0;cb=d;g=e+48|0;Ub(d+8|0,g,62);f=v[d+12>>2];Yb(d,b,v[d+8>>2],f);j=v[d+4>>2];if((j|0)==(f|0)){Ob(b,v[d+12>>2])}cb=d+16|0;d=(f|0)==(j|0);if(!d){Hb(g,0,62)}if(!d){break g}d=0;f=B(i,104)+a|0;j=f+484380|0;ed(j,0);l=e+32|0;Ie(l,2,e+48|0);g=e+8|0;xc(g,v[e+32>>2],v[e+36>>2],w[e+40|0]);uc(((i<<5)+a|0)+946304|0,g);rb(g);sk(l,2,m);xc(g,v[e+32>>2],v[e+36>>2],w[e+40|0]);pe(f+484423|0,g);rb(g);g=w[e+106|0]|w[e+107|0]<<8;v[f+484404>>2]=g;if(!vm(v[n>>2])){break f}while(1){if((d|0)==16){break f}if((g|0)==x[(d<<1)+26640>>1]){t[f+484417|0]=d<<4;break f}else{d=d+1|0;continue}}}h:{if(!(c&2)){break h}if(!Tc(b,w[e+244|0]|w[e+245|0]<<8|(w[e+246|0]<<16|w[e+247|0]<<24))){break h}f=a+480190|0;d=1;while(1){g=d&65535;if(g>>>0>x[f>>1]){break h}g=B(g,104)+a|0;vg(Nc(e+48|0,u[g+484414>>1]&1?16:8,1,0,1),g+484380|0,b);d=d+1|0;continue}}l=a+484344|0;wg(l,w[e+239|0]+1|0);f=fq(a);d=cb-16|0;cb=d;v[d+12>>2]=0;As(d+12|0,f);j=v[d+12>>2];cb=d+16|0;Tc(b,w[e+235|0]|w[e+236|0]<<8|(w[e+237|0]<<16|w[e+238|0]<<24));q=c&1;r=a+480188|0;s=a+480180|0;i=0;m=1;i:{j:{k:{while(1){if(w[e+239|0]<i>>>0){if(v[a+480180>>2]==1){break k}c=v[a+480208>>2]&-8454145;break j}l:{d=Sg(b);if(d>>>0>=3){c=e+8|0;Td(c,b,d-2|0);n=cc(e+48|0,c);sb(c);m:{if(!q){break m}v[22440]=0;c=T(180,e+48|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break l}if(!c){break m}v[22440]=0;c=Y(229,l|0,i&65535,64)|0;d=v[22440];v[22440]=0;if((d|0)==1){break l}k=0;if(!c){break m}while(1){if((k|0)==64){break m}y=Gf(Sb(l,i),k);n:{o:while(1){v[22440]=0;c=T(208,n|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break i}if(!c){break n}d=c&31;if(d>>>0>=x[r>>1]){break n}f=B(d,6)+y|0;if(c&32){v[22440]=0;R(267,e+8|0,n|0);d=v[22440];v[22440]=0;if((d|0)==1){break i}g=Ec(e+8|0);d=w[e+8|0];if(d){d=(d&127)-1|0;t[e+8|0]=d;d=(B((d&240)>>>4|0,12)+(d&15)|0)+13|0;t[f|0]=d;m=UA(d)&m}t[f+1|0]=w[g|0]}if(!(c&64)){continue}t[f+2|0]=0;t[f+3|0]=0;g=f+5|0;while(1){v[22440]=0;c=Q(158,e+48|0,2)|0;d=v[22440];v[22440]=0;if((d|0)==1){break i}if(!c){continue o}p=w[g|0];c=w[f+3|0];v[22440]=0;R(267,e+8|0,n|0);d=v[22440];v[22440]=0;if((d|0)!=1){d=e+8|0;o=d;h=w[Ec(d)|0];t[g|0]=h;d=w[(w[d|0]&31)+26672|0];t[f+3|0]=d;p:{q:{r:{s:{t:{switch(d-2|0){case 0:case 1:if(h>>>0<224){break r}d=223;if(v[s>>2]!=1){break s}break r;case 11:t[e+32|0]=64;z=g,A=w[Tb(g,e+32|0)|0],t[z|0]=A;if(!tT(v[j+88>>2])){break r}t[f+2|0]=1;t[f+4|0]=w[g|0];t[f+3|0]=c;t[g|0]=p;d=c;break q;case 17:u:{switch(((h&240)>>>4|0)-8|0){case 0:t[f+3|0]=2;t[g|0]=h&15|224;break p;case 1:t[f+3|0]=3;t[g|0]=h&15|224;break p;default:break u}}if(Xt(v[j+84>>2],19)){break r}Cu(f);break r;case 13:d=v[j+84>>2];if(Xt(d,15)){break r}if(!Xt(d,19)){break r}t[f+3|0]=19;t[g|0]=h&15|144;break p;case 18:d=145;if((h|0)==1){break s}if((h&240)==128){if(Xt(v[j+84>>2],20)){break r}t[f+3|0]=19;break p}t[f+3|0]=0;break p;case 4:case 5:break t;default:break q}}d=h&240;if(!d){break r}}t[g|0]=d}d=w[f+3|0]}if((d&255)!=20){break p}d=w[g|0];if(w[f+2|0]|(d&240)!=128){break p}t[f+2|0]=2;t[f+4|0]=(((d&15)<<6|8)>>>0)/15;t[f+3|0]=c;t[g|0]=p}if(!(w[o|0]&32)){continue o}continue}break}break}break i}k=k+1|0;continue}}sb(e+48|0)}i=i+1|0;continue}break}break i}c=v[a+480208>>2]&-8454145|(x[a+480188>>1]==4?m&1?8454144:0:0)}v[a+480208>>2]=c;f=1;if(!(w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24))){break a}if(!Tc(b,w[e+249|0]|w[e+250|0]<<8|(w[e+251|0]<<16|w[e+252|0]<<24))){break a}gB(a+1298332|0,b,w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24),4);break a}d=P()|0;O()|0;sb(e+48|0);break b}u[f+484412>>1]=64;d=w[e+93|0]|w[e+94|0]<<8|(w[e+95|0]<<16|w[e+96|0]<<24);v[j>>2]=d;if(w[e+105|0]&2){g=f+484414|0;u[g>>1]=x[g>>1]|1;v[j>>2]=d>>>1}v[f+484384>>2]=w[e+97|0]|w[e+98|0]<<8|(w[e+99|0]<<16|w[e+100|0]<<24);v[f+484388>>2]=(w[e+101|0]|w[e+102|0]<<8|(w[e+103|0]<<16|w[e+104|0]<<24))-1;d=w[e+105|0];if(d&1){d=f+484414|0;u[d>>1]=x[d>>1]|2;d=w[e+105|0]}v:{w:{if(!(d&4)){break w}d=w[e+108|0];if((d|0)==255){break w}t[e+8|0]=d;t[e+32|0]=64;z=f+484410|0,A=w[Tb(e+8|0,e+32|0)|0]<<2,u[z>>1]=A;break v}d=f+484414|0;u[d>>1]=x[d>>1]|32768}x:{if(w[e+105|0]&8){d=f+484414|0;g=x[d>>1]|32;u[d>>1]=g;i=f+484408|0;f=w[e+109|0];if(f>>>0<=15){v[e+32>>2]=256;v[e+8>>2]=f<<4|8;o=v[ld(e+8|0,e+32|0)>>2]}else{o=128}u[i>>1]=o;u[d>>1]=g&65279|(w[e+109|0]==16)<<8;break x}u[f+484408>>1]=128}h=h+1|0;d=x[k>>1];continue}}d=P()|0;O()|0;rb(e+48|0);break b}d=P()|0;O()|0;Ab(e+8|0)}S(d|0);L()}cb=e+272|0;return f|0}function HV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;f=cb-224|0;cb=f;sc(b);a:{b:{c:{d:{if(!qC(b,f+176|0)){break d}if(!tC(f+176|0)){break d}if(!c){n=1;break d}ud(a,2048);eg(a);d=cb-16|0;cb=d;l=f+8|0;e=jc(d,3947);zc(l,e);rb(e);cb=d+16|0;v[22440]=0;d=l;l=f+176|3;U(216,f+80|0,d|0,l|0);d=v[22440];v[22440]=0;e:{if((d|0)!=1){d=f+80|0;Cb(a+1298344|0,d);rb(d);e=f+8|0;Ab(e);g=jc(d,11118);Cb(a+1298356|0,g);rb(g);v[a+1298404>>2]=5;g=a+480188|0;u[g>>1]=w[f+216|0];u[a+480190>>1]=w[f+212|0];Ie(e,2,f+176|4);xc(d,v[f+8>>2],v[f+12>>2],w[f+16|0]);tc(a+1298308|0,d);rb(d);d=w[l|0];if(d>>>0<=8){u[g>>1]=4;xg(b,1);mh(a,1);d=w[l|0]}f:{d=d&255;if(d>>>0>=11){e=(d|0)==11?16:32;d=0;while(1){if((d|0)==(e|0)){break f}g=Su(b);g:{if((g|0)==100){v[((d<<5)+a|0)+480280>>2]=256;break g}v[f+80>>2]=(g<<1)+128;v[f+8>>2]=0;v[f+160>>2]=256;y=((d<<5)+a|0)+480284|0,z=v[Gj(f+80|0,f+8|0,f+160|0)>>2],u[y>>1]=z}d=d+1|0;continue}}if(d>>>0<9){break f}e=f+80|0;d=cb-16|0;cb=d;h:{if(!Kb(b,16)){cC(e);break h}Ju(d+8|0,e);md(d,b,v[d+8>>2],v[d+12>>2])}cb=d+16|0;d=0;while(1){if((d|0)==16){break f}u[((d<<5)+a|0)+480284>>1]=t[(f+80|0)+d|0]&1?64:192;d=d+1|0;continue}}i:{if(w[l|0]>=13){e=f+80|0;Nu(e,b);g=Ec(e);d=w[e|0];if(d>>>0<=31){t[e|0]=125;d=125}v[a+480204>>2]=B(d,1e4);v[a+480196>>2]=w[g|0];break i}v[a+480196>>2]=6;v[a+480204>>2]=125e4}e=a+484360|0;Ff(Nb(e),w[f+213|0]);o=Rb(f+160|0);d=v[b+8>>2];g=w[l|0]>13;if(!g){break e}i=w[f+213|0];v[22440]=0;R(217,o|0,i|0);i=v[22440];v[22440]=0;if((i|0)!=1){break e}d=P()|0;O()|0;break b}d=P()|0;O()|0;Ab(f+8|0);break a}r=d+(g<<1)|0;g=a+480188|0;d=0;j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{while(1){t:{if(w[f+213|0]<=d>>>0){d=0;if(w[l|0]!=10){break s}m=v[b+8>>2];n=a+480190|0;d=1;while(1){h=x[n>>1];if(h>>>0<(d&65535)>>>0){break t}v[22440]=0;e=Q(218,b|0,f+80|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break r}if(e){k=w[f+212|0];e=0;g=f+80|0;u:{if(w[g|0]>1){break u}i=g+46|0;if(k>>>0<(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))>>>0){break u}i=g+50|0;k=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);if(k>>>0>1048576|w[g+56|0]>64){break u}i=g+57|0;if(k>>>0<(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))>>>0){break u}e=g+61|0;e=k>>>0>=(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0}if(!e){break t}}d=d+1|0;continue}}y=Xb(v[Nb(e)>>2],d),z=d,u[y>>1]=z;if(w[l|0]>=14){v[22440]=0;i=T(196,b|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break q}y=Xb(v[o>>2],d),z=i,u[y>>1]=z}i=x[g>>1];v[22440]=0;Q(190,b|0,i<<1)|0;i=v[22440];v[22440]=0;if((i|0)==1){break q}d=d+1|0;continue}break}v[22440]=0;Q(157,b|0,m|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}d=h>>>0>=(d&65535)>>>0}m=a+480190|0;e=x[m>>1];v[22440]=0;v[f+80>>2]=0;i=Y(219,f- -64|0,e|0,f+80|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break p}n=d?59:65;k=f+80|1;e=1;v:{while(1){g=e&65535;if(g>>>0>x[m>>1]){g=Rb(f+48|0);d=w[f+214|0]|w[f+215|0]<<8;v[22440]=0;n=Y(220,b|0,g|0,d|0)|0;d=v[22440];v[22440]=0;w:{if((d|0)!=1){if(!n){break j}k=0;d=v[g>>2];if(!hc(d,v[g+4>>2])){d=yb(d);k=yb(v[g+4>>2]);e=cb-16|0;cb=e;x:{if(!Qb(d,k)){break x}v[e+8>>2]=d;while(1){Ne(e+8|0);m=v[e+8>>2];if(!Qb(m,k)){break x}d=gC(d,m)?m:d;continue}}cb=e+16|0;k=w[d|0]|w[d+1|0]<<8}v[22440]=0;m=Q(221,f+32|0,k|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break w}d=0;y:{while(1){if((d|0)==(k|0)){if(!(c&2)){break o}j=Nc(f+80|0,8,1,0,1);p=a+480190|0;e=x[p>>1];h=1;z:{A:while(1){q=h&65535;if(q>>>0>(e&65535)>>>0){break o}v[22440]=0;d=Q(158,b|0,1)|0;e=v[22440];v[22440]=0;if((e|0)==1){break z}if(!d){break o}s=v[b+8>>2];d=0;while(1){e=x[p>>1];if(e>>>0<=d>>>0){h=h+1|0;continue A}if((q|0)!=v[Ib(v[i>>2],d)>>2]){d=d+1|0;continue}v[22440]=0;Q(157,b|0,s|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){v[22440]=0;d=d+1|0;Y(222,j|0,(B(d,104)+a|0)+484380|0,b|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){continue}}break}break}d=P()|0;O()|0;break n}d=P()|0;O()|0;break n}v[22440]=0;e=T(196,b|0)|0;h=v[22440];v[22440]=0;B:{if((h|0)==1){break B}v[22440]=0;Q(190,b|0,1)|0;h=v[22440];v[22440]=0;if((h|0)==1){break B}if(e){h=w[l|0];v[22440]=0;U(192,f+8|0,b|0,B(e,3)+((h|0)==1?3:0)|0);e=v[22440];v[22440]=0;if((e|0)==1){break y}e=f+80|0;h=f+8|0;j=cc(e,h);Sc(Ng(v[m>>2],d),j);sb(e);sb(h)}d=d+1|0;continue}break}d=P()|0;O()|0;break n}d=P()|0;O()|0;break n}d=P()|0;O()|0;break m}d=P()|0;O()|0;break m}C:{D:{if(w[l|0]<=9){v[22440]=0;R(223,b|0,f+80|0);h=v[22440];v[22440]=0;E:{F:{if((h|0)==1){break F}v[22440]=0;R(224,f+80|0,(B(g,104)+a|0)+484380|0);h=v[22440];v[22440]=0;if((h|0)==1){break F}Ie(f+48|0,2,k);v[22440]=0;W(225,f+8|0,v[f+48>>2],v[f+52>>2],w[f+56|0]);h=v[22440];v[22440]=0;if((h|0)==1){break E}break D}d=P()|0;O()|0;break l}d=P()|0;O()|0;break l}v[22440]=0;U(226,b|0,f+80|0,n|0);h=v[22440];v[22440]=0;if((h|0)==1){break C}v[22440]=0;U(227,f+80|0,(B(g,104)+a|0)+484380|0,d|0);h=v[22440];v[22440]=0;if((h|0)==1){break C}Ie(f+48|0,2,k);v[22440]=0;W(225,f+8|0,v[f+48>>2],v[f+52>>2],w[f+56|0]);h=v[22440];v[22440]=0;if((h|0)==1){break v}}h=f+8|0;uc(((g<<5)+a|0)+946304|0,h);rb(h);y=Ib(v[i>>2],g-1|0),z=w[f+126|0]|w[f+127|0]<<8|(w[f+128|0]<<16|w[f+129|0]<<24),v[y>>2]=z;e=e+1|0;continue}break}d=P()|0;O()|0;break l}d=P()|0;O()|0;break l}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}if(!(c&1)){break k}c=w[f+213|0];v[22440]=0;h=a+484344|0;R(228,h|0,c|0);c=v[22440];v[22440]=0;G:{if((c|0)!=1){c=a+480188|0;a=0;while(1){H:{if(w[f+213|0]<=a>>>0){break k}d=64;e=v[o>>2];if(Fc(e,v[o+4>>2])>>>0>a>>>0){d=x[Xb(e,a)>>1]}v[22440]=0;d=Y(229,h|0,a&65535,d&65535)|0;e=v[22440];v[22440]=0;if((e|0)==1){break G}I:{if(d){d=x[c>>1];e=w[l|0];v[22440]=0;Q(157,b|0,B(((e>>>0>13)<<1)+(d<<1)|0,a)+r|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break G}e=Rb(f+80|0);d=x[c>>1];v[22440]=0;j=Y(220,b|0,e|0,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break I}d=0;J:{if(!j){break J}while(1){if(x[c>>1]<=d>>>0){break J}K:{j=Xb(v[f+80>>2],d);j=w[j|0]|w[j+1|0]<<8;if(!j|j>>>0>(w[f+214|0]|w[f+215|0]<<8)>>>0){break K}j=Xb(v[g>>2],j-1|0);j=(w[j|0]|w[j+1|0]<<8)-1&65535;if(j>>>0>=k>>>0){break K}p=Sb(h,a);q=v[m>>2];v[22440]=0;U(230,p|0,d&65535,Ng(q,j)|0);j=v[22440];v[22440]=0;if((j|0)!=1){break K}break H}d=d+1|0;continue}}_c(e)}a=a+1|0;continue}}break}d=P()|0;O()|0;_c(e);break n}d=P()|0;O()|0;break n}d=P()|0;O()|0}Ic(m)}_c(g)}fc(i);break b}Ic(m)}_c(g);fc(i);_c(o)}cb=f+224|0;return n|0}d=P()|0;O()|0}_c(o)}S(d|0);L()}function tfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0;d=cb-304|0;cb=d;sc(b);a:{b:{c:{d:{if(!xt(b,d+208|0)){break d}if(!LQ(d+208|0)){break d}if(!Kb(b,wc(KQ(d+208|0),fb))){break d}if(!c){s=1;break d}if(!Tc(b,w[d+208|4])){break d}ud(a,268435456);eg(a);v[a+480208>>2]=4;Gb(a+1074312|0,114,1);e=d+88|0;j=jc(e,15350);Cb(a+1298344|0,j);rb(j);j=jc(e,10301);Cb(a+1298356|0,j);rb(j);v[a+1298404>>2]=5;pf(d+16|0,d+208|6,48,3);xc(e,v[d+16>>2],v[d+20>>2],w[d+24|0]);tc(a+1298308|0,e);rb(e);A=d+262|0;u[a+480188>>1]=w[A|0]+1;v[a+480228>>2]=w[d+265|0];v[a+480204>>2]=B(w[d+266|0],1e4);v[a+480196>>2]=w[d+267|0];while(1){if(w[A|0]<=g>>>0){e:{n=d+300|0;u[a+480190>>1]=w[n|0];j=d+302|0;g=w[j|0]|w[j+1|0]<<8;e=d+192|0;h=yd(e);f:{g:{if(g){v[22440]=0;R(653,e|0,g|0);f=v[22440];v[22440]=0;if((f|0)==1){break g}nA(e,g)}break f}a=P()|0;O()|0;fc(h);S(a|0);L()}g=w[j|0]|w[j+1|0]<<8;v[22440]=0;j=e;U(648,b|0,e|0,g|0);e=v[22440];v[22440]=0;if((e|0)==1){break b}C=Rb(d+176|0);y=Rb(d+160|0);H=d+301|0;e=w[H|0];v[22440]=0;Y(421,b|0,C|0,e|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}e=w[n|0];v[22440]=0;Y(421,b|0,y|0,e|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}D=c&2;e=d+88|0;z=e|4;o=d+140|0;l=d+155|0;p=d+151|0;h=d+147|0;r=d+141|0;q=d+139|0;s=d+138|0;F=d+126|0;G=e|6;e=0;h:{while(1){g=e;if(e>>>0>=w[n|0]){s=1;if(!(c&1)){break e}v[d+68>>2]=0;i=a+484360|0;Ac(Nb(i));K=d,M=yb(v[j>>2]),v[K+64>>2]=M;l=a+484344|0;c=d+88|0;D=c|5;p=c|4;F=yb(v[j+4>>2]);break h}v[22440]=0;e=g+1|0;i=B(e,104)+a|0;m=i+484380|0;R(284,m|0,0);f=v[22440];v[22440]=0;i:{if((f|0)!=1){f=Ib(v[y>>2],g);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);if(!f){continue}v[22440]=0;f=Q(157,b|0,f|0)|0;k=v[22440];v[22440]=0;j:{if((k|0)==1){break j}if(!f){continue}v[22440]=0;f=Q(649,b|0,d+88|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break j}if(!f){continue}Ie(d+72|0,2,G);v[22440]=0;W(225,d+16|0,v[d+72>>2],v[d+76>>2],w[d+80|0]);f=v[22440];v[22440]=0;if((f|0)==1){break c}f=d+16|0;uc(((e<<5)+a|0)+946304|0,f);rb(f);sk(d+72|0,2,F);v[22440]=0;W(225,f|0,v[d+72>>2],v[d+76>>2],w[d+80|0]);f=v[22440];v[22440]=0;if((f|0)==1){break c}f=d+16|0;pe(i+484423|0,f);rb(f);if(w[s|0]<=15){f=i+484414|0;u[f>>1]=x[f>>1]|32;u[i+484408>>1]=B(w[s|0],17)}t[d+16|0]=w[q|0];t[d+72|0]=64;K=i+484412|0,M=w[Tb(d+16|0,d+72|0)|0],u[K>>1]=M;v[i+484404>>2]=w[r|0]|w[r+1|0]<<8;E=i+484384|0;k=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);v[E>>2]=k;I=i+484388|0;f=w[p|0]|w[p+1|0]<<8|(w[p+2|0]<<16|w[p+3|0]<<24);v[I>>2]=f;J=w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24);v[m>>2]=J;if(t[o|0]&1){k=k>>>1|0;v[E>>2]=k;f=f>>>1|0;v[I>>2]=f;v[m>>2]=J>>>1}k:{if(f>>>0<=k>>>0){break k}f=i+484414|0;i=x[f>>1];u[f>>1]=i|2;if(!(w[o|0]&2)){break k}u[f>>1]=i|6}yk(m);if(!D){continue}g=Ib(v[y>>2],g);g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);f=w[z|0];v[22440]=0;Q(157,b|0,g+f|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){break i}}break c}break c}g=Nc(d+16|0,t[o|0]&1?16:8,1,0,1);v[22440]=0;Y(222,g|0,m|0,b|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){continue}break}break c}while(1){l:{m:{c=v[d+64>>2];if(!Qb(c,F)){a=v[d+68>>2];b=a&63;if(!b){break m}c=Nb(i);v[22440]=0;a=a>>>6|0;c=Q(318,c|0,a&65535)|0;e=v[22440];v[22440]=0;if((e|0)!=1){if(!c){break m}a=Sb(l,x[Xb(v[Nb(i)>>2],a&65535)>>1]);v[22440]=0;R(650,a|0,b|0);a=v[22440];v[22440]=0;if((a|0)!=1){break m}}break c}e=w[c+3|0];if(e>>>0>=w[H|0]){break l}z=c+2|0;if(w[z|0]>w[A|0]){break l}e=Ib(v[C>>2],e);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[22440]=0;e=Q(157,b|0,e|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break c}if(!e){break l}v[22440]=0;R(651,b|0,d+88|0);e=v[22440];v[22440]=0;if((e|0)==1){break c}if(!w[p|0]){break l}c=w[c|0]|w[c+1|0]<<8;t[d+16|0]=w[D|0];t[d+72|0]=w[A|0]-w[z|0];m=w[Tb(d+16|0,d+72|0)|0];v[d+60>>2]=c+w[p|0];K=d,M=v[Pc(d+68|0,d+60|0)>>2],v[K+68>>2]=M;v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;g=c&63;o=c>>>6|0;k=0;while(1){if(w[p|0]<=k>>>0){break l}c=Nb(i);e=Fc(v[c>>2],v[c+4>>2]);h=g>>>0>63;o=h+o|0;c=o&65535;if(e>>>0<=c>>>0){e=Nb(i);v[22440]=0;R(333,e|0,o+1&65535);e=v[22440];v[22440]=0;if((e|0)==1){break c}v[22440]=0;e=Y(370,l|0,64,0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break c}K=Xb(v[Nb(i)>>2],c),M=e,u[K>>1]=M}n=x[Xb(v[Nb(i)>>2],c)>>1];if(!ve(l,n)){break l}e=0;r=h?0:g;g=Zc(Sb(l,n),r,w[z|0]);n:{while(1){if((e|0)==(m|0)){c=w[D|0];if(c>>>0<=m>>>0){break n}v[22440]=0;Q(190,b|0,B(c-m|0,5)|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break n}break c}v[22440]=0;R(652,d+72|0,b|0);c=v[22440];v[22440]=0;if((c|0)!=1){c=d+72|0;h=Ec(c);G=Oe(c);q=Li(c);E=bc(c);f=0;c=w[c|0];if((c-1&255)>>>0<=142){f=(B((c&240)>>>4|0,12)+(c&15)|0)+13|0;t[(d+16|0)+e|0]=f}t[g|0]=f;c=w[h|0];t[g+2|0]=1;t[g+1|0]=c;c=w[G|0];o:{if((c|0)!=255){t[g+4|0]=c;break o}t[g+2|0]=0}c=w[q|0];p:{if(c>>>0>22){break p}t[g+3|0]=w[c+27104|0];h=w[E|0];t[g+5|0]=h;c=g+5|0;q:{switch(w[q|0]-4|0){case 3:t[c|0]=h&3|64;break p;case 4:t[c|0]=h&3|48;break p;case 7:f=v[j>>2];if(pc(f,v[j+4>>2])>>>0<=h>>>0){break p}q=c;c=Ib(f,h);c=w[c|0]|w[c+1|0]<<8;t[q|0]=c>>>6;h=Zc(Sb(l,n),r,x[a+480188>>1]-1&65535);t[h+5|0]=c&63;t[h+3|0]=14;break p;case 8:q=c;c=v[d+60>>2];t[q|0]=c>>>6;h=Zc(Sb(l,n),r,x[a+480188>>1]-1&65535);t[h+5|0]=c&63;t[h+3|0]=14;break p;case 10:t[c|0]=h&15|128;break p;case 12:t[d+15|0]=15;K=c,M=w[Tb(c,d+15|0)|0]|208,t[K|0]=M;break p;case 13:t[d+15|0]=15;K=c,M=w[Tb(c,d+15|0)|0]|192,t[K|0]=M;break p;case 14:t[d+15|0]=15;K=c,M=w[Tb(c,d+15|0)|0]|224,t[K|0]=M;break p;case 0:case 16:case 17:if(!(h&15)){break p}f=h&240;if(!f|(f|0)==240){break p}t[c|0]=h|15;break p;case 9:case 18:break q;default:break p}}if(f&255){break p}t[g|0]=w[(d+16|0)+e|0]}g=g+6|0;e=e+1|0;continue}break}break c}g=r+1|0;k=k+1|0;continue}}a=Nb(i);K=d,M=yb(v[a>>2]),v[K+88>>2]=M;b=yb(v[a+4>>2]);f=65535;while(1){a=v[d+88>>2];if(!Qb(a,b)){break e}if(x[a>>1]==65535){r:{if((f&65535)!=65535){break r}v[22440]=0;f=Y(370,l|0,64,0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break r}break c}u[a>>1]=f}Ne(d+88|0);continue}}Ge(d- -64|0);continue}}}else{u[((g<<5)+a|0)+480284>>1]=B(w[(d+g|0)+268|0],17);g=g+1|0;continue}break}fc(y);fc(C);fc(j)}cb=d+304|0;return s|0}g=P()|0;O()|0;fc(y);fc(C);break a}g=P()|0;O()|0}fc(j);S(g|0);L()}function Ap(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;g=cb-16|0;cb=g;h=x[a+480192>>1]>=c>>>0?v[((c<<2)+a|0)+900380>>2]:h;s=v[b+752>>2];k=w[b+802|0];a:{if(!k){ub(g+8|0,a+1074312|0,11);if(tb(v[v[g+8>>2]>>2],v[g+12>>2])){break a}}b:{c:{if(!h){break c}if(!Rc(k)){break c}d:{l=k-1|0;k=Xb(h+236|0,l);if(x[k>>1]){break d}ub(g+8|0,a+1074312|0,43);if(!tb(v[v[g+8>>2]>>2],v[g+12>>2])){break d}if(sj(w[h+31|0])){break d}v[b+656>>2]=h;break a}if(w[Eb(h+108|0,l)|0]>120){break a}k=x[k>>1];l=(k-1&65535)>>>0<3999?(B(k,104)+a|0)+484380|0:0;break b}l=(B(c,104)+a|0)+484380|0;if(!x[a+480192>>1]){break b}if(k>>>0>250){break a}ub(g+8|0,a+1074312|0,43);if(tb(v[v[g+8>>2]>>2],v[g+12>>2])){if(h){l=0;if(sj(w[h+31|0])){break b}}t[b+803|0]=0;v[b+656>>2]=0;break a}l=0}k=v[b+104>>2];n=(k|0)!=0&(k|0)!=(l|0);j=v[b+656>>2];o=!h|v[a+480180>>2]!=16777216?o:v[h+44>>2]!=0;p=d^1;i=(h|0)!=(j|0);if((p|i|n)==1){u[b+774>>1]=0}r=!n;if(!(r|(i|!(d&o)))){break a}e:{if(!(d&n)){break e}k=a+1074312|0;ub(g+8|0,k,32);if(!(!tb(v[v[g+8>>2]>>2],v[g+12>>2])|!(w[a+480208|0]&8))){l=v[b+8>>2]|v[b+12>>2]?v[b+104>>2]:l}m=v[a+480180>>2];f:{if(!(h?i|!(m&1048580):1)|(m|0)==268435456){break f}if((m|0)==1){if(zi(v[b+8>>2],v[b+12>>2])){break f}}ub(g+8|0,k,79);if(!tb(v[v[g+8>>2]>>2],v[g+12>>2])){break e}if(!zi(v[b+8>>2],v[b+12>>2])){break e}}q=1}g:{if(!v[b+16>>2]|(!n|(i|!x[a+480192>>1]))){break g}ub(g+8|0,a+1074312|0,87);if(!tb(v[v[g+8>>2]>>2],v[g+12>>2])){break g}q=Rc(w[b+788|0])^1|q}h:{i:{j:{k:{l:{if(zi(v[b+8>>2],v[b+12>>2])|!(v[a+480180>>2]&16777248)){break l}if(h){if(sj(w[h+31|0])){break l}}k=1;break k}if(!(i|n)){break j}k=(h|0)!=(j|0)}if(!d){break i}ub(g+8|0,a+1074312|0,61);if(!tb(v[v[g+8>>2]>>2],v[g+12>>2])){break i}j=v[b+656>>2];if(!j){j=0;m=0;i=v[b+104>>2];if(!i){break i}break h}i=v[b+104>>2];m=0;break h}k=0}v[b+656>>2]=h;j=h;m=k;i=l}m:{if(!e){break m}n:{o:{p:{if(w[a+480180|0]&3){if(i){if(Sd(i)){break p}}if(!dk(j)){break m}}if(!i){break o}}if(u[i+34>>1]<0){break m}h=x[i+30>>1];break n}h=0;if(!j|!w[j+34|0]){break n}h=v[b+656>>2];q:{if(h){h=v[h+4>>2]<<2;break q}h=v[b+688>>2]}}v[b+688>>2]=h}if(q){if(!((i|0)!=0&n)){break a}ub(g+8|0,a+1074312|0,85);if(tb(v[v[g+8>>2]>>2],v[g+12>>2])){u[b+772>>1]=t[i+37|0]}if(v[a+480180>>2]!=2){break a}if(!Sd(i)){break a}v[b+704>>2]=v[i+24>>2];break a}t[b+803|0]=0;r:{if(!j){break r}ub(g+8|0,a+1074312|0,29);if(z=0,A=(D=tb(v[v[g+8>>2]>>2],v[g+12>>2]),E=1,F=i,F?D:E),C=w[j+34|0]|m,C?z:A){break r}t[b+798|0]=w[j+16|0]}h=64;v[b+752>>2]=64;if(i){h=x[i+32>>1];v[b+752>>2]=h}if(j){v[b+752>>2]=B(v[j+4>>2],h)>>>6}s:{if(!(v[a+480180>>2]&1048580?e:1)){break s}ub(g+8|0,a+1074312|0,48);if(tb(v[v[g+8>>2]>>2],v[g+12>>2])){break s}FM(a,b,j,i)}t:{u:{v:{if(!f){break v}e=a+1074312|0;ub(g+8|0,e,19);w:{x:{y:{z:{A:{B:{C:{D:{if(tb(v[v[g+8>>2]>>2],v[g+12>>2])){if(!v[b+76>>2]){h=1;break C}if(!(!c|p)){h=(w[a+480208|0]&8)>>>3|0;if(h){break C}break D}h=0;if(c){break D}break C}c=v[a+480180>>2]&17301536;E:{if(!(!d|!c)){h=1;if(!v[b+76>>2]|w[a+480208|0]&8){break E}if(!(w[b+89|0]&16)){break z}h=!v[b+696>>2];break E}h=1;if(!c){break y}}if(!j|m){break A}if(!h){break z}h=v[b+88>>2];c=h&6144;break B}if(d){break C}if(!(w[b+89|0]&24)){h=0;break C}h=(w[a+480208|0]&4)>>>2|0}if(!v[b+696>>2]|m){break A}if(!h){break z}h=v[b+88>>2];c=h&2048}v[b+88>>2]=h|2097152;if(!j){break w}if(c){break x}if(!(w[j+60|0]&8)){mj(b+724|0)}if(!(w[j+80|0]&8)){mj(b+732|0)}if(w[j+100|0]&8){break w}mj(b+740|0);break w}if(h){break y}}if(j){if(t[j+60|0]&1){break v}ub(g+8|0,e,32);if(tb(v[v[g+8>>2]>>2],v[g+12>>2])){mj(b+724|0);break v}hm(b);break v}h=0;if(!i){break u}break t}v[b+88>>2]=v[b+88>>2]|2097152;if(!j){break w}}hm(b)}ub(g+8|0,e,21);if(tb(v[v[g+8>>2]>>2],v[g+12>>2])){break v}t[b+818|0]=0;v[b+756>>2]=0}h=0;if(i){break t}if(!j){break u}h=1;if(sj(w[j+31|0])){break t}}v[b+752>>2]=0;v[b+104>>2]=0;break a}F:{G:{H:{I:{J:{if(!(!d|!i|v[b+104>>2]!=(i|0))){c=v[a+480180>>2];if(v[b+76>>2]?c&16777250:0){break a}if((c|0)!=4){break J}ub(g+8|0,a+1074312|0,40);if(!tb(v[v[g+8>>2]>>2],v[g+12>>2])|w[b+789|0]){break J}c=v[b+88>>2];break I}v[b+88>>2]=v[b+88>>2]&-6145;c=a+1074312|0;ub(g+8|0,c,18);K:{if(z=tb(v[v[g+8>>2]>>2],v[g+12>>2]),A=1,C=v[a+480180>>2]&16777248,C?z:A){e=-640;if(!(v[b+104>>2]!=(i|0)|m)){break K}}e=-768}v[b+88>>2]=e&v[b+88>>2];L:{if(!j){break L}t[b+730|0]=w[j+60|0];t[b+738|0]=w[j+80|0];t[b+746|0]=w[j+100|0];M:{if((w[j+100|0]&17)!=17){break M}ub(g+8|0,c,36);if(tb(v[v[g+8>>2]>>2],v[g+12>>2])|w[b+837|0]){break M}t[b+837|0]=127}c=w[j+21|0];if(Eq(c)){z=b,A=Fq(c),t[z+837|0]=A}c=w[j+22|0];if(!Eq(c)){break L}z=b,A=Fq(c),t[z+838|0]=A}if(h){break H}if(!d){break F}break G}c=v[b+88>>2]&-6145}v[b+88>>2]=c&-640;if(!h){break G}}v[b+76>>2]=0;v[b+104>>2]=0;break a}if(v[b+76>>2]){break F}c=a+1074312|0;ub(g+8|0,c,54);if(!tb(v[v[g+8>>2]>>2],v[g+12>>2])){ub(g,c,39);if(!tb(v[v[g>>2]>>2],v[g+4>>2])){break F}}v[b+8>>2]=0;v[b+12>>2]=0}N:{if(w[b+788|0]!=255){break N}ub(g+8|0,a+1074312|0,100);if(!tb(v[v[g+8>>2]>>2],v[g+12>>2])|(!(v[a+480208>>2]&4)|r)){break N}c=v[b+104>>2];if(c){v[b+88>>2]=v[b+88>>2]|x[c+34>>1]&1023}v[b+752>>2]=s;v[b+688>>2]=x[i+30>>1];if(!(w[i+34|0]&32)){break a}Mp(b,x[i+28>>1],a);break a}v[b+104>>2]=i;v[b+76>>2]=v[i>>2];v[b+80>>2]=v[i+4>>2];v[b+84>>2]=v[i+8>>2];e=a+1074312|0;ub(g+8|0,e,83);if(!(!tb(v[v[g+8>>2]>>2],v[g+12>>2])|v[b+80>>2])){v[b+84>>2]=v[i>>2]}v[b+88>>2]=v[b+88>>2]|x[i+34>>1]&1023;ub(g+8|0,e,21);if(tb(v[v[g+8>>2]>>2],v[g+12>>2])){t[b+818|0]=0;v[b+756>>2]=0}O:{P:{if(o){v[b+704>>2]=v[i+24>>2];t[b+851|0]=w[b+851|0]|64;c=0;break P}if(!(n|p)){d=v[a+480180>>2];if(d&5){break O}}v[b+704>>2]=v[i+24>>2];c=t[i+37|0]}u[b+772>>1]=c;d=v[a+480180>>2]}if(vm(d)){c=t[i+36|0]}else{c=0}u[b+770>>1]=c;ub(g+8|0,e,69);if(!(tb(v[v[g+8>>2]>>2],v[g+12>>2])|v[a+480180>>2]==1)){v[b+708>>2]=0}v[b+852>>2]=0;h=v[b+88>>2];if(h&8){v[b+80>>2]=v[i+12>>2];v[b+84>>2]=v[i+16>>2];h=h>>>2&4|h|2;v[b+88>>2]=h}Q:{if(!(h&2)){h=v[b+76>>2];break Q}h=v[b+76>>2];c=v[b+84>>2];if(h>>>0<=c>>>0){break Q}v[b+76>>2]=c;h=c}if(!(v[a+480180>>2]&16777248)|y[b+4>>2]<h>>>0){break a}v[b>>2]=0;v[b+4>>2]=0}cb=g+16|0}function saa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=cb+-64|0;cb=j;v[22440]=0;g=T(180,b|0)|0;f=v[22440];v[22440]=0;a:{b:{c:{d:{if((f|0)==1){break d}e:{f:{if(g){g=0;e=Rb(j+48|0);g:{h:{i:{if(c&16){break i}v[22440]=0;h=(c|0)!=0;i=Y(846,e|0,b|0,h|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break e}f=4;j:{if(i){break j}v[22440]=0;i=Y(847,e|0,b|0,h|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break e}f=5;if(i){break j}v[22440]=0;i=Y(848,e|0,b|0,h|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break e}f=6;if(i){break j}d=0;v[22440]=0;i=Y(849,e|0,b|0,h|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break e}f=3;if(!i){break i}}if(!c){f=1;break h}d=v[e>>2];if(!hc(d,v[e+4>>2])){ev(b,d+12|0)}d=f}f=0;if(c&32){break h}g=31664;k:{while(1){f=g;if((g|0)!=32204){i=v[f+8>>2];h=(i>>1)+a|0;g=v[f+4>>2];g=i&1?v[v[h>>2]+g>>2]:g;v[22440]=0;i=Y(g|0,h|0,b|0,c|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break c}g=f+12|0;if(!i){continue}break k}break}v[a+480180>>2]=0;v[a+480184>>2]=0}if(!c){f=(f|0)!=32204;g=0;break h}if(!(v[a+480184>>2]|!d)){v[a+480184>>2]=d}v[22440]=0;g=1;R(789,a+1298264|0,1);d=v[22440];v[22440]=0;f=1;if((d|0)==1){break g}}EL(e);if(g){break f}break a}break c}v[22440]=0;R(252,a|0,0);d=v[22440];v[22440]=0;if((d|0)==1){break d}v[22440]=0;R(789,a+1298264|0,1);d=v[22440];v[22440]=0;if((d|0)==1){break d}v[a+1074304>>2]=19988487}f=0;while(1){if((f|0)==127){i=a+1298300|0;g=1;while(1){d=g&65535;if(d>>>0>x[a+480190>>1]){d=0;i=a+480180|0;f=0;l:{while(1){g=f&65535;if(g>>>0>x[a+480192>>1]){m:{u[a+480192>>1]=d;d=a+480204|0;if(y[a+480204>>2]>=1e4){break m}v[d>>2]=125e4;break l}}else{e=v[((g<<2)+a|0)+900380>>2];if(e){g=v[i>>2];qc(e,65536);qc(e+4|0,64);qc(e+8|0,256);Kf(e+28|0,16384);yf(e+30|0,128);yf(e+31|0,17);if(w[e+16|0]>=4){t[e+16|0]=0}if(w[e+17|0]>=5){t[e+17|0]=0}if(w[e+18|0]>=3){t[e+18|0]=0}yf(e+19|0,64);yf(e+20|0,100);h=224;d=t[e+26|0];n:{if((d|0)>=-32){h=32;if((d|0)<33){break n}}t[e+26|0]=h}yf(e+23|0,64);yf(e+24|0,64);mz(e+48|0,64);mz(e+68|0,64);mz(e+88|0,(g|0)==4096?255:64);g=e+108|0;h=0;while(1){o:{if((h|0)==128){if(!qo(w[e+14|0])){t[e+14|0]=5}if(w[e+34|0]>=251){t[e+34|0]=0}break o}d=Eb(g,h);if((w[d|0]-121&255)>>>0<=135){t[d|0]=h+1}h=h+1|0;continue}break}d=f}f=f+1|0;continue}break}qc(d,65535e4)}if(!v[a+480196>>2]){v[a+480196>>2]=6}i=a+480216|0;g=v[a+480216>>2];p:{if(!g){if(w[a+480224|0]!=2){d=a+480220|0;break p}v[i>>2]=1;g=1}d=a+480220|0;if(y[a+480220>>2]>=g>>>0){break p}v[d>>2]=g}qc(i,65536);qc(d,65536);qc(a+480200|0,256);q:{f=a+480248|0;if(!hc(v[f>>2],v[a+480252>>2])){d=v[i>>2];v[22440]=0;R(850,f|0,d|0);d=v[22440];v[22440]=0;if((d|0)==1){break q}}v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];d=v[a+480220>>2];f=a+1074408|0;v[f>>2]=v[a+480216>>2];v[f+4>>2]=d;v[a+1074456>>2]=v[a+480200>>2];Hy(a+1074376|0);d=a+1074446|0;u[d>>1]=0;u[d+2>>1]=0;u[d+4>>1]=0;u[d+6>>1]=65535;v[a+1074392>>2]=-2;d=a+1074384|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074380>>2]=0;d=a+1074424|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074432>>2]=0;d=a+1074396|0;v[d>>2]=0;v[d+4>>2]=0;if(vm(v[a+480180>>2])){v[22440]=0;Q(272,a+1074312|0,7)|0;d=v[22440];v[22440]=0;if((d|0)==1){break q}}u[a+480276>>1]=0;rp(a);d=a+484360|0;n=j,o=Pg(d),v[n+48>>2]=o;f=Og(d);while(1){g=v[j+48>>2];if(!Qb(g,f)){r:{s:{i=v[a+480180>>2];if(i){As(a+8|0,fq(a));if(v[a+1074308>>2]){v[22440]=0;Z(851,a|0);d=v[22440];v[22440]=0;if((d|0)==1){break q}}l=Rb(j+48|0);t:{if((c&12)!=12){break t}g=a+1298464|0;f=0;u:{v:{w:{x:{y:{z:{while(1){if((f|0)==250){break t}e=B(f,160)+a|0;k=e+906300|0;d=k+16|0;A:{c=k+20|0;B:{if(!(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)|(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)))){break B}v[22440]=0;R(852,k|0,a|0);c=v[22440];v[22440]=0;C:{if((c|0)!=1){h=v[k>>2];if(!h){break C}d=v[e+906448>>2];c=v[v[h>>2]+56>>2];v[22440]=0;R(c|0,h|0,d|0);c=v[22440];v[22440]=0;if((c|0)!=1){break B}}a=P()|0;O()|0;break r}m=yb(v[l>>2]);c=yb(v[l+4>>2]);h=cb-16|0;cb=h;v[h+8>>2]=m;while(1){D:{if(!Qb(m,c)){break D}d=v[m>>2];if((w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))==(w[k+20|0]|w[k+21|0]<<8|(w[k+22|0]<<16|w[k+23|0]<<24))){d=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==(w[k+16|0]|w[k+17|0]<<8|(w[k+18|0]<<16|w[k+19|0]<<24))}else{d=0}if(d){break D}Ge(h+8|0);m=v[h+8>>2];continue}break}cb=h+16|0;if(Qb(m,yb(v[l+4>>2]))){break B}v[22440]=0;v[j+32>>2]=e+906316;R(853,l|0,j+32|0);c=v[22440];v[22440]=0;if((c|0)==1){break A}v[22440]=0;d=Q(1,j+16|0,17732)|0;c=v[22440];v[22440]=0;if((c|0)==1){break z}v[22440]=0;R(854,j|0,k|0);c=v[22440];v[22440]=0;if((c|0)==1){break y}v[22440]=0;U(2,j+32|0,d|0,j|0);c=v[22440];v[22440]=0;if((c|0)==1){break x}c=v[g>>2];v[22440]=0;U(388,c|0,2,j+32|0);c=v[22440];v[22440]=0;if((c|0)==1){break w}rb(j+32|0);rb(j);rb(d)}f=f+1|0;continue}break}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;break u}a=P()|0;O()|0;break v}a=P()|0;O()|0;rb(j+32|0)}rb(j)}rb(d);break r}c=w[a+1074368|0];v[22440]=0;R(855,a|0,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break s}fc(l)}f=(i|0)!=0;break a}a=P()|0;O()|0}fc(l);break b}v[22440]=0;Z(856,g|0);d=v[22440];v[22440]=0;if((d|0)!=1){if(Fc(v[g>>2],v[g+4>>2])>>>0<=x[g+28>>1]){Qe(g,0)}iz(j+48|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}h=B(d,104)+a|0;e=h+484380|0;E:{if(Sd(e)){Ai(e,a);break E}f=h+484414|0;d=x[f>>1];if(d&16384){break E}v[e>>2]=0;v[e+4>>2]=0;v[e+16>>2]=0;v[e+8>>2]=0;v[e+12>>2]=0;u[f>>1]=d&65505}d=h+484412|0;if(x[d>>1]>=65){u[d>>1]=64}F:{G:{if(!(w[h+484415|0]&2)){break G}if(!gk(i)){break G}v[22440]=0;Z(857,a|0);d=v[22440];v[22440]=0;if((d|0)==1){break F}}g=g+1|0;continue}break}a=P()|0;O()|0;break b}g=(f<<5)+a|0;Kf(g+480286|0,64);d=g+480284|0;if(x[d>>1]>=257){u[d>>1]=128}d=g+480288|0;if(w[d|0]>=251){t[d|0]=0}Ln((B(f,872)+a|0)+1074992|0,a,f&65535,134217728);f=f+1|0;continue}}break c}a=P()|0;O()|0;break b}a=P()|0;O()|0;EL(e)}sb(b);S(a|0);L()}sb(b);cb=j- -64|0;return f|0}function bfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=cb-272|0;cb=d;sc(b);f=cb-16|0;cb=f;j=d+120|0;wQ(f+8|0,j);g=v[f+12>>2];Yb(f,b,v[f+8>>2],g);h=v[f+4>>2];if((h|0)==(g|0)){Ob(b,v[f+12>>2])}cb=f+16|0;f=(g|0)==(h|0);if(!f){vQ(j)}a:{b:{c:{d:{if(!f){break d}if(!xQ(d+120|0)){break d}if(!c){l=1;break d}ud(a,4194304);f=d+32|0;g=jc(f,17069);Cb(a+1298344|0,g);rb(g);g=jc(f,10156);Cb(a+1298356|0,g);rb(g);v[a+1298404>>2]=5;n=a,o=wd(w[d+198|0]|w[d+199|0]<<8,w[d+200|0]|w[d+201|0]<<8,127),u[n+480188>>1]=o;g=w[d+189|0];v[a+480228>>2]=(g|0)==255?48:g;v[a+480196>>2]=w[d+187|0];v[a+480204>>2]=B(w[d+188|0],1e4);pf(d+96|0,d+120|4,59,3);xc(f,v[d+96>>2],v[d+100>>2],w[d+104|0]);tc(a+1298308|0,f);rb(f);f=w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24);e:{if(f>>>0<5){break e}if(!Tc(b,f-4|0)){break e}if(!Ah(b,14341)){break e}Zn(Nb(a+484360|0),b,w[d+192|0]|w[d+193|0]<<8,65535,65535)}f:{f=w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24);if(f>>>0<5){break f}if(!Tc(b,f-4|0)){break f}if(!Ah(b,13870)){break f}while(1){if((e|0)==32){break f}f=(e<<5)+a|0;$e(f+480280|0);n=f+480284|0,o=((((He(b)^-1)&15)<<8|8)>>>0)/15|0,u[n>>1]=o;e=e+1|0;continue}}e=w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24);g:{if(e>>>0<5){break g}if(!Tc(b,e-4|0)){break g}if(!Ah(b,14198)){break g}e=d+32|0;Td(e,b,(w[d+196|0]|w[d+197|0]<<8)<<6);k=c&2;j=a+480190|0;g=cc(d+96|0,e);sb(e);l=d+45|0;e=0;h:{while(1){if((e&65535)>>>0>=(w[d+196|0]|w[d+197|0]<<8)>>>0){break h}v[22440]=0;f=Q(679,g|0,d+32|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break b}if(!f){break h}f=w[d+77|0]|w[d+78|0]<<8;u[d+30>>1]=f;i:{j:{if((f-1&65535)>>>0>3998){break j}f=(B(f,104)+a|0)+484380|0;if(Sd(f)){break j}n=j,o=x[ie(j,d+30|0)>>1],u[n>>1]=o;v[22440]=0;R(680,d+32|0,f|0);f=v[22440];v[22440]=0;if((f|0)==1){break i}iT(d,1,l);v[22440]=0;W(225,d+16|0,v[d>>2],v[d+4>>2],w[d+8|0]);f=v[22440];v[22440]=0;if((f|0)==1){break b}f=d+16|0;uc(((x[d+30>>1]<<5)+a|0)+946304|0,f);rb(f);if(!k){break j}f=w[d+69|0]|w[d+70|0]<<8|(w[d+71|0]<<16|w[d+72|0]<<24);v[22440]=0;Q(157,b|0,f|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break i}f=1;i=d+16|0;h=d+79|0;m=Nc(i,w[h|0]&4?16:8,1,0,0);h=w[h|0];k:{l:{if(h&8){break l}f=2;if(h&16){break l}if(h&127){break k}}Hf(m,f)}v[22440]=0;Y(222,i|0,(B(x[d+30>>1],104)+a|0)+484380|0,b|0)|0;f=v[22440];v[22440]=0;if((f|0)!=1){break j}break b}e=e+1|0;continue}break}break b}sb(g)}l=1;if(!(c&1)){break d}m:{c=w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24);if(c>>>0<5){break m}if(!Tc(b,c-4|0)){break m}if(!Ah(b,13720)){break m}h=a+484344|0;wg(h,w[d+194|0]|w[d+195|0]<<8);k=d+16|2;f=0;while(1){if((w[d+194|0]|w[d+195|0]<<8)>>>0<=f>>>0){break m}if(!fA(b,d+16|0)){break m}n:{e=w[d+16|0]|w[d+17|0]<<8;if(e>>>0>3){c=d+96|0;Td(c,b,(e+15&131056)-4|0);g=cc(d+32|0,c);sb(c);c=w[k|0];v[22440]=0;c=Y(229,h|0,f&65535,c|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break n}j=0;o:{if(!c){break o}while(1){p:{v[22440]=0;c=Q(158,d+32|0,1)|0;e=v[22440];v[22440]=0;q:{if((e|0)!=1){e=w[k|0];if(!(c&e>>>0>(j&255)>>>0)){break p}v[22440]=0;e=T(208,g|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}if(e){break q}j=j+1|0;continue}break c}c=Sb(h,f);u[d+96>>1]=e&31;u[d>>1]=x[a+480188>>1]-1;c=Zc(c,j,x[Kc(d+96|0,d)>>1]);if(e&128){v[22440]=0;R(267,d+96|0,g|0);i=v[22440];v[22440]=0;if((i|0)==1){break c}i=d+96|0;t[c|0]=w[i|0]+36;n=c,o=w[Ec(i)|0],t[n+1|0]=o}if(e&64){t[c+2|0]=1;v[22440]=0;i=T(208,g|0)|0;m=v[22440];v[22440]=0;if((m|0)==1){break c}t[d+96|0]=i;t[d|0]=64;n=c,o=w[Tb(d+96|0,d)|0],t[n+4|0]=o}if(!(e&32)){continue}v[22440]=0;R(267,d+96|0,g|0);e=v[22440];v[22440]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{if((e|0)!=1){e=w[Ec(d+96|0)|0];t[c+5|0]=e;switch(w[d+96|0]-1|0){case 71:break s;case 70:break t;case 69:break u;case 60:break v;case 59:break w;case 52:break x;case 51:break y;case 50:break z;case 49:break A;case 42:break B;case 41:break C;case 40:break D;case 39:break E;case 30:break F;case 29:break G;case 22:break H;case 21:break I;case 20:break J;case 19:break K;case 16:break L;case 15:break M;case 14:break N;case 13:break O;case 12:break P;case 11:break Q;case 10:break R;case 9:break S;case 3:break T;case 2:break U;case 1:break V;case 0:break W;default:break r}}break c}t[c+3|0]=11;t[c+5|0]=e<<4|15;continue}t[c+3|0]=11;t[c+5|0]=e<<4;continue}t[c+3|0]=11;t[c+5|0]=e|240;continue}t[c+3|0]=11;t[c+5|0]=e&15;continue}t[c+3|0]=2;t[c+5|0]=e|240;continue}t[c+3|0]=2;continue}t[c+3|0]=3;t[c+5|0]=e|240;continue}t[c+3|0]=3;continue}t[c+3|0]=4;continue}t[c+3|0]=20;t[c+5|0]=e|16;continue}t[c+3|0]=6;t[c+5|0]=e<<4;continue}t[c+3|0]=6;t[c+5|0]=e&15;continue}t[c+3|0]=5;continue}t[c+3|0]=20;t[c+5|0]=e|48;continue}t[c+3|0]=7;t[c+5|0]=e<<4;continue}t[c+3|0]=7;t[c+5|0]=e&15;continue}t[c+3|0]=8;continue}t[c+3|0]=20;t[c+5|0]=e|64;continue}t[c+3|0]=10;v[22440]=0;e=T(208,g|0)|0;i=v[22440];v[22440]=0;if((i|0)!=1){t[c+5|0]=e;v[22440]=0;Q(190,d+32|0,1)|0;c=v[22440];v[22440]=0;if((c|0)!=1){continue}}break c}t[c+3|0]=15;t[c+5|0]=e&15;continue}t[c+3|0]=20;t[c+5|0]=e|192;continue}t[c+3|0]=20;t[c+5|0]=e|208;continue}t[c+3|0]=12;continue}t[c+3|0]=14;continue}t[c+3|0]=20;t[c+5|0]=e|176;continue}t[c+3|0]=20;t[c+5|0]=e|224;continue}t[c+3|0]=16;continue}t[c+3|0]=17;continue}t[c+3|0]=1;continue}t[c+3|0]=20;t[c+5|0]=e&15|32;continue}t[c+3|0]=20;t[c+5|0]=e&15|128;continue}t[c+3|0]=0;continue}break}if((e|0)==64){break o}xe(Sb(h,f),yh(Pe(Je(d+96|0,14,0),w[k|0]-1|0)))}sb(d+32|0)}f=f+1|0;continue}break}break c}c=w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24);if(!c){break d}Tc(b,c);gB(a+1298332|0,b,Sg(b),4)}cb=d+272|0;return l|0}e=P()|0;O()|0;sb(d+32|0);break a}e=P()|0;O()|0;sb(g)}S(e|0);L()}function K0(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,C=0,E=0,F=0;m=cb-560|0;cb=m;v[m+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){x=1;A=5299;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){x=1;A=5302;break a}x=e&1;A=x?5305:5300;F=!x}b:{if((g&2146435072)==2146435072){d=x+3|0;Nf(a,32,c,d,e&-65537);tf(a,A,x);f=f&32;tf(a,b!=b?f?9997:13875:f?11106:14241,3);Nf(a,32,c,d,e^8192);i=(c|0)>(d|0)?c:d;break b}z=m+16|0;c:{d:{e:{b=QG(b,m+44|0);b=b+b;if(b!=0){g=v[m+44>>2];v[m+44>>2]=g-1;u=f|32;if((u|0)!=97){break e}break c}u=f|32;if((u|0)==97){break c}l=v[m+44>>2];n=(d|0)<0?6:d;break d}l=g-29|0;v[m+44>>2]=l;b=b*268435456;n=(d|0)<0?6:d}r=(l|0)<0?m+48|0:m+336|0;h=r;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}v[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;k=r;break f}k=r;d=l;while(1){d=d>>>0<29?d:29;g=h-4|0;g:{if(k>>>0>g>>>0){break g}i=0;while(1){q=v[g>>2];p=d&31;C=i;if((d&63)>>>0>=32){i=q<<p;q=0}else{i=(1<<p)-1&q>>>32-p;q=q<<p}p=C+q|0;i=i+E|0;i=p>>>0<q>>>0?i+1|0:i;i=nka(p,i,1e9,0);q=kka(i,fb,-1e9,-1)+p|0;v[g>>2]=q;g=g-4|0;if(k>>>0<=g>>>0){continue}break}if(!i){break g}k=k-4|0;v[k>>2]=i}while(1){g=h;if(k>>>0<g>>>0){h=g-4|0;if(!v[h>>2]){continue}}break}d=v[m+44>>2]-d|0;v[m+44>>2]=d;h=g;if((d|0)>0){continue}break}}h=(n+25>>>0)/9|0;if((d|0)<0){y=h+1|0;p=(u|0)==102;while(1){d=0-d|0;i=d>>>0<9?d:9;h:{if(g>>>0>k>>>0){q=1e9>>>i|0;E=-1<<i^-1;d=0;h=k;while(1){C=d;d=v[h>>2];v[h>>2]=C+(d>>>i|0);d=B(q,d&E);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=v[k>>2];if(!d){break h}v[g>>2]=d;g=g+4|0;break h}h=v[k>>2]}d=i+v[m+44>>2]|0;v[m+44>>2]=d;k=(!h<<2)+k|0;h=p?r:k;g=g-h>>2>(y|0)?h+(y<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=k>>>0){break i}d=B(r-k>>2,9);h=10;i=v[k>>2];if(i>>>0<10){break i}while(1){d=d+1|0;h=B(h,10);if(i>>>0>=h>>>0){continue}break}}h=(n-((u|0)==102?0:d)|0)-((u|0)==103&(n|0)!=0)|0;if((h|0)<(B(g-r>>2,9)-9|0)){i=h+9216|0;p=(i|0)/9|0;l=((((l|0)<0?4:292)+m|0)+(p<<2)|0)-4048|0;h=10;i=i+B(p,-9)|0;if((i|0)<=7){while(1){h=B(h,10);i=i+1|0;if((i|0)!=8){continue}break}}p=v[l>>2];y=(p>>>0)/(h>>>0)|0;i=B(y,h);p=p-i|0;q=l+4|0;j:{if(!p&(q|0)==(g|0)){break j}k:{if(!(y&1)){b=9007199254740992;if(!(t[l-4|0]&1)|((h|0)!=1e9|k>>>0>=l>>>0)){break k}}b=9007199254740994}s=(g|0)==(q|0)?1:1.5;q=h>>>1|0;s=p>>>0<q>>>0?.5:(q|0)==(p|0)?s:1.5;if(!(w[A|0]!=45|F)){s=-s;b=-b}v[l>>2]=i;if(b+s==b){break j}d=h+i|0;v[l>>2]=d;if(d>>>0>=1e9){while(1){v[l>>2]=0;l=l-4|0;if(l>>>0<k>>>0){k=k-4|0;v[k>>2]=0}d=v[l>>2]+1|0;v[l>>2]=d;if(d>>>0>999999999){continue}break}}d=B(r-k>>2,9);h=10;i=v[k>>2];if(i>>>0<10){break j}while(1){d=d+1|0;h=B(h,10);if(i>>>0>=h>>>0){continue}break}}h=l+4|0;g=g>>>0>h>>>0?h:g}while(1){h=g;i=g>>>0<=k>>>0;if(!i){g=h-4|0;if(!v[g>>2]){continue}}break}l:{if((u|0)!=103){l=e&8;break l}g=n?n:1;l=(g|0)>(d|0)&(d|0)>-5;n=(l?d^-1:-1)+g|0;f=(l?-1:-2)+f|0;l=e&8;if(l){break l}g=-9;m:{if(i){break m}p=v[h-4>>2];if(!p){break m}i=10;g=0;if((p>>>0)%10|0){break m}while(1){l=g;g=g+1|0;i=B(i,10);if(!((p>>>0)%(i>>>0)|0)){continue}break}g=l^-1}i=B(h-r>>2,9);if((f&-33)==70){l=0;g=(g+i|0)-9|0;g=(g|0)>0?g:0;n=(g|0)>(n|0)?n:g;break l}l=0;g=((d+i|0)+g|0)-9|0;g=(g|0)>0?g:0;n=(g|0)>(n|0)?n:g}i=-1;u=l|n;if(((u?2147483645:2147483646)|0)<(n|0)){break b}p=(((u|0)!=0)+n|0)+1|0;q=f&-33;n:{if((q|0)==70){if((2147483647-p|0)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=ln(g+d^g,0,z);if((z-g|0)<=1){while(1){g=g-1|0;t[g|0]=48;if((z-g|0)<2){continue}break}}y=g-2|0;t[y|0]=f;t[g-1|0]=(d|0)<0?45:43;g=z-y|0;if((g|0)>(2147483647-p|0)){break b}}d=g+p|0;if((d|0)>(x^2147483647)){break b}f=d+x|0;Nf(a,32,c,f,e);tf(a,A,x);Nf(a,48,c,f,e^65536);o:{p:{q:{if((q|0)==70){g=m+16|0;d=g|8;l=g|9;i=k>>>0>r>>>0?r:k;k=i;while(1){g=ln(v[k>>2],0,l);r:{if((i|0)!=(k|0)){if(m+16>>>0>=g>>>0){break r}while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(l|0)){break r}t[m+24|0]=48;g=d}tf(a,g,l-g|0);k=k+4|0;if(r>>>0>=k>>>0){continue}break}if(u){tf(a,16802,1)}if((n|0)<=0|h>>>0<=k>>>0){break q}while(1){g=ln(v[k>>2],0,l);if(g>>>0>m+16>>>0){while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}}tf(a,g,(n|0)<9?n:9);g=n-9|0;k=k+4|0;if(h>>>0<=k>>>0){break p}d=(n|0)>9;n=g;if(d){continue}break}break p}s:{if((n|0)<0){break s}i=h>>>0>k>>>0?h:k+4|0;d=m+16|0;r=d|9;d=d|8;h=k;while(1){g=ln(v[h>>2],0,r);if((r|0)==(g|0)){t[m+24|0]=48;g=d}t:{if((h|0)!=(k|0)){if(m+16>>>0>=g>>>0){break t}while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break t}tf(a,g,1);g=g+1|0;if(!(l|n)){break t}tf(a,16802,1)}C=g;g=r-g|0;tf(a,C,(g|0)<(n|0)?g:n);n=n-g|0;h=h+4|0;if(i>>>0<=h>>>0){break s}if((n|0)>=0){continue}break}}Nf(a,48,n+18|0,18,0);tf(a,y,z-y|0);break o}g=n}Nf(a,48,g+9|0,9,0)}Nf(a,32,c,f,e^8192);i=(c|0)>(f|0)?c:f;break b}n=(f<<26>>31&9)+A|0;u:{if(d>>>0>11){break u}g=12-d|0;s=16;while(1){s=s*16;g=g-1|0;if(g){continue}break}if(w[n|0]==45){b=-(s+(-b-s));break u}b=b+s-s}l=x|2;k=f&32;h=v[m+44>>2];g=h>>31;g=ln(g^g+h,0,z);if((z|0)==(g|0)){t[m+15|0]=48;g=m+15|0}r=g-2|0;t[r|0]=f+15;t[g-1|0]=(h|0)<0?45:43;i=e&8;h=m+16|0;while(1){f=h;if(D(b)<2147483648){g=~~b}else{g=-2147483648}t[h|0]=k|w[g+73040|0];b=(b-+(g|0))*16;h=f+1|0;if(!(!(i|(d|0)>0)&b==0|(h-(m+16|0)|0)!=1)){t[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}i=-1;p=z-r|0;f=p+l|0;if((2147483645-f|0)<(d|0)){break b}v:{w:{if(!d){break w}k=h-(m+16|0)|0;if((k-2|0)>=(d|0)){break w}g=d+2|0;break v}k=h-(m+16|0)|0;g=k}d=g+f|0;Nf(a,32,c,d,e);tf(a,n,l);Nf(a,48,c,d,e^65536);tf(a,m+16|0,k);Nf(a,48,g-k|0,0,0);tf(a,r,p);Nf(a,32,c,d,e^8192);i=(c|0)>(d|0)?c:d}cb=m+560|0;return i|0}function kea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=cb-208|0;cb=e;sc(c);a:{if(!ao(c,e+192|0)){break a}if(Mb(e+192|0,13901,4)){break a}h=e+200|0;if(Mb(h,14274,4)){if(Mb(h,14378,4)){break a}}g=cb-32|0;cb=g;i=e+176|0;f=bf(i);b:{c:{d:{e:{f:{while(1){v[22440]=0;j=Q(158,c|0,8)|0;k=v[22440];v[22440]=0;if((k|0)==1){break d}if(!j){break e}v[22440]=0;R(811,g|0,c|0);j=v[22440];v[22440]=0;if((j|0)!=1){v[22440]=0;R(812,f|0,g|0);j=v[22440];v[22440]=0;if((j|0)==1){break f}Xc(g);continue}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;Xc(g);break c}cb=g+32|0;break b}a=P()|0;O()|0}Qd(f);S(a|0);L()}v[22440]=0;U(737,e+152|0,i|0,1129270605);c=v[22440];v[22440]=0;g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){v[22440]=0;c=Q(738,e+152|0,e+128|0)|0;g=v[22440];v[22440]=0;n:{o:{if((g|0)!=1){if(!c){break g}g=e+128|2;if(!Wb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))){break g}if((wb(w[e+128|0]|w[e+129|0]<<8)-3&65535)>>>0<65534){break g}f=e+128|6;if((wb(w[f|0]|w[f+1|0]<<8)-65&65535)>>>0<65472){break g}v[e+124>>2]=1162760014;c=1;if(!Mb(h,14378,4)){v[22440]=0;c=Q(622,e+152|0,e+124|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break o}if(!c){break g}c=v[e+124>>2]!=1936684916}v[22440]=0;U(737,e+104|0,e+176|0,1397968452);h=v[22440];v[22440]=0;p:{q:{if((h|0)!=1){v[22440]=0;l=Q(739,e+104|0,e+96|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break p}if(l){break q}break h}c=P()|0;O()|0;break j}h=((wb(w[f|0]|w[f+1|0]<<8)-1|0)/8|0)-1|0;i=h<<3;f=i&31;f=Nc(e+88|0,(h>>>0<7?(i&63)>>>0>=32?4196360>>>f|0:((1<<f)-1&4196360)<<32-f|136321040>>>f:8)&255,(wb(w[e+128|0]|w[e+129|0]<<8)|0)==2?2:1,c,0);c=v[e+124>>2];r:{if((c|0)!=544694642){s:{t:{if(!((c|0)==842222662|(c|0)==842230886|(c|0)==875973702)){if((c|0)==2002873461){break s}if((c|0)==1463897153){break t}if((c|0)==1463897173){break s}if((c|0)==2002873441){break t}if((c|0)!=875981926){break r}}Hf(f,3);break r}Hf(f,17);kd(f,16);break r}Hf(f,16);kd(f,16);break r}Hf(f,1)}if(d){qN(f)}c=w[e+96|0]|w[e+97|0]<<8|(w[e+98|0]<<16|w[e+99|0]<<24);v[22440]=0;c=Q(158,e+104|0,Wb(c)|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break l}if(c){c=w[e+96|0]|w[e+97|0]<<8|(w[e+98|0]<<16|w[e+99|0]<<24);v[22440]=0;Q(190,e+104|0,Wb(c)|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break l}}Ts(a,b);v[22440]=0;c=B(b,104)+a|0;h=c+484380|0;R(284,h|0,0);d=v[22440];v[22440]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((d|0)==1){break D}n=h,o=Wb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24)),v[n>>2]=o;j=c+484404|0;c=e+128|0;g=w[c+13|0]|(w[c+11|0]<<16|w[c+10|0]<<24|w[c+12|0]<<8);i=30-w[c+9|0]|0;d=0;while(1){c=g;if(i&255){g=c>>>1|0;i=i-1|0;d=c;continue}break}v[j>>2]=c+(d&1);v[22440]=0;Y(222,f|0,h|0,e+104|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break D}v[22440]=0;U(737,e- -64|0,e+176|0,1296126539);c=v[22440];v[22440]=0;if((c|0)==1){break C}v[22440]=0;c=T(180,e- -64|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break B}if(!c){break u}v[22440]=0;U(737,e+16|0,e+176|0,1229869908);c=v[22440];v[22440]=0;if((c|0)==1){break A}v[22440]=0;c=Q(740,e+16|0,e+40|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break z}sb(e+16|0);if(!c){break u}v[22440]=0;d=T(278,e- -64|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break y}g=Rb(e+16|0);v[22440]=0;R(741,g|0,d|0);c=v[22440];v[22440]=0;if((c|0)==1){break w}i=e|6;c=0;while(1){if((c|0)==(d|0)){break x}v[22440]=0;f=Q(742,e- -64|0,e|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break w}if(!f){break x}v[22440]=0;R(743,g|0,e|0);f=v[22440];v[22440]=0;if((f|0)==1){break w}f=w[i|0];v[22440]=0;Q(190,e- -64|0,f+((f^-1)&1)|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break w}c=c+1|0;continue}}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break m}c=P()|0;O()|0;break m}c=P()|0;O()|0;sb(e+16|0);break m}c=P()|0;O()|0;break m}if(wb(w[e+48|0]|w[e+49|0]<<8)){c=(B(b,104)+a|0)+484414|0;d=x[c>>1]|8;u[c>>1]=d;n=c,o=d&65519|((wb(w[e+48|0]|w[e+49|0]<<8)|0)==2)<<4,u[n>>1]=o}if(wb(w[e+54|0]|w[e+55|0]<<8)){c=(B(b,104)+a|0)+484414|0;d=x[c>>1]|2;u[c>>1]=d;n=c,o=d&65531|((wb(w[e+54|0]|w[e+55|0]<<8)|0)==2)<<2,u[n>>1]=o}n=e,o=yb(v[g>>2]),v[n>>2]=o;c=B(b,104)+a|0;f=c+484388|0;i=c+484384|0;j=c+484396|0;k=c+484392|0;m=yb(v[g+4>>2]);while(1){d=v[e>>2];if(!Qb(d,m)){break v}c=wb(w[d|0]|w[d+1|0]<<8);if((c|0)==(wb(w[e+50|0]|w[e+51|0]<<8)|0)){n=k,o=Wb(w[d+2|0]|w[d+3|0]<<8|(w[d+4|0]<<16|w[d+5|0]<<24)),v[n>>2]=o;c=wb(w[d|0]|w[d+1|0]<<8)}if((wb(w[e+52|0]|w[e+53|0]<<8)|0)==(c|0)){n=j,o=Wb(w[d+2|0]|w[d+3|0]<<8|(w[d+4|0]<<16|w[d+5|0]<<24)),v[n>>2]=o;c=wb(w[d|0]|w[d+1|0]<<8)}if((wb(w[e+56|0]|w[e+57|0]<<8)|0)==(c|0)){n=i,o=Wb(w[d+2|0]|w[d+3|0]<<8|(w[d+4|0]<<16|w[d+5|0]<<24)),v[n>>2]=o;c=wb(w[d|0]|w[d+1|0]<<8)}if((c|0)==(wb(w[e+58|0]|w[e+59|0]<<8)|0)){n=f,o=Wb(w[d+2|0]|w[d+3|0]<<8|(w[d+4|0]<<16|w[d+5|0]<<24)),v[n>>2]=o}v[e>>2]=v[e>>2]+7;continue}}c=P()|0;O()|0;mN(g);break m}yk(h);mN(g)}v[22440]=0;U(737,e+16|0,e+176|0,1312902469);c=v[22440];v[22440]=0;if((c|0)==1){break n}v[22440]=0;c=T(180,e+16|0)|0;d=v[22440];v[22440]=0;E:{if((d|0)==1){break E}F:{if(c){v[22440]=0;c=T(162,e+16|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break E}v[22440]=0;U(321,e+16|0,((b<<5)+a|0)+946304|0,c|0);b=v[22440];v[22440]=0;if((b|0)!=1){break F}break E}v[22440]=0;c=Q(56,e|0,21685)|0;d=v[22440];v[22440]=0;if((d|0)==1){break E}uc(((b<<5)+a|0)+946304|0,c);rb(c)}bt(h,v[a+480180>>2]);Ai(h,a);sb(e+16|0);sb(e- -64|0);break h}c=P()|0;O()|0;sb(e+16|0);break m}c=P()|0;O()|0;break k}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break m}c=P()|0;O()|0;break i}sb(e- -64|0);break k}c=P()|0;O()|0}sb(e+104|0)}sb(e+152|0)}Qd(e+176|0);S(c|0);L()}sb(e+104|0)}sb(e+152|0);Qd(e+176|0)}cb=e+208|0;return l|0}
function Mea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;e=cb-224|0;cb=e;sc(b);a:{if(!At(b,e+160|0)){break a}if(!ZP(e+160|0)){break a}if(!Kb(b,wc(YP(e+160|0),fb))){break a}if(!c){d=1;break a}ud(a,256);Bj(e+144|0,2,e+160|0);d=e+48|0;xc(d,v[e+144>>2],v[e+148>>2],w[e+152|0]);tc(a+1298308|0,d);rb(d);h=e+210|0;i=w[h|0]|w[h+1|0]<<8;v[a+480260>>2]=64;v[a+480264>>2]=32767;u[a+480188>>1]=4;u[a+480190>>1]=i;Gb(a+1074312|0,107,1);i=w[e+203|0];i=i?i:96;g=Fz(i);v[a+480196>>2]=i>>>4;v[a+480204>>2]=g;t[e+48|0]=64;C=a,D=w[Tb(e+202|0,d)|0]<<2,v[C+480200>>2]=D;d=0;b:{c:{d:{e:{f:{g:{while(1){if((d|0)==4){h:{i=Rb(e+144|0);o=Rb(e+128|0);d=e+192|0;d=w[d|0]|w[d+1|0]<<8;v[22440]=0;Q(157,b|0,d<<4)|0;d=v[22440];v[22440]=0;i:{if((d|0)==1){break i}n=e+208|0;d=w[n|0]|w[n+1|0]<<8;v[22440]=0;Y(220,b|0,i|0,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break i}d=e+194|0;d=w[d|0]|w[d+1|0]<<8;v[22440]=0;Q(157,b|0,d<<4)|0;d=v[22440];v[22440]=0;if((d|0)==1){break i}d=w[h|0]|w[h+1|0]<<8;v[22440]=0;Y(220,b|0,o|0,d|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break i}d=e+196|0;d=w[d|0]|w[d+1|0]<<8;v[22440]=0;Q(157,b|0,(d<<4)+32|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break i}g=a+484360|0;d=Nb(g);f=e+212|0;f=w[f|0]|w[f+1|0]<<8;v[22440]=0;R(333,d|0,f|0);d=v[22440];v[22440]=0;if((d|0)==1){break i}d=Nb(g);C=e,D=yb(v[d>>2]),v[C+48>>2]=D;d=yb(v[d+4>>2]);j:{while(1){f=v[e+48>>2];if(!Qb(f,d)){d=0;if(!aQ(Nb(g))){break b}l=c&2;g=e- -64|0;m=e+48|1;d=1;break j}v[22440]=0;l=T(208,b|0)|0;m=v[22440];v[22440]=0;k:{if((m|0)==1){break k}u[f>>1]=l;v[22440]=0;Q(190,b|0,4)|0;f=v[22440];v[22440]=0;if((f|0)==1){break k}Ne(e+48|0);continue}break}d=P()|0;O()|0;break c}l:{m:{n:{o:{while(1){f=d&65535;if(f>>>0>(w[h|0]|w[h+1|0]<<8)>>>0){break l}j=Xb(v[o>>2],f-1|0);j=w[j|0]|w[j+1|0]<<8;v[22440]=0;j=Q(157,b|0,j<<4)|0;k=v[22440];v[22440]=0;p:{if((k|0)!=1){if(j){break p}d=0;break b}d=P()|0;O()|0;break c}v[22440]=0;Q(688,b|0,e+48|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break o}v[22440]=0;j=(B(f,104)+a|0)+484380|0;U(689,e+48|0,j|0,0);k=v[22440];v[22440]=0;if((k|0)==1){break o}sk(e+16|0,2,m);v[22440]=0;W(225,e+32|0,v[e+16>>2],v[e+20>>2],w[e+24|0]);k=v[22440];v[22440]=0;if((k|0)==1){break n}k=((f<<5)+a|0)+946304|0;f=e+32|0;uc(k,f);rb(f);f=nQ(e+48|0);q:{r:{if(!l|!(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))){break r}v[22440]=0;f=Q(157,b|0,f|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break m}if(!f){break r}f=e+32|0;mQ(f,e+48|0,1);v[22440]=0;Y(222,f|0,j|0,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break q}}d=d+1|0;continue}break}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}t[e+15|0]=1;d=v[i>>2];s:{if(hc(d,v[i+4>>2])){break s}h=e+188|0;if((w[h|0]|w[h+1|0]<<8)==26){break s}g=w[d|0]|w[d+1|0]<<8;d=0;v[22440]=0;g=Q(157,b|0,g<<4)|0;f=v[22440];v[22440]=0;if((f|0)==1){break h}if(!g){break b}v[22440]=0;d=T(196,b|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break h}if((d|0)!=(w[h|0]|w[h+1|0]<<8)){break s}t[e+15|0]=0}j=c&1;if(j){c=w[n|0]|w[n+1|0]<<8;v[22440]=0;R(228,a+484344|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break h}}m=a+484344|0;c=e+48|0;k=c|5;q=c|4;r=c|2;s=c|1;y=a+480188|0;h=0;while(1){t:{if(!j|(w[n|0]|w[n+1|0]<<8)>>>0<=h>>>0){break t}v[22440]=0;c=Y(229,m|0,h&65535,64)|0;d=v[22440];v[22440]=0;if((d|0)==1){break g}if(!c){break t}c=Xb(v[i>>2],h);c=w[c|0]|w[c+1|0]<<8;v[22440]=0;c=Q(157,b|0,c<<4)|0;d=v[22440];v[22440]=0;if((d|0)==1){break g}d=0;if(!c){break b}if(!w[e+15|0]){v[22440]=0;c=T(196,b|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break g}if(c>>>0>2112){break b}}u[e+16>>1]=65535;v[e+32>>2]=63;u:while(1){z=Gf(Sb(m,h),d);v:while(1){c=d;while(1){if(c>>>0<=63){v[22440]=0;l=T(208,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break f}if(!l){d=64;if(c>>>0>62){continue v}d=c+1|0;continue u}A=tg(e+48|0);g=l&31;d=g>>>0<x[y>>1];g=B(g,6)+z|0;if(l&32){v[22440]=0;R(267,e+8|0,b|0);f=v[22440];v[22440]=0;w:{x:{y:{if((f|0)!=1){f=e+8|0;p=Ec(f);f=w[f|0];if(f>>>0>239){break y}f=lQ((B(f>>>4|0,12)+(f&15)|0)+37|0);break x}d=P()|0;O()|0;break c}z:{switch(f-254|0){case 0:break x;case 1:break z;default:break w}}f=0}t[(d?g:e+48|0)|0]=f}t[(d?g+1|0:s)|0]=w[p|0]}if(l&64){v[22440]=0;f=T(208,b|0)|0;p=v[22440];v[22440]=0;if((p|0)==1){break e}t[e+8|0]=f;t[(d?g+2|0:r)|0]=1;t[e+7|0]=64;C=d?g+4|0:q,D=w[Tb(e+8|0,e+7|0)|0],t[C|0]=D}if(!(l&128)){continue}v[22440]=0;R(267,e+8|0,b|0);f=v[22440];v[22440]=0;if((f|0)==1){break d}f=e+8|0;C=d?g+5|0:k,D=w[Ec(f)|0],t[C|0]=D;$P(d?g:A,w[f|0],c,255,e+16|0,e+32|0);continue}break}break}break}c=x[e+16>>1];if((c|0)!=65535){xe(Sb(m,h),ym(Pe(Je(e+48|0,12,c&255),v[e+32>>2])))}h=h+1|0;continue}break}v[22440]=0;b=Q(1,e+48|0,6091)|0;c=v[22440];v[22440]=0;A:{B:{C:{if((c|0)!=1){Cb(a+1298344|0,b);rb(b);v[22440]=0;b=Q(1,e+48|0,5277)|0;c=v[22440];v[22440]=0;if((c|0)==1){break C}Cb(a+1298356|0,b);rb(b);v[a+1298404>>2]=5;v[22440]=0;R(691,e+32|0,4408);b=v[22440];v[22440]=0;if((b|0)==1){break B}v[22440]=0;U(312,e+48|0,e+32|0,e+15|0);b=v[22440];v[22440]=0;if((b|0)==1){break A}b=a+1298368|0;a=e+48|0;Cb(b,a);rb(a);Ab(e+32|0);d=1;break b}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;Ab(e+32|0);break c}d=P()|0;O()|0;break c}}else{i=(d<<5)+a|0;$e(i+480280|0);u[i+480284>>1]=d&1?64:192;d=d+1|0;continue}break}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0}_c(o);_c(i);S(d|0);L()}_c(o);_c(i)}cb=e+224|0;return d|0}function Uia(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;k=cb-128|0;cb=k;t[k+127|0]=d;a:{if(!c|(e|0)<0&c>>>0>=176){break a}t[b+5|0]=d;t[k+8|0]=15;l=k+127|0;p=k+8|0;j=p;o=w[Tb(l,j)|0];t[k+8|0]=14;l=w[Tb(l,j)|0];v[k+8>>2]=d+31>>>5;v[k+120>>2]=14;r=k+120|0;n=v[ld(j,r)>>2];v[k+8>>2]=d+127>>>7;v[k+120>>2]=14;q=c&15;j=q<<8|d;p=ld(p,r);b:{switch((c>>>4|0)-2|0){case 0:t[b+2|0]=1;t[b+4|0]=j>>>2;break a;case 1:t[b+2|0]=1;if(!j){t[b+4|0]=0;break a}s=b,y=rg(RA(j)>>>2|0),t[s+4|0]=y;break a;case 2:t[b+3|0]=9;t[b+5|0]=j>>>4;break a;case 3:t[b+3|0]=23;t[b+5|0]=j+1>>>5;break a;case 4:t[b+3|0]=23;if(j){a=rg(RA(j)>>>5|0)}else{a=0}t[b+5|0]=a;break a;case 5:t[b+5|0]=q;t[b+3|0]=15;break a;case 6:t[b+3|0]=15;if((e|0)>=0){if(w[b+2|0]){break a}t[b+2|0]=2;s=b,y=yc(((q<<6|7)>>>0)/15|0,0),t[s+4|0]=y;break a}t[b+2|0]=1;t[b+5|0]=q;t[b+4|0]=d+3>>>2;break a;case 7:t[b+3|0]=10;c:{if((e|0)>5){break c}if(!j){t[b+5|0]=1;break a}c=dq(a,f,g);if(!c){break c}a=Fi(a,c);c=x[a+34>>1];if(c&1){j=j>>>1|0;v[k+120>>2]=j}if(!(c&2)){break c}c=v[a>>2];if(c>>>0>=j<<8>>>0){break c}v[k+120>>2]=v[a+4>>2]+8>>>8;qc(k+120|0,c-1>>>8|0);j=v[k+120>>2]}t[b+5|0]=j;if(w[b+2|0]|j>>>0<256){break a}t[b+2|0]=15;v[k+116>>2]=j>>>8;QA(k+8|0);v[k+112>>2]=9;s=b,y=v[Bb(k+116|0,k+112|0)>>2],t[s+4|0]=y;break a;default:break b}}j=v[p>>2];d:{switch(c-160|0){default:e:{switch(c-1|0){case 0:case 1:case 2:case 3:case 6:case 10:case 14:Ef(b,c,d);f:{switch(w[b+3|0]-16|0){case 1:v[h>>2]=B(w[b+5|0],1e4);break a;case 0:break f;default:break a}}a=w[b+5|0];if(!a){break a}v[i>>2]=a;break a;case 4:t[b+3|0]=4;if(w[b+2|0]){break a}t[b+4|0]=0;t[b+2|0]=8;break a;case 5:t[b+3|0]=5;if(w[b+2|0]){break a}t[b+4|0]=0;t[b+2|0]=11;break a;case 7:if(!Rc(w[b|0])|!d){break a}t[b+3|0]=35;t[b+5|0]=(d>>>1&120|128)-(d<<3&120);e=a+480192|0;if(x[e>>1]){break a}u[k+8>>1]=255;c=x[Kc(a+480190|0,k+8|0)>>1];u[e>>1]=c;b=1;while(1){d=b&65535;if(d>>>0>(c&65535)>>>0){break a}c=wu(a,d,d);if(c){t[c+33|0]=2;d=(d<<5)+a|0;f=d+946304|0;g=v[f+4>>2];v[c+492>>2]=v[f>>2];v[c+496>>2]=g;f=d+946312|0;g=v[f+4>>2];v[c+500>>2]=v[f>>2];v[c+504>>2]=g;f=d+946320|0;g=v[f+4>>2];v[c+508>>2]=v[f>>2];v[c+512>>2]=g;d=d+946328|0;f=v[d+4>>2];v[c+516>>2]=v[d>>2];v[c+520>>2]=f;Jj(c,127,1);Ij(c,0,1)}b=b+1|0;c=x[e>>1];continue};case 8:t[b+3|0]=19;t[b+5|0]=o|208;break a;case 9:t[b+3|0]=25;break a;case 11:if(d>>>0>2){break a}t[b+3|0]=19;t[b+5|0]=d|64;break a;case 12:t[b+3|0]=14;break a;case 13:if(d>>>0>2){break a}t[b+3|0]=19;t[b+5|0]=d|112;break a;case 15:t[b+3|0]=1;break a;case 16:case 17:t[b+3|0]=19;t[b+5|0]=l|c<<4;break a;case 18:t[b+3|0]=15;break a;case 19:t[b+3|0]=11;t[b+5|0]=l<<4;break a;case 20:t[b+5|0]=l;t[b+3|0]=11;break a;case 23:t[b+3|0]=6;t[b+5|0]=l<<4;break a;case 24:t[b+5|0]=l;t[b+3|0]=6;break a;case 27:t[b+3|0]=7;t[b+5|0]=l<<4;break a;case 28:break e;default:break a}}t[b+5|0]=l;t[b+3|0]=7;break a;case 0:if(!d){break a}t[b+3|0]=24;t[b+5|0]=n<<4;break a;case 1:if(!d){break a}t[b+5|0]=n;t[b+3|0]=24;break a;case 4:t[b+3|0]=11;t[b+5|0]=l<<4|15;break a;case 5:t[b+3|0]=11;t[b+5|0]=l|240;break a;case 6:if(!d){break a}t[b+3|0]=24;t[b+5|0]=n<<4|15;break a;case 7:if(!d){break a}t[b+3|0]=24;t[b+5|0]=n|240;break a;case 8:if(!d){break a}t[b+3|0]=16;v[i>>2]=d;break a;case 9:if((e|0)>5){break a}a=v[h>>2];if(a>>>0<1e4){break a}t[b+3|0]=17;m=122925/(+(a>>>0)/1e4)+ +((d<<1)-256|0);s=b,y=rk(245850/(m+m)),t[s+5|0]=y;break a;case 10:t[b+3|0]=19;t[b+5|0]=o|224;break a;case 12:t[b+3|0]=28;t[b+5|0]=o|16;break a;case 13:t[b+3|0]=28;t[b+5|0]=o|32;break a;case 14:t[b+3|0]=29;t[b+5|0]=l<<3&240;break a;case 15:t[b+3|0]=29;t[b+5|0]=(l&254)>>>1;break a;case 16:t[b+3|0]=18;break a;case 17:t[b+3|0]=19;t[b+5|0]=o|176;break a;case 18:case 19:t[b+3|0]=20;t[b+5|0]=d?120:119;break a;case 20:t[b+3|0]=20;t[b+5|0]=d?125:123;break a;case 21:t[b+3|0]=20;t[b+5|0]=d?122:121;break a;case 22:t[b+3|0]=20;t[b+5|0]=d?126:123;break a;case 26:t[b+3|0]=10;t[b+5|0]=d+15>>>4;break a;case 27:t[b+5|0]=1;t[b+3|0]=10;break a;case 30:case 31:if(!d|(!g|!f)){break a}o=v[h>>2];if(o>>>0<1e4){break a}l=v[i>>2];if(!l){break a}i=dq(a,f,g);if(!i){break a}j=Fi(a,i);n=x[j+34>>1];g:{if(!(n&2)){i=v[j>>2];break g}i=v[j+8>>2]-((e|0)<6?v[j+4>>2]:0)|0;if(!(n&4)){break g}i=i<<((e|0)>5)}if(!i|(e|0)<6&i>>>0<1024){break a}n=v[j+24>>2];if(!n){break a}h:{if(x[a+480192>>1]<g>>>0){break h}a=v[((g<<2)+a|0)+900380>>2];if(!a){break h}m=+(w[Eb(a+108|0,f-1|0)|0]-f|0)}a=(c|0)==190;m=ni(m/12+(a?(e|0)<6?+t[j+37|0]/-1536:-0:-0))*+(n>>>0);if(a){t[b+3|0]=17;a=rk(m*.5*(+(B(d,l)>>>0)*2.5)/+(i>>>0));t[b+5|0]=a;v[h>>2]=B(a,1e4);break a}m=Wt(lK(+(i>>>0)/m/(+(B(d,l)>>>0)*2.5/(+(o>>>0)/1e4)))*12+61,1,120);i:{if(m<4294967296&m>=0){a=~~m>>>0;break i}a=0}c=Rc(w[b|0]);t[b|0]=a;m=(m-H(m))*64+128;j:{if(m<4294967296&m>=0){a=~~m>>>0;break j}a=0}t[b+5|0]=a;if((a|0)!=128){t[b+3|0]=35}if(c){break a}if(!w[b+2|0]){t[b+4|0]=9;t[b+2|0]=11;break a}t[b+5|0]=255;t[b+3|0]=4;break a;case 32:a=d>>>4|0;if(a-1>>>0>1){break a}t[b+3|0]=20;t[b+5|0]=a-99;break a;case 34:t[b+3|0]=21;t[b+5|0]=d<<2;break a;case 35:t[b+3|0]=21;s=b,y=rg(RA(d<<4)>>>6|0),t[s+5|0]=y;break a;case 36:case 38:t[b+3|0]=22;t[b+5|0]=j<<4;break a;case 37:case 39:t[b+5|0]=j;t[b+3|0]=22;break a;case 40:t[b+3|0]=22;t[b+5|0]=l<<4|15;break a;case 2:case 3:case 11:case 23:case 24:case 25:case 28:case 29:case 33:break a;case 41:break d}}t[b+3|0]=22;t[b+5|0]=l|240}cb=k+128|0}function Yha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;f=cb-208|0;cb=f;if(Ah(b,13916)){if(d){t[d|0]=1}m=a+480216|0;n=a+480220|0;o=a+480224|0;k=a+1074368|0;q=a+480228|0;r=a+480232|0;p=a+480200|0;s=a+484360|0;l=a+480268|0;z=a+1298320|0;A=a+480248|0;C=Rt(a+1074312|0);D=a+480180|0;E=a+480190|0;a:{b:{c:{d:{e:{f:{g:{h:{while(1){if(!Kb(b,7)){break a}d=Ag(b);e=Sg(b);if((d|0)==(w[21661]|w[21662]<<8|(w[21663]<<16|w[21664]<<24))){xg(b,6);break a}if(!(d&1616928864)|d&-2139062144){break a}if(!Kb(b,e)){break a}h=f+24|0;Td(h,b,e);g=cc(f+184|0,h);sb(h);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((d|0)!=1127099950){if((d|0)==1129797166){break w}if((d|0)==1130917459){break o}if((d|0)==1145525806){break s}if((d|0)==1448301654){break t}if((d|0)==1196316499){break m}if((d|0)==1213486401){break p}if((d|0)==1280530262){break v}if((d|0)==1297303086){break l}if((d|0)==1347243310){break x}if((d|0)==1347244882){break q}z:{if((d|0)!=1380340804){if((d|0)==1380986414){break r}if((d|0)==1380991534){break z}if((d|0)==1380994350){break k}if((d|0)==1397052739){break n}if((d|0)==1397768494){break u}if((d|0)==1414344238){break y}if((d|0)!=1146367534){break j}v[22440]=0;U(452,g|0,e|0,f+24|0);d=v[22440];v[22440]=0;if((d|0)==1){break i}v[a+480204>>2]=B(v[f+24>>2],1e4)+(y[a+480204>>2]%1e4|0);break j}v[22440]=0;U(452,g|0,e|0,f+24|0);d=v[22440];v[22440]=0;if((d|0)!=1){d=v[a+480204>>2];v[a+480204>>2]=d-((d>>>0)%1e4|0)+y[f+24>>2]%1e4;break j}e=P()|0;O()|0;break b}v[22440]=0;U(452,g|0,e|0,m|0);d=v[22440];v[22440]=0;if((d|0)!=1){break j}break c}if(c){break j}v[22440]=0;u[f+24>>1]=0;U(453,g|0,e|0,f+24|0);d=v[22440];v[22440]=0;if((d|0)!=1){F=a,G=wd(x[f+24>>1],x[a+480188>>1],127),u[F+480188>>1]=G;break j}e=P()|0;O()|0;break b}v[22440]=0;U(454,g|0,e|0,o|0);d=v[22440];v[22440]=0;if((d|0)==1){break c}break j}v[22440]=0;U(455,g|0,e|0,k|0);d=v[22440];v[22440]=0;if((d|0)==1){break c}break j}v[22440]=0;v[f+24>>2]=0;U(452,g|0,e|0,f+24|0);d=v[22440];v[22440]=0;if((d|0)!=1){v[a+1074304>>2]=v[f+24>>2];break j}e=P()|0;O()|0;break b}v[22440]=0;v[f+24>>2]=0;U(452,g|0,e|0,f+24|0);d=v[22440];v[22440]=0;if((d|0)==1){break h}d=v[f+24>>2];if(!d){break j}v[a+1074308>>2]=d;break j}v[22440]=0;U(452,g|0,e|0,q|0);d=v[22440];v[22440]=0;if((d|0)==1){break c}break j}v[22440]=0;U(452,g|0,e|0,r|0);d=v[22440];v[22440]=0;if((d|0)==1){break c}break j}v[22440]=0;U(452,g|0,e|0,p|0);d=v[22440];v[22440]=0;if((d|0)==1){break c}break j}if(v[D>>2]==4){break j}v[22440]=0;U(453,g|0,e|0,f+24|0);d=v[22440];v[22440]=0;if((d|0)!=1){Qe(Nb(s),x[f+24>>1]);break j}e=P()|0;O()|0;break b}v[22440]=0;U(456,g|0,e|0,l|0);d=v[22440];v[22440]=0;if((d|0)==1){break c}if(qo(w[l|0])){break j}t[l|0]=5;break j}d=Db(f+24|0);v[22440]=0;e=T(162,f+184|0)|0;h=v[22440];v[22440]=0;A:{if((h|0)==1){break A}v[22440]=0;U(457,g|0,d|0,e|0);e=v[22440];v[22440]=0;if((e|0)==1){break A}v[22440]=0;U(11,f+168|0,0,d|0);e=v[22440];v[22440]=0;if((e|0)==1){break A}e=f+168|0;Cb(z,e);rb(e);rb(d);break j}e=P()|0;O()|0;rb(d);break b}if(e&1|e>>>0>126){break j}d=64;u[f+24>>1]=(e>>>1|0)- -64;u[f+168>>1]=127;e=x[Kc(f+24|0,f+168|0)>>1];i=e>>>0>64?e:64;while(1){if((d|0)==(i|0)){break j}v[22440]=0;R(267,f+24|0,g|0);e=v[22440];v[22440]=0;if((e|0)==1){break g}B:{if(w[f+24|0]==255){break B}h=w[Ec(f+24|0)|0];e=(d<<5)+a|0;j=e+480284|0;u[j>>1]=128;u[e+480286>>1]=h;h=e+480280|0;v[h>>2]=0;v[h>>2]=(w[f+24|0]&128)<<3;e=w[f+24|0]&127;t[f+24|0]=e;if(e>>>0<65){u[j>>1]=e<<2;e=w[f+24|0]}if((e&255)!=100){break B}v[h>>2]=v[h>>2]|256}d=d+1|0;continue}}if(e>>>0<3){break j}v[22440]=0;d=T(196,g|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break f}if(!d|d>>>0>x[E>>1]){break j}d=(B(d,104)+a|0)+484448|0;e=HS(d);while(1){if((d|0)==(e|0)){break j}v[22440]=0;h=T(159,g|0)|0;i=v[22440];v[22440]=0;if((i|0)!=1){v[d>>2]=h;d=d+4|0;continue}break}e=P()|0;O()|0;break b}if(e>>>0<3){break j}v[22440]=0;R(458,f+8|0,f+184|0);d=v[22440];v[22440]=0;C:{D:{E:{F:{if((d|0)!=1){v[22440]=0;U(459,f+168|0,v[f+8>>2],v[f+12>>2]);d=v[22440];v[22440]=0;if((d|0)==1){break F}v[22440]=0;d=Q(91,f+24|0,f+168|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break E}rb(f+168|0);_b(f+8|0);v[22440]=0;e=T(162,f+184|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break C}v[22440]=0;U(460,f+24|0,A|0,e|0);e=v[22440];v[22440]=0;if((e|0)==1){break C}uf(d);break j}e=P()|0;O()|0;break b}e=P()|0;O()|0;break D}e=P()|0;O()|0;rb(f+168|0)}_b(f+8|0);break b}e=P()|0;O()|0;uf(d);break b}e=0;h=Rt(C);G:while(1){v[22440]=0;d=Q(158,f+184|0,1)|0;i=v[22440];v[22440]=0;if((i|0)==1){break d}if(!(d&e>>>0<117)){break j}v[22440]=0;i=T(208,g|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break e}d=0;while(1){if((d|0)==8){continue G}H:{if(!(i>>>d&1)|e>>>0>116){break H}v[22440]=0;Y(271,h|0,e|0,1)|0;j=v[22440];v[22440]=0;if((j|0)!=1){break H}e=P()|0;O()|0;break b}e=e+1|0;d=d+1|0;continue}}}v[22440]=0;U(452,g|0,e|0,n|0);d=v[22440];v[22440]=0;if((d|0)==1){break c}}sb(f+184|0);continue}break}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}sb(f+184|0);S(e|0);L()}b=v[a+8>>2];xo(a+480204|0,B(v[b+20>>2],1e4),B(v[b+24>>2],1e4));if(w[a+480224|0]>=3){t[o|0]=0}if(w[k|0]>=6){t[k|0]=0}qc(p,256);qc(m,65536);qc(n,65536)}cb=f+208|0}function sia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;e=cb-1360|0;cb=e;sc(b);k=cb-16|0;cb=k;d=e+784|0;QS(k+8|0,d);i=v[k+12>>2];Yb(k,b,v[k+8>>2],i);g=v[k+4>>2];if((g|0)==(i|0)){Ob(b,v[k+12>>2])}cb=k+16|0;g=(g|0)==(i|0);if(!g){PS(d)}a:{if(!g){break a}if(!SS(e+784|0)){break a}if(!Kb(b,wc(RS(e+784|0),fb))){break a}if(!c){f=1;break a}p=Rp(e+776|0);b:{while(1){if((f|0)!=32){k=(f<<5)+a|0;i=k+480280|0;$e(i);d=(e+784|0)+(f<<4)|0;u[k+480284>>1]=((w[d+78|0]<<8&65280)>>>0)/255;sk(e+512|0,1,d- -64|0);g=e+112|0;xc(g,v[e+512>>2],v[e+516>>2],w[e+520|0]);Al(k+480289|0,g);rb(g);c:{d:{switch(w[d+79|0]){case 0:o=h+1|0;break c;case 1:v[i>>2]=1024;o=f+1|0;break c;case 2:break d;default:break b}}v[i>>2]=1024;g=e+112|0;Cc(g,p,f);rm(g)}h=h+1|0;f=f+1|0;continue}break}ud(a,33554432);u[a+480188>>1]=o&255;d=e+112|0;g=jc(d,6776);Cb(a+1298344|0,g);rb(g);g=jc(d,11110);Cb(a+1298356|0,g);rb(g);v[a+1298404>>2]=5;e:{if(w[e+863|0]){break e}f=1;h=1;while(1){if((f|0)==16){while(1){if((h|0)==16){break e}g=((h<<5)+a|0)+480280|0;v[g>>2]=v[g>>2]&-1025;h=h+1|0;continue}}g=f<<4;f=f+1|0;if(w[(e+g|0)+863|0]==1){continue}break}}d=e+512|0;Ie(d,1,e+784|0);g=e+112|0;xc(g,v[e+512>>2],v[e+516>>2],w[e+520|0]);tc(a+1298308|0,g);rb(g);v[a+480208>>2]=v[a+480208>>2]&-17|(w[e+822|0]|w[e+823|0]<<8)<<4&16;v[a+480196>>2]=w[e+832|0];v[a+480204>>2]=B(w[e+833|0],1e4);v[a+480200>>2]=w[e+834|0]<<2;v[a+480228>>2]=w[e+835|0];g=w[e+820|0]|w[e+821|0]<<8;u[a+480190>>1]=0;u[a+480192>>1]=g;Ou(b,d);zq(Nb(a+484360|0),d,w[e+816|0]|w[e+817|0]<<8,65535,255);s=c&1;if(s){wg(a+484344|0,w[e+818|0]|w[e+819|0]<<8)}q=a+484344|0;k=a+480188|0;f:{while(1){g:{if((w[e+818|0]|w[e+819|0]<<8)>>>0<=j>>>0){r=c&2;g=e- -64|0;n=e+108|0;s=a+480192|0;o=1;c=0;h:while(1){if(x[s>>1]<=(c&65535)>>>0){f=32;break b}c=c+1|0;m=wu(a,c&65535,0);f=!m;k=cb-16|0;cb=k;h=e+112|0;Ub(k+8|0,h,384);i=v[k+12>>2];Yb(k,b,v[k+8>>2],i);d=v[k+4>>2];if((d|0)==(i|0)){Ob(b,v[k+12>>2])}cb=k+16|0;d=(d|0)==(i|0);if(!d){Hb(h,0,384)}if(!d|f){continue}h=o&65535;i=cb-32|0;cb=i;f=e+112|0;Ie(i,1,f);d=i+16|0;xc(d,v[i>>2],v[i+4>>2],w[i+8|0]);uc(m+492|0,d);rb(d);i:{if(!(w[f+378|0]|w[f+379|0]<<8)){break i}d=m+236|0;j=0;while(1){v[i+16>>2]=120;v[i>>2]=116;if(y[Bb(i+16|0,i)>>2]<=j>>>0){break i}z=Xb(d,j+12|0),A=h+w[(f+j|0)+32|0]|0,u[z>>1]=A;j=j+1|0;continue}}d=w[f+376|0]|w[f+377|0]<<8;t[m+33|0]=1;v[m>>2]=d;JA(f,m+48|0,0);JA(f,m+68|0,1);JA(f,m+88|0,2);d=w[m+100|0];if(d&1){t[m+100|0]=d|16}if(!(v[m>>2]|t[m+60|0]&1)){v[m>>2]=32767}cb=i+32|0;f=0;while(1){d=w[e+490|0]|w[e+491|0]<<8;if(d>>>0<=f>>>0){o=d+o|0;continue h}UT(b,e+48|0);j:{k:{if(Mb(n,15568,4)){break k}d=f+o|0;q=d&65535;if(q>>>0>3999){break k}u[a+480190>>1]=d;p=cb-32|0;cb=p;m=B(q,104)+a|0;l=m+484380|0;ed(l,0);j=e+48|0;Wh(p,1,j);d=p+16|0;xc(d,v[p>>2],v[p+4>>2],w[p+8|0]);pe(l+43|0,d);rb(d);k=w[j+16|0]|w[j+17|0]<<8|(w[j+18|0]<<16|w[j+19|0]<<24);v[l>>2]=k;i=w[j+20|0]|w[j+21|0]<<8|(w[j+22|0]<<16|w[j+23|0]<<24);v[l+4>>2]=i;h=w[j+24|0]|w[j+25|0]<<8|(w[j+26|0]<<16|w[j+27|0]<<24);v[l+8>>2]=h;v[l+24>>2]=w[j+28|0]|w[j+29|0]<<8|(w[j+30|0]<<16|w[j+31|0]<<24);u[l+30>>1]=w[j+32|0]<<2;u[l+28>>1]=w[j+33|0];d=w[j+48|0];if(d&1){u[l+34>>1]=x[l+34>>1]|2;d=w[j+48|0]}if(d&2){u[l+34>>1]=x[l+34>>1]|4;d=w[j+48|0]}if(d&4){v[l+8>>2]=h>>>1;v[l+4>>2]=i>>>1;v[l>>2]=k>>>1;u[l+34>>1]=x[l+34>>1]|1;d=w[j+48|0]}if(d&8){u[l+34>>1]=x[l+34>>1]|32}cb=p+32|0;h=cb-16|0;cb=h;Xu(h+8|0,m+484423|0);d=e+24|0;Gq(d,v[h+8>>2],v[h+12>>2]);cb=h+16|0;uc(((q<<5)+a|0)+946304|0,d);rb(d);d=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);if(!d){break k}Td(e,b,d);h=cc(e+24|0,e);sb(e);if(r){d=Nc(e,u[m+484414>>1]&1?16:8,1,0,0);v[22440]=0;Y(222,d|0,l|0,h|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break j}}sb(e+24|0)}f=f+1|0;continue}break}break}f=P()|0;O()|0;sb(e+24|0);break f}g=Sg(b);m=Sg(b);d=e+48|0;Td(d,b,g-4|0);l=cc(e+112|0,d);sb(d);l:{m:{if(!s){break m}v[22440]=0;d=Y(229,q|0,j&65535,m|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break l}if(!d){break m}o=0;g=tg(e+24|0);while(1){if(m>>>0<=o>>>0){break m}v[22440]=0;n=T(208,l|0)|0;d=v[22440];v[22440]=0;n:{if((d|0)!=1){if(n){break n}o=o+1|0;continue}break g}h=g;r=n&31;if(r>>>0<x[k>>1]){h=Zc(Sb(q,j),o,r)}if(n&32){v[22440]=0;R(267,e+48|0,l|0);d=v[22440];v[22440]=0;if((d|0)==1){break g}d=e+48|0;i=w[d|0];t[h|0]=i;z=h,A=w[Ec(d)|0],t[z+1|0]=A;o:{p:{if((i|0)==160){f=255;break p}if((i|0)==255){f=0;break p}f=0;d=(B(i>>>4|0,12)+(i&15)|0)+13|0;if(OS(d)){break o}}d=f}t[h|0]=d}d=n&192;q:{if(!d){break q}if((d|0)==192){v[22440]=0;R(360,e+48|0,l|0);d=v[22440];v[22440]=0;if((d|0)!=1){n=e+48|0;d=Ec(n);i=Oe(n);f=Li(n);KA(e,w[n|0],w[d|0]);d=Ec(e);n=e+504|0;KA(n,w[i|0],w[f|0]);io(e+496|0,h,w[e|0],w[d|0],w[n|0],w[Ec(n)|0]);break q}break g}v[22440]=0;R(267,e+48|0,l|0);d=v[22440];v[22440]=0;r:{s:{if((d|0)!=1){d=e+48|0;KA(e,w[d|0],w[Ec(d)|0]);f=w[Ec(e)|0];d=w[e|0];if((d|0)!=13){break s}t[h+2|0]=1;d=h+4|0;break r}break g}t[h+3|0]=d;d=h+5|0}t[d|0]=f}Cc(e+48|0,p,r);if(!tb(v[v[e+48>>2]>>2],v[e+52>>2])){continue}if(!KU(w[h+3|0],w[h+5|0])){continue}t[h+3|0]=0;continue}}j=j+1|0;sb(e+112|0);continue}}break}f=P()|0;O()|0;sb(e+112|0)}S(f|0);L()}f=f>>>0>31}cb=e+1360|0;return f|0}function OG(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,C=0,D=0,E=0,F=0;i=cb-80|0;cb=i;v[i+76>>2]=b;D=i+55|0;s=i+56|0;b=0;a:{b:{c:{d:{e:while(1){if((2147483647-o|0)<(b|0)){break d}o=b+o|0;f:{g:{h:{k=v[i+76>>2];b=k;h=w[b|0];if(h){while(1){i:{h=h&255;j:{if(!h){h=b;break j}if((h|0)!=37){break i}h=b;while(1){if(w[b+1|0]!=37){break j}j=b+2|0;v[i+76>>2]=j;h=h+1|0;l=w[b+2|0];b=j;if((l|0)==37){continue}break}}b=h-k|0;C=2147483647-o|0;if((b|0)>(C|0)){break d}if(a){tf(a,k,b)}if(b){continue e}r=-1;h=1;b=v[i+76>>2];j=t[b+1|0];if(!(!Yj(j)|w[b+2|0]!=36)){r=j-48|0;y=1;h=3}b=h+b|0;v[i+76>>2]=b;p=0;m=t[b|0];j=m-32|0;k:{if(j>>>0>31){h=b;break k}h=b;j=1<<j;if(!(j&75913)){break k}while(1){h=b+1|0;v[i+76>>2]=h;p=j|p;m=t[b+1|0];j=m-32|0;if(j>>>0>=32){break k}b=h;j=1<<j;if(j&75913){continue}break}}l:{if((m|0)==42){b=t[h+1|0];m:{if(!(!Yj(b)|w[h+2|0]!=36)){v[((b<<2)+e|0)-192>>2]=10;m=h+3|0;q=v[((t[h+1|0]<<3)+d|0)-384>>2];y=1;break m}if(y){break h}m=h+1|0;if(!a){v[i+76>>2]=m;y=0;q=0;break l}b=v[c>>2];v[c>>2]=b+4;q=v[b>>2];y=0}v[i+76>>2]=m;if((q|0)>=0){break l}q=0-q|0;p=p|8192;break l}q=NG(i+76|0);if((q|0)<0){break d}m=v[i+76>>2]}b=0;l=-1;n:{if(w[m|0]!=46){j=m;h=0;break n}if(w[m+1|0]==42){h=t[m+2|0];o:{if(!(!Yj(h)|w[m+3|0]!=36)){v[((h<<2)+e|0)-192>>2]=10;j=m+4|0;l=v[((t[m+2|0]<<3)+d|0)-384>>2];break o}if(y){break h}j=m+2|0;l=0;if(!a){break o}h=v[c>>2];v[c>>2]=h+4;l=v[h>>2]}v[i+76>>2]=j;h=(l^-1)>>>31|0;break n}v[i+76>>2]=m+1;l=NG(i+76|0);j=v[i+76>>2];h=1}z=h;while(1){n=b;h=28;x=j;if(t[j|0]-123>>>0<4294967238){break c}j=x+1|0;v[i+76>>2]=j;b=w[(t[x|0]+B(n,58)|0)+72511|0];if(b-1>>>0<8){continue}break}p:{q:{if((b|0)!=27){if(!b){break c}if((r|0)>=0){v[(r<<2)+e>>2]=b;b=(r<<3)+d|0;h=v[b+4>>2];v[i+64>>2]=v[b>>2];v[i+68>>2]=h;break q}if(!a){break f}MG(i- -64|0,b,c,g);break p}if((r|0)>=0){break c}}b=0;if(!a){continue e}}m=p&-65537;j=p&8192?m:p;p=0;r=5289;h=s;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{b=t[x|0];b=n?(b&15)==3?b&-33:b:b;switch(b-88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break G}}H:{switch(b-65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break g;default:break H}}if((b|0)==83){break w}break g}n=v[i+64>>2];k=v[i+68>>2];r=5289;break z}b=0;I:{switch(n&255){case 0:v[v[i+64>>2]>>2]=o;continue e;case 1:v[v[i+64>>2]>>2]=o;continue e;case 2:h=v[i+64>>2];v[h>>2]=o;v[h+4>>2]=o>>31;continue e;case 3:u[v[i+64>>2]>>1]=o;continue e;case 4:t[v[i+64>>2]]=o;continue e;case 6:v[v[i+64>>2]>>2]=o;continue e;case 7:break I;default:continue e}}h=v[i+64>>2];v[h>>2]=o;v[h+4>>2]=o>>31;continue e}l=l>>>0>8?l:8;j=j|8;b=120}m=s;E=b&32;n=v[i+64>>2];k=v[i+68>>2];if(n|k){while(1){m=m-1|0;t[m|0]=E|w[(n&15)+73040|0];F=!k&n>>>0>15|(k|0)!=0;x=k;k=k>>>4|0;n=(x&15)<<28|n>>>4;if(F){continue}break}}k=m;if(!(j&8)|!(v[i+64>>2]|v[i+68>>2])){break y}r=(b>>>4|0)+5289|0;p=2;break y}b=s;n=v[i+64>>2];k=v[i+68>>2];if(n|k){while(1){b=b-1|0;t[b|0]=n&7|48;x=!k&n>>>0>7|(k|0)!=0;m=k;k=m>>>3|0;n=(m&7)<<29|n>>>3;if(x){continue}break}}k=b;if(!(j&8)){break y}b=s-k|0;l=(b|0)<(l|0)?l:b+1|0;break y}b=v[i+68>>2];k=b;n=v[i+64>>2];if((b|0)<0){k=0-(k+((n|0)!=0)|0)|0;n=0-n|0;v[i+64>>2]=n;v[i+68>>2]=k;p=1;r=5289;break z}if(j&2048){p=1;r=5290;break z}p=j&1;r=p?5291:5289}k=ln(n,k,s)}if((l|0)<0?z:0){break d}j=z?j&-65537:j;m=v[i+64>>2];b=v[i+68>>2];if(!((m|b)!=0|l)){k=s;h=k;l=0;break g}b=!(b|m)+(s-k|0)|0;l=(b|0)<(l|0)?l:b;break g}b=v[i+64>>2];k=b?b:17103;b=k;h=(l|0)<0?2147483647:l;j=ys(b,0,h);b=j?j-b|0:h;h=b+k|0;if((l|0)>=0){j=m;l=b;break g}j=m;l=b;if(w[h|0]){break d}break g}if(l){h=v[i+64>>2];break u}b=0;Nf(a,32,q,0,j);break t}v[i+12>>2]=0;v[i+8>>2]=v[i+64>>2];h=i+8|0;v[i+64>>2]=h;l=-1}b=0;J:{while(1){k=v[h>>2];if(!k){break J}k=LG(i+4|0,k);m=(k|0)<0;if(!(m|k>>>0>l-b>>>0)){h=h+4|0;b=b+k|0;if(l>>>0>b>>>0){continue}break J}break}if(m){break b}}h=61;if((b|0)<0){break c}Nf(a,32,q,b,j);if(!b){b=0;break t}k=0;h=v[i+64>>2];while(1){l=v[h>>2];if(!l){break t}l=LG(i+4|0,l);k=l+k|0;if(k>>>0>b>>>0){break t}tf(a,i+4|0,l);h=h+4|0;if(b>>>0>k>>>0){continue}break}}Nf(a,32,q,b,j^8192);b=(b|0)<(q|0)?q:b;continue e}if((l|0)<0?z:0){break d}h=61;b=gb[f|0](a,A[i+64>>3],q,l,j,b)|0;if((b|0)>=0){continue e}break c}t[i+55|0]=v[i+64>>2];l=1;k=D;j=m;break g}j=b+1|0;v[i+76>>2]=j;h=w[b+1|0];b=j;continue}}if(a){break a}if(!y){break f}b=1;while(1){a=v[(b<<2)+e>>2];if(a){MG((b<<3)+d|0,a,c,g);o=1;b=b+1|0;if((b|0)!=10){continue}break a}break}o=1;if(b>>>0>=10){break a}h=0;while(1){if(h){break h}b=b+1|0;if((b|0)==10){break a}h=v[(b<<2)+e>>2];continue}}h=28;break c}m=h-k|0;n=(l|0)<(m|0)?m:l;if((n|0)>(2147483647-p|0)){break d}h=61;l=n+p|0;b=(l|0)>(q|0)?l:q;if((C|0)<(b|0)){break c}Nf(a,32,b,l,j);tf(a,r,p);Nf(a,48,b,l,j^65536);Nf(a,48,n,m,0);tf(a,k,m);Nf(a,32,b,l,j^8192);continue}break}o=0;break a}h=61}v[114922]=h}o=-1}cb=i+80|0;return o}function bga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0;d=cb-1824|0;cb=d;sc(b);e=cb-16|0;cb=e;j=d+1224|0;gR(e+8|0,j);f=v[e+12>>2];Yb(e,b,v[e+8>>2],f);i=v[e+4>>2];if((i|0)==(f|0)){Ob(b,v[e+12>>2])}cb=e+16|0;e=(f|0)==(i|0);if(!e){fR(j)}a:{if(!e){break a}if(!hR(d+1224|0)){break a}if(!Uz(b,16,0)){break a}v[d+1216>>2]=v[d+1240>>2];e=v[d+1228>>2];v[d+1200>>2]=v[d+1224>>2];v[d+1204>>2]=e;e=d+1232|0;f=v[e+4>>2];v[d+1208>>2]=v[e>>2];v[d+1212>>2]=f;ud(a,1);Gb(Gb(Vf(a+1074312|0,83),84,1),85,1);u[a+480188>>1]=4;v[d+1196>>2]=0;u[a+480190>>1]=15;Tc(b,20);k=a+480188|0;h=1;j=1;while(1){b:{if((h|0)==16){e=d+1064|0;qR(b,e);o=a+484360|0;pq(Nb(o),e|2,128);h=0;m=pR(b,Nb(o),w[e|0],g,k,0,1);f=e|1;if(!(w[e|0]?1:w[f|0]|m>>>0>1)){break a}if(_e(b)+65536>>>0<(m<<10)+g>>>0){break a}if(c){break b}h=1;break a}f=B(h,104)+a|0;i=f+484380|0;e=((h<<5)+a|0)+946304|0;Vz(b,d+16|0,i,e,1);m=v[i>>2];c:{if(!w[Eb(e,0)|0]){break c}d:{if(Mb(e,16804,3)){if(Mb(e,16808,3)){break d}}if(w[Eb(e,5)|0]==58){break c}}j=0}if(wb(w[d+44|0]|w[d+45|0]<<8)>>>0>=2){y=f+484384|0,z=wb(w[d+42|0]|w[d+43|0]<<8),v[y>>2]=z;y=f+484388|0,z=wb(w[d+42|0]|w[d+43|0]<<8)+(wb(w[d+44|0]|w[d+45|0]<<8)<<1)|0,v[y>>2]=z;yk(i)}e:{if(wb(w[d+38|0]|w[d+39|0]<<8)>>>0<=4999){if(wb(w[d+42|0]|w[d+43|0]<<8)>>>0<1e4){break e}}v[d+1064>>2]=5;y=d,z=v[Ke(d+1196|0,d+1064|0)>>2],v[y+1196>>2]=z}g=g+m|0;h=h+1|0;continue}break}if(!w[f|0]){t[f|0]=120}if(!Mb(d+1200|0,15021,6)){t[f|0]=120}v[a+480204>>2]=125e4;e=w[f|0];f:{if((e|0)==120){break f}y=a,z=Le(1773447.5/(+(240-e|0)*122)*1e4),v[y+480204>>2]=z;if(v[d+1196>>2]>=2){v[d+16>>2]=j&1?4:5;y=d,z=v[Ke(d+1196|0,d+16|0)>>2],v[y+1196>>2]=z;break f}v[d+16>>2]=j&1?1:2;y=d,z=v[Ke(d+1196|0,d+16|0)>>2],v[y+1196>>2]=z}v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|2097152;Bj(d+1048|0,3,d+1200|0);e=d+16|0;xc(e,v[d+1048>>2],v[d+1052>>2],w[d+1056|0]);tc(a+1298308|0,e);rb(e);mh(a,0);r=j&1;s=v[b+8>>2];j=0;while(1){u[d+1040>>1]=j;g:{if((j&65535)>>>0<m>>>0){e=Nb(o);e=Qb(Oz(Pg(e),Og(e),d+1040|0),Og(e));eR(b,d+16|0);h:{if(e){n=Sz(d+16|0,0)+n|0;if(n>>>0>512){break h}}k=0;e=0;g=0;i:while(1){if((g|0)==64){break g}h=0;x=sd(d+16|0,g);while(1){f=e;if((h|0)==4){g=g+1|0;continue i}else{p=Ib(x,h);l=w[Eb(p,2)|0]&15;i=w[Eb(p,3)|0];e=0;j:{if(!(f&255)){break j}if(Mb(p,26996,4)){break j}e=f+1|0;if((e&255)>>>0<33){break j}v[d+1196>>2]=6}k:{l:{m:{switch(l-1|0){case 0:case 1:f=v[d+1196>>2];if((f|0)==1&i>>>0>=32){break l}l=(l|0)!=1;if(!(l|!i|i>>>0>2)){v[d+1048>>2]=2;y=d,z=v[Ke(d+1196|0,d+1048|0)>>2],v[y+1196>>2]=z;break k}if(l|(i|0)!=55&(i|0)!=71){break k}if((f|0)<=2){break l}break k;case 10:v[d+1196>>2]=6;break k;case 11:case 12:case 13:v[d+1048>>2]=2;y=d,z=v[Ke(d+1196|0,d+1048|0)>>2],v[y+1196>>2]=z;if((l|0)!=13){break k}k=((g|i)!=0)+k|0;e=1;break k;case 14:break m;default:break k}}v[d+1048>>2]=3;y=d,z=v[Ke(d+1196|0,d+1048|0)>>2],v[y+1196>>2]=z;break k}v[d+1196>>2]=r}h=h+1|0;continue}}}}h=0;break a}if(!(v[d+1196>>2]!=6|m+32>>>0>=q>>>0)){v[d+1196>>2]=5}Tc(b,s);p=c&1;if(p){wg(a+484344|0,m)}o=a+484344|0;j=0;while(1){if((j|0)==(m|0)){h=21685;e=v[d+1196>>2];if(e>>>0<7){h=v[(e<<2)+27008>>2]}e=d+16|0;f=jc(e,8333);Cb(a+1298344|0,f);rb(f);e=jc(e,10775);Cb(a+1298356|0,e);rb(e);Kl(a+1298368|0,h);v[a+1298404>>2]=2;h=1;if(!(c&2)){break a}g=1;while(1){if((g|0)==16){break a}c=B(g,104)+a|0;e=c+484384|0;Ob(b,v[e>>2]);f=v[e>>2];v[e>>2]=0;e=c+484380|0;v[e>>2]=v[e>>2]-f;c=c+484388|0;v[c>>2]=v[c>>2]-f;c=d+16|0;Nc(c,8,1,1,0);vg(c,e,b);g=g+1|0;continue}}eR(b,d+16|0);n:{if(!p){break n}if(!nh(o,j&65535,64)){break n}n=0;v[d+1048>>2]=0;o:while(1){if((n|0)==64){break n}h=0;q=Zc(Sb(o,j),n,0);r=sd(d+16|0,n);while(1)if((h|0)==4){n=n+1|0;continue o}else{e=Ib(r,h);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[d+8>>2]=e;v[d+12>>2]=e;k=d+1040|0;e=q+B(h,6)|0;_t(k,d+8|0,e);f=w[k|0];i=Ec(k);g=w[i|0];if(!((f|0)!=14?g:0)){t[(d+1048|0)+h|0]=0}l=(d+1048|0)+h|0;p:{if(f|g){q:{g=w[l|0];if(g){r:{if(g>>>0>=16){t[e+2|0]=3;g=g>>>4|0;break r}t[e+2|0]=4}t[e+4|0]=g;f=w[k|0]}s:{t:{u:{switch((f&255)-12|0){case 1:if(v[d+1196>>2]!=6){t[k|0]=10;break t}t[i|0]=0;break t;case 0:t[i|0]=w[i|0]&127;break t;case 2:g=w[i|0];if(g>>>0<=1){f=14;if(v[d+1196>>2]>3){break s}}t[k|0]=10;t[l|0]=w[i|0];break t;case 3:break u;default:break t}}t[i|0]=w[i|0]&15}if(v[d+1196>>2]<2){break q}g=w[i|0];f=w[k|0]}Ef(e,f,g&255);break p}f=w[i|0];t[e+5|0]=f;v:{switch(w[k|0]){case 0:if(w[i|0]<=2){t[e+3|0]=0;break p}t[e+3|0]=1;break p;case 1:t[e+3|0]=1;break p;case 2:g=f&15;if(g){t[e+3|0]=2;t[e+5|0]=g;break p}if(f>>>0<16){break p}t[e+3|0]=3;t[e+5|0]=(f&240)>>>4;break p;default:break v}}t[e+3|0]=0;break p}t[l|0]=0}h=h+1|0;continue}}}j=j+1|0;continue}}if((k-1&255)>>>0<2){v[d+1196>>2]=6}j=j+1|0;q=(k&255)+q|0;continue}}cb=d+1824|0;return h|0}function qH(a,b,c,d,e,f){var g=0,h=C(0),i=0,j=0,k=C(0),l=C(0),m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,A=C(0),D=C(0),E=0,F=0,G=0,H=C(0),I=C(0),J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0),P=0,Q=0;F=(d|0)>0?d:0;while(1){if((s|0)!=(F|0)){G=B(s,2304)+b|0;v=0;q=(c|0)>0?c:0;n=cb-128|0;x=n+96|0;y=n- -64|0;E=n+32|0;while(1){if((q|0)!=(v|0)){o=G+(v<<2)|0;w=0;i=n;p=i;j=0;while(1){if((j|0)!=8){k=z[B(15-j|0,72)+o>>2];g=B(j,72)+o|0;h=z[g+1152>>2];l=C(k+h);m=z[g>>2];A=z[B(31-j|0,72)+o>>2];D=C(m+A);z[p>>2]=l+D;g=B(j,12);k=C(C(k-h)*z[g+67232>>2]);h=C(C(m-A)*z[g+67236>>2]);z[p+64>>2]=k+h;m=C(D-l);l=z[g+67240>>2];z[p+32>>2]=m*l;z[p+96>>2]=C(h-k)*l;p=p+4|0;j=j+1|0;continue}break}while(1){if((w|0)!=4){l=z[i+8>>2];m=z[i+20>>2];h=C(l+m);A=z[i+4>>2];D=z[i+24>>2];H=C(A+D);k=C(h+H);I=z[i+12>>2];J=z[i+16>>2];K=C(I+J);L=z[i>>2];M=z[i+28>>2];N=C(L+M);O=C(K+N);z[i>>2]=k+O;z[i+16>>2]=C(O-k)*C(.7071067690849304);k=C(N-K);h=C(C(k+C(H-h))*C(.7071067690849304));z[i+24>>2]=C(k-h)*C(1.3065630197525024);z[i+8>>2]=C(k+h)*C(.5411961078643799);k=C(L-M);h=C(l-m);l=C(A-D);m=C(C(h+l)*C(.7071067690849304));A=C(k+m);D=C(C(I-J)+h);h=C(l+k);l=C(D-C(h*C(.1989123672246933)));h=C(C(l*C(.3826834261417389))+h);z[i+28>>2]=C(A-h)*C(2.562915563583374);z[i+4>>2]=C(A+h)*C(.509795606136322);k=C(k-m);h=C(l-C(h*C(.1989123672246933)));z[i+20>>2]=C(k+h)*C(.8999761939048767);z[i+12>>2]=C(k-h)*C(.601344883441925);i=i+32|0;w=w+1|0;continue}break}i=0;while(1){if((i|0)!=7){p=i<<2;z[o>>2]=z[p+n>>2];k=z[p+x>>2];i=i+1|0;j=i<<2;h=z[j+x>>2];z[o+72>>2]=C(z[p+y>>2]+k)+h;z[o+144>>2]=z[p+E>>2]+z[j+E>>2];z[o+216>>2]=h+C(k+z[j+y>>2]);o=o+288|0;continue}break}z[o>>2]=z[n+28>>2];k=z[n+124>>2];z[o+72>>2]=z[n+92>>2]+k;h=z[n+60>>2];z[o+216>>2]=k;z[o+144>>2]=h;v=v+1|0;continue}break}s=s+1|0;continue}break}E=ic(f,a,3840);G=d<<5;s=0;while(1){if((c|0)>(s|0)){i=cb-32|0;cb=i;o=E+(s<<8)|0;v=(s<<2)+b|0;z[o+4080>>2]=z[v+1152>>2];f=d-1|0;w=v+B(f,2304)|0;z[o+4084>>2]=z[w+1152>>2];z[o+4088>>2]=z[v>>2];z[o+4092>>2]=z[w>>2];z[o+4336>>2]=z[v+1156>>2];z[o+4340>>2]=z[w+1156>>2];z[o+4344>>2]=z[v+4>>2];z[o+4348>>2]=z[w+4>>2];x=(B(s,G)<<1)+e|0;y=x+(f<<1)|0;Or(y,d,o+244|0);f=d<<6;Or(f+y|0,d,o+500|0);Or(x,d,o+240|0);Or(f+x|0,d,o+496|0);F=o+3840|0;p=14;n=67328;while(1){if((p|0)>=0){g=p<<4;j=g+F|0;f=B(31-p|0,72);z[j>>2]=z[f+v>>2];z[j+4>>2]=z[f+w>>2];f=f|4;z[j+8>>2]=z[f+v>>2];z[j+12>>2]=z[f+w>>2];f=B(p,72);q=f+76|0;z[j+256>>2]=z[q+v>>2];z[j+260>>2]=z[q+w>>2];f=f+72|0;z[j-248>>2]=z[f+v>>2];z[j-244>>2]=z[f+w>>2];q=p<<2;t=g+o|0;k=z[n+4>>2];h=z[n>>2];f=0;while(1){if((f|0)!=4){g=f<<2;l=z[g+j>>2];m=z[g+t>>2];z[g+(i+16|0)>>2]=C(l*h)-C(k*m);z[i+g>>2]=C(l*k)+C(h*m);f=f+1|0;continue}break}j=F+(q<<2)|0;q=j-3584|0;t=j-256|0;k=z[n+12>>2];h=z[n+8>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-3328|0;t=j-512|0;k=z[n+20>>2];h=z[n+16>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}q=j-3072|0;t=j-768|0;k=z[n+28>>2];h=z[n+24>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-2816|0;t=j-1024|0;k=z[n+36>>2];h=z[n+32>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}q=j-2560|0;t=j-1280|0;k=z[n+44>>2];h=z[n+40>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-2304|0;t=j-1536|0;k=z[n+52>>2];h=z[n+48>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}g=j-2048|0;q=j-1792|0;k=z[n+60>>2];h=z[n+56>>2];f=0;while(1){if((f|0)!=4){j=f<<2;t=j+i|0;l=z[j+q>>2];m=z[g+j>>2];z[t>>2]=z[t>>2]+C(C(l*k)+C(h*m));j=j+(i+16|0)|0;z[j>>2]=C(C(m*k)-C(h*l))+z[j>>2];f=f+1|0;continue}break}f=B(15-p|0,d)<<1;P=f+y|0,Q=ej(z[i+20>>2]),u[P>>1]=Q;j=B(p+17|0,d)<<1;P=j+y|0,Q=ej(z[i+4>>2]),u[P>>1]=Q;P=f+x|0,Q=ej(z[i+16>>2]),u[P>>1]=Q;P=j+x|0,Q=ej(z[i>>2]),u[P>>1]=Q;f=B(47-p|0,d)<<1;P=f+y|0,Q=ej(z[i+28>>2]),u[P>>1]=Q;j=B(p+49|0,d)<<1;P=j+y|0,Q=ej(z[i+12>>2]),u[P>>1]=Q;P=f+x|0,Q=ej(z[i+24>>2]),u[P>>1]=Q;P=j+x|0,Q=ej(z[i+8>>2]),u[P>>1]=Q;p=p-1|0;n=n- -64|0;continue}break}cb=i+32|0;s=s+2|0;continue}break}b=c<<6;a:{if((d|0)==1){s=0;while(1){if(s>>>0>959){break a}z[(s<<2)+a>>2]=z[E+(b+s<<2)>>2];s=s+2|0;continue}}ic(a,E+(b<<2)|0,3840)}}function Qea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=cb-336|0;cb=d;Tc(b,60);i=15;a:{if(!Ah(b,14226)){Tc(b,124);i=31;if(!Ah(b,15423)){break a}}ud(a,536870912);u[a+480190>>1]=i;sc(b);b:{while(1){if(x[a+480190>>1]>g>>>0){f=Am(b);v[(d+208|0)+(g<<2)>>2]=f;g=g+1|0;if(f>>>0<=131072){continue}break b}break}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480196>>2]=6;g=0;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;mh(a,1);Ob(b,4);f=Ii(b);if(f>>>0<178){break a}p=a,q=Le(1776930/+(f>>>0)*1e4),v[p+480204>>2]=q;Ob(b,14);o=d+62|0;i=0;n=1;c:while(1){m=n&65535;if(m>>>0<=x[a+480190>>1]){g=d+40|0;lR(b,g);f=v[((m<<2)+d|0)+204>>2];h=cb-16|0;cb=h;j=(B(m,104)+a|0)+484380|0;ed(j,1);v[j>>2]=f;t[j+37|0]=w[g+24|0]<<4;t[h+15|0]=w[g+25|0];t[h+14|0]=64;p=j,q=w[Tb(h+15|0,h+14|0)|0]<<2,u[p+30>>1]=q;e=g+26|0;l=wb(w[e|0]|w[e+1|0]<<8);d:{if(!f){break d}e=g+28|0;e=w[e|0]|w[e+1|0]<<8;v[j+4>>2]=l;e=(wb(e)<<1)+l|0;v[j+8>>2]=e;if(f>>>0<=l>>>0){l=f-1|0;v[j+4>>2]=l}if(f>>>0<e>>>0){v[j+8>>2]=f;e=f}if(!(!(e>>>0<l>>>0|e>>>0<4)&e-l>>>0>3)){v[j+4>>2]=0;v[j+8>>2]=0;break d}if(e>>>0<=l>>>0){break d}u[j+34>>1]=x[j+34>>1]|2}cb=h+16|0;while(1)if((g|0)==(o|0)){if(i>>>0>127){break b}Bl(d+176|0,3,d+40|0);f=d+192|0;xc(f,v[d+176>>2],v[d+180>>2],w[d+184|0]);uc(((m<<5)+a|0)+946304|0,f);n=n+1|0;rb(f);continue c}else{if((w[g|0]-1&255)>>>0<=30){t[g|0]=32;i=i+1|0}g=g+1|0;continue}}break}l=1;e:{f:{g:{g=a+946336|0;f=Bc(d+40|0,14093);if(!gQ(g,f)){v[22440]=0;e=Q(56,d+192|0,14104)|0;i=v[22440];v[22440]=0;if((i|0)==1){break g}l=gQ(g,e);rb(e)}rb(f);g=0;f=d+40|0;e=jR(b,f);if(!e){Qz(f)}if(!e){break a}if(!jQ(d+40|0)){break a}if(!c){break e}u[d+38>>1]=0;while(1){f=w[d+40|0];if(f>>>0<=g>>>0){e=a+484360|0;h=Nb(e);g=d+40|0;i=w[g|1];Qe(h,f>>>0>i>>>0?i:0);pq(Nb(e),g|2,w[d+40|0]);if(x[a+480190>>1]==31){Ob(b,4)}v[d+32>>2]=0;v[d+28>>2]=0;v[d+24>>2]=0;t[d+23|0]=0;m=c&1;if(m){wg(a+484344|0,x[d+38>>1])}n=a+484344|0;i=0;while(1){h:{i:{j:{if(x[d+38>>1]<=i>>>0){if(!(c&2)){break j}g=1;while(1){i=x[a+480190>>1];c=g&65535;if(i>>>0<c>>>0){break i}c=(B(c,104)+a|0)+484380|0;if(v[c>>2]){vg(Nc(d+192|0,8,1,0,0),c,b)}g=g+1|0;continue}}k:{if(m){j=0;if(nh(n,i&65535,64)){break k}}Ob(b,1024);break h}l:while(1){if((j|0)==64){break h}g=0;o=Zc(Sb(n,i),j,0);while(1)if((g|0)==4){j=j+1|0;continue l}else{e=d+192|0;Gm(e,b);f=o+B(g,6)|0;m:{n:{o:{p:{if(w[Eb(e,0)|0]!=255){break p}t[(d+32|0)+g|0]=0;t[(d+24|0)+g|0]=0;e=Eb(d+192|0,1);h=w[e|0];if((h|0)==252&l){t[e|0]=254;break n}switch(h-252|0){case 1:break m;case 2:break n;case 0:break o;default:break p}}e=v[d+192>>2];v[d+16>>2]=e;v[d+8>>2]=e;h=d+176|0;_t(h,d+8|0,f);k=Ec(h);e=w[f|0];q:{if(!e){break q}t[(d+24|0)+g|0]=0;t[(d+32|0)+g|0]=e;if(e>>>0>48){break q}t[d+15|0]=8;p=d,q=w[ff(d+23|0,d+15|0)|0],t[p+23|0]=q}e=w[k|0];r:{if(!(e|w[h|0])){break r}t[f+5|0]=e;s:{t:{switch(w[h|0]-1|0){case 0:t[f+3|0]=1;break r;case 1:if(e&240){t[f+3|0]=3;t[f+5|0]=e>>>4;break r}e=e&15;if(e){t[f+3|0]=2;t[f+5|0]=e;break r}t[f+3|0]=0;break r;case 2:if(w[(d+24|0)+g|0]){t[f+3|0]=0;break r}t[f+3|0]=19;t[f+5|0]=0;break r;case 3:if(w[(d+24|0)+g|0]){t[f+3|0]=0;break r}t[f+3|0]=19;t[f+5|0]=1;break r;case 4:if(!w[f+1|0]){break s}t[d+15|0]=63;t[d+14|0]=w[f+5|0]+(x[(B(w[f+1|0],104)+a|0)+484410>>1]>>>2|0);e=w[Tb(d+15|0,d+14|0)|0];t[f+3|0]=13;t[f+5|0]=e;if(!w[(d+24|0)+g|0]){break r}t[f+4|0]=w[f+5|0];t[f+2|0]=1;t[f+3|0]=0;break r;case 5:h=w[f+1|0];if(h){t[f+3|0]=13;h=x[(B(h,104)+a|0)+484410>>1]>>>2|0;e=e>>>0>h>>>0?0:h-e|0;t[f+5|0]=e;if(!w[(d+24|0)+g|0]){break r}t[f+4|0]=e;t[f+2|0]=1}t[f+3|0]=0;break r;case 6:h=e&15;t[(d+24|0)+g|0]=h;k=w[(d+32|0)+g|0];e=k-(e>>>4|0)|0;t[(d+28|0)+g|0]=e;e=fQ(h,e&255,k);t[f+3|0]=3;t[f+5|0]=e;break r;case 7:h=e&15;t[(d+24|0)+g|0]=h;k=e>>>4|0;e=w[(d+32|0)+g|0];k=k+e|0;t[(d+28|0)+g|0]=k;e=fQ(h,e,k&255);t[f+3|0]=2;t[f+5|0]=e;break r;case 8:break t;default:break s}}t[d+15|0]=8;p=d,q=w[ff(d+23|0,d+15|0)|0],t[p+23|0]=q}t[f+3|0]=0}if(w[f+3|0]){break m}h=w[(d+24|0)+g|0];if(!h){break m}k=(d+28|0)+g|0;e=w[k|0];if(e){t[(d+32|0)+g|0]=e;t[f|0]=e;t[f+5|0]=h;t[k|0]=0}t[f+3|0]=4;break m}t[f+3|0]=14;t[d+23|0]=9;break m}t[f+3|0]=13}g=g+1|0;continue}}}i=x[a+480190>>1]}u:{v:{if((i&65535)==15){b=d+176|0;Xf(b,4421);v[22440]=0;U(312,d+192|0,b|0,d+23|0);b=v[22440];v[22440]=0;if((b|0)!=1){break v}i=P()|0;O()|0;Ab(d+176|0);break f}v[22440]=0;Q(1,d+192|0,12358)|0;b=v[22440];v[22440]=0;if((b|0)==1){break u}}b=d+192|0;Cb(a+1298344|0,b);rb(b);if((i&65535)==15){Ab(d+176|0)}Kl(a+1298356|0,x[a+480190>>1]==15?5285:15210);v[a+1298404>>2]=2;break e}i=P()|0;O()|0;break f}i=i+1|0;continue}}else{u[d+192>>1]=w[(d+g|0)+42|0]+1;p=d,q=x[ie(d+38|0,d+192|0)>>1],u[p+38>>1]=q;g=g+1|0;continue}}}i=P()|0;O()|0;rb(f)}S(i|0);L()}g=1;break a}g=0}cb=d+336|0;return g|0}function Yia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;f=cb-288|0;cb=f;sc(b);e=cb-16|0;cb=e;h=f+80|0;qT(e+8|0,h);g=v[e+12>>2];Yb(e,b,v[e+8>>2],g);i=v[e+4>>2];if((i|0)==(g|0)){Ob(b,v[e+12>>2])}cb=e+16|0;e=(g|0)==(i|0);if(!e){pT(h)}a:{if(!e){break a}if(!sT(f+80|0)){break a}if(!Kb(b,wc(rT(f+80|0),fb))){break a}b:{if(!c){break b}ud(a,16777216);eg(a);v[a+480208>>2]=v[a+480208>>2]|16777216;d=f+56|0;eq(d,32);g=f- -64|0;h=v[g+4>>2];e=a+1074320|0;v[e>>2]=v[g>>2];v[e+4>>2]=h;e=v[f+60>>2];v[a+1074312>>2]=v[f+56>>2];v[a+1074316>>2]=e;Gb(a+1074312|0,114,1);z=a+480188|0,A=wb(w[f+280|0]|w[f+281|0]<<8),u[z>>1]=A;mh(a,1);e=jc(d,8570);Cb(a+1298368|0,e);rb(e);e=f+32|0;Xf(e,3927);v[22440]=0;o=f+80|3;U(373,d|0,e|0,o|0);d=v[22440];v[22440]=0;c:{if((d|0)!=1){d=f+56|0;Cb(a+1298344|0,d);rb(d);e=f+32|0;Ab(e);g=jc(d,10779);Cb(a+1298356|0,g);rb(g);v[a+1298404>>2]=2;Ie(e,3,f+80|4);xc(d,v[f+32>>2],v[f+36>>2],w[f+40|0]);tc(a+1298308|0,d);rb(d);e=160;while(1){d:{d=e;if(!d){d=0;break d}e=d-1|0;if(w[(f+e|0)+116|0]==32){continue}}break}oT(a+1298332|0,f+116|0,d,4);p=a+480190|0;d=wb(w[f+276|0]|w[f+277|0]<<8);u[p>>1]=d;n=1;while(1){e:{f:{g:{h:{i:{e=d&65535;d=n&65535;if(e>>>0<d>>>0){e=a+484360|0;Qe(Nb(e),wb(w[f+284|0]|w[f+285|0]<<8));d=f+32|0;Td(d,b,512);l=cc(f+56|0,d);sb(d);d=Nb(e);g=w[f+282|0]|w[f+283|0]<<8;v[22440]=0;U(281,d|0,l|0,wb(g)|0);d=v[22440];v[22440]=0;if((d|0)!=1){break i}d=P()|0;O()|0;break h}h=B(d,104)+a|0;l=h+484380|0;ed(l,1);_n(l);nU(b,((d<<5)+a|0)+946304|0,w[o|0]==1?32:28);i=1;d=w[o|0];if(d>>>0>=3){Ob(b,14);d=SA(b);if((d|0)>=0){e=h+484414|0;u[e>>1]=x[e>>1]|32;z=h+484408|0,A=wc((((d&65535)<<8)+2047>>>0)/4095|0,0),u[z>>1]=A}d=w[o|0]}if(d>>>0>=2){i=Ii(b);z=h+484404|0,A=Ii(b),v[z>>2]=A}d=f+56|0;g=cb-16|0;cb=g;j:{if(!Kb(b,12)){v[g>>2]=0;e=d;j=3;while(1){if(j){k=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[e|0]=k;t[e+1|0]=k>>>8;t[e+2|0]=k>>>16;t[e+3|0]=k>>>24;j=j-1|0;e=e+4|0;continue}break}break j}kq(g+8|0,d);md(g,b,v[g+8>>2],v[g+12>>2])}cb=g+16|0;e=bc(d);g=xb(d);m=Wb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));v[l>>2]=m;q=h+484384|0;k=Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[q>>2]=k;r=h+484388|0;s=Wb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))+k|0;v[r>>2]=s;j=h+484414|0;if(k){e=x[j>>1];break f}e=x[j>>1];if(Wb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))>>>0>=3){break f}d=e&-3;break e}d=yb(v[Nb(e)>>2]);g=yb(v[Nb(e)+4>>2]);e=cb-16|0;cb=e;k:{if(!Qb(d,g)){break k}v[e+8>>2]=d;while(1){Ne(e+8|0);h=v[e+8>>2];if(!Qb(h,g)){break k}d=Hl(x[d>>1],x[h>>1])?h:d;continue}}cb=e+16|0;d=x[d>>1];v[22440]=0;n=a+484344|0;q=d+1&65535;R(228,n|0,q|0);d=v[22440];v[22440]=0;if((d|0)!=1){d=w[o|0];v[f+24>>2]=v[a+480204>>2];v[f+20>>2]=v[a+480196>>2];k=d>>>0<4?4:5;r=c&1;j=a+480188|0;e=0;while(1){if((e|0)==(q|0)){if(!(c&2)){break g}c=a+480190|0;d=1;while(1){e=d&65535;if(e>>>0>x[c>>1]){break g}e=B(e,104)+a|0;g=Nc(f+32|0,u[e+484414>>1]&1?16:8,1,1,0);v[22440]=0;Y(222,g|0,e+484380|0,b|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){d=d+1|0;continue}break}d=P()|0;O()|0;break h}l:{if(!r){break l}d=w[f+278|0]|w[f+279|0]<<8;g=x[j>>1];v[22440]=0;d=Q(158,b|0,B(g,B(wb(d),k))|0)|0;g=v[22440];v[22440]=0;m:{n:{if((g|0)==1){break n}if(!d){break l}d=w[f+278|0]|w[f+279|0]<<8;v[22440]=0;d=Y(229,n|0,e&65535,wb(d)|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break n}if(!d){break l}d=x[j>>1];t[f+19|0]=0;g=ae(f+8|0,0,f+19|0);v[22440]=0;p=Y(374,f+32|0,d|0,g|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break m}h=0;o:while(1){if(wb(w[f+278|0]|w[f+279|0]<<8)>>>0<=h>>>0){_c(p);break l}d=0;s=Gf(Sb(n,e),h);while(1){if(x[j>>1]<=d>>>0){h=h+1|0;continue o}t[f+12|0]=0;v[f+8>>2]=0;v[22440]=0;U(375,b|0,f+8|0,k|0);g=v[22440];v[22440]=0;p:{if((g|0)==1){break p}g=B(d,6)+s|0;i=w[f+8|0];if((i-24&255)>>>0<=59){i=i+13|0;t[g|0]=i;z=Xb(v[f+32>>2],d),A=i,t[z|0]=A}m=w[f+9|0];q:{if(!m){i=Xb(v[f+32>>2],d);break q}t[g+1|0]=m;i=Xb(v[f+32>>2],d);t[i+1|0]=m}m=w[i+1|0];i=w[i|0];y=w[o|0];v[22440]=0;Ca(376,a|0,g|0,w[f+10|0],w[f+11|0],0-y|0,i|0,m|0,f+24|0,f+20|0);i=v[22440];v[22440]=0;if((i|0)==1){break p}if(w[f+12|0]){t[g+2|0]=1;t[g+4|0]=w[f+12|0]+1>>>2}d=d+1|0;continue}break}break}d=P()|0;O()|0;_c(p);break h}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}e=e+1|0;continue}}d=P()|0;O()|0}sb(l);break c}sb(l);break b}d=e|2}u[j>>1]=d;if((i|0)==2){u[j>>1]=d|1;v[l>>2]=m>>>1;v[q>>2]=k>>>1;v[r>>2]=s>>>1}z=h+484410|0,A=Ii(b),u[z>>1]=A;d=SA(b);if(d){vl(l,+(d|0)/96)}t[h+484417|0]=d<<4;n=n+1|0;d=x[p>>1];continue}}d=P()|0;O()|0;Ab(f+32|0)}S(d|0);L()}d=1}cb=f+288|0;return d|0}function mea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=cb-144|0;cb=d;sc(c);a:{b:{c:{d:{if(!ao(c,d+128|0)){break d}if(Mb(d+128|0,13901,4)){break d}g=d+136|0;e:{if(!Mb(g,13547,4)){break e}if(!Mb(g,13605,4)){break e}if(Mb(g,14336,4)){break d}}e=cb-32|0;cb=e;l=bf(d+112|0);f:{g:{h:{i:{j:{while(1){v[22440]=0;k=Q(158,c|0,8)|0;i=v[22440];v[22440]=0;if((i|0)==1){break h}if(!k){break i}v[22440]=0;R(815,e|0,c|0);k=v[22440];v[22440]=0;if((k|0)!=1){v[22440]=0;R(816,l|0,e|0);k=v[22440];v[22440]=0;if((k|0)==1){break j}Xc(e);continue}break}a=P()|0;O()|0;break g}a=P()|0;O()|0;Xc(e);break g}cb=e+32|0;break f}a=P()|0;O()|0}Qd(l);S(a|0);L()}v[22440]=0;k=T(176,d+88|0)|0;c=v[22440];v[22440]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if((c|0)!=1){l=Nc(d+84|0,8,1,1,0);if(Mb(g,14336,4)){break t}v[22440]=0;U(731,d- -64|0,d+112|0,1296581714);c=v[22440];v[22440]=0;if((c|0)==1){break q}v[22440]=0;U(731,d+40|0,d+112|0,1296318804);c=v[22440];v[22440]=0;if((c|0)==1){break c}c=d+40|0;e=Sc(k,c);sb(c);c=0;v[22440]=0;g=T(732,d- -64|0)|0;j=v[22440];v[22440]=0;f=1;if((j|0)==1){break c}j=0;if(!g){break u}v[22440]=0;e=T(180,e|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break c}j=0;if(!e){break u}v[22440]=0;j=T(286,d- -64|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}v[22440]=0;g=T(278,d- -64|0)|0;c=v[22440];v[22440]=0;w:{if((c|0)==1){break w}v[22440]=0;Q(190,d- -64|0,2)|0;c=v[22440];v[22440]=0;if((c|0)==1){break w}v[22440]=0;c=T(286,d- -64|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){break v}}break c}f=P()|0;O()|0;break a}v[22440]=0;R(644,d+40|0,d- -64|0);e=v[22440];v[22440]=0;if((e|0)==1){break c}e=d+40|0;h=e;e=hT(e);h=wb(w[h|0]|w[h+1|0]<<8);if(!h){break u}c=(c>>>0)/(h>>>0)|0;f=d+40|0;h=bc(f);i=Oe(f);f=1;h=wb(w[h|0]|w[h+1|0]<<8);if((h|0)!=(wb(w[i|0]|w[i+1|0]<<8)+1|0)){break u}if((h|0)==2){so(l,2)}x:{if((g|0)!=16){if((g|0)!=8){break u}y:{switch(wb(w[e|0]|w[e+1|0]<<8)|0){case 0:Hf(l,1);break x;case 2:Hf(l,17);break x;case 3:break y;default:break u}}Hf(l,16);break x}if(wb(w[e|0]|w[e+1|0]<<8)){break u}kd(l,16)}f=0}sb(d- -64|0);h=0;if(!f){break s}f=0;break k}v[22440]=0;U(731,d- -64|0,d+112|0,1447576658);c=v[22440];v[22440]=0;z:{A:{if((c|0)!=1){v[22440]=0;U(731,d+40|0,d+112|0,1128808782);c=v[22440];v[22440]=0;if((c|0)==1){break A}v[22440]=0;U(731,d+16|0,d+112|0,1112491097);c=v[22440];v[22440]=0;if((c|0)==1){break m}c=d+16|0;i=Sc(k,c);sb(c);v[22440]=0;m=T(180,i|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break z}c=0;e=0;B:{if(!m){break B}v[22440]=0;m=T(180,d- -64|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break z}c=0;e=0;if(!m){break B}v[22440]=0;m=Q(733,d- -64|0,d+16|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break z}c=0;e=0;if(!m){break B}e=Mb(g,13547,4);v[22440]=0;j=T(286,d+40|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break m}if(e){Nc(d+12|0,16,1,0,0);v[d+84>>2]=v[d+12>>2]}if((j|0)==6){so(l,3)}c=d+16|0;g=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c|4;n=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=w[d+28|0]|w[d+29|0]<<8;h=w[d+32|0]|w[d+33|0]<<8|(w[d+34|0]<<16|w[d+35|0]<<24);v[22440]=0;i=T(162,i|0)|0;m=v[22440];v[22440]=0;o=1;if((m|0)==1){break m}e=B((j|0)==6?2:1,e?2:1);j=(i>>>0)/(e>>>0)|0;h=Wb(h);c=wb(c);n=(Wb(n)>>>0)/(e>>>0)|0;e=(Wb(g)>>>0)/(e>>>0)|0}sb(d+40|0);sb(d- -64|0);if(o){break r}break k}f=P()|0;O()|0;break b}f=P()|0;O()|0;break l}break m}e=0}Ts(a,b);v[22440]=0;f=B(b,104)+a|0;g=f+484380|0;R(284,g|0,0);i=v[22440];v[22440]=0;if((i|0)==1){break p}v[g>>2]=j;i=e+n|0;v[f+484388>>2]=i;v[f+484384>>2]=e;if(!(i>>>0<=e+4>>>0|i>>>0>j>>>0)){e=(B(b,104)+a|0)+484414|0;u[e>>1]=x[e>>1]|2}e=B(b,104)+a|0;v[e+484404>>2]=c?c:22050;c=h>>>8|0;u[e+484410>>1]=(h&16776960)>>>0>65536?256:c&65535?c:256;bt(g,v[a+480180>>2]);v[22440]=0;U(731,d- -64|0,d+112|0,1312902469);c=v[22440];v[22440]=0;if((c|0)==1){break o}v[22440]=0;c=T(180,d- -64|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break n}C:{D:{if(c){v[22440]=0;c=T(162,d- -64|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break n}v[22440]=0;U(334,d- -64|0,((b<<5)+a|0)+946304|0,c|0);b=v[22440];v[22440]=0;if((b|0)!=1){break D}break n}v[22440]=0;c=Q(56,d+40|0,21685)|0;e=v[22440];v[22440]=0;if((e|0)==1){break C}uc(((b<<5)+a|0)+946304|0,c);rb(c)}v[22440]=0;Y(222,l|0,g|0,k|0)|0;b=v[22440];v[22440]=0;f=1;if((b|0)==1){break n}Ai(g,a);sb(d- -64|0);break k}break n}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;sb(d- -64|0);break b}f=P()|0;O()|0;sb(d+40|0)}sb(d- -64|0);break b}sb(k);Qd(d+112|0)}cb=d+144|0;return f|0}f=P()|0;O()|0;sb(d- -64|0)}sb(k)}Qd(d+112|0);S(f|0);L()}function Fd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;m=cb-96|0;cb=m;o=i&65535;p=h;A=h<<15|g>>>17;q=(e^i)&-2147483648;l=e&65535;s=l;y=l;l=0;B=(o&131071)<<15|h>>>17;z=i>>>16&32767;J=e>>>16&32767;a:{b:{if(z-32767>>>0>4294934529&J-32767>>>0>=4294934530){break b}k=e&2147483647;j=d;if(!(!j&(k|0)==2147418112?!(b|c):k>>>0<2147418112)){n=d;q=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){n=h;q=i|32768;b=f;c=g;break a}if(!(b|j|(k^2147418112|c))){if(!(f|h|(e|g))){q=2147450880;b=0;c=0;break a}q=q|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){d=b|j;e=c|k;b=0;c=0;if(!(d|e)){q=2147450880;break a}q=q|2147418112;break a}if(!(b|j|(c|k))){b=0;c=0;break a}if(!(f|h|(e|g))){b=0;c=0;break a}if((k|0)==65535|k>>>0<65535){j=b;h=!(d|s);i=h<<6;k=E(h?b:d)+32|0;b=E(h?c:s);b=i+((b|0)==32?k:b)|0;Tf(m+80|0,j,c,d,s,b-15|0);t=16-b|0;d=v[m+88>>2];y=v[m+92>>2];c=v[m+84>>2];b=v[m+80>>2]}if(e>>>0>65535){break b}e=!(o|p);h=e<<6;i=E(e?f:p)+32|0;e=E(e?g:o);e=h+((e|0)==32?i:e)|0;Tf(m- -64|0,f,g,p,o,e-15|0);t=(t-e|0)+16|0;e=v[m+76>>2];i=v[m+72>>2];f=v[m+64>>2];g=v[m+68>>2];A=i<<15|g>>>17;B=(e&131071)<<15|i>>>17}e=f;p=e<<15&-32768;w=c;o=kka(p,0,c,0);c=fb;x=c;e=c;r=(g&131071)<<15|f>>>17;k=0;c=b;i=0;f=kka(r,k,b,i);b=f+o|0;j=fb+e|0;e=b;b=e>>>0<f>>>0?j+1|0:j;h=0;g=kka(c,i,p,i);f=h+g|0;j=fb+e|0;j=f>>>0<g>>>0?j+1|0:j;g=j;C=(e|0)==(j|0)&f>>>0<h>>>0|e>>>0>j>>>0;u=d;K=kka(p,i,d,0);G=fb;j=kka(w,k,r,k);d=j+K|0;h=fb+G|0;h=d>>>0<j>>>0?h+1|0:h;L=d;s=kka(A,0,c,i);d=d+s|0;j=fb+h|0;H=d;j=d>>>0<s>>>0?j+1|0:j;s=j;d=j;j=(b|0)==(x|0)&e>>>0<o>>>0|b>>>0<x>>>0;x=b;b=b+H|0;e=d+j|0;e=b>>>0<x>>>0?e+1|0:e;x=b;o=e;D=y|65536;M=kka(p,i,D,l);I=fb;d=kka(u,n,r,k);b=d+M|0;j=fb+I|0;j=b>>>0<d>>>0?j+1|0:j;N=b;d=kka(w,k,A,n);b=b+d|0;p=j;j=j+fb|0;j=b>>>0<d>>>0?j+1|0:j;O=b;F=B&2147483647|-2147483648;c=kka(F,0,c,i);b=b+c|0;y=j;j=j+fb|0;B=b;i=b>>>0<c>>>0?j+1|0:j;c=0;b=c+x|0;e=e+B|0;e=b>>>0<c>>>0?e+1|0:e;P=b;c=b;b=b+C|0;C=e;j=b>>>0<c>>>0?e+1|0:e;c=j;t=((J+z|0)+t|0)-16383|0;l=kka(u,n,A,n);d=fb;r=kka(r,k,D,n);e=r+l|0;j=fb+d|0;j=e>>>0<r>>>0?j+1|0:j;r=e;e=j;z=(d|0)==(e|0)&l>>>0>r>>>0|d>>>0>e>>>0;l=kka(F,n,w,k);d=l+r|0;j=fb+e|0;j=d>>>0<l>>>0?j+1|0:j;l=d;d=j;k=(e|0)==(j|0)&l>>>0<r>>>0|e>>>0>j>>>0;e=z+k|0;j=0;j=e>>>0<k>>>0?1:j;k=kka(F,n,D,n);e=k+e|0;j=fb+j|0;j=e>>>0<k>>>0?j+1|0:j;k=j;w=l;z=e;e=(h|0)==(G|0)&K>>>0>L>>>0|h>>>0<G>>>0;h=(h|0)==(s|0)&H>>>0<L>>>0|h>>>0>s>>>0;e=e+h|0;j=0;j=e>>>0<h>>>0?1:j;l=e;h=w+e|0;e=d+j|0;e=h>>>0<l>>>0?e+1|0:e;r=h;l=e;e=(e|0)==(d|0)&h>>>0<w>>>0|d>>>0>e>>>0;d=z+e|0;j=k;w=d;e=d>>>0<e>>>0?j+1|0:j;k=kka(F,n,u,n);h=fb;u=kka(A,n,D,n);d=u+k|0;j=fb+h|0;j=d>>>0<u>>>0?j+1|0:j;u=d;d=j;j=(h|0)==(j|0)&k>>>0>u>>>0|h>>>0>j>>>0;k=d+w|0;e=e+j|0;e=k>>>0<d>>>0?e+1|0:e;w=k;k=0;d=k+r|0;j=l+u|0;j=d>>>0<k>>>0?j+1|0:j;h=j;k=(l|0)==(j|0)&d>>>0<r>>>0|j>>>0<l>>>0;l=w+k|0;u=l;l=l>>>0<k>>>0?e+1|0:e;k=d;e=(p|0)==(I|0)&M>>>0>N>>>0|p>>>0<I>>>0;p=(p|0)==(y|0)&N>>>0>O>>>0|p>>>0>y>>>0;e=e+p|0;e=e+((i|0)==(y|0)&B>>>0<O>>>0|i>>>0<y>>>0)|0;d=i+d|0;e=h+e|0;e=d>>>0<i>>>0?e+1|0:e;i=(e|0)==(h|0)&d>>>0<k>>>0|e>>>0<h>>>0;h=i+u|0;j=l;p=h;h=h>>>0<i>>>0?j+1|0:j;l=d;i=e;d=(o|0)==(s|0)&x>>>0<H>>>0|o>>>0<s>>>0;o=(o|0)==(C|0)&x>>>0>P>>>0|o>>>0>C>>>0;d=d+o|0;j=0;j=d>>>0<o>>>0?1:j;o=d;d=l+d|0;e=e+j|0;e=d>>>0<o>>>0?e+1|0:e;l=(e|0)==(i|0)&d>>>0<l>>>0|e>>>0<i>>>0;i=l+p|0;j=h;h=i;j=h>>>0<l>>>0?j+1|0:j;i=j;c:{if(j&65536){t=t+1|0;break c}o=g>>>31|0;l=0;j=i<<1|h>>>31;h=h<<1|e>>>31;i=j;j=e<<1|d>>>31;d=d<<1|c>>>31;e=j;j=g<<1|f>>>31;f=f<<1;g=j;j=c<<1|b>>>31;b=b<<1|o;c=j|l}if((t|0)>=32767){q=q|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){j=1-t|0;if(j>>>0>=128){b=0;c=0;break a}l=t+127|0;Tf(m+48|0,f,g,b,c,l);Tf(m+32|0,d,e,h,i,l);qm(m+16|0,f,g,b,c,j);qm(m,d,e,h,i,j);f=v[m+32>>2]|v[m+16>>2]|(v[m+48>>2]|v[m+56>>2]|(v[m+52>>2]|v[m+60>>2]))!=0;g=v[m+36>>2]|v[m+20>>2];b=v[m+40>>2]|v[m+24>>2];c=v[m+44>>2]|v[m+28>>2];d=v[m>>2];e=v[m+4>>2];i=v[m+12>>2];h=v[m+8>>2];break d}i=i&65535|t<<16}n=h|n;q=i|q;if(!(!b&(c|0)==-2147483648?!(f|g):(c|0)>0|(c|0)>=0)){b=d+1|0;h=b?e:e+1|0;c=h;f=(e|0)==(h|0)&b>>>0<d>>>0|e>>>0>h>>>0;d=f+n|0;e=q;n=d;q=d>>>0<f>>>0?e+1|0:e;break a}if(b|f|(c^-2147483648|g)){b=d;c=e;break a}h=q;c=d&1;b=c+d|0;j=b>>>0<c>>>0?e+1|0:e;c=j;e=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;d=e+n|0;n=d;q=d>>>0<e>>>0?h+1|0:h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=n;v[a+12>>2]=q;cb=m+96|0}function jM(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;f=cb-16|0;cb=f;a:{if(!Rc(d&255)){break a}o=a+1074376|0;l=(o+B(b,872)|0)+616|0;b:{c:{d:{e:{f:{if(!(v[a+480180>>2]&17825824)){break f}g=x[a+480192>>1];if(!g){break f}if(!e){break e}}e=B(b,872)+a|0;if(!dk(v[e+1075648>>2])){break d}g=x[a+480192>>1]}e=B(b,872)+a|0;m=v[e+1075096>>2];c=c>>>0>g>>>0?0:c;p=e+1075648|0;h=v[(c?((c<<2)+a|0)+900380|0:p)>>2];if(!h){break b}i=d-1|0;c=x[Xb(h+236|0,i)>>1];g=a+1074312|0;ub(f+8|0,g,104);g:{if(tb(v[v[f+8>>2]>>2],v[f+12>>2])){ub(f,g,34);if(tb(v[v[f>>2]>>2],v[f+4>>2])){break g}}d=w[Eb(h+108|0,i)|0]}if((c-1&65535)>>>0>3998){break c}m=(B(c,104)+a|0)+484380|0;break b}d=e+1075068|0;if(!v[d>>2]){break a}c=B(b,872)+a|0;e=v[c+1075080>>2];if(e&1024){break a}g=c+1075012|0;c=c+1075016|0;if(!(v[g>>2]|v[c>>2])){break a}h:{if(!(e&512)){break h}e=a+1298300|0;if(!Bd(e)){break h}pj(v[e>>2],b,0);break a}e=wy(a,b);if((e|0)==65535){break a}j=B(e,872);e=a+1074992|0;a=j+e|0;wp(a,l);t[a+831|0]=0;t[a+805|0]=0;u[a+786>>1]=b+1;v[a+88>>2]=v[a+88>>2]&-918529;Rn(a+788|0);v[a+696>>2]=0;v[a+88>>2]=v[a+88>>2]|2101248;v[d>>2]=0;v[l>>2]=0;v[l+4>>2]=0;a=e+B(b,872)|0;v[a+92>>2]=0;v[a+96>>2]=0;v[g>>2]=0;v[c>>2]=0;break a}ub(f+8|0,g,43);if(!tb(v[v[f+8>>2]>>2],v[f+12>>2])){break b}if(!sj(w[h+31|0])){break a}}if(w[e+1075081|0]&4){break a}r=b>>>0>256?b:256;g=a+1298300|0;n=a+1074312|0;s=b+1|0;y=a+480188|0;c=b;i:{while(1){if((c|0)==(r|0)){j:{e=0;c=0;if(!dk(v[p>>2])){break i}c=0;if(!Rc(w[(B(b,872)+a|0)+1075789|0])){break i}d=Il(a,o,b,2,1);c=0;if((d-1&255)>>>0>249){break i}e=v[(B(d,160)+a|0)+906140>>2];if(e){break j}e=0;c=0;break i}}else{k:{if((b|0)!=(c|0)&x[y>>1]>c>>>0){break k}e=B(c,872)+a|0;if(x[e+1075778>>1]!=(s|0)&(b|0)!=(c|0)){break k}q=e+1075648|0;i=v[q>>2];if(!i){break k}k=e+1074992|0;l:{m:{n:{o:{p:{q:{r:{switch(w[i+17|0]-1|0){case 0:if(!d){break k}j=w[e+1075789|0]==(d|0)&(h|0)==(i|0);if(!h){break q}if(j){break n}break k;case 1:if(!m|v[e+1075096>>2]!=(m|0)){break k}if((h|0)==(i|0)){break l}ub(f+8|0,n,104);if(!tb(v[v[f+8>>2]>>2],v[f+12>>2])){break l}break k;case 3:break p;case 2:break r;default:break k}}if(h){break o}j=(h|0)==(i|0)}if(j){break l}break k}if(!h){break k}j=w[h+34|0];if(!j){break k}if((j|0)==w[i+34|0]){break m}break k}if((h|0)!=(i|0)){break k}}if(!w[h+34|0]){break l}}if(!w[e+1075789|0]|w[i+18|0]>2){break l}ub(f+8|0,n,34);gm(a,c&65535,HO(k,tb(v[v[f+8>>2]>>2],v[f+12>>2]))+255|0,0);t[e+1075792|0]=0}s:{t:{switch(w[v[q>>2]+18|0]){case 0:Bn(a,k);v[e+1075680>>2]=0;if(!(w[e+1075081|0]&2)){break s}if(!Bd(g)){break s}pj(v[g>>2],c&65535,1);break s;case 1:Bn(a,k);if(!(w[e+1075081|0]&2)){break s}if(!Bd(g)){break s}fk(v[g>>2],c&65535);break s;case 2:break t;default:break s}}k=e+1075080|0;i=v[k>>2];v[k>>2]=i|4096;if(!(i&512)){break s}if(!Bd(g)){break s}ub(f+8|0,n,105);if(tb(v[v[f+8>>2]>>2],v[f+12>>2])){break s}fk(v[g>>2],c&65535)}if(v[e+1075680>>2]){break k}v[e+1075688>>2]=0;e=e+1075080|0;v[e>>2]=v[e>>2]|2101248}c=c+1|0;continue}break}ub(f+8|0,n,34);c=(A=e,C=HO(l,tb(v[v[f+8>>2]>>2],v[f+12>>2])),D=b,z=v[v[e>>2]+100>>2],gb[z](A|0,C|0,D|0)|0)}d=(B(b,872)+a|0)+1075e3|0;if(!(zi(v[d>>2],v[d+4>>2])?1:c)){break a}h=wy(a,b);if((h|0)==65535){break a}i=B(h,872)+a|0;d=i+1075080|0;m=i+1074992|0;u:{if(!(w[i+1075081|0]&2)){break u}if(!Bd(g)){break u}pj(v[g>>2],h,1)}m=wp(m,l);v[d>>2]=v[d>>2]&-917505;t[i+1075823|0]=0;k=x[a+480188>>1];t[i+1075797|0]=0;u[i+1075778>>1]=b>>>0<k>>>0?b+1|0:0;v:{if(!(c&(e|0)!=0)){break v}c=w[(B(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break v}gm(a,b,255,0);t[(B(b,872)+a|0)+1075792|0]=0}w:{x:{switch(w[(B(b,872)+a|0)+1075790|0]){case 2:Bn(a,m);if(!(w[d+1|0]&2)){break w}if(!Bd(g)){break w}fk(v[g>>2],b);ub(f+8|0,n,105);if(!tb(v[v[f+8>>2]>>2],v[f+12>>2])){break w}bz(v[g>>2],b,h);break w;case 0:v[(B(h,872)+a|0)+1075688>>2]=0;c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break w}if(!Bd(g)){break w}pj(v[g>>2],b,1);break w;case 3:c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break w}if(!Bd(g)){break w}ub(f+8|0,n,105);e=tb(v[v[f+8>>2]>>2],v[f+12>>2]);c=v[g>>2];if(e){bz(c,b,h);break w}fk(c,b);break w;case 1:break x;default:break w}}if(!(w[d+1|0]&2)){break w}if(!Bd(g)){break w}bz(v[g>>2],b,h)}if(!v[(B(h,872)+a|0)+1075680>>2]){v[(B(h,872)+a|0)+1075688>>2]=0;v[d>>2]=v[d>>2]|2101248}a=B(b,872)+a|0;v[a+1075068>>2]=0;v[l>>2]=0;v[l+4>>2]=0;a=a+1075084|0;v[a>>2]=0;v[a+4>>2]=0}cb=f+16|0}function Zda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;g=cb-208|0;cb=g;sc(b);a:{b:{c:{if(!XA(b,g+160|0)){break c}if(!iP(g+160|0)){break c}if(!c){h=1;break c}if(!Kb(b,wc(hP(w[g+207|0]),fb))){break c}ud(a,128);h=g+144|0;Ie(h,2,g+175|0);d=g+72|0;xc(d,v[g+144>>2],v[g+148>>2],w[g+152|0]);tc(a+1298308|0,d);rb(d);e=jc(d,8482);Cb(a+1298344|0,e);rb(e);e=jc(d,6059);Cb(a+1298356|0,e);rb(e);h=jc(h,17571);v[22440]=0;U(746,d|0,h|0,v[(w[g+174|0]<<2)+26972>>2]);d=v[22440];v[22440]=0;if((d|0)==1){break b}d=g+72|0;Cb(a+1298368|0,d);rb(d);rb(h);v[a+480208>>2]=12;v[a+1298404>>2]=5;oB(a+1298332|0,b,w[g+207|0]<<5,32,0);k=a+480190|0;d=He(b);u[k>>1]=d;h=1;while(1){l=h&65535;if(l>>>0>(d&65535)>>>0){Zn(Nb(a+484360|0),b,256,255,254);h=0;d=He(b);if(d>>>0>=127){break c}f=a+480188|0;u[f>>1]=d+1;e=He(b);while(1){if(x[f>>1]<=h>>>0){p=a+484344|0;s=e+1|0;wg(p,s);d=0;while(1){f=d&65535;if(f>>>0>e>>>0){y=a+480188|0;d:while(1){e:{A=z&65535;h=x[y>>1];if(A>>>0>=h>>>0){d=g+8|0;e=Nn(d);t[d+16|0]=0;u[d+14>>1]=0;u[d+12>>1]=h;v[22440]=0;R(748,e|0,h|0);h=v[22440];v[22440]=0;if((h|0)==1){a=P()|0;O()|0;Re(e);S(a|0);L()}v[22440]=0;U(747,g+32|0,p|0,d|0);e=v[22440];v[22440]=0;h=1;if((e|0)==1){break e}Re(g+32|0);Re(d);if(!(c&2)){break c}c=a+480190|0;d=1;while(1){e=d&65535;if(e>>>0>x[c>>1]){break c}e=B(e,104)+a|0;vg(Nc(g+72|0,u[e+484414>>1]&1?16:8,1,0,0),e+484380|0,b);d=d+1|0;continue}}q=0;e=tg(g+72|0);while(1){f:{if((q|0)!=(s|0)){if(Kb(b,5)){break f}}z=z+1|0;continue d}d=0;h=Zc(Sb(p,q),0,A);while(1){k=w[g+174|0];m=cb-32|0;cb=m;r=1;f=He(b);if((f|0)==252){r=He(b);f=He(b)}t[e|0]=(f-1&255)>>>0<60?f+36|0:0;f=m+24|0;Gm(f,b);j=Ec(f);l=Oe(f);n=Li(f);t[e+1|0]=w[f|0];i=m+16|0;fP(i,w[j|0]&15,w[l|0],k);l=Ec(i);f=m+8|0;fP(f,w[j|0]>>>4|0,w[n|0],k);k=Ec(f);n=w[i|0];o=(n|0)!=10;j=w[f|0];g:{if(!(o|(j|0)!=10)){i=w[l|0];f=w[k|0];t[e+3|0]=10;i=i|f<<8;t[e+5|0]=i>>>6;if(i>>>0<16384){break g}t[e+2|0]=15;t[e+4|0]=f>>>6;break g}h:{i:{j:{k:{l:{if(!o){n=w[l|0];o=n<<2;C=l,D=El(o),t[C|0]=D;if(n>>>0<64){break l}j=w[f|0];if(Ji(j)>>>0>=rz(10)>>>0){break k}t[e+5|0]=o;t[e+2|0]=15;t[e+3|0]=10;t[e+4|0]=n>>>6;break g}if((j|0)==10){j=w[k|0];n=j<<2;C=k,D=El(n),t[C|0]=D;if(j>>>0<64){break l}if(Ji(w[i|0])>>>0>=rz(10)>>>0){break l}t[e+5|0]=n;t[e+2|0]=15;t[e+3|0]=10;t[e+4|0]=j>>>6;break g}if((j|0)!=(n|0)){break l}t[f|0]=0;break j}j=w[f|0]}if((j|0)==13){break i}if(j){break h}}if(w[i|0]==13){break h}}xh(i,f);xh(l,k)}Bu(f,k,i,l);io(m,e,w[i|0],w[l|0],w[f|0],w[k|0])}cb=m+32|0;i=d+r|0;d=i>>>0>64?64-d|0:r;if(d){while(1){if(d){f=v[g+72>>2];t[h|0]=f;t[h+1|0]=f>>>8;t[h+2|0]=f>>>16;t[h+3|0]=f>>>24;f=x[g+76>>1];t[h+4|0]=f;t[h+5|0]=f>>>8;d=d-1|0;h=B(x[y>>1],6)+h|0;continue}break}f=i>>>0<64;d=f?i:64;if(f){continue}}break}q=q+1|0;continue}}break}a=P()|0;O()|0;Re(d);break a}d=d+1|0;h=0;if(nh(p,f,64)){continue}break}}else{d=(h<<5)+a|0;$e(d+480280|0);i=d+480284|0;m:{if(w[g+174|0]>=51){d=(He(b)<<4|8)&248;break m}d=h&1?192:64}u[i>>1]=d;h=h+1|0;continue}break}}else{n:{if(w[g+174|0]>=52){d=g+72|0;if(!ZT(b,d)){qB(d)}break n}e=cb-32|0;cb=e;v[e+28>>2]=64;v[e+8>>2]=66;d=v[Bb(e+28|0,e+8|0)>>2];if(!Kb(b,d)){d=_e(b)}f=e+8|0;i=g+72|0;ju(f,i);m=$b(e+16|0,v[e+8>>2],d);Yb(e,b,v[m>>2],v[m+4>>2]);ju(f,i);Hb(v[e+8>>2]+d|0,0,66-d|0);Ob(b,v[e+28>>2]);cb=e+32|0;d=w[g+134|0]|w[g+135|0]<<8;t[g+136|0]=d;t[g+137|0]=d>>>8;t[g+134|0]=171;t[g+135|0]=32}i=cb-32|0;cb=i;e=(B(l,104)+a|0)+484380|0;ed(e,0);_n(e);d=g+72|0;sk(i,2,d+32|0);f=i+16|0;xc(f,v[i>>2],v[i+4>>2],w[i+8|0]);pe(e+43|0,f);rb(f);f=w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24);m=w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24);o:{if(f>>>0<=m>>>0){break o}v[e>>2]=f-m;v[e+12>>2]=w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24);v[i+16>>2]=w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24);C=e,D=v[Bb(i+16|0,e)>>2],v[C+16>>2]=D;u[e+30>>1]=w[d+60|0];v[e+24>>2]=w[d+62|0]|w[d+63|0]<<8;f=d- -64|0;f=w[f|0]|w[f+1|0]<<8;if(f){vl(e,+(f<<16>>16)/393216)}f=w[d+61|0];if(f&8){u[e+34>>1]=x[e+34>>1]|8;f=w[d+61|0]}if(f&16){u[e+34>>1]=x[e+34>>1]|16;f=w[d+61|0]}if(!(f&4)){break o}u[e+34>>1]=x[e+34>>1]|1;v[e+12>>2]=v[e+12>>2]>>>1;v[e+16>>2]=v[e+16>>2]>>>1}cb=i+32|0;Ie(g+56|0,2,d);d=g+144|0;xc(d,v[g+56>>2],v[g+60>>2],w[g+64|0]);uc(((l<<5)+a|0)+946304|0,d);h=h+1|0;rb(d);d=x[k>>1];continue}break}}cb=g+208|0;return h|0}a=P()|0;O()|0;rb(h)}S(a|0);L()}function zfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=cb-112|0;cb=f;sc(b);a:{b:{c:{d:{e:{if(!OQ(b,14222)){break e}i=Rb(f+96|0);j=Rb(f+80|0);v[22440]=0;v[f+72>>2]=0;v[f+76>>2]=0;R(252,a|0,32768);d=v[22440];v[22440]=0;if((d|0)==1){break b}v[22440]=0;d=Q(1,f+40|0,8198)|0;h=v[22440];v[22440]=0;if((h|0)==1){break c}Cb(a+1298344|0,d);rb(d);v[22440]=0;d=Q(1,f+40|0,6063)|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}Cb(a+1298356|0,d);rb(d);v[a+1298404>>2]=2;m=a+484360|0;h=f- -64|4;k=a+480280|0;while(1){v[22440]=0;d=Q(158,b|0,8)|0;e=v[22440];v[22440]=0;f:{g:{h:{if((e|0)!=1){i:{j:{k:{l:{m:{n:{if(!d){break n}v[22440]=0;d=Q(643,b|0,f- -64|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break m}if(!d){break n}d=h;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[22440]=0;U(192,f+16|0,b|0,Wb(d)|0);d=v[22440];v[22440]=0;if((d|0)==1){break l}d=f+40|0;e=f+16|0;g=cc(d,e);sb(e);v[22440]=0;d=T(180,d|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break j}if(d){break k}sb(f+40|0)}if(x[a+480188>>1]){break i}d=0;break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}o:{p:{q:{r:{s:{t:{d=f- -64|0;d=Wb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));if((d|0)!=1397769541){if((d|0)==1346458708){break s}if((d|0)==1346522948){break r}if((d|0)==1347175758){break t}if((d|0)!=1396788560){if((d|0)==1396854596){break q}if((d|0)==1397507406){break f}if((d|0)!=1129140036){break p}if(x[a+480188>>1]){break f}v[22440]=0;d=T(162,f+40|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break j}if(d>>>0<8){break f}e=0;v[22440]=0;R(644,f+16|0,g|0);d=v[22440];v[22440]=0;if((d|0)==1){break j}while(1)if((e|0)==4){if(c){break f}d=1;break o}else{d=x[a+480188>>1];g=Xb(f+16|0,e);u:{if(!wb(w[g|0]|w[g+1|0]<<8)){g=(e&3)-1|0;break u}g=f+72|0;o=Eb(g,d),p=1,t[o|0]=p;o=Eb(g,x[a+480188>>1]+1|0),p=255,t[o|0]=p;$e(k+(x[a+480188>>1]<<5)|0);g=x[a+480188>>1];d=g+1|0;u[a+480188>>1]=d;l=k+(g<<5)|0;g=(e&3)-1|0;u[l+4>>1]=g>>>0<2?192:64}$e(k+((d&65535)<<5)|0);d=x[a+480188>>1];u[a+480188>>1]=d+1;u[(k+(d<<5)|0)+4>>1]=g>>>0<2?192:64;e=e+1|0;continue}}if(x[a+480190>>1]){break f}v[22440]=0;R(645,g|0,a|0);d=v[22440];v[22440]=0;if((d|0)!=1){break f}break j}v[22440]=0;d=T(162,f+40|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break j}if(d>>>0<2){break f}v[22440]=0;d=T(278,g|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break j}o=a,p=wd(d,1,255),v[o+480196>>2]=p;break f}v[22440]=0;d=T(162,f+40|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break j}if(d>>>0<2){break f}v[22440]=0;n=T(278,g|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){break f}break j}d=Nb(m);v[22440]=0;e=T(162,f+40|0)|0;l=v[22440];v[22440]=0;if((l|0)==1){break j}v[22440]=0;ea(351,d|0,g|0,e|0,255,254)|0;d=v[22440];v[22440]=0;if((d|0)!=1){break f}break j}if(Df(v[i>>2],v[i+4>>2])>>>0>255){break f}v[22440]=0;R(646,i|0,g|0);d=v[22440];v[22440]=0;if((d|0)==1){break j}break f}if(Df(v[j>>2],v[j+4>>2])>>>0>3998){break f}v[22440]=0;d=T(162,f+40|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break j}if(!d){break f}v[22440]=0;R(646,j|0,g|0);d=v[22440];v[22440]=0;if((d|0)!=1){break f}break j}if(!(d&-2139062144)){break f}d=0}sb(f+40|0);break g}a=P()|0;O()|0;sb(f+40|0);break a}v[a+480200>>2]=256;v[a+480204>>2]=125e4;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=48;v[a+480232>>2]=48;b=Nb(m);v[22440]=0;R(333,b|0,n&65535);b=v[22440];v[22440]=0;if((b|0)==1){break b}v:{if(!(c&1)){break v}b=v[i+4>>2];d=v[i>>2];e=0;v[22440]=0;R(228,a+484344|0,Df(d,b)&65535);b=v[22440];v[22440]=0;if((b|0)==1){break b}while(1){h=v[i>>2];b=e&65535;if(Df(h,v[i+4>>2])>>>0<=b>>>0){break v}v[22440]=0;d=v[f+76>>2];g=v[f+72>>2];v[f+8>>2]=g;v[f+12>>2]=d;v[f>>2]=g;v[f+4>>2]=d;W(647,Ng(h,b)|0,b|0,a|0,f|0);b=v[22440];v[22440]=0;if((b|0)!=1){e=e+1|0;continue}break}a=P()|0;O()|0;break a}h=c&2;d=1;e=1;b=0;while(1){if(x[a+480190>>1]<=e>>>0){break g}if(!h|Df(v[j>>2],v[j+4>>2])>>>0<=b>>>0){break g}c=(B(e,104)+a|0)+484380|0;Jz(c);w:{if(v[c>>2]){g=v[j>>2];v[22440]=0;g=T(162,Ng(g,b)|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break h}qc(c,g);g=Nc(f+40|0,8,1,1,0);k=v[j>>2];v[22440]=0;Y(222,g|0,c|0,Ng(k,b)|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break w}b=b+1|0}e=e+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}Ic(j);Ic(i);break e}sb(f+40|0);continue}}cb=f+112|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Ic(j);Ic(i);S(a|0);L()}function Zfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=cb-208|0;cb=d;sc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!ao(b,d+192|0)){break l}if(!cR(d+192|0)){break l}j=ai(d+168|0);k=Db(d+152|0);bu(d+88|0);v[22440]=0;e=Q(611,b|0,d+80|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break h}m:{if(!e){break m}e=d+80|4;h=Wb(Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-4|0);t[e|0]=h;t[e+1|0]=h>>>8;t[e+2|0]=h>>>16;t[e+3|0]=h>>>24;h=0;while(1){f=Wb(Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-8|0);t[e|0]=f;t[e+1|0]=f>>>8;t[e+2|0]=f>>>16;t[e+3|0]=f>>>24;n:{if(c){break n}f=d+80|0;if((Wb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))|0)!=1347699796){break n}h=1;break m}f=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[22440]=0;U(192,d+56|0,b|0,Wb(f)|0);f=v[22440];v[22440]=0;if((f|0)==1){break d}g=d+8|0;i=d+56|0;f=cc(g,i);sb(i);v[22440]=0;i=T(180,g|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break b}o:{if(!i){break o}p:{g=d+80|0;g=Wb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));if((g|0)!=1129139796){if((g|0)!=1229866575){if((g|0)==1347699796){break p}if((g|0)!=1447383635){break o}v[22440]=0;Q(190,d+8|0,4)|0;g=v[22440];v[22440]=0;if((g|0)==1){break b}v[22440]=0;g=T(612,f|0)|0;l=v[22440];v[22440]=0;if((l|0)==1){break b}if(!g){break o}g=Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));if(g>>>0<7){break o}v[22440]=0;U(613,f|0,k|0,g-6|0);f=v[22440];v[22440]=0;if((f|0)==1){break b}break o}v[22440]=0;m=Q(614,f|0,d+88|0)|0;f=v[22440];v[22440]=0;if((f|0)!=1){break o}break b}ev(j,f);break o}v[22440]=0;h=Y(615,a|0,f|0,c|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break b}}sb(d+8|0);if(i){v[22440]=0;f=Q(611,b|0,d+80|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break i}if(f){continue}}break}if(xd(k)){v[22440]=0;b=Q(1,d+8|0,14973)|0;c=v[22440];v[22440]=0;if((c|0)==1){break g}Cb(k,b);rb(b)}q:{if(!(h&m&1)){break q}b=d+130|0;b=w[b|0]|w[b+1|0]<<8;v[22440]=0;c=wb(b)&256;Y(271,a+1074312|0,5,!c|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break f}b=d+126|0;if(wb(w[b|0]|w[b+1|0]<<8)){u[d+8>>1]=64;n=d,o=wb(w[b|0]|w[b+1|0]<<8),u[n+56>>1]=o;n=a,o=x[Kc(d+8|0,d+56|0)>>1],v[n+480228>>2]=o}b=d+128|0;b=wb(w[b|0]|w[b+1|0]<<8);if(!(!c|!b)){v[a+480204>>2]=B(b,1e4)}if(w[d+88|0]){Ie(d+56|0,2,d+88|0);v[22440]=0;W(225,d+8|0,v[d+56>>2],v[d+60>>2],w[d+64|0]);b=v[22440];v[22440]=0;if((b|0)==1){break e}b=d+8|0;tc(a+1298308|0,b);rb(b)}c=d+134|0;if(!Vp(c,1,12)){break q}e=d+132|0;if(!Vp(e,1,31)){break q}f=d+138|0;if(!Vp(f,0,23)){break q}g=d+140|0;if(!Vp(g,0,59)){break q}i=d+142|0;if(!Vp(i,0,59)){break q}b=eo(d+8|0);l=d+136|0;n=b,o=wb(w[l|0]|w[l+1|0]<<8),v[n+20>>2]=o;n=b,o=wb(w[c|0]|w[c+1|0]<<8)-1|0,v[n+16>>2]=o;n=b,o=wb(w[e|0]|w[e+1|0]<<8),v[n+12>>2]=o;n=b,o=wb(w[f|0]|w[f+1|0]<<8),v[n+8>>2]=o;n=b,o=wb(w[g|0]|w[g+1|0]<<8),v[n+4>>2]=o;n=b,o=wb(w[i|0]|w[i+1|0]<<8),v[n>>2]=o;v[22440]=0;R(446,a+1298408|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break q}a=P()|0;O()|0;break a}if(h&1){v[22440]=0;b=T(180,j|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break h}if(b){b=Db(d+8|0);v[22440]=0;U(275,j|0,b|0,32);c=v[22440];v[22440]=0;if((c|0)==1){break c}if(gq(b,13819)){v[22440]=0;U(11,d+56|0,2,b|0);c=v[22440];v[22440]=0;if((c|0)==1){break c}c=d+56|0;Cb(a+1298320|0,c);rb(c)}v[22440]=0;c=T(616,j|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}if(!c){v[22440]=0;c=T(204,j|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}v[22440]=0;ga(320,a+1298332|0,j|0,c|0,40,0);c=v[22440];v[22440]=0;if((c|0)==1){break c}}rb(b)}v[22440]=0;b=Q(1,d+56|0,17559)|0;c=v[22440];v[22440]=0;if((c|0)==1){break k}v[22440]=0;U(490,d+8|0,b|0,k|0);c=v[22440];v[22440]=0;if((c|0)==1){break j}c=d+8|0;Cb(a+1298368|0,c);rb(c);rb(b)}v[a+480208>>2]=v[a+480208>>2]|2097152;v[22440]=0;a=Y(271,a+1074312|0,84,1)|0;b=v[22440];v[22440]=0;if((b|0)==1){break h}v[22440]=0;a=Y(271,a|0,83,1)|0;b=v[22440];v[22440]=0;if((b|0)==1){break h}v[22440]=0;Q(272,a|0,85)|0;a=v[22440];v[22440]=0;if((a|0)==1){break h}}rb(k);sb(j)}cb=d+208|0;return h&1}a=P()|0;O()|0;break a}a=P()|0;O()|0;rb(b);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;rb(b);break a}a=P()|0;O()|0;sb(d+8|0)}rb(k);sb(j);S(a|0);L()}function uV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=cb-112|0;cb=e;sc(b);a:{if(!yq(b,11810)){break a}if(!Hu(b,e+96|0)){break a}if(!aC(e+96|0)){break a}if(!Kb(b,wc($B(e+96|0),fb))){break a}if(!Ob(b,w[e+105|0]|w[e+106|0]<<8)){break a}b:{if(!c){break b}ud(a,4096);v[a+480208>>2]=12;d=e+96|0;u[a+480188>>1]=(w[d|2]&31)+1;g=a+480190|0;i=d|3;u[g>>1]=w[i|0];mh(a,1);k=e+24|0;h=jc(k,8505);Cb(a+1298344|0,h);rb(h);h=jc(k,7053);Cb(a+1298356|0,h);rb(h);h=cb-16|0;cb=h;f=jc(h,4250);zc(e,f);rb(f);cb=h+16|0;v[22440]=0;W(235,k|0,e|0,d|1,d|0);d=v[22440];v[22440]=0;c:{if((d|0)!=1){d=e+24|0;Cb(a+1298368|0,d);rb(d);Ab(e);v[a+1298404>>2]=5;d=w[i|0];k=e+80|0;v[k>>2]=0;v[k+4>>2]=0;og(k+8|0,0);if(d){Dq(k,d);QC(k,d,0)}d=1;d:{while(1){h=d&65535;if(h>>>0>x[g>>1]){v[22440]=0;Q(236,b|0,a+1298308|0)|0;h=v[22440];v[22440]=0;d=1;e:{if((h|0)==1){break e}h=a+480190|0;while(1){g=d&65535;if(g>>>0>x[h>>1]){d=0;h=a+480188|0;f:{while(1){if(x[h>>1]<=d>>>0){h=e+96|4;d=w[h|0]|w[h+1|0]<<8;v[22440]=0;i=a+484344|0;R(228,i|0,d|0);d=v[22440];v[22440]=0;if((d|0)==1){break e}d=0;break f}g=(d<<5)+a|0;$e(g+480280|0);v[22440]=0;R(237,b|0,g+480289|0);g=v[22440];v[22440]=0;if((g|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}g:{h:{i:{j:{while(1){if((w[h|0]|w[h+1|0]<<8)>>>0<=d>>>0){v[22440]=0;f=T(196,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break h}if(!f){break i}v[22440]=0;d=Q(158,b|0,f|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break h}if(d){break j}break i}v[22440]=0;g=Q(238,b|0,e+24|0)|0;f=v[22440];v[22440]=0;k:{if((f|0)==1){break k}v[22440]=0;f=Y(229,i|0,d&65535,64)|0;j=v[22440];v[22440]=0;if((j|0)==1){break k}if((f&g)==1){g=Sb(i,d);v[22440]=0;R(239,g|0,e+24|0);g=v[22440];v[22440]=0;if((g|0)==1){break k}}d=d+1|0;continue}break}b=P()|0;O()|0;break d}g=Rb(e+24|0);v[22440]=0;U(240,b|0,g|0,f|0);d=v[22440];v[22440]=0;l:{if((d|0)!=1){d=Db(e);v[22440]=0;R(47,d|0,f|0);f=v[22440];v[22440]=0;m:{if((f|0)==1){break m}m=e,n=yb(v[g>>2]),v[m+48>>2]=n;j=yb(v[g+4>>2]);while(1){n:{f=v[e+48>>2];if(!Qb(f,j)){v[22440]=0;W(241,e+48|0,5,6,d|0);f=v[22440];v[22440]=0;if((f|0)==1){break n}j=e+48|0;f=tc(d,j);rb(j);j=Fb(f);l=vb(f);v[22440]=0;ga(242,a+1298332|0,j|0,l|0,76,0);j=v[22440];v[22440]=0;if((j|0)==1){break m}rb(f);_b(g);break i}o:{f=w[f|0];if(f&128){m=e,n=gf(d),v[m+64>>2]=n;kj(e+72|0,e- -64|0);v[22440]=0;W(243,d|0,v[e+72>>2],f&127,32);f=v[22440];v[22440]=0;if((f|0)!=1){break o}break m}v[22440]=0;R(48,d|0,f<<24>>24);f=v[22440];v[22440]=0;if((f|0)!=1){break o}break m}Fe(e+48|0);continue}break}}b=P()|0;O()|0;rb(d);break l}b=P()|0;O()|0}_b(g);break d}d=Nb(a+484360|0);g=e+96|6;g=w[g|0]|w[g+1|0]<<8;v[22440]=0;ea(244,d|0,b|0,g|0,65535,65535)|0;d=v[22440];v[22440]=0;if((d|0)==1){break h}g=c&1;d=0;while(1){p:{q:{if((w[h|0]|w[h+1|0]<<8)>>>0>d>>>0){v[22440]=0;f=Q(158,b|0,4)|0;j=v[22440];v[22440]=0;if((j|0)==1){break p}if(f){break q}}if(!(c&2)){break g}h=a+480190|0;d=1;while(1){c=d&65535;if(c>>>0>x[h>>1]){break g}g=B(c,104)+a|0;i=x[g+484414>>1];ub(e+24|0,v[k>>2],c-1|0);c=Nc(e,i&1?16:8,1,0,tb(v[v[e+24>>2]>>2],v[e+28>>2])?6:0);v[22440]=0;Y(222,c|0,g+484380|0,b|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}v[22440]=0;f=T(159,b|0)|0;j=v[22440];v[22440]=0;r:{s:{if((j|0)!=1){v[22440]=0;U(192,e|0,b|0,f|0);f=v[22440];v[22440]=0;if((f|0)==1){break s}f=cc(e+24|0,e);sb(e);if(!g){break r}if(!ve(i,d&65535)){break r}j=Sb(i,d);v[22440]=0;U(245,j|0,0,f|0);f=v[22440];v[22440]=0;if((f|0)!=1){break r}b=P()|0;O()|0;sb(e+24|0);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}d=d+1|0;sb(e+24|0);continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}Re(k);break b}v[22440]=0;Q(246,b|0,((g<<5)+a|0)+946304|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[22440]=0;R(247,b|0,e+24|0);i=v[22440];v[22440]=0;t:{if((i|0)==1){break t}v[22440]=0;R(248,e+24|0,(B(h,104)+a|0)+484380|0);i=v[22440];v[22440]=0;if((i|0)==1){break t}i=w[e+40|0];ub(e,v[k>>2],h-1|0);Te(e,(i&3)!=0);d=d+1|0;continue}break}b=P()|0;O()|0}Re(k);break c}b=P()|0;O()|0;Ab(e)}S(b|0);L()}d=1}cb=e+112|0;return d|0}function n9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0;e=cb-160|0;cb=e;d=-1;a:{b:{c:{if(!Zj(v[v[b>>2]-12>>2]+b|0)){b=Tl(e+48|0,b);v[22440]=0;d=Q(462,e+32|0,14053)|0;f=v[22440];v[22440]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){v[22440]=0;v[e+24>>2]=83886084;v[e+28>>2]=0;U(463,b|0,d|0,e+24|0);f=v[22440];v[22440]=0;if((f|0)==1){break A}Ab(d);t[e+23|0]=0;v[22440]=0;d=Q(462,e+32|0,14831)|0;f=v[22440];v[22440]=0;if((f|0)==1){break z}v[22440]=0;U(464,b|0,e+23|0,d|0);f=v[22440];v[22440]=0;if((f|0)==1){break y}Ab(d);v[22440]=0;f=w[e+23|0];d=Q(462,e+32|0,15837)|0;g=v[22440];v[22440]=0;if((g|0)==1){break x}v[22440]=0;f=f?0:c;W(905,b|0,a+40|0,d|0,f|0);c=v[22440];v[22440]=0;if((c|0)==1){break w}Ab(d);u[e+20>>1]=65535;v[22440]=0;c=Q(462,e+32|0,15507)|0;d=v[22440];v[22440]=0;if((d|0)==1){break v}v[22440]=0;Y(492,b|0,e+20|0,c|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break u}Ab(c);u[e+18>>1]=0;v[22440]=0;c=Q(462,e+32|0,15406)|0;d=v[22440];v[22440]=0;if((d|0)==1){break t}v[22440]=0;Y(492,b|0,e+18|0,c|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break s}Ab(c);u[a>>1]=x[e+18>>1];v[22440]=0;c=Q(462,e+32|0,15141)|0;d=v[22440];v[22440]=0;if((d|0)==1){break r}v[22440]=0;W(906,b|0,a+52|0,c|0,f|0);d=v[22440];v[22440]=0;if((d|0)==1){break q}Ab(c);v[22440]=0;c=Q(462,e+32|0,15077)|0;d=v[22440];v[22440]=0;if((d|0)==1){break p}v[22440]=0;U(897,b|0,a+36|0,c|0);d=v[22440];v[22440]=0;if((d|0)==1){break o}Ab(c);v[22440]=0;c=Q(462,e+32|0,15514)|0;d=v[22440];v[22440]=0;if((d|0)==1){break n}v[22440]=0;h=a+4|0;U(907,b|0,h|0,c|0);d=v[22440];v[22440]=0;if((d|0)==1){break m}Ab(c);v[22440]=0;c=Q(462,e+32|0,15408)|0;d=v[22440];v[22440]=0;if((d|0)==1){break l}v[22440]=0;f=a+28|0;U(908,b|0,f|0,c|0);d=v[22440];v[22440]=0;if((d|0)==1){break k}Ab(c);v[22440]=0;c=Q(462,e+32|0,15263)|0;d=v[22440];v[22440]=0;if((d|0)==1){break j}v[22440]=0;U(908,b|0,a+30|0,c|0);d=v[22440];v[22440]=0;if((d|0)==1){break i}Ab(c);v[22440]=0;c=Q(462,e+32|0,15106)|0;d=v[22440];v[22440]=0;if((d|0)==1){break h}v[22440]=0;U(909,b|0,a+32|0,c|0);d=v[22440];v[22440]=0;if((d|0)==1){break g}Ab(c);u[e+16>>1]=0;v[22440]=0;c=Q(462,e+32|0,15056)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}v[22440]=0;Y(492,b|0,e+16|0,c|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break f}Ab(c);i=zK(z[a+32>>2]);z[a+32>>2]=i;d=-1;if(!cm(i)){break d}k=e,l=yb(v[a+4>>2]),v[k+32>>2]=l;c=yb(v[a+8>>2]);while(1){g=v[e+32>>2];if(!Qb(g,c)){break e}if(!cm(z[g>>2])){break d}Ge(e+32|0);continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(c);break a}a=P()|0;O()|0;Ab(c);break a}if(Gk(w[e+48|0])){break d}c=x[f>>1];if((c-301&65535)>>>0<64935){break d}g=x[a>>1];if(g>>>0>3|(g|0)==2){break d}j=u[a+30>>1];if((j|0)<0){break d}k=e,l=Ei(v[a+36>>2]),v[k+32>>2]=l;v[e+24>>2]=0;k=a,l=v[Gj(e+32|0,e+24|0,43936)>>2],v[k+36>>2]=l;if(pc(v[a+4>>2],v[a+8>>2])>>>0>32767){break d}B:{C:{switch(g-1|0){case 2:f=u[e+16>>1];if((f|0)<=0){break d}u[e+14>>1]=j;z[e+32>>2]=z[a+32>>2];v[22440]=0;u[e+24>>1]=c;u[e+26>>1]=(c+f|0)-1;a=da(910,a|0,e+14|0,e+32|0,e+24|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;O()|0;break a;case 0:g=u[e+16>>1];if((g|0)<=0){break d}z[e+32>>2]=z[a+32>>2];v[22440]=0;u[e+24>>1]=c;u[e+26>>1]=(c+g|0)-1;a=ea(911,a|0,h|0,e+32|0,e+24|0,f|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;O()|0;break a;default:break C}}v[22440]=0;Z(912,a|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}}d=1}jh(b)}cb=e+160|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}jh(b);S(a|0);L()}function cja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;d=cb-320|0;cb=d;sc(b);f=cb-16|0;cb=f;yT(f+8|0,d+96|0);g=v[f+12>>2];Yb(f,b,v[f+8>>2],g);h=v[f+4>>2];if((h|0)==(g|0)){Ob(b,v[f+12>>2])}cb=f+16|0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=(h|0)){break g}if(!AT(d+96|0)){break g}if(!Kb(b,wc(zT(w[d+312|0],w[d+313|0]),fb))){break g}if(!c){e=1;break g}ud(a,2);eg(a);v[a+480188>>2]=524296;z=a,A=Le(455e3),v[z+480204>>2]=A;Gb(a+1074312|0,110,1);v[a+480208>>2]=v[a+480208>>2]|16777216;Ie(d- -64|0,2,d+127|0);f=d+80|0;xc(f,v[d+64>>2],v[d+68>>2],w[d+72|0]);tc(a+1298308|0,f);rb(f);h:{i:{while(1){if((e|0)==8){j:{l=a+484360|0;e=Nb(l);o=w[d+312|0];m=o+1|0;Zn(e,b,m,65535,65535);f=Rb(d+80|0);v[22440]=0;U(240,b|0,f|0,m|0);e=v[22440];v[22440]=0;if((e|0)==1){break j}z=d,A=yb(v[f>>2]),v[z+64>>2]=A;e=yb(v[f+4>>2]);while(1){g=v[d+64>>2];p=Qb(g,e);if(p){if((w[g|0]-9&255)>>>0<248){break h}Fe(d- -64|0);continue}break}z=a,A=w[Eb(v[f>>2],0)|0],v[z+480196>>2]=A;e=w[d+311|0];h=w[d+313|0];g=Rb(d- -64|0);v[22440]=0;n=h+1|0;U(240,b|0,g|0,n|0);h=v[22440];v[22440]=0;k:{if((h|0)==1){break k}v[22440]=0;h=a+484344|0;R(228,h|0,n|0);i=v[22440];v[22440]=0;if((i|0)==1){break k}q=e+1|0;if(!(c&1)){break i}c=0;while(1){if((c|0)==(n|0)){break i}e=w[Eb(v[g>>2],c)|0];v[22440]=0;e=Y(229,h|0,e|0,q|0)|0;i=v[22440];v[22440]=0;l:{if((i|0)!=1){if(!e){break i}j=0;r=Sb(h,w[Eb(v[g>>2],c)|0]);m:while(1){s=j&65535;if(s>>>0>7){break l}j=j+1|0;e=0;while(1){if(y[r+12>>2]<=e>>>0){continue m}v[22440]=0;i=T(208,b|0)|0;k=v[22440];v[22440]=0;n:{o:{if((k|0)!=1){if(!(i&128)){break o}e=(i&127)+e|0;break n}e=P()|0;O()|0;break b}k=Zc(r,e,s);if((i|0)==1){t[k|0]=254;break n}if((i-1&255)>>>0>96){break n}t[k+1|0]=j;t[k|0]=i+12}e=e+1|0;continue}}}e=P()|0;O()|0;break b}c=c+1|0;continue}}e=P()|0;O()|0;break b}}else{g=(d+96|0)+B(e,19)|0;WA(d+80|0,g+63|0);f=d- -64|0;xc(f,v[d+80>>2],v[d+84>>2],w[d+88|0]);Al(((e<<5)+a|0)+480289|0,f);rb(f);e=e+1|0;i=B(e,104)+a|0;l=i+484380|0;ed(l,2);v[d+72>>2]=0;v[d+64>>2]=0;v[d+68>>2]=0;h=w[g+78|0]|w[g+79|0]<<8|(w[g+80|0]<<16|w[g+81|0]<<24);t[f+7|0]=h;t[f+8|0]=h>>>8;t[f+9|0]=h>>>16;t[f+10|0]=h>>>24;h=w[g+75|0]|w[g+76|0]<<8|(w[g+77|0]<<16|w[g+78|0]<<24);g=w[g+71|0]|w[g+72|0]<<8|(w[g+73|0]<<16|w[g+74|0]<<24);t[f|0]=g;t[f+1|0]=g>>>8;t[f+2|0]=g>>>16;t[f+3|0]=g>>>24;t[f+4|0]=h;t[f+5|0]=h>>>8;t[f+6|0]=h>>>16;t[f+7|0]=h>>>24;v[d+8>>2]=v[d+72>>2];f=v[d+68>>2];v[d>>2]=v[d+64>>2];v[d+4>>2]=f;zl(l,1,d);v[i+484404>>2]=8215;f=d+48|0;xc(f,v[d+80>>2],v[d+84>>2],w[d+88|0]);uc(((e<<5)+a|0)+946304|0,f);rb(f);continue}break}e=P()|0;O()|0;break a}i=o+1|0;e=0;p:{q:{while(1){if((e|0)==(i|0)){v[22440]=0;b=Q(1,d+48|0,8645)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break p}e=P()|0;O()|0;break b}b=Nb(l);v[22440]=0;c=e&65535;b=Q(318,b|0,c|0)|0;j=v[22440];v[22440]=0;if((j|0)!=1){r:{if(!b){v[22440]=0;b=Y(370,h|0,q|0,0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break q}if((b|0)==65535){break r}z=Xb(v[Nb(l)>>2],e),A=b,u[z>>1]=A}z=d,A=Og(Sb(h,x[Xb(v[Nb(l)>>2],e)>>1])),v[z+48>>2]=A;b=VA(d+48|0,1);k=w[b+5|0];j=w[Eb(v[f>>2],(e+1>>>0)%(m>>>0)|0)|0];if((k|0)==(j|0)){break r}s:{if(w[b+3|0]!=16){break s}k=Nb(l);v[22440]=0;c=Q(371,k|0,c|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break c}if((c|0)==65535){break s}z=d,A=Og(Sb(h,c)),v[z+48>>2]=A;b=VA(d+48|0,1)}t[b+5|0]=j;t[b+3|0]=16}e=e+1|0;continue}break}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}Cb(a+1298344|0,b);rb(b);v[22440]=0;b=Q(1,d+48|0,6052)|0;c=v[22440];v[22440]=0;if((c|0)==1){break f}Cb(a+1298356|0,b);rb(b);Bj(d+16|0,2,d+107|0);v[22440]=0;W(225,d+32|0,v[d+16>>2],v[d+20>>2],w[d+24|0]);b=v[22440];v[22440]=0;if((b|0)==1){break e}v[22440]=0;U(11,d+48|0,5,d+32|0);b=v[22440];v[22440]=0;if((b|0)==1){break d}b=d+48|0;Cb(a+1298368|0,b);rb(b);rb(d+32|0);v[a+1298404>>2]=5;_b(g)}_b(f);e=p^1}cb=d+320|0;return e|0}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;rb(d+32|0);break b}e=P()|0;O()|0}_b(g)}_b(f);S(e|0);L()}function hx(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0;l=cb-48|0;cb=l;v[l+44>>2]=0;if(i?1:d|g|h){j=g?l+44|0:0;a:{if(!j){break a}k=v[j>>2];if(!k){break a}zb(k);v[j>>2]=0}v[22440]=0;X(107);k=v[22440];v[22440]=0;b:{c:{if((k|0)==1){m=Ta(88360,49008,49064,58712,88536,88640,88588,88480,88468,88784,88752,88720,88708,88932,0)|0;d:{e:{n=O()|0;if((n|0)==(fa(88360)|0)){k=_(m|0)|0;v[22440]=0;R(1071,j|0,k|0);j=v[22440];v[22440]=0;k=277;if((j|0)==1){break e}break b}if((fa(49008)|0)==(n|0)){k=_(m|0)|0;v[22440]=0;R(1071,j|0,k|0);j=v[22440];v[22440]=0;k=358;if((j|0)!=1){break b}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break c}break d}if((fa(49064)|0)==(n|0)){k=_(m|0)|0;v[22440]=0;R(1071,j|0,k|0);j=v[22440];v[22440]=0;k=359;if((j|0)!=1){break b}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break c}break d}if((fa(58712)|0)==(n|0)){k=_(m|0)|0;v[22440]=0;R(1071,j|0,k|0);j=v[22440];v[22440]=0;k=357;if((j|0)!=1){break b}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break c}break d}if((fa(88536)|0)==(n|0)){k=_(m|0)|0;v[22440]=0;R(1071,j|0,k|0);j=v[22440];v[22440]=0;k=300;if((j|0)!=1){break b}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break c}break d}if((fa(88640)|0)==(n|0)){k=_(m|0)|0;v[22440]=0;R(1071,j|0,k|0);j=v[22440];v[22440]=0;k=299;if((j|0)!=1){break b}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break c}break d}if((fa(88588)|0)==(n|0)){k=_(m|0)|0;v[22440]=0;R(1071,j|0,k|0);j=v[22440];v[22440]=0;k=298;if((j|0)!=1){break b}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break c}break d}if((fa(88480)|0)==(n|0)){k=_(m|0)|0;v[22440]=0;R(1071,j|0,k|0);j=v[22440];v[22440]=0;k=297;if((j|0)!=1){break b}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break c}break d}if((fa(88468)|0)==(n|0)){k=_(m|0)|0;v[22440]=0;R(1071,j|0,k|0);j=v[22440];v[22440]=0;k=296;if((j|0)!=1){break b}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break c}break d}if((fa(88784)|0)==(n|0)){k=_(m|0)|0;v[22440]=0;R(1071,j|0,k|0);j=v[22440];v[22440]=0;k=289;if((j|0)!=1){break b}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break c}break d}if((fa(88752)|0)==(n|0)){k=_(m|0)|0;v[22440]=0;R(1071,j|0,k|0);j=v[22440];v[22440]=0;k=288;if((j|0)!=1){break b}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break c}break d}if((fa(88720)|0)==(n|0)){k=_(m|0)|0;v[22440]=0;R(1071,j|0,k|0);j=v[22440];v[22440]=0;k=287;if((j|0)!=1){break b}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break c}break d}if((fa(88708)|0)==(n|0)){k=_(m|0)|0;v[22440]=0;R(1071,j|0,k|0);j=v[22440];v[22440]=0;k=286;if((j|0)!=1){break b}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break c}break d}o=fa(88932)|0;k=257;m=_(m|0)|0;if((n|0)!=(o|0)){break b}v[22440]=0;R(1071,j|0,m|0);j=v[22440];v[22440]=0;k=267;if((j|0)!=1){break b}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)==1){break d}break c}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break c}}V(0)|0;O()|0;Lb()}L()}S(a|0);L()}$()}o=!g;if(d){j=gb[d|0](k,e)|0}else{j=3}if(!(o|!(j&2))){v[g+16>>2]=k;m=v[l+44>>2];f:{if(m){o=le(m);break f}o=le(21685)}v[g+20>>2]=o}if(h){v[h>>2]=k}if(i){g=v[l+44>>2];g:{if(g){g=le(g);break g}g=le(21685)}v[i>>2]=g}g=v[l+44>>2];if(g){zb(g);v[l+44>>2]=0}h:{if(!(j&1)){break h}v[22440]=0;R(1069,l+32|0,a|0);g=v[22440];v[22440]=0;i:{j:{if((g|0)!=1){k:{if(f){v[22440]=0;R(1070,f|0,l+32|0);g=v[22440];v[22440]=0;if((g|0)!=1){break k}break j}g=Fb(l+32|0);if(b){v[22440]=0;R(b|0,g|0,c|0);g=v[22440];v[22440]=0;if((g|0)==1){break j}break k}hs(g,l)}rb(l+32|0);break h}g=V(0)|0;O()|0;break i}g=V(0)|0;O()|0;rb(l+32|0)}_(g|0)|0;v[l+28>>2]=f;v[l+24>>2]=e;v[l+20>>2]=d;v[l+16>>2]=c;v[l+12>>2]=b;v[l+8>>2]=a?a:21685;v[l+4>>2]=250;v[l>>2]=9203;nJ(17901,l);fs(89288);$()}cb=l+48|0}function uL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;k=cb-16|0;cb=k;a:{b:{c:{d:{if(!Rc(c)|!d|v[b+480180>>2]!=16777216|x[b+480192>>1]<d>>>0){break d}d=v[((d<<2)+b|0)+900380>>2];if(!d){break d}d=v[d+44>>2];if(!d){break d}u[k+14>>1]=c-61;c=cb-80|0;cb=c;e:{f:{e=u[d+28>>1];g=k+14|0;b=u[g>>1];if((e|0)<=(b|0)){if((b|0)<=(pc(v[d+4>>2],v[d+8>>2])+e<<16)-65536>>16){break f}}Db(a);break e}g:{e=x[d+30>>1];if(!e){b=d+52|0;m=c,n=Hx(b,g),v[m+56>>2]=n;m=c,n=Af(b),v[m+40>>2]=n;if(!ih(c+56|0,c+40|0)){break g}qf(a,od(c+56|0)+4|0);break e}b=wn(b,e<<16>>16);u[c+78>>1]=b;e=Db(a);a=d+52|0;m=c,n=Hx(a,c+78|0),v[m+72>>2]=n;m=c,n=Af(a),v[m+56>>2]=n;h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(ih(c+72|0,c+56|0)){a=od(c+72|0);v[22440]=0;R(137,e|0,a+4|0);a=v[22440];v[22440]=0;if((a|0)==1){break u}a=u[d+30>>1];b=u[g>>1];v[22440]=0;m=c,n=Gx(b,a)+5|0,v[m+40>>2]=n;R(134,c+56|0,c+40|0);a=v[22440];v[22440]=0;v:{if((a|0)!=1){v[22440]=0;Q(100,e|0,c+56|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break v}rb(c+56|0);break e}a=P()|0;O()|0;break h}a=P()|0;O()|0;rb(c+56|0);break h}if(u[d+30>>1]>26){break r}v[22440]=0;b=Y(540,c+40|0,1,(b<<24)+1090519040>>24)|0;a=v[22440];v[22440]=0;if((a|0)==1){break t}v[22440]=0;U(11,c+56|0,0,b|0);a=v[22440];v[22440]=0;if((a|0)==1){break s}a=c+56|0;f=Cb(e,a);rb(a);rb(b);v[22440]=0;Q(135,f|0,14732)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break q}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;rb(b);break h}v[22440]=0;a=b<<16>>16;v[c+36>>2]=(a|0)%16;R(864,c+40|0,c+36|0);f=v[22440];v[22440]=0;if((f|0)==1){break p}v[22440]=0;v[c+20>>2]=((a|0)/16<<16>>16)%16;R(864,c+24|0,c+20|0);a=v[22440];v[22440]=0;if((a|0)==1){break o}v[22440]=0;U(2,c+56|0,c+40|0,c+24|0);a=v[22440];v[22440]=0;if((a|0)==1){break n}a=c+56|0;f=Cb(e,a);rb(a);rb(c+24|0);rb(c+40|0);if(b<<16>>16<256){break q}v[22440]=0;U(8,c+8|0,0,f|0);a=v[22440];v[22440]=0;if((a|0)==1){break l}h=c+40|0;b=c+8|0;i=fd(b);j=gf(b);l=fd(b);a=cb-32|0;cb=a;v[a+16>>2]=j;v[a+24>>2]=i;v[a+8>>2]=l;while(1){if(oj(a+24|0,a+16|0)){i=a+24|0;j=Dp(t[v[i>>2]]);l=a+8|0;t[v[l>>2]]=j;Fe(i);Fe(l);continue}break}cb=a+32|0;zc(h,b);v[22440]=0;U(11,c+56|0,0,h|0);a=v[22440];v[22440]=0;if((a|0)==1){break k}a=c+56|0;Cb(f,a);rb(a);rb(c+40|0);rb(c+8|0)}a=u[d+30>>1];b=u[g>>1];v[22440]=0;m=c,n=Gx(b,a)+5|0,v[m+40>>2]=n;R(134,c+56|0,c+40|0);a=v[22440];v[22440]=0;if((a|0)==1){break j}v[22440]=0;Q(100,e|0,c+56|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break i}rb(c+56|0);break e}a=P()|0;O()|0;break h}a=P()|0;O()|0;break m}a=P()|0;O()|0;rb(c+24|0)}rb(c+40|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;rb(c+40|0);rb(c+8|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;rb(c+56|0)}break b}e=cb-16|0;cb=e;f=cb-32|0;cb=f;d=Me(f+16|0,1,0);w:{while(1){i=f+8|0;b=Fb(d);j=vb(d)+b|0;h=u[g>>1];if(!((b|0)==(j|0)|(h|0)>=0)){t[b|0]=45;h=0-(h&65535)&65535;b=b+1|0}mx(i,b,j,h&65535);if(!v[f+12>>2]){break w}b=Yf(vb(d));v[22440]=0;R(60,d|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){continue}break}break a}b=v[f+8>>2];g=Fb(d);v[22440]=0;R(61,d|0,b-g|0);b=v[22440];v[22440]=0;x:{if((b|0)!=1){v[22440]=0;R(74,e|0,d|0);b=v[22440];v[22440]=0;if((b|0)!=1){break x}break a}break a}rb(d);cb=f+32|0;v[22440]=0;R(73,a|0,e|0);a=v[22440];v[22440]=0;y:{if((a|0)!=1){rb(e);cb=e+16|0;break y}a=P()|0;O()|0;break b}}cb=c+80|0;break c}e=v[b>>2];b=cb-32|0;cb=b;z:{if(pp(c)){v[b+16>>2]=v[8056];d=v[8055];v[b+8>>2]=v[8054];v[b+12>>2]=d;d=v[8053];v[b>>2]=v[8052];v[b+4>>2]=d;jc(a,(b+(c<<2)|0)-1004|0);break z}if(Rc(c)){d=Db(b);v[22440]=0;c=c-1|0;f=(c|0)/12|0;c=Q(865,d|0,e+(B(f,-12)+c<<16>>16<<2)|0)|0;e=v[22440];v[22440]=0;A:{if((e|0)==1){break A}v[22440]=0;c=Q(866,c|0,f+48&255)|0;e=v[22440];v[22440]=0;if((e|0)==1){break A}v[22440]=0;Q(3,a|0,c|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break A}rb(c);break z}break a}if(!c){jc(a,16796);break z}jc(a,14703)}cb=b+32|0}cb=k+16|0;return}rb(e);S(a|0);L()}a=P()|0;O()|0;rb(d);S(a|0);L()}function VH(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=cb-48|0;cb=g;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(Qr(c)){b=b+24|0;h=v[b>>2]+484344|0;if(ve(h,c&65535)){break j}}c=a;a=Db(g+32|0);b=Db(g+16|0);mi(c,a,b);rb(b);rb(a);break i}c=Sb(h,c);if(!(v[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Db(g+32|0);b=Db(g+16|0);mi(c,a,b);rb(b);rb(a);break i}if(!(x[v[b>>2]+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Db(g+32|0);b=Db(g+16|0);mi(c,a,b);rb(b);rb(a);break i}if(f>>>0>=6){c=a;a=Db(g+32|0);b=Db(g+16|0);mi(c,a,b);rb(b);rb(a);break i}c=Zc(c,d,e&65535);k:{switch(f|0){case 0:l:{m:{n:{d=w[c|0];if(!Rc(d)){if(!pp(d)){break n}}e=g+16|0;uL(e,v[b>>2],d,w[c+1|0]);v[22440]=0;R(1033,g+32|0,e|0);d=v[22440];v[22440]=0;b=1;if((d|0)!=1){break m}c=P()|0;O()|0;break b}b=0;v[22440]=0;Q(56,g+32|0,16796)|0;d=v[22440];v[22440]=0;if((d|0)==1){break l}}c=w[c|0];o:{if(Rc(c)){v[22440]=0;Q(56,g|0,9987)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}break o}if(pp(c)){v[22440]=0;Q(56,g|0,10297)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break o}break c}v[22440]=0;Q(56,g|0,16796)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}}c=a;a=g+32|0;mi(c,a,g);rb(g);rb(a);if(!b){break i}rb(g+16|0);break i}c=P()|0;O()|0;break a;case 1:b=c+1|0;p:{if(w[c+1|0]){Et(g+32|0,b);break p}Bc(g+32|0,16801)}q:{if(w[b|0]){v[22440]=0;Q(56,g+16|0,10791)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break q}break d}v[22440]=0;Q(56,g+16|0,16801)|0;b=v[22440];v[22440]=0;if((b|0)==1){break d}}c=a;a=g+32|0;b=g+16|0;mi(c,a,b);rb(b);rb(a);break i;case 2:r:{if(eh(w[c|0])){Bc(g+32|0,17856);break r}d=w[c+2|0];if(d){Me(g+32|0,1,UK(v[v[v[b>>2]+8>>2]+88>>2],d));break r}Bc(g+32|0,17856)}s:{if(eh(w[c|0])){v[22440]=0;Q(56,g+16|0,17856)|0;b=v[22440];v[22440]=0;if((b|0)==1){break e}break s}if(w[c+2|0]){v[22440]=0;Q(56,g+16|0,5508)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break s}break e}v[22440]=0;Q(56,g+16|0,17856)|0;b=v[22440];v[22440]=0;if((b|0)==1){break e}}c=a;a=g+32|0;b=g+16|0;mi(c,a,b);rb(b);rb(a);break i;case 4:b=w[c+2|0];t:{if(eh(w[c|0])){i=g,j=ek(b,w[c+4|0])&255,v[i>>2]=j;aA(g+32|0,g);break t}if(b){Et(g+32|0,c+4|0);break t}Bc(g+32|0,16801)}u:{if(eh(w[c|0])){v[22440]=0;Q(56,g+16|0,5492)|0;b=v[22440];v[22440]=0;if((b|0)==1){break f}break u}if(w[c+2|0]){v[22440]=0;Q(56,g+16|0,5492)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break u}break f}v[22440]=0;Q(56,g+16|0,16801)|0;b=v[22440];v[22440]=0;if((b|0)==1){break f}}c=a;a=g+32|0;b=g+16|0;mi(c,a,b);rb(b);rb(a);break i;case 3:d=w[c+3|0];v:{if(eh(w[c|0])){i=g,j=(ek(d,w[c+5|0])&3840)!=0,t[i|0]=j;b=cb-32|0;cb=b;v[b+8>>2]=-1;v[b+12>>2]=0;v[b>>2]=0;Db(b+16|0);v[22440]=0;v[b>>2]=v[b>>2]&-1332|1058;v[b+4>>2]=1;U(1111,g+32|0,g|0,b|0);d=v[22440];v[22440]=0;w:{if((d|0)!=1){Qc(b);cb=b+32|0;break w}a=P()|0;O()|0;Qc(b);S(a|0);L()}break v}if(d){Me(g+32|0,1,TK(v[v[v[b>>2]+8>>2]+84>>2],d));break v}Bc(g+32|0,16802)}x:{if(eh(w[c|0])){v[22440]=0;Q(56,g+16|0,12343)|0;b=v[22440];v[22440]=0;if((b|0)==1){break g}break x}if(w[c+3|0]){v[22440]=0;Q(56,g+16|0,12343)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break x}break g}v[22440]=0;Q(56,g+16|0,16802)|0;b=v[22440];v[22440]=0;if((b|0)==1){break g}}c=a;a=g+32|0;b=g+16|0;mi(c,a,b);rb(b);rb(a);break i;case 5:b=w[c+3|0];y:{if(eh(w[c|0])){i=g,j=ek(b,w[c+5|0])&255,v[i>>2]=j;aA(g+32|0,g);break y}if(b){Et(g+32|0,c+5|0);break y}Bc(g+32|0,16801)}z:{if(eh(w[c|0])){v[22440]=0;Q(56,g+16|0,11135)|0;b=v[22440];v[22440]=0;if((b|0)==1){break h}break z}if(w[c+3|0]){v[22440]=0;Q(56,g+16|0,11135)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break z}break h}v[22440]=0;Q(56,g+16|0,16801)|0;b=v[22440];v[22440]=0;if((b|0)==1){break h}}c=a;a=g+32|0;b=g+16|0;mi(c,a,b);rb(b);rb(a);break i;default:break k}}c=a;a=Db(g+32|0);b=Db(g+16|0);mi(c,a,b);rb(b);rb(a)}cb=g+48|0;return}c=P()|0;O()|0;rb(g+32|0);break a}c=P()|0;O()|0;rb(g+32|0);break a}c=P()|0;O()|0;rb(g+32|0);break a}c=P()|0;O()|0;rb(g+32|0);break a}c=P()|0;O()|0;rb(g+32|0);break a}c=P()|0;O()|0;rb(g+32|0);if(!b){break a}}rb(g+16|0)}S(c|0);L()}function ZU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=cb-3056|0;cb=e;sc(b);f=cb-16|0;cb=f;i=e+1096|0;FB(f+8|0,i);j=b;b=v[f+12>>2];Yb(f,j,v[f+8>>2],b);h=v[f+4>>2];if((h|0)==(b|0)){Ob(j,v[f+12>>2])}cb=f+16|0;b=(b|0)==(h|0);if(!b){EB(i)}a:{if(!b){break a}if(!GB(e+1096|0)){break a}if(!c){d=1;break a}if(!Kb(j,wc(1024,0))){break a}DB(j,e+576|0);DB(j,e- -64|0);while(1){if((g|0)!=128){f=g<<2;b=f+(e+576|0)|0;i=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(i>>>0>16777215){break a}b=f+(e- -64|0)|0;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(b-4097>>>0<4294963202){break a}g=g+1|0;if(Xq(j,(b+i|0)+2978|0)){continue}break a}break}ud(a,2);eg(a);b=e+40|0;d=jc(b,13926);Cb(a+1298344|0,d);rb(d);d=jc(b,14854);Cb(a+1298356|0,d);rb(d);b=jc(b,15530);Cb(a+1298368|0,b);rb(b);v[a+1298404>>2]=5;b=w[e+1096|0];v[a+480204>>2]=143e4;v[a+480196>>2]=b;i=a+484360|0;Qe(Nb(i),w[e+1097|0]);v[a+480188>>2]=4194317;Gb(a+1074312|0,95,1);v[a+480208>>2]=v[a+480208>>2]|16777216;d=0;while(1){if((d|0)==4){b:{d=0;while(1){c:{if((d|0)==32){g=0;break c}b=d+1|0;g=B(b,104)+a|0;h=g+484380|0;ed(h,2);Wh(e+16|0,1,(B(d,13)+e|0)+1098|0);f=e+40|0;xc(f,v[e+16>>2],v[e+20>>2],w[e+24|0]);uc(((b<<5)+a|0)+946304|0,f);rb(f);d=(e+1096|0)+(d<<4)|0;f=d+422|0;v[h>>2]=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);if((w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24))>>>0<=(w[d+422|0]|w[d+423|0]<<8|(w[d+424|0]<<16|w[d+425|0]<<24))>>>0){v[g+484384>>2]=w[d+426|0]|w[d+427|0]<<8|(w[d+428|0]<<16|w[d+429|0]<<24);d=w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24);u[g+484414>>1]=2;v[g+484388>>2]=d}v[g+484404>>2]=8287;d=b;continue}break}while(1){if((g|0)!=32){d=g+33|0;f=(B(d,104)+a|0)+484380|0;ed(f,2);Wh(e+16|0,1,(B(g,13)+e|0)+2026|0);b=e+40|0;xc(b,v[e+16>>2],v[e+20>>2],w[e+24|0]);uc(((d<<5)+a|0)+946304|0,b);rb(b);v[e+48>>2]=0;v[e+40>>2]=0;v[e+44>>2]=0;d=(e+1096|0)+B(g,11)|0;o=Eb(b,0),p=w[d+1347|0],t[o|0]=p;o=Eb(b,1),p=w[d+1352|0],t[o|0]=p;o=Eb(b,2),p=w[d+1348|0],t[o|0]=p;o=Eb(b,3),p=w[d+1353|0],t[o|0]=p;o=Eb(b,4),p=w[d+1349|0],t[o|0]=p;o=Eb(b,5),p=w[d+1354|0],t[o|0]=p;o=Eb(b,6),p=w[d+1350|0],t[o|0]=p;o=Eb(b,7),p=w[d+1355|0],t[o|0]=p;o=Eb(b,8),p=w[d+1351|0],t[o|0]=p;o=Eb(b,9),p=w[d+1356|0],t[o|0]=p;o=Eb(b,10),p=w[d+1346|0],t[o|0]=p;v[e+8>>2]=v[e+48>>2];b=v[e+44>>2];v[e>>2]=v[e+40>>2];v[e+4>>2]=b;zl(f,1,e);g=g+1|0;continue}break}zq(Nb(i),e+2794|0,256,255,65535);m=a+484344|0;wg(m,128);n=c&1;g=0;while(1){d:{e:{if((g|0)!=128){f=g<<2;b=f+(e+576|0)|0;Tc(j,(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+2978|0);d=e+16|0;b=f+(e- -64|0)|0;Td(d,j,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));f=cc(e+40|0,d);sb(d);if(!n){break d}v[22440]=0;b=Y(229,m|0,g&65535,64)|0;d=v[22440];v[22440]=0;if((d|0)==1){break b}if(!b){break d}d=0;i=Sb(m,g);while(1){if(d>>>0>63){break d}v[22440]=0;b=Q(158,e+40|0,1)|0;h=v[22440];v[22440]=0;f:{if((h|0)!=1){if(!b){break d}v[22440]=0;b=T(208,f|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break b}if(b>>>0>12){break f}h=Zc(i,d,b);v[22440]=0;R(267,e+16|0,f|0);k=v[22440];v[22440]=0;if((k|0)==1){break b}k=e+16|0;l=w[k|0];b=b>>>0>3;t[h|0]=((l&15)+(b?13:37)|0)+B(l>>>4&7,12);l=Ec(k);t[h+1|0]=((w[l|0]>>>4|0)+(b?33:1)|0)+(w[k|0]>>>3&16);CB(h,w[l|0],b);continue}break b}h=b-32|0;if((h&255)>>>0<=12){h=Zc(i,d,h&65535);v[22440]=0;k=T(208,f|0)|0;l=v[22440];v[22440]=0;if((l|0)==1){break b}CB(h,k,b>>>0>35);continue}if((b|0)!=64){if((b|0)!=96){break e}if(!d){break d}o=Zc(i,d-1|0,0),p=14,t[o+3|0]=p;break d}v[22440]=0;b=T(208,f|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break b}d=b+d|0;continue}}d=1;if(!(c&2)){break a}g=1;while(1){if((g|0)==33){break a}vg(Nc(e+40|0,8,1,0,1),(B(g,104)+a|0)+484380|0,j);g=g+1|0;continue}}sb(e+40|0);d=0;break a}g=g+1|0;sb(e+40|0);continue}}}else{u[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;continue}break}a=P()|0;O()|0;sb(e+40|0);S(a|0);L()}cb=e+3056|0;return d|0}function RG(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,C=0;i=cb-560|0;cb=i;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;k=g+B(s,-24)|0;o=v[(e<<2)+69728>>2];j=d-1|0;if((o+j|0)>=0){g=d+o|0;c=s-j|0;while(1){A[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+v[(c<<2)+69744>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=k-24|0;t=(o|0)>0?o:0;g=0;while(1){f=0;if((d|0)>0){h=g+j|0;c=0;while(1){f=A[(c<<3)+a>>3]*A[(i+320|0)+(h-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;c=(g|0)==(t|0);g=g+1|0;if(!c){continue}break}z=47-k|0;u=48-k|0;C=k-25|0;g=o;a:{while(1){f=A[(g<<3)+i>>3];c=0;h=g;l=(g|0)<=0;if(!l){while(1){n=(i+480|0)+(c<<2)|0;m=f*5.960464477539063e-8;b:{if(D(m)<2147483648){j=~~m;break b}j=-2147483648}m=+(j|0);f=m*-16777216+f;c:{if(D(f)<2147483648){j=~~f;break c}j=-2147483648}v[n>>2]=j;h=h-1|0;f=A[(h<<3)+i>>3]+m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=Tj(f,q);f=f+H(f*.125)*-8;d:{if(D(f)<2147483648){n=~~f;break d}n=-2147483648}f=f-+(n|0);e:{f:{g:{w=(q|0)<=0;h:{if(!w){h=(g<<2)+i|0;j=v[h+476>>2];c=j>>u;r=h;h=j-(c<<u)|0;v[r+476>>2]=h;n=c+n|0;j=h>>z;break h}if(q){break g}j=v[((g<<2)+i|0)+476>>2]>>23}if((j|0)<=0){break e}break f}j=2;if(f>=.5){break f}j=0;break e}c=0;h=0;if(!l){while(1){r=(i+480|0)+(c<<2)|0;x=v[r>>2];l=16777215;i:{j:{if(h){break j}l=16777216;if(x){break j}h=0;break i}v[r>>2]=l-x;h=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}k:{if(w){break k}c=8388607;l:{switch(C|0){case 1:c=4194303;break;case 0:break l;default:break k}}l=(g<<2)+i|0;v[l+476>>2]=v[l+476>>2]&c}n=n+1|0;if((j|0)!=2){break e}f=1-f;j=2;if(!h){break e}f=f-Tj(1,q)}if(f==0){c=1;l=0;h=g;m:{if((g|0)<=(o|0)){break m}while(1){h=h-1|0;l=v[(i+480|0)+(h<<2)>>2]|l;if((h|0)>(o|0)){continue}break}if(!l){break m}k=q;while(1){k=k-24|0;g=g-1|0;if(!v[(i+480|0)+(g<<2)>>2]){continue}break}break a}while(1){h=c;c=c+1|0;if(!v[(i+480|0)+(o-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;A[(i+320|0)+(j<<3)>>3]=v[(s+g<<2)+69744>>2];c=0;f=0;if((d|0)>0){while(1){f=A[(c<<3)+a>>3]*A[(i+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}break}f=Tj(f,24-k|0);n:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;m=f*5.960464477539063e-8;o:{if(D(m)<2147483648){c=~~m;break o}c=-2147483648}f=+(c|0)*-16777216+f;p:{if(D(f)<2147483648){a=~~f;break p}a=-2147483648}v[d>>2]=a;g=g+1|0;break n}if(D(f)<2147483648){c=~~f}else{c=-2147483648}k=q}v[(i+480|0)+(g<<2)>>2]=c}f=Tj(1,k);if((g|0)>=0){d=g;while(1){a=d;A[(a<<3)+i>>3]=f*+v[(i+480|0)+(a<<2)>>2];d=a-1|0;f=f*5.960464477539063e-8;if(a){continue}break}a=0;h=g;while(1){d=a>>>0<t>>>0?a:t;c=0;f=0;while(1){f=A[(c<<3)+72512>>3]*A[(c+h<<3)+i>>3]+f;k=(c|0)!=(d|0);c=c+1|0;if(k){continue}break}A[(i+160|0)+(g-h<<3)>>3]=f;h=h-1|0;c=(a|0)!=(g|0);a=a+1|0;if(c){continue}break}}q:{r:{s:{switch(e|0){case 3:t:{if((g|0)<=0){break t}d=(i+160|0)+(g<<3)|0;f=A[d>>3];c=g;while(1){m=f;e=i+160|0;a=c-1|0;h=e+(a<<3)|0;y=A[h>>3];f=y+f;A[e+(c<<3)>>3]=m+(y-f);A[h>>3]=f;e=c>>>0>1;c=a;if(e){continue}break}if((g|0)<2){break t}f=A[d>>3];c=g;while(1){m=f;d=i+160|0;a=c-1|0;e=d+(a<<3)|0;p=A[e>>3];f=p+f;A[d+(c<<3)>>3]=m+(p-f);A[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;while(1){p=p+A[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=A[i+160>>3];if(j){break r}A[b>>3]=f;f=A[i+168>>3];A[b+16>>3]=p;A[b+8>>3]=f;break q;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+A[(i+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;break q;case 1:case 2:break s;default:break q}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=a-1|0;f=f+A[(i+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;f=A[i+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+A[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}A[b+8>>3]=j?-f:f;break q}A[b>>3]=-f;f=A[i+168>>3];A[b+16>>3]=-p;A[b+8>>3]=-f}cb=i+560|0;return n&7}function _ea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;d=cb-752|0;cb=d;sc(b);e=cb-16|0;cb=e;h=d+144|0;sQ(e+8|0,h);f=v[e+12>>2];Yb(e,b,v[e+8>>2],f);g=v[e+4>>2];if((g|0)==(f|0)){Ob(b,v[e+12>>2])}cb=e+16|0;e=(f|0)==(g|0);if(!e){rQ(h)}a:{if(!e){break a}if(!uQ(d+144|0)){break a}if(!Kb(b,wc(tQ(d+144|0),fb))){break a}if(!c){o=1;break a}ud(a,262144);f=d+104|0;Gi(f,2,d+144|0);e=d+24|0;xc(e,v[d+104>>2],v[d+108>>2],w[d+112|0]);tc(a+1298308|0,e);rb(e);h=jc(e,8346);Cb(a+1298344|0,h);rb(h);e=jc(e,10144);Cb(a+1298356|0,e);rb(e);e=cb-16|0;cb=e;i=f;f=jc(e,4196);zc(i,f);rb(f);cb=e+16|0;t[d+8|0]=w[d+174|0];e=w[d+173|0];v[22440]=0;t[d+127|0]=e;R(681,d+128|0,d+127|0);e=v[22440];v[22440]=0;b:{c:{d:{if((e|0)!=1){v[22440]=0;W(256,d+24|0,d+104|0,d+8|0,d+128|0);e=v[22440];v[22440]=0;if((e|0)!=1){e=d+24|0;Cb(a+1298368|0,e);rb(e);rb(d+128|0);f=d+104|0;Ab(f);v[a+480208>>2]=12;v[a+1298404>>2]=5;h=a+480188|0;u[h>>1]=w[d+182|0]|w[d+183|0]<<8;u[d+24>>1]=w[d+178|0]|w[d+179|0]<<8;u[d+104>>1]=3999;A=a,C=x[Kc(e,f)>>1],u[A+480190>>1]=C;DT(Nb(a+484360|0),d+240|0,w[d+176|0]|w[d+177|0]<<8);e=0;while(1)if(x[h>>1]<=e>>>0){e=d+24|0;Td(e,b,B(w[d+178|0]|w[d+179|0]<<8,80));h=c&2;m=cc(d+104|0,e);sb(e);g=d+72|0;e=0;e:{f:{while(1){if(x[a+480190>>1]<=e>>>0){o=1;if(c&1){break f}break b}v[22440]=0;R(682,m|0,d+24|0);f=v[22440];v[22440]=0;if((f|0)==1){break e}Gi(d+8|0,2,g);v[22440]=0;W(225,d+128|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);f=v[22440];v[22440]=0;if((f|0)==1){break e}e=e+1|0;f=d+128|0;uc(((e<<5)+a|0)+946304|0,f);rb(f);v[22440]=0;i=f;f=(B(e,104)+a|0)+484380|0;U(683,i|0,d+24|0,f|0);j=v[22440];v[22440]=0;g:{if((j|0)==1){break g}if(!h|!v[f>>2]){continue}j=w[d+42|0]|w[d+43|0]<<8|(w[d+44|0]<<16|w[d+45|0]<<24);v[22440]=0;j=Q(157,b|0,j|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break g}if(!j){continue}v[22440]=0;Y(222,d+128|0,f|0,b|0)|0;f=v[22440];v[22440]=0;if((f|0)!=1){continue}}break}break e}c=w[d+180|0]|w[d+181|0]<<8;v[22440]=0;n=a+484344|0;R(228,n|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break e}c=d+24|0;r=c|4;s=c|2;p=c|3;y=c|5;z=c|1;q=a+480188|0;f=0;while(1){if((w[d+180|0]|w[d+181|0]<<8)>>>0<=f>>>0){break b}v[22440]=0;a=Y(229,n|0,f&65535,64)|0;c=v[22440];v[22440]=0;if((c|0)==1){break e}h:{if(!a){break h}a=(f<<1)+d|0;a=w[a+496|0]|w[a+497|0]<<8;if(!a){break h}v[22440]=0;a=Q(157,b|0,a<<4)|0;c=v[22440];v[22440]=0;if((c|0)==1){break e}if(!a){break h}j=0;c=Zc(Sb(n,f),0,0);while(1){if(j>>>0>63){break h}v[22440]=0;a=Q(158,b|0,1)|0;e=v[22440];v[22440]=0;i:{if((e|0)!=1){if(!a){break h}v[22440]=0;h=T(208,b|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break e}if(h){break i}j=j+1|0;c=B(x[q>>1],6)+c|0;continue}break e}u[d+28>>1]=0;v[d+24>>2]=0;l=tg(d+24|0);e=h&31;a=e>>>0<x[q>>1];e=B(e,6)+c|0;j:{if(!(h&32)){break j}v[22440]=0;R(267,d+128|0,b|0);g=v[22440];v[22440]=0;if((g|0)==1){break e}i=a?e:d+24|0;k=d+128|0;g=w[k|0];t[i|0]=g;A=a?e+1|0:z,C=w[Ec(k)|0],t[A|0]=C;k:{if(g){if((g|0)==254){break k}if(g>>>0<121){break j}}g=0}t[i|0]=g}l:{if(!(h&64)){break l}v[22440]=0;R(267,d+128|0,b|0);g=v[22440];v[22440]=0;if((g|0)==1){break e}g=a?e+5|0:y;k=Ec(d+128|0);t[g|0]=w[k|0];i=w[d+128|0];m:{if(i>>>0<=15){Ef(a?e:l,i,w[k|0]);break m}t[(a?e+3|0:p)|0]=i>>>0<=23?w[i+27111|0]:0}i=a?e+3|0:p;l=w[i|0];if((l|0)!=23){if((l|0)!=9){break l}t[i|0]=20;t[d+8|0]=w[g|0]>>>3;t[d+127|0]=1;A=g,C=w[ff(d+8|0,d+127|0)|0]-1&15|128,t[A|0]=C;break l}t[d+8|0]=64;A=g,C=w[Tb(g,d+8|0)|0]<<1,t[A|0]=C}if(!(h&128)){continue}t[(a?e+2|0:s)|0]=1;v[22440]=0;h=T(208,b|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break e}t[(a?e+4|0:r)|0]=h;continue}}f=f+1|0;continue}}e=P()|0;O()|0;sb(m);break c}else{f=(e<<5)+a|0;$e(f+480280|0);u[f+480284>>1]=(w[(d+e|0)+208|0]<<4|4)&244;e=e+1|0;continue}}e=P()|0;O()|0;rb(d+128|0);break d}e=P()|0;O()|0}Ab(d+104|0)}S(e|0);L()}sb(m)}cb=d+752|0;return o|0}function C_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=cb+-64|0;cb=h;v[h+56>>2]=b;v[e>>2]=0;Jc(h,d);v[22440]=0;i=T(1159,h|0)|0;j=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Pb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Pb(h);S(a|0);L()}jF(a,f+24|0,h+56|0,c,e,i);break b}iF(a,f+16|0,h+56|0,c,e,i);break b}g=a;i=b;a=gb[v[v[a+8>>2]+12>>2]](a+8|0)|0;b=Fb(a);k=h,l=Vj(g,i,c,d,e,f,b,b+(vb(a)<<2)|0),v[k+56>>2]=l;break b}a=Vi(h+56|0,c,e,i,2);b=v[e>>2];B:{if(!(b&4|a-1>>>0>30)){v[f+12>>2]=a;break B}v[e>>2]=b|4}break b}g=v[19947];v[h+24>>2]=v[19946];v[h+28>>2]=g;g=v[19945];v[h+16>>2]=v[19944];v[h+20>>2]=g;g=v[19943];v[h+8>>2]=v[19942];v[h+12>>2]=g;g=v[19941];v[h>>2]=v[19940];v[h+4>>2]=g;k=h,l=Vj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}g=v[19955];v[h+24>>2]=v[19954];v[h+28>>2]=g;g=v[19953];v[h+16>>2]=v[19952];v[h+20>>2]=g;g=v[19951];v[h+8>>2]=v[19950];v[h+12>>2]=g;g=v[19949];v[h>>2]=v[19948];v[h+4>>2]=g;k=h,l=Vj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=Vi(h+56|0,c,e,i,2);b=v[e>>2];C:{if(!(b&4|(a|0)>23)){v[f+8>>2]=a;break C}v[e>>2]=b|4}break b}a=Vi(h+56|0,c,e,i,2);b=v[e>>2];D:{if(!(b&4|a-1>>>0>11)){v[f+8>>2]=a;break D}v[e>>2]=b|4}break b}a=Vi(h+56|0,c,e,i,3);b=v[e>>2];E:{if(!(b&4|(a|0)>365)){v[f+28>>2]=a;break E}v[e>>2]=b|4}break b}a=Vi(h+56|0,c,e,i,2);b=v[e>>2];F:{if(!(b&4|(a|0)>12)){v[f+16>>2]=a-1;break F}v[e>>2]=b|4}break b}a=Vi(h+56|0,c,e,i,2);b=v[e>>2];G:{if(!(b&4|(a|0)>59)){v[f+4>>2]=a;break G}v[e>>2]=b|4}break b}a=h+56|0;b=cb-16|0;cb=b;v[b+8>>2]=c;while(1){H:{if(!Cr(a,b+8|0)){break H}if(!Rk(i,8192,Sk(v[a>>2]))){break H}gn(a);continue}break}if(Qk(a,b+8|0)){v[e>>2]=v[e>>2]|2}cb=b+16|0;break b}b=h+56|0;a=gb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((vb(a)|0)==(0-vb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=or(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=ic(h,79824,44);k=g,l=Vj(a,b,c,d,e,f,g,g+44|0),v[k+56>>2]=l;break b}v[h+16>>2]=v[19972];g=v[19971];v[h+8>>2]=v[19970];v[h+12>>2]=g;g=v[19969];v[h>>2]=v[19968];v[h+4>>2]=g;k=h,l=Vj(a,b,c,d,e,f,h,h+20|0),v[k+56>>2]=l;break b}a=Vi(h+56|0,c,e,i,2);b=v[e>>2];J:{if(!(b&4|(a|0)>60)){v[f>>2]=a;break J}v[e>>2]=b|4}break b}g=v[19983];v[h+24>>2]=v[19982];v[h+28>>2]=g;g=v[19981];v[h+16>>2]=v[19980];v[h+20>>2]=g;g=v[19979];v[h+8>>2]=v[19978];v[h+12>>2]=g;g=v[19977];v[h>>2]=v[19976];v[h+4>>2]=g;k=h,l=Vj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=Vi(h+56|0,c,e,i,1);b=v[e>>2];K:{if(!(b&4|(a|0)>6)){v[f+24>>2]=a;break K}v[e>>2]=b|4}break b}a=gb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=gb[v[v[a+8>>2]+24>>2]](a+8|0)|0;b=Fb(a);k=h,l=Vj(g,i,c,d,e,f,b,b+(vb(a)<<2)|0),v[k+56>>2]=l;break b}hF(f+20|0,h+56|0,c,e,i);break b}a=Vi(h+56|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=cb-16|0;cb=a;v[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if(Qk(c,a+8|0)){break M}b=4;if((Ym(i,Sk(v[c>>2]))|0)!=37){break M}b=2;if(!Qk(gn(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}cb=a+16|0}a=v[h+56>>2]}cb=h- -64|0;return a|0}function g9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=0;d=cb-128|0;cb=d;g=-1;a:{b:{c:{d:{if(!Gh(v[v[b>>2]-12>>2]+b|0)){break d}e=d+112|0;ke(e,b);f=v[e+8>>2];l=v[e+12>>2];e=d+104|0;Rj(e);b=Uk(b,e,8);if(Mb(e,16772,8)){a=Xg(d+88|0,f,l);c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;Uj(b,d+8|0);break d}u[d+86>>1]=0;bg(b,d+86|0);l=x[d+86>>1];if((l&65534)!=2){break d}f=d+78|0;Rj(f);e=Uk(b,f,8);if(Mb(f,14383,8)){break d}u[d+76>>1]=0;bg(e,d+76|0);f=u[d+76>>1];if((f-5&65535)>>>0<65534){break d}e:{f:{g:{h:{i:{j:{if(f>>>0<=3){b=Db(d+112|0);v[22440]=0;h=Y(496,e|0,b|0,65535)|0;k=v[22440];v[22440]=0;if((k|0)==1){break b}if(!h){break i}v[22440]=0;U(11,d- -64|0,c|0,b|0);h=v[22440];v[22440]=0;if((h|0)!=1){break j}break b}b=Db(d+112|0);v[22440]=0;h=Q(498,e|0,b|0)|0;k=v[22440];v[22440]=0;if((k|0)==1){break c}if(!h){break h}v[22440]=0;U(11,d- -64|0,c|0,b|0);h=v[22440];v[22440]=0;if((h|0)==1){break c}}h=d- -64|0;Cb(a+40|0,h);rb(h);rb(b);u[d+62>>1]=0;bg(e,d+62|0);u[d+60>>1]=0;bg(e,d+60|0);u[a>>1]=x[d+60>>1];u[d+58>>1]=0;k:{if((f|0)<=3){v[d+112>>2]=0;nk(e,d+112|0);b=v[d+112>>2];if(b>>>0>65535){break d}b=xl(b);u[d+58>>1]=b;break k}bg(e,d+58|0);b=x[d+58>>1]}h=a+52|0;k=b&65535;n=(f|0)>3;f=0;l:{m:{while(1){if(k>>>0<=(f&65535)>>>0){break l}b=Db(d+112|0);v[22440]=0;u[d+40>>1]=0;R(916,e|0,d+40|0);i=v[22440];v[22440]=0;if((i|0)==1){break g}n:{if(!n){v[22440]=0;i=Y(496,e|0,b|0,65535)|0;j=v[22440];v[22440]=0;if((j|0)==1){break g}if(i){break n}break e}v[22440]=0;i=Q(498,e|0,b|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break g}if(!i){break e}}v[22440]=0;U(11,d- -64|0,c|0,b|0);i=v[22440];v[22440]=0;if((i|0)!=1){v[22440]=0;i=Q(913,h|0,d+40|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break m}j=i;i=d- -64|0;Cb(j,i);rb(i);rb(b);f=f+1|0;continue}break}g=P()|0;O()|0;break f}g=P()|0;O()|0;rb(d- -64|0);break f}c=d- -64|0;Rj(c);b=Uk(e,c,8);if(Mb(c,14327,8)){break d}c=x[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;e=l<<16>>16;o:{if((e|0)<=2){if(xK(b,c)){break o}break d}if(!wK(b,c)){break d}}o=d,p=yb(v[a+4>>2]),v[o+112>>2]=p;c=yb(v[a+8>>2]);while(1){f=v[d+112>>2];if(Qb(f,c)){if(!cm(z[f>>2])){break d}Ge(d+112|0);continue}break}c=a+16|0;p:{if((e|0)<=2){if(xK(b,c)){break p}break d}if(!wK(b,c)){break d}}o=d,p=yb(v[a+16>>2]),v[o+112>>2]=p;c=yb(v[a+20>>2]);while(1){e=v[d+112>>2];if(Qb(e,c)){if(!cm(z[e>>2])){break d}Ge(d+112|0);continue}break}o=a,p=pc(v[a+16>>2],v[a+20>>2]),v[o+36>>2]=p;u[d+56>>1]=0;bg(b,d+56|0);c=x[d+56>>1];u[a+28>>1]=c;if((c-201&65535)>>>0<65135){break d}u[d+54>>1]=0;bg(b,d+54|0);c=u[d+54>>1];u[a+30>>1]=c;if((c|0)<0){break d}v[d+48>>2]=0;gp(b,d+48|0);m=zK(z[d+48>>2]);z[a+32>>2]=m;if(!cm(m)){break d}c=d+40|0;Rj(c);Uk(b,c,8);if(Mb(c,16763,8)){break d}b=pc(v[a+4>>2],v[a+8>>2]);if(b>>>0>32767){break d}c=u[a+30>>1];e=a+32|0;q:{if(!(z[e>>2]<=C(0)?0:(c|0)>0)){if(!x[a>>1]){break q}break d}r:{switch(x[a>>1]-1|0){case 0:case 2:break r;default:break q}}if(b>>>0<c>>>0){break d}}b=0;c=v[a+36>>2];if(c){b=c-1|0;v[a+36>>2]=b}o=d,p=Ei(b),v[o+112>>2]=p;v[d+32>>2]=0;o=a,p=v[Gj(d+112|0,d+32|0,43936)>>2],v[o+36>>2]=p;ip(a);g=1;if(x[a>>1]!=3){break d}if((u[a+30>>1]-u[a+28>>1]|0)>(HK(pc(v[a+4>>2],v[a+8>>2]))|0)){break d}c=Rb(d+112|0);b=0;while(1){s:{if(u[a+30>>1]<=(b|0)){b=x[a+28>>1];u[d+32>>1]=b;o=d,p=(pc(v[a+4>>2],v[a+8>>2])+b|0)-1|0,u[o+34>>1]=p;v[22440]=0;u[d+30>>1]=0;ea(911,a|0,c|0,e|0,d+32|0,d+30|0)|0;a=v[22440];v[22440]=0;g=1;if((a|0)==1){break s}fc(c);break d}g=u[a+28>>1];f=v[a+4>>2];v[22440]=0;R(917,c|0,Ib(f,b-g|0)|0);g=v[22440];v[22440]=0;if((g|0)!=1){b=b+1|0;continue}}break}g=P()|0;O()|0;fc(c);break a}rb(b);break d}rb(b);break d}g=P()|0;O()|0}rb(b);break a}rb(b)}cb=d+128|0;return g|0}g=P()|0;O()|0;rb(b);break a}g=P()|0;O()|0;rb(b)}S(g|0);L()}function Gja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;d=cb-336|0;cb=d;sc(b);a:{if(!ao(b,d+320|0)){break a}if(!XT(d+320|0)){break a}if(!Mb(d+320|0,14250,4)){Ob(b,4)}if(!$h(b,d+312|0)){break a}if(Mb(d+312|0,14226,4)){break a}if(!c){f=1;break a}n=d+312|4;e=n;JB(b,d+120|0,w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));if((w[d+156|0]|w[d+157|0]<<8)>>>0>128|(w[d+162|0]|w[d+163|0]<<8)>>>0>16|((w[d+160|0]|w[d+161|0]<<8)>>>0>256|(w[d+154|0]|w[d+155|0]<<8)>>>0>128)){break a}ud(a,8192);i=d+32|0;e=jc(i,6542);Cb(a+1298344|0,e);rb(e);e=jc(i,10160);Cb(a+1298356|0,e);rb(e);v[a+1298404>>2]=5;e=d+96|0;Gi(e,2,d+120|0);xc(i,v[d+96>>2],v[d+100>>2],w[d+104|0]);tc(a+1298308|0,i);rb(i);u[d+32>>1]=w[d+162|0]|w[d+163|0]<<8;u[d+96>>1]=1;g=x[ie(i,e)>>1];u[a+480188>>1]=g;v[a+480196>>2]=w[d+166|0];v[a+480204>>2]=B(w[d+167|0],1e4);t[d+32|0]=w[d+164|0];t[d+96|0]=64;e=w[Tb(i,e)|0];v[a+480200>>2]=e<<2;if(!e){v[a+480200>>2]=256}e=w[d+165|0];b:{if((e|0)==128){v[d+32>>2]=256/(g>>>0);v[d+96>>2]=128;e=v[Bb(d+32|0,d+96|0)>>2];break b}e=e&127}v[a+480228>>2]=e;while(1){if((f|0)==16){i=a+484360|0;o=Nb(i);g=d+184|0;k=cb-16|0;cb=k;v[k+12>>2]=w[d+156|0]|w[d+157|0]<<8;e=k+12|0;qc(e,128);qc(e,65535);e=x[k+12>>1];Ff(o,e);f=0;while(1){if((e|0)==(f|0)){cb=k+16|0}else{p=w[f+g|0];s=Oi(v[o>>2],v[o+4>>2],f),y=(p|0)==255?-1:(p|0)==254?-2:p,u[s>>1]=y;f=f+1|0;continue}break}e=w[d+154|0]|w[d+155|0]<<8;if(e>>>0<(w[d+156|0]|w[d+157|0]<<8)>>>0){Qe(Nb(i),e)}k=c&2;q=a+484344|0;f=1;o=c&1;p=d+68|0;i=a+480188|0;while(1){if(!$h(b,d+312|0)){break a}c=d+32|0;Td(c,b,w[n|0]|w[n+1|0]<<8|(w[n+2|0]<<16|w[n+3|0]<<24));l=cc(d+96|0,c);sb(c);c:{d:{if(!(Mb(d+312|0,13615,4)|!o)){v[22440]=0;g=r&65535;e=Y(229,q|0,g|0,64)|0;c=v[22440];v[22440]=0;if((c|0)==1){break d}if(!e){break c}v[22440]=0;Q(190,d+96|0,2)|0;c=v[22440];v[22440]=0;if((c|0)==1){break d}Ej(d+32|0);m=0;e:{while(1){v[22440]=0;e=Q(158,d+96|0,1)|0;c=v[22440];v[22440]=0;f:{if((c|0)!=1){if(!(e&m>>>0<64)){break e}v[22440]=0;h=T(208,l|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break d}if(h){break f}m=m+1|0;continue}break d}j=d+32|0;c=h&15;if(c>>>0<x[i>>1]){j=Zc(Sb(q,g),m,c)}g:{if(!(h&128)){break g}v[22440]=0;e=T(208,l|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break d}if(!e){break g}t[j|0]=e>>>0<109?e+12|0:e}if(h&64){v[22440]=0;e=T(208,l|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break d}t[j+1|0]=e}if(h&32){t[j+2|0]=1;v[22440]=0;e=T(208,l|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break d}t[d+16|0]=e;t[d|0]=64;s=j,y=w[Tb(d+16|0,d)|0],t[s+4|0]=y}if(!(h&16)){continue}v[22440]=0;R(267,d+16|0,l|0);c=v[22440];v[22440]=0;if((c|0)!=1){e=d+16|0;h=Ec(e);h:{i:{j:{k:{l:{c=w[e|0];switch(c-17|0){case 2:break k;case 0:case 1:break l;default:break j}}c=c&15;break i}t[e|0]=33;t[h|0]=145;c=w[e|0];break h}if(c>>>0<17){break h}c=(c&240)==32?9:-1}t[e|0]=c}Ef(j,c&255,w[h|0]);continue}break}break d}r=r+1|0;break c}if(Mb(d+312|0,13620,4)){break c}if(!Sh(a)){break c}e=x[a+480190>>1]+1|0;u[a+480190>>1]=e;v[22440]=0;R(328,l|0,d+32|0);c=v[22440];v[22440]=0;m:{if((c|0)==1){break m}v[22440]=0;g=(B(e&65535,104)+a|0)+484380|0;R(329,d+32|0,g|0);c=v[22440];v[22440]=0;if((c|0)==1){break m}Gi(d,2,p);v[22440]=0;W(225,d+16|0,v[d>>2],v[d+4>>2],w[d+8|0]);c=v[22440];v[22440]=0;if((c|0)==1){break m}c=d+16|0;uc(((x[a+480190>>1]<<5)+a|0)+946304|0,c);rb(c);if(!k){break c}e=d+16|0;m=Nc(e,8,1,0,1);j=2;h=d+45|0;c=w[h|0]|w[h+1|0]<<8;n:{if(!(c&64)){j=0;if(!(c&2)){break n}}Hf(m,j)}if(w[h|0]&4){kd(m,16)}v[22440]=0;Y(222,e|0,g|0,l|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break c}}}a=P()|0;O()|0;sb(d+96|0);S(a|0);L()}sb(d+96|0);continue}}g=(f<<5)+a|0;$e(g+480280|0);e=w[(d+f|0)+168|0];if(e>>>0<=128){u[g+480284>>1]=e<<1}f=f+1|0;continue}}cb=d+336|0;return f|0}function Hfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=cb-256|0;cb=e;sc(b);a:{if(!pU(b,e+184|0)){break a}if(!VQ(e+184|0)){break a}if(!Kb(b,wc(UQ(e+184|0),fb))){break a}b:{if(!c){break b}ud(a,16);f=e+24|0;g=e+184|0;Bj(f,2,g|4);d=e+48|0;xc(d,v[e+24>>2],v[e+28>>2],w[e+32|0]);tc(a+1298308|0,d);rb(d);l=a+480190|0;u[l>>1]=w[e+214|0];u[a+480188>>1]=w[e+217|0];h=jc(d,8394);Cb(a+1298344|0,h);rb(h);h=jc(d,10148);Cb(a+1298356|0,h);rb(h);Xf(f,4214);g=w[g|3];v[e>>2]=g>>>4;v[22440]=0;v[e+180>>2]=g&15;W(309,d|0,f|0,e|0,e+180|0);d=v[22440];v[22440]=0;c:{d:{e:{if((d|0)!=1){d=e+48|0;Cb(a+1298368|0,d);rb(d);Ab(e+24|0);v[a+1298404>>2]=5;g=1;while(1){j=g&65535;if(j>>>0>x[l>>1]){g=0;d=a+480188|0;while(1)if(x[d>>1]<=g>>>0){d=e+48|0;f=cb-16|0;cb=f;h=b;f:{if(!Kb(b,128)){b=d;g=d+128|0;while(1){if((b|0)!=(g|0)){ug(b);b=b+1|0;continue}break}break f}kS(f+8|0,d);md(f,h,v[f+8>>2],v[f+12>>2])}cb=f+16|0;CC(Nb(a+484360|0),d,w[e+211|0]+1|0);b=w[e+216|0];Td(e,h,B(w[e+208|0]|w[e+209|0]<<8,192));i=cc(e+24|0,e);sb(e);n=c&1;if(n){d=w[e+210|0];v[22440]=0;R(228,a+484344|0,d+1|0);d=v[22440];v[22440]=0;if((d|0)==1){break d}}o=b?b:64;p=a+484344|0;q=a+480188|0;while(1){if(w[e+210|0]<m>>>0){b=w[e+212|0]|w[e+213|0]<<8;if(b){v[22440]=0;ga(320,a+1298332|0,h|0,b|0,39,1);b=v[22440];v[22440]=0;if((b|0)==1){break d}}if(!(c&2)){break e}b=a+480190|0;g=1;while(1){c=g&65535;if(c>>>0>x[b>>1]){break e}c=B(c,104)+a|0;d=Nc(e,u[c+484414>>1]&1?16:8,1,0,1);v[22440]=0;Y(222,d|0,c+484380|0,h|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){g=g+1|0;continue}break}break d}g:{h:{if(n){v[22440]=0;b=Y(229,p|0,m&65535,o|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break d}k=0;if(b){break h}}v[22440]=0;Q(190,h|0,64)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break g}break d}while(1){d=k&65535;if(d>>>0>31){break g}v[22440]=0;b=T(196,h|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break d}i:{if(!b|b>>>0>(w[e+208|0]|w[e+209|0]<<8)>>>0|d>>>0>=x[q>>1]){break i}v[22440]=0;Q(157,i|0,B(b,192)-192|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break d}l=0;g=Zc(Sb(p,m),0,d);while(1){if((l|0)==(o|0)){break i}v[22440]=0;R(547,e|0,i|0);b=v[22440];v[22440]=0;if((b|0)!=1){j=Ec(e);d=Oe(e);b=w[e|0];if(b>>>0>=4){t[g|0]=(b>>>2|0)+37;b=w[e|0]}t[g+1|0]=b<<4&48|w[j|0]>>>4;b=w[d|0];d=0;f=0;j:{k:{l:{m:{n:{o:{j=w[j|0]&15;switch(j-8|0){case 0:break l;case 6:break n;case 2:break o;default:break m}}b=(b&240?-16:15)&b;j=10;break k}j=14;r=(b+16&240)>>>4|0;if(r>>>0>8){break k}if(1<<r&435){break l}break k}d=j;f=b}j=d;b=f;if(!((d|f)&255)){break j}}Ef(g,j,b&255)}l=l+1|0;g=B(x[q>>1],6)+g|0;continue}break}break d}k=k+1|0;continue}}m=m+1|0;continue}}else{f=(g<<5)+a|0;$e(f+480280|0);u[f+480284>>1]=(w[(e+g|0)+218|0]<<4|8)&248;g=g+1|0;continue}}else{f=e+48|0;uC(b,f);h=cb-16|0;cb=h;d=(B(j,104)+a|0)+484380|0;ed(d,0);u[h+14>>1]=w[f+35|0]<<2;u[h+12>>1]=256;s=d,y=x[Kc(h+14|0,h+12|0)>>1],u[s+30>>1]=y;i=w[f+22|0]|w[f+23|0]<<8|(w[f+24|0]<<16|w[f+25|0]<<24);p:{if(i>>>0<3){break p}v[d>>2]=i;v[d+4>>2]=w[f+26|0]|w[f+27|0]<<8|(w[f+28|0]<<16|w[f+29|0]<<24);v[h+8>>2]=w[f+30|0]|w[f+31|0]<<8|(w[f+32|0]<<16|w[f+33|0]<<24);v[h+4>>2]=1;s=d,y=v[Pc(h+8|0,h+4|0)>>2]-1|0,v[s+8>>2]=y;qc(d+8|0,i);k=v[d+8>>2];i=v[d+4>>2];q:{if(k>>>0<=i+4>>>0){v[d+4>>2]=0;v[d+8>>2]=0;k=0;i=0;break q}u[d+34>>1]=x[d+34>>1]|2;k=k>>>1|0;i=i>>>1|0}t[d+37|0]=w[f+34|0];s=d,y=Eu(0,t[f+34|0]<<4),v[s+24>>2]=y;if(!(t[f+36|0]&1)){break p}v[d+8>>2]=k;v[d+4>>2]=i;u[d+34>>1]=x[d+34>>1]|1;v[d>>2]=v[d>>2]>>>1}cb=h+16|0;Bl(e,2,f);d=e+24|0;xc(d,v[e>>2],v[e+4>>2],w[e+8|0]);uc(((j<<5)+a|0)+946304|0,d);g=g+1|0;rb(d);continue}}}g=P()|0;O()|0;Ab(e+24|0);break c}v[a+480260>>2]=64;v[a+480264>>2]=32767;sb(i);break b}g=P()|0;O()|0;sb(i)}S(g|0);L()}g=1}cb=e+256|0;return g|0}function ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=cb-736|0;cb=i;a:{b:{if(d>>>0<=511){a=cb-16|0;cb=a;f=i+56|0;Ub(a+8|0,f,554);d=v[a+12>>2];Yb(a,b,v[a+8>>2],d);h=v[a+4>>2];if((h|0)==(d|0)){Ob(b,v[a+12>>2])}cb=a+16|0;a=(d|0)==(h|0);if(!a){Hb(f,0,554)}if(!a){break b}b=cb-32|0;cb=b;c:{a=i+56|0;if(Mb(a,14083,4)){break c}Hq(b,a+32|0);d=b+16|0;xc(d,v[b>>2],v[b+4>>2],w[b+8|0]);uc(c+492|0,d);rb(d);Wh(b,1,a+4|0);xc(d,v[b>>2],v[b+4>>2],w[b+8|0]);uc(c+524|0,d);rb(d);d=w[a+24|0]|w[a+25|0]<<8;v[c+4>>2]=64;v[c+8>>2]=128;v[c>>2]=d<<6;t[c+16|0]=w[a+26|0];t[c+17|0]=w[a+27|0];f=c+108|0;h=c+236|0;while(1)if((e|0)==120){d=w[c+60|0]&-2|t[a+17|0]&1;t[c+60|0]=d;d=d&-3|w[a+17|0]&2;t[c+60|0]=d;t[c+60|0]=d&251|w[a+17|0]&4;f=c+61|0;t[f|0]=w[a+18|0];h=c+62|0;t[h|0]=w[a+19|0];g=c+63|0;t[g|0]=w[a+20|0];j=c- -64|0;t[j|0]=w[a+21|0];d=c+48|0;Qg(d,25);k=v[c+48>>2];e=0;while(1){d:{if((e|0)!=25){l=Ib(k,e);m=e<<1;n=w[(a+m|0)+504|0];u[l>>1]=n;if((n|0)!=255){break d}Qg(d,e)}a=ff(f,h);if(Dd(d)>>>0<=w[a|0]){t[c+60|0]=w[c+60|0]&253}a=ff(g,j);if(Dd(d)>>>0>w[a|0]){break c}t[c+60|0]=w[c+60|0]&251;break c}t[l+2|0]=w[(a+(m|1)|0)+504|0];e=e+1|0;continue}}else{g=a+(e<<1)|0;d=w[g- -64|0];o=Xb(h,e),p=w[g+65|0],u[o>>1]=p;o=Eb(f,e),p=(d>>>0<120?d:e)+1|0,t[o|0]=p;e=e+1|0;continue}}cb=b+32|0;break b}h=v[b+8>>2];e=cb-32|0;cb=e;v[e+28>>2]=674;v[e+8>>2]=674;f=v[Bb(e+28|0,e+8|0)>>2];if(!Kb(b,f)){f=_e(b)}g=e+8|0;d=i+56|0;NS(g,d);j=$b(e+16|0,v[e+8>>2],f);Yb(e,b,v[j>>2],v[j+4>>2]);NS(g,d);Hb(v[e+8>>2]+f|0,0,674-f|0);Ob(b,v[e+28>>2]);cb=e+32|0;f=v[a+480180>>2];a=0;e=cb-32|0;cb=e;if(!Mb(d,14083,4)){Hq(e,d+32|0);a=e+16|0;xc(a,v[e>>2],v[e+4>>2],w[e+8|0]);uc(c+492|0,a);rb(a);Wh(e,1,d+4|0);xc(a,v[e>>2],v[e+4>>2],w[e+8|0]);uc(c+524|0,a);rb(a);v[c>>2]=(w[d+20|0]|w[d+21|0]<<8)<<5;v[c+4>>2]=w[d+24|0]>>>1;qc(c+4|0,64);g=w[d+25|0]&127;v[c+8>>2]=g>>>0>64?128:g<<2;t[c+15|0]=w[c+15|0]&254|((w[d+25|0]^-1)&128)>>>7;t[e+16|0]=w[d+26|0];t[e|0]=100;o=c,p=w[Tb(a,e)|0],t[o+20|0]=p;t[e+16|0]=w[d+27|0];t[e|0]=64;o=c,p=w[Tb(a,e)|0],t[o+19|0]=p;t[c+16|0]=w[d+17|0];t[c+17|0]=w[d+18|0];t[c+18|0]=w[d+19|0];t[c+26|0]=w[d+22|0];t[c+27|0]=w[d+23|0];a=w[d+58|0];Jj(c,a&127,a>>>7|0);a=w[d+59|0];Ij(c,a&127,a>>>7|0);e:{f:{g:{h:{i:{a=w[d+28|0]|w[d+29|0]<<8;switch(a-529|0){case 1:case 2:break g;case 0:case 3:break h;default:break i}}if((a|0)==544){break h}if((a|0)!=514){break g}}a=w[d+61|0];if((a|0)==255){break g}if(a>>>0<=128){t[c+30|0]=a}a=w[d+62|0]|w[d+63|0]<<8;if(a>>>0<129){break f}break e}a=t[d+61|0];if((a|0)>=0){t[c+30|0]=a+1}a=w[d+62|0];a=a<<24>>24>=0?a+1|0:0;g=t[d+63|0];if((g|0)<0){break f}a=((g&255)<<7)+a|0}u[c+28>>1]=a}a=t[d+60|0];t[c+31|0]=a;if((a|0)<0){t[c+31|0]=0;t[c+34|0]=a^128}a=0;f=f&16777216?240:25;$u(d+304|0,c+48|0,0,f);$u(d+386|0,c+68|0,32,f);$u(d+468|0,c+88|0,32,f);t[c+100|0]=w[c+100|0]&239|w[d+468|0]>>>3&16;g=c+108|0;j=c+236|0;while(1){if((a|0)!=120){k=d+(a<<1)|0;f=w[k- -64|0];o=Xb(j,a),p=w[k+65|0],u[o>>1]=p;o=Eb(g,a),p=(f>>>0<120?f:a)+1|0,t[o|0]=p;a=a+1|0;continue}break}a=554}cb=e+32|0;if(a){j:{e=d+550|0;if(Mb(e,13552,4)){if(Mb(e,13911,4)){break j}}e=c+236|0;a=0;while(1){if((a|0)!=120){f=Xb(e,a);u[f>>1]=x[f>>1]|w[(a+d|0)+554|0]<<8;a=a+1|0;continue}break}a=674}}else{a=0}Tc(b,a+h|0);if(!Ah(b,14088)){break b}d=i+8|0;Td(d,b,Ag(b));a=cc(i+32|0,d);sb(d);v[22440]=0;T(162,a|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break a}v[22440]=0;b=Q(414,a|0,13834)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}if(b){v[22440]=0;b=T(208,a|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}t[c+34|0]=b>>>0>250?0:b}sb(a)}cb=i+736|0;return}b=P()|0;O()|0;sb(a);S(b|0);L()}function I_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=cb-32|0;cb=h;v[h+24>>2]=b;v[e>>2]=0;i=h+8|0;Jc(i,d);v[22440]=0;i=T(19,i|0)|0;j=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Pb(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Pb(h+8|0);S(a|0);L()}nF(a,f+24|0,h+24|0,c,e,i);break b}mF(a,f+16|0,h+24|0,c,e,i);break b}g=a;i=b;a=gb[v[v[a+8>>2]+12>>2]](a+8|0)|0;b=Fb(a);k=h,l=Wj(g,i,c,d,e,f,b,vb(a)+b|0),v[k+24>>2]=l;break b}a=Wi(h+24|0,c,e,i,2);b=v[e>>2];B:{if(!(b&4|a-1>>>0>30)){v[f+12>>2]=a;break B}v[e>>2]=b|4}break b}v[h+8>>2]=623865125;v[h+12>>2]=2032480100;k=h,l=Wj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}v[h+8>>2]=623728933;v[h+12>>2]=1680158061;k=h,l=Wj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=Wi(h+24|0,c,e,i,2);b=v[e>>2];C:{if(!(b&4|(a|0)>23)){v[f+8>>2]=a;break C}v[e>>2]=b|4}break b}a=Wi(h+24|0,c,e,i,2);b=v[e>>2];D:{if(!(b&4|a-1>>>0>11)){v[f+8>>2]=a;break D}v[e>>2]=b|4}break b}a=Wi(h+24|0,c,e,i,3);b=v[e>>2];E:{if(!(b&4|(a|0)>365)){v[f+28>>2]=a;break E}v[e>>2]=b|4}break b}a=Wi(h+24|0,c,e,i,2);b=v[e>>2];F:{if(!(b&4|(a|0)>12)){v[f+16>>2]=a-1;break F}v[e>>2]=b|4}break b}a=Wi(h+24|0,c,e,i,2);b=v[e>>2];G:{if(!(b&4|(a|0)>59)){v[f+4>>2]=a;break G}v[e>>2]=b|4}break b}a=h+24|0;b=cb-16|0;cb=b;v[b+8>>2]=c;while(1){H:{if(!To(a,b+8|0)){break H}if(!qh(i,8192,Tk(v[a>>2]))){break H}Ul(a);continue}break}if(Xj(a,b+8|0)){v[e>>2]=v[e>>2]|2}cb=b+16|0;break b}b=h+24|0;a=gb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((vb(a)|0)==(0-vb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=qr(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=w[79748]|w[79749]<<8|(w[79750]<<16|w[79751]<<24);t[h+15|0]=g;t[h+16|0]=g>>>8;t[h+17|0]=g>>>16;t[h+18|0]=g>>>24;g=w[79745]|w[79746]<<8|(w[79747]<<16|w[79748]<<24);v[h+8>>2]=w[79741]|w[79742]<<8|(w[79743]<<16|w[79744]<<24);v[h+12>>2]=g;k=h,l=Wj(a,b,c,d,e,f,h+8|0,h+19|0),v[k+24>>2]=l;break b}t[h+12|0]=w[79756];v[h+8>>2]=w[79752]|w[79753]<<8|(w[79754]<<16|w[79755]<<24);k=h,l=Wj(a,b,c,d,e,f,h+8|0,h+13|0),v[k+24>>2]=l;break b}a=Wi(h+24|0,c,e,i,2);b=v[e>>2];J:{if(!(b&4|(a|0)>60)){v[f>>2]=a;break J}v[e>>2]=b|4}break b}v[h+8>>2]=624576549;v[h+12>>2]=1394948685;k=h,l=Wj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=Wi(h+24|0,c,e,i,1);b=v[e>>2];K:{if(!(b&4|(a|0)>6)){v[f+24>>2]=a;break K}v[e>>2]=b|4}break b}a=gb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=gb[v[v[a+8>>2]+24>>2]](a+8|0)|0;b=Fb(a);k=h,l=Wj(g,i,c,d,e,f,b,vb(a)+b|0),v[k+24>>2]=l;break b}lF(f+20|0,h+24|0,c,e,i);break b}a=Wi(h+24|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=cb-16|0;cb=a;v[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(Xj(c,a+8|0)){break M}b=4;if((Zm(i,Tk(v[c>>2]))|0)!=37){break M}b=2;if(!Xj(Ul(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}cb=a+16|0}a=v[h+24>>2]}cb=h+32|0;return a|0}function Gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;f=cb-48|0;cb=f;a:{b:{if(!c){break b}g=Bh(a,b);a=yb(v[d>>2]);v[f+40>>2]=a;d=yb(v[d+4>>2]);while(1){if(!Qb(a,d)){break b}sc(a);c:{if((Ii(a)|0)==(c|0)){Ob(a,20);c=Ii(a);k=Jg(f+24|0);d=ul(f+16|0,0,b?32:64);v[22440]=0;R(405,g|0,d|0);d=v[22440];v[22440]=0;if((d|0)==1){break c}n=(b|0)==2?4096:(b|0)==1?2048:16384;d=24;c=c+24|0;o=1;l=1;d:{while(1){i=n;while(1){v[22440]=0;e=Q(158,a|0,1)|0;h=v[22440];v[22440]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){if(!e){break d}e=Dd(g);h=v[a+8>>2];v[22440]=0;v[f+16>>2]=h;h=Q(406,k|0,f+16|0)|0;p=v[22440];v[22440]=0;if((p|0)==1){break a}v[h>>2]=e;v[22440]=0;e=T(208,a|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break a}q:{switch(e-128|0){case 3:case 4:case 7:case 8:break e;case 5:case 6:case 9:case 10:break h;case 2:break i;case 1:break j;case 0:break k;default:break q}}r:{switch(e|0){case 0:break g;case 5:break l;case 4:break m;case 3:break n;case 2:break o;case 1:break p;default:break r}}s:{switch(e-160|0){case 3:case 4:break e;case 5:case 6:break h;case 2:break i;case 1:break j;case 0:break k;default:break s}}switch(e-192|0){case 2:break i;case 1:break j;case 0:break k;default:break e}}break a}if(w[g+12|0]&4){break e}v[22440]=0;e=T(278,a|0)|0;h=v[22440];v[22440]=0;t:{if((h|0)==1){break t}v[22440]=0;v[f+16>>2]=e;e=Q(406,k|0,f+16|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break t}t[g+15|0]=v[e>>2];s=g,y=Dd(g)-1|0,t[s+16|0]=y;t[g+12|0]=w[g+12|0]|4;break e}break a}v[22440]=0;e=T(278,a|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break a}u[f+16>>1]=e;u[f+14>>1]=1;e=x[ie(f+16|0,f+14|0)>>1];i=B(e,B(q<<16>>16,l))+i|0;u:{if(e>>>0<2){break u}s=f,y=xl((e+x[zj(v[g+4>>2])>>1]|0)-1|0),u[s+16>>1]=y;e=Tt(b,i);v[22440]=0;t[f+14|0]=e;U(407,g|0,f+16|0,f+14|0);e=v[22440];v[22440]=0;if((e|0)!=1){break u}break a}s=f,y=xl(x[zj(v[g+4>>2])>>1]+1|0),u[s+16>>1]=y;e=Tt(b,i);v[22440]=0;t[f+14|0]=e;U(407,g|0,f+16|0,f+14|0);e=v[22440];v[22440]=0;if((e|0)!=1){break e}break a}v[22440]=0;j=T(208,a|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break a}r=v[a+8>>2];break e}v[22440]=0;e=T(278,a|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break a}e=d+e|0;v[f+16>>2]=e;if(!(!(j&255)|e>>>0<r>>>0)){j=j-1|0;if(!(j&255)){break f}v[22440]=0;Q(157,a|0,e|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){break e}break a}if(!(j&255)){break f}v[22440]=0;e=Q(408,k|0,f+16|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break a}t[g+13|0]=v[e>>2];s=g,y=Dd(g)-1|0,t[s+14|0]=y;t[g+12|0]=w[g+12|0]|2;break e}o=0;m=1;break e}v[22440]=0;i=T(278,a|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break a}e=Tt(b,i);s=zj(v[g+4>>2]),y=e,t[s+2|0]=y;break e}v[22440]=0;q=T(409,a|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){break e}break a}v[22440]=0;e=T(208,a|0)|0;l=v[22440];v[22440]=0;if((l|0)!=1){t[f+16|0]=e;t[f+14|0]=1;l=w[ff(f+16|0,f+14|0)|0];break e}break a}v[22440]=0;Q(190,a|0,1)|0;e=v[22440];v[22440]=0;if((e|0)==1){break a}break e}m=1;if(c>>>0>d>>>0){break e}break d}j=0}if(!m|c>>>0<=d>>>0){continue}break}v[22440]=0;d=Q(157,a|0,c|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break a}if(!d){break d}v[22440]=0;d=Q(158,a|0,2)|0;i=v[22440];v[22440]=0;if((i|0)==1){break a}if(!d){break d}d=w[g+12|0];if(!(!o|d&4)){i=Dd(g);t[g+12|0]=d|4;d=i-1|0;t[g+15|0]=d;t[g+16|0]=d}s=f,y=xl(x[zj(v[g+4>>2])>>1]+1|0),u[s+16>>1]=y;d=Tt(b,n);v[22440]=0;t[f+14|0]=d;U(407,g|0,f+16|0,f+14|0);d=v[22440];v[22440]=0;if((d|0)!=1){m=1;t[g+17|0]=w[g+16|0]+1;d=c;continue}break}break a}t[g+12|0]=w[g+12|0]|1;$S(k);break b}Uf(f+40|0);a=v[f+40>>2];continue}break}break a}cb=f+48|0;return}a=P()|0;O()|0;$S(k);S(a|0);L()}function dM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=cb-16|0;cb=f;h=a+1074376|0;g=B(b,872);e=(h+g|0)+616|0;d=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+g|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(w[a+480209|0]&16)){break a}c=B(b,872)+a|0;if(uj(v[c+1075648>>2])){u[c+1075764>>1]=d-8;a=c+1075843|0;t[a|0]=w[a|0]|64;break a}if(v[a+480180>>2]!=64){b=B(b,872)+a|0;u[b+1075764>>1]=d<<28>>24;c=x[(d<<1)+33392>>1];v[b+1075696>>2]=c;e=b+1075692|0;if(!v[e>>2]){break a}l=e,m=ch(a,w[b+1075789|0],d<<28>>24,c),v[l>>2]=m;break a}a=B(b,872)+a|0;b=v[a+1075096>>2];if(!b){break a}v[a+1075696>>2]=v[b+24>>2]+B(d,80);break a;case 2:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075814|0]=c&3;break a}ub(f+8|0,a+1074312|0,21);if(tb(v[v[f+8>>2]>>2],v[f+12>>2])){t[(B(b,872)+a|0)+1075814|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075817|0]=c&3;break a}ub(f+8|0,a+1074312|0,21);if(tb(v[v[f+8>>2]>>2],v[f+12>>2])){t[(B(b,872)+a|0)+1075817|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075817|0]=c&7;break a;case 4:ub(f+8|0,a+1074312|0,21);if(tb(v[v[f+8>>2]>>2],v[f+12>>2])){a=B(b,872)+a|0;t[a+1075813|0]=0;t[a+1075820|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(v[a+1074392>>2]|!(w[a+480209|0]&16)){break a}a=a+1074400|0;v[a>>2]=v[a>>2]+d;break a;case 6:if(!(w[a+480209|0]&16)){break a}if(d>>>0<=2){d=x[a+480188>>1];i=d>>>0>256?d:256;e=a+1298300|0;j=b+1|0;k=(c&15)-1|0;while(1){if((d|0)==(i|0)){break a}c=B(d,872)+a|0;c:{if((j|0)!=x[c+1075778>>1]){break c}d:{e:{switch(k|0){case 0:Bn(a,c+1074992|0);if(!(w[c+1075081|0]&2)){break d}if(!Bd(e)){break d}fk(v[e>>2],d&65535);break d;case 1:g=c+1075080|0;h=v[g>>2];v[g>>2]=h|4096;if(!(h&512)){break d}if(!Bd(e)){break d}fk(v[e>>2],d&65535);break d;default:break e}}v[c+1075688>>2]=0;g=c+1075080|0;h=v[g>>2];v[g>>2]=h|4096;if(!(h&512)){break d}if(!Bd(e)){break d}pj(v[e>>2],d&65535,1)}h=v[c+1075648>>2];if(!h){break c}g=w[h+34|0];if(!g){break c}g=v[(B(g,160)+a|0)+906140>>2];if(!g){break c}gb[v[v[g>>2]+92>>2]](g,h,w[c+1075789|0]+255|0,0,b)}d=d+1|0;continue}}FO(e,d,a);break a;case 7:if(!(w[a+480209|0]&16)){break a}im(a,e,d,4);break a;case 8:b=v[a+480208>>2];f:{if(!(b&4096)){break f}g:{switch(d&15){case 0:v[e+88>>2]=v[e+88>>2]&-257;break f;case 1:v[e+692>>2]=128;v[e+88>>2]=v[e+88>>2]|256;break f;case 8:v[e+88>>2]=v[e+88>>2]&-25165825|16777216;break f;case 9:v[e+88>>2]=v[e+88>>2]&-25165825|8388608;break f;case 10:v[a+480208>>2]=b&-16385;break f;case 11:v[a+480208>>2]=b|16384;break f;case 12:v[a+480208>>2]=b&-8193;break f;case 13:v[a+480208>>2]=b|8192;break f;case 14:v[e+88>>2]=v[e+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(v[e>>2]|v[e+4>>2]){break h}a=v[e+76>>2];if(!a){break h}if(!(l=Rc(w[e+788|0]),m=1,n=w[e+88|0]&2,n?l:m)){break h}v[e>>2]=-1;v[e+4>>2]=a-1}v[e+88>>2]=v[e+88>>2]|128}break a;case 9:if(!(w[a+480209|0]&16)){break a}c=B(b,872)+a|0;t[c+1075828|0]=d;ub(f+8|0,a+1074312|0,35);if(tb(v[v[f+8>>2]>>2],v[f+12>>2])){break a}if(!Rc(w[c+1075780|0])){break a}b=v[(B(b,872)+a|0)+1075068>>2];a=d<<16;if(b>>>0<=a>>>0){break a}v[e+4>>2]=a;break a;case 10:if(!(w[a+480209|0]&16)){break a}Ps(a,h,e,d);break a;case 11:i:{if(d){break i}d=1;c=v[a+480180>>2];if(c&16777248){break i}d=0;if((c|0)==2){break a}}ub(f+8|0,a+1074312|0,30);if(tb(v[v[f+8>>2]>>2],v[f+12>>2])){c=1}else{c=v[a+480180>>2]==2}vy(a,b,d,c);break a;case 14:break b;default:break a}}if(v[a+480180>>2]==2){break a}t[(B(b,872)+a|0)+1075836|0]=d}cb=f+16|0}function _j(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=1;o(+b);f=j(1)|0;e=j(0)|0;a:{b:{m=f&2147483647;g=e;c:{if(!(m|e)){break c}o(+a);e=j(1)|0;t=j(0)|0;if(!t&(e|0)==1072693248){break c}q=e&2147483647;if(!(!(q>>>0>2146435072|(q|0)==2146435072&(t|0)!=0|m>>>0>2146435072)&(!g|(m|0)!=2146435072))){return a+b}d:{e:{f:{r=0;g:{if((e|0)>0|(e|0)>=0){break g}r=2;if(m>>>0>1128267775){break g}r=0;if(m>>>0<1072693248){break g}h=m>>>20|0;if(m>>>0<1094713344){break f}d=1075-h|0;h=g>>>d|0;r=0;if((g|0)!=h<<d){break g}r=2-(h&1)|0}d=r;if(!g){break e}break d}if(g){break d}g=1043-h|0;h=m>>>g|0;d=0;if((m|0)!=h<<g){break e}d=2-(h&1)|0}if((m|0)==2146435072){if(!(q-1072693248|t)){break c}if(q>>>0>=1072693248){return(f|0)>0|(f|0)>=0?b:0}return(f|0)>0|(f|0)>=0?0:-b}if((m|0)==1072693248){if((f|0)>0|(f|0)>=0){return a}return 1/a}if((f|0)==1073741824){return a*a}if((f|0)!=1071644672|(e|0)<0){break d}return K(a)}c=D(a);if(!((q?(e&1073741823)!=1072693248:0)|t)){k=(f|0)<0?1/c:c;if((e|0)>0|(e|0)>=0){break c}if(!(q-1072693248|d)){a=k-k;return a/a}return(d|0)==1?-k:k}h:{if((e|0)>0|(e|0)>=0){break h}i:{switch(d|0){case 0:a=a-a;return a/a;case 1:break i;default:break h}}k=-1}j:{if(m>>>0>=1105199105){if(m>>>0>=1139802113){if(q>>>0<=1072693247){return(f|0)<0?N:0}return(f|0)>0?N:0}if(q>>>0<=1072693246){return(f|0)<0?k*1e300*1e300:k*1e-300*1e-300}if(q>>>0>=1072693249){return(f|0)>0?k*1e300*1e300:k*1e-300*1e-300}a=c+-1;c=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;i=c;c=a*1.4426950216293335;o(+(i+c));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();c=i-(a-c);break j}a=c*9007199254740992;g=q>>>0<1048576;c=g?a:c;o(+a);d=j(1)|0;j(0)|0;h=g?d:q;e=h&1048575;d=e|1072693248;h=(h>>20)+(g?-1076:-1023)|0;g=0;k:{if(e>>>0<235663){break k}if(e>>>0<767610){g=1;break k}d=e|1071644672;h=h+1|0}e=g<<3;w=A[e+3536>>3];o(+c);j(1)|0;q=0;l(0,j(0)|q);l(1,d|0);p=+n();s=A[e+3520>>3];i=p-s;u=1/(s+p);c=i*u;o(+c);m=j(1)|0;j(0)|0;l(0,0);l(1,m|0);a=+n();x=a;l(0,q|0);l(1,((g<<18)+(d>>>1|0)|0)+537395200|0);v=a*a;y=i;i=+n();p=u*(y-a*i-a*(p-(i-s)));i=p*(c+a);a=c*c;s=i+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(v+3+s));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();i=x*a;c=p*a+c*(s-(a+-3-v));o(+(i+c));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();c=w+(a*-7.028461650952758e-9+(c-(a-i))*.9617966939259756);i=c;p=A[e+3552>>3];c=a*.9617967009544373;s=+(h|0);o(+(p+(i+c)+s));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();c=i-(a-s-p-c)}l(0,0);l(1,f|0);p=+n();c=(b-p)*a+c*b;b=a*p;a=c+b;o(+a);e=j(1)|0;d=j(0)|0;l:{f=e;if((e|0)>=1083179008){if(d|f-1083179008){break b}if(!(c+8.008566259537294e-17>a-b)){break l}break b}if((f&2147482624)>>>0<1083231232){break l}if(d|f+1064252416){break a}if(!(c<=a-b)){break l}break a}g=0;h=f&2147483647;if(h>>>0>=1071644673){d=f+(1048576>>>(h>>>20|0)-1022|0)|0;f=d>>>20&2047;g=(d&1048575|1048576)>>>1043-f|0;g=(e|0)<0?0-g|0:g;l(0,0);l(1,d&-1048576>>f-1023);b=b-+n();o(+(c+b));e=j(1)|0;j(0)|0}l(0,0);l(1,e|0);a=+n();p=a*.6931471824645996;c=(c-(a-b))*.6931471805599453+a*-1.904654299957768e-9;a=p+c;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);i=a*b/(b+-2);b=a;a=c-(a-p);a=b-(i-(b*a+a))+1;o(+a);d=j(1)|0;e=j(0)|0;d=(g<<20)+d|0;m:{if((d|0)<=1048575){a=Tj(a,g);break m}l(0,e|0);l(1,d|0);a=+n()}k=k*a}return k}return k*1e300*1e300}return k*1e-300*1e-300}function fJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=cb-176|0;cb=e;f=v[b+4>>2];a:{if(!f){break a}g=v[b>>2];h=w[Zk(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}fl(e,g,f,f-1|0);f=v[e+4>>2];v[b>>2]=v[e>>2];v[b+4>>2]=f}Od(e);f=v[e>>2];Od(e+152|0);h=Yk(f,v[e+156>>2],b);Od(e);f=v[b+4>>2];g=v[b>>2];b:{c:{d:{e:{if((h|0)==v[e+4>>2]){a=nc(e+168|0,21685);if(Hc(g,f,v[a>>2],v[a+4>>2])){d=aa(8)|0;v[22440]=0;c=Q(985,e+152|0,c|0)|0;a=v[22440];v[22440]=0;f:{g:{h:{if((a|0)!=1){v[22440]=0;U(986,e|0,17664,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break h}oc(d,e);a=0;v[22440]=0;U(121,d|0,58712,975);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;rb(e);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}rb(c);if(!a){break c}}ba(d|0);break c}if(!d){break e}d=aa(8)|0;v[22440]=0;f=Q(985,e+120|0,b|0)|0;a=v[22440];v[22440]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[22440]=0;U(986,e+136|0,17700,f|0);a=v[22440];v[22440]=0;if((a|0)==1){break q}v[22440]=0;R(988,e+152|0,e+136|0);b=v[22440];v[22440]=0;a=1;if((b|0)==1){break p}v[22440]=0;c=Q(985,e+104|0,c|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break o}v[22440]=0;U(990,e|0,e+152|0,c|0);b=v[22440];v[22440]=0;a=1;if((b|0)==1){break n}oc(d,e);v[22440]=0;U(121,d|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}b=P()|0;O()|0;rb(e);a=0;break m}b=P()|0;O()|0;break i}b=P()|0;a=1;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}rb(c)}rb(e+152|0)}rb(e+136|0)}rb(f);if(!a){break c}}ba(d|0);break c}d=nc(e+96|0,21685);if(Hc(g,f,v[d>>2],v[d+4>>2])){d=aa(8)|0;v[22440]=0;c=Q(985,e+152|0,c|0)|0;a=v[22440];v[22440]=0;r:{s:{t:{if((a|0)!=1){v[22440]=0;U(986,e|0,17664,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break t}oc(d,e);a=0;v[22440]=0;U(121,d|0,58712,975);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;rb(e);break s}b=P()|0;O()|0;break r}b=P()|0;a=1;O()|0}rb(c);if(!a){break c}}ba(d|0);break c}f=v[b>>2];g=v[b+4>>2];d=nc(e+88|0,12389);if(Hc(f,g,v[d>>2],v[d+4>>2])){b=v[c>>2];d=v[c+4>>2];f=nc(e+80|0,5604);if(Hc(b,d,v[f>>2],v[f+4>>2])){v[a+52>>2]=0;break e}f=nc(e+72|0,11321);if(Hc(b,d,v[f>>2],v[f+4>>2])){v[a+52>>2]=1;break e}f=b;b=nc(e- -64|0,9235);if(Hc(f,d,v[b>>2],v[b+4>>2])){v[a+52>>2]=2;break e}d=aa(8)|0;v[22440]=0;c=Q(985,e+152|0,c|0)|0;a=v[22440];v[22440]=0;u:{v:{w:{if((a|0)!=1){v[22440]=0;U(986,e|0,14709,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break w}oc(d,e);a=0;v[22440]=0;U(121,d|0,58712,975);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;rb(e);break v}b=P()|0;O()|0;break u}b=P()|0;a=1;O()|0}rb(c);if(!a){break c}}ba(d|0);break c}d=v[b>>2];f=v[b+4>>2];b=nc(e+56|0,11558);if(!Hc(d,f,v[b>>2],v[b+4>>2])){break e}b=0;x:{d=v[c>>2];c=v[c+4>>2];f=nc(e+48|0,15627);if(Hc(d,c,v[f>>2],v[f+4>>2])){break x}b=1;f=nc(e+40|0,15632);if(Hc(d,c,v[f>>2],v[f+4>>2])){break x}b=2;f=nc(e+32|0,12663);if(Hc(d,c,v[f>>2],v[f+4>>2])){break x}b=3;f=c;c=nc(e+24|0,9299);if(Hc(d,f,v[c>>2],v[c+4>>2])){break x}a=aa(8)|0;v[22440]=0;c=Q(56,e|0,11594)|0;b=v[22440];v[22440]=0;if((b|0)==1){break d}oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}b=P()|0;O()|0;rb(c);break c}v[a+56>>2]=b;a=a+24|0;if(!v[v[a>>2]+24668>>2]){break e}a=v[a>>2];c=a+24664|0;d=v[c+4>>2];v[e+16>>2]=v[c>>2];v[e+20>>2]=d;c=a+24656|0;d=v[c+4>>2];v[e+8>>2]=v[c>>2];v[e+12>>2]=d;c=v[a+24652>>2];v[e>>2]=v[a+24648>>2];v[e+4>>2]=c;i=e,j=LI(b),v[i+20>>2]=j;if(!dx(e,a+24648|0)){break e}fy(a,e)}cb=e+176|0;return}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function eja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=cb-976|0;cb=f;sc(b);d=cb-16|0;cb=d;i=f+872|0;GT(d+8|0,i);g=v[d+12>>2];Yb(d,b,v[d+8>>2],g);h=v[d+4>>2];if((h|0)==(g|0)){Ob(b,v[d+12>>2])}cb=d+16|0;d=(g|0)==(h|0);if(!d){FT(i)}a:{if(!d){break a}if(!IT(f+872|0)){break a}if(!Kb(b,wc(HT(f+872|0),fb))){break a}b:{if(!c){break b}ud(a,512);v[a+480228>>2]=32;u[a+480188>>1]=16;v[a+480196>>2]=w[f+947|0];v[a+480208>>2]=16;v[a+480200>>2]=256;v[a+480204>>2]=8e5;Gb(a+1074312|0,7,1);e=f+96|0;d=jc(e,8253);Cb(a+1298344|0,d);rb(d);d=jc(e,8941);Cb(a+1298356|0,d);rb(d);v[a+1298404>>2]=5;ET(f+16|0,f+872|4);xc(e,v[f+16>>2],v[f+20>>2],w[f+24|0]);tc(a+1298308|0,e);rb(e);e=0;while(1){if((e|0)==16){c:{e=w[f+968|0]|w[f+969|0]<<8;if(e){oB(a+1298332|0,b,e,132,0)}e=0;d=cb-16|0;cb=d;i=f+96|0;Ub(d+8|0,i,771);g=v[d+12>>2];Yb(d,b,v[d+8>>2],g);h=v[d+4>>2];if((h|0)==(g|0)){Ob(b,v[d+12>>2])}cb=d+16|0;d=(g|0)==(h|0);if(!d){Hb(i,0,771)}if(!d){break a}e=a+484360|0;DT(Nb(e),f+96|0,w[f+353|0]);Qe(Nb(e),w[f+354|0]);Tc(b,w[f+919|0]|w[f+920|0]<<8);n=a+484344|0;p=c&1;i=0;while(1){d:{if((i|0)==256){e=1;if(!(c&2)){break a}JU(b,f- -64|0);e=0;while(1){if((e|0)==64){break b}if(!(w[f- -64+(e>>>3)|0]>>>(e&7)&1)){e=e+1|0;continue}if(!XA(b,f+16|0)){break b}e=e+1|0;u[a+480190>>1]=e;c=f+16|0;Ie(f,1,c);i=f+72|0;xc(i,v[f>>2],v[f+4>>2],w[f+8|0]);uc(((x[a+480190>>1]<<5)+a|0)+946304|0,i);rb(i);d=(B(e,104)+a|0)+484380|0;ed(d,0);j=w[c+32|0]|w[c+33|0]<<8|(w[c+34|0]<<16|w[c+35|0]<<24);v[d>>2]=j;g=w[c+38|0]|w[c+39|0]<<8|(w[c+40|0]<<16|w[c+41|0]<<24);v[d+4>>2]=g;h=w[c+42|0]|w[c+43|0]<<8|(w[c+44|0]<<16|w[c+45|0]<<24);v[d+24>>2]=16726;v[d+8>>2]=h;u[d+30>>1]=w[c+37|0]<<4;if(t[c+46|0]&1){h=h>>>1|0;v[d+8>>2]=h;g=g>>>1|0;v[d+4>>2]=g;v[d>>2]=j>>>1}if(!(!(w[c+47|0]&8)|g>>>0>=h>>>0)){u[d+34>>1]=x[d+34>>1]|2}Nc(i,t[c+46|0]&1?16:8,1,0,0);vg(i,d,b);continue}}e:{e=(i<<1)+f|0;g=w[e+355|0]|w[e+356|0]<<8;if(g){d=f+72|0;Td(d,b,g);o=cc(f+16|0,d);sb(d);j=((w[e+355|0]|w[e+356|0]<<8)-2|0)/64|0;f:{if(!p){break f}v[22440]=0;e=Y(229,n|0,i&65535,j|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break e}if(!e){break f}v[22440]=0;e=T(208,o|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}v[22440]=0;Q(190,f+16|0,1)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}q=e?e>>>0<j-2>>>0?e+1|0:-1:-1;g=0;g:while(1){h:{d=Sb(n,i);if((g|0)==(j|0)){break h}e=0;l=Gf(d,g);while(1){if((e|0)==16){g=g+1|0;continue g}v[22440]=0;R(360,f+72|0,o|0);d=v[22440];v[22440]=0;if((d|0)==1){break d}d=f+72|0;h=Oe(d);m=Li(d);d=w[d|0];if((d-1&255)>>>0<=71){k=B(e,6)+l|0;t[k|0]=d+36;r=k,s=w[Ec(f+72|0)|0]+1|0,t[r+1|0]=s}if((w[h|0]-1&255)>>>0<=15){d=B(e,6)+l|0;t[d+2|0]=1;t[d+4|0]=((w[h|0]<<6)+-64>>>0)/15}d=B(e,6)+l|0;k=w[m|0];h=k&15;t[d+5|0]=h;i:{j:{switch((w[m|0]>>>4|0)-1|0){case 0:case 1:t[d+5|0]=k|240;break i;case 2:t[d+5|0]=h<<2;break i;case 3:t[d+5|0]=(6/(h+1>>>0)|0)+1;break i;case 5:case 6:t[d+5|0]=h<<3;break i;case 9:t[d+4|0]=(h<<2)+4;t[d+2|0]=1;break i;case 10:t[d+5|0]=h|128;break i;case 11:break j;default:break i}}t[d+5|0]=(6/(h+1>>>0)|0)+1|13}t[d+3|0]=w[(w[m|0]>>>4|0)+26480|0];e=e+1|0;continue}}break}xe(d,yh(Pe(Je(f+72|0,14,0),q)))}sb(f+16|0)}i=i+1|0;continue}}break}}}else{d=(e<<5)+a|0;g=d+480280|0;$e(g);h=g;g=(f+872|0)+e|0;v[h>>2]=!w[g+50|0]<<10;u[d+480284>>1]=(w[g+76|0]<<4|8)&248;e=e+1|0;continue}break}a=P()|0;O()|0;sb(f+16|0);S(a|0);L()}e=1}cb=f+976|0;return e|0}function dba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=cb-112|0;cb=e;f=e+88|0;g=a+140|0;Aj(f,g,1296125513);v[22440]=0;f=T(180,f|0)|0;h=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){if(f){f=Db(e+32|0);v[22440]=0;h=T(162,e+88|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break p}v[22440]=0;U(800,e+88|0,f|0,h|0);h=v[22440];v[22440]=0;if((h|0)==1){break p}h=x[a+174>>1];v[22440]=0;U(801,e+72|0,h|0,f|0);h=v[22440];v[22440]=0;if((h|0)==1){break o}v[22440]=0;U(8,e+8|0,c|0,e+72|0);c=v[22440];v[22440]=0;if((c|0)==1){break n}c=e+8|0;uc(d,c);rb(c);rb(e+72|0);rb(f)}if(w[a+176|0]){v[22440]=0;R(802,e+32|0,d|0);c=v[22440];v[22440]=0;if((c|0)==1){break e}c=e+32|0;pe(b+43|0,c);rb(c)}v[22440]=0;U(795,e+32|0,g|0,1413894985);c=v[22440];v[22440]=0;if((c|0)==1){break l}v[22440]=0;f=T(803,e+32|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break k}g=e+32|0;sb(g);c=a+40|0;sc(c);v[22440]=0;g=Q(804,c|0,g|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break j}if(g){q:{if((w[e+60|0]|w[e+61|0]<<8|(w[e+62|0]<<16|w[e+63|0]<<24))>>>0<2){break q}v[22440]=0;g=Q(805,c|0,e+8|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break i}if(!g){break q}_K(e+8|0,b+12|0,b+16|0,v[b>>2],b+34|0,8,16,f)}v[22440]=0;c=Q(805,c|0,e+8|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break i}if(c){_K(e+8|0,b+4|0,b+8|0,v[b>>2],b+34|0,2,4,f)}c=w[e+44|0]|w[e+45|0]<<8|(w[e+46|0]<<16|w[e+47|0]<<24);t[b+42|0]=c&128?0:c+1|0;yk(b)}r:{if(w[b+42|0]){break r}v[22440]=0;c=a+60|0;f=Q(669,c|0,7)|0;g=v[22440];v[22440]=0;if((g|0)==1){break j}if(!f){break r}sc(c);v[22440]=0;c=Q(806,c|0,e+8|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break d}if(!c){break r}c=t[e+8|0];t[b+42|0]=(c|0)<0?0:c+1|0}v[22440]=0;h=a+120|0;c=T(180,h|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break j}if(!c){break f}v[22440]=0;c=T(159,h|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break c}v[e+72>>2]=c;qc(e+72|0,9);g=b+68|0;f=e+8|4;i=v[e+72>>2];c=0;while(1){if((c|0)==(i|0)){break g}v[22440]=0;R(807,h|0,e+8|0);j=v[22440];v[22440]=0;if((j|0)==1){break h}k=Ib(g,c),l=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),v[k>>2]=l;c=c+1|0;continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break m}a=P()|0;O()|0;break m}a=P()|0;O()|0;rb(e+72|0)}rb(f);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;sb(e+32|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}Pz(g+(i<<2)|0,HS(g),42792)}a=a+80|0;sc(a);v[22440]=0;c=Q(808,a|0,e+8|0)|0;f=v[22440];v[22440]=0;s:{if((f|0)==1){break s}if(!c){break b}if(w[e+8|0]&32){u[b+34>>1]=x[b+34>>1]|32}c=e+8|0;f=c|4;u[e+72>>1]=w[f|0]|w[f+1|0]<<8;u[e+6>>1]=256;k=b,l=x[Kc(e+72|0,e+6|0)>>1],u[k+28>>1]=l;c=c|6;u[e+72>>1]=w[c|0]|w[c+1|0]<<8;u[e+6>>1]=256;k=b,l=x[Kc(e+72|0,e+6|0)>>1],u[k+30>>1]=l;u[e+72>>1]=w[e+16|0]|w[e+17|0]<<8;u[e+6>>1]=64;k=b,l=x[Kc(e+72|0,e+6|0)>>1],u[k+32>>1]=l;t[b+38|0]=w[e+20|0];t[b+39|0]=w[e+21|0];t[b+40|0]=w[e+22|0];t[b+41|0]=w[e+23|0];v[22440]=0;c=Q(158,a|0,32)|0;f=v[22440];v[22440]=0;if((f|0)==1){break s}if(!c){break b}v[22440]=0;R(809,a|0,d|0);c=v[22440];v[22440]=0;if((c|0)==1){break s}v[22440]=0;c=T(204,a|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break s}v[22440]=0;U(810,a|0,b+43|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}sb(e+88|0);cb=e+112|0;return}sb(e+88|0);S(a|0);L()}function In(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;d=cb-112|0;cb=d;y=Xy(v[a+24>>2],w[a+32|0]);l=rj(y);c=v[a>>2];f=gd(c,v[a+4>>2]);a:{if(l>>>0>f>>>0){h=cb-32|0;cb=h;f=l-f|0;c=v[xb(a)>>2];e=v[a+4>>2];b:{if(f>>>0<=(c-e|0)/12>>>0){e=cb-16|0;cb=e;f=tt(e,a,f);g=v[f+4>>2];c=v[f+8>>2];while(1){if((c|0)==(g|0)){dc(f);cb=e+16|0}else{AN(g);g=g+12|0;v[f+4>>2]=g;continue}break}break b}c=xb(a);i=Ll(h+8|0,Io(a,gd(v[a>>2],e)+f|0),gd(v[a>>2],v[a+4>>2]),c);c=cb-16|0;cb=c;e=NP(c,i+8|0,f);f=v[e>>2];while(1){if(v[e+4>>2]!=(f|0)){AN(f);f=v[e>>2]+12|0;v[e>>2]=f;continue}break}Gd(e);cb=c+16|0;c=v[a>>2];f=v[a+4>>2];e=i+4|0;while(1){if((c|0)!=(f|0)){f=f-12|0;Hz(v[e>>2]-12|0,f);v[e>>2]=v[e>>2]-12;continue}break}ec(a,e);ec(a+4|0,i+8|0);ec(xb(a),mc(i));v[i>>2]=v[i+4>>2];e=v[i+4>>2];while(1){c=v[i+8>>2];if((c|0)!=(e|0)){c=c-12|0;v[i+8>>2]=c;Re(c);continue}break}c=v[i>>2];if(c){br(i);zb(c)}}cb=h+32|0;break a}if(f>>>0>l>>>0){GN(a,c+B(l,12)|0)}}if(b){c=a+12|0;Fp(c,Kd(c));z=xb(c),A=0,v[z>>2]=A;e=c;c=bc(c);v[e>>2]=c;v[c>>2]=0;v[a+28>>2]=0}m=Rb(d+96|0);c=Xs(v[a+24>>2]+484344|0);v[22440]=0;n=Y(620,d+80|0,c|0,30332)|0;c=v[22440];v[22440]=0;c:{if((c|0)!=1){k=a+12|0;d:{while(1){if((j|0)==(l|0)){_c(n);_b(m);cb=d+112|0;return}o=x[Xb(v[y>>2],j)>>1];c=NN(a,o);v[d+76>>2]=c;h=rd(v[a>>2],j);e:{f:{if(b){v[22440]=0;t[d+40|0]=0;U(790,h|0,c|0,d+40|0);c=v[22440];v[22440]=0;if((c|0)!=1){break f}g=P()|0;O()|0;break d}v[22440]=0;R(748,h|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break e}}v[22440]=0;e=Q(318,y|0,j&65535)|0;c=v[22440];v[22440]=0;if((c|0)==1){break e}g:{if(!e){break g}v[d+40>>2]=b?0:v[h+4>>2];i=v[Bb(d+40|0,d+76|0)>>2];s=Af(k);c=x[Xb(v[n>>2],o)>>1];if((c|0)!=65535){km(d+40|0,c,i);c=LN(k,x[d+40>>1],v[d+44>>2]);v[d+72>>2]=c;z=d,A=Af(k),v[z+16>>2]=A;h:{if(ih(d+72|0,d+16|0)){km(d+40|0,x[Xb(v[n>>2],o)>>1],v[d+76>>2]);e=LN(k,x[d+40>>1],v[d+44>>2]);break h}e=Af(k)}v[d+64>>2]=e;v[d+56>>2]=c;while(1){i:{if(!ih(d+56|0,d- -64|0)){break g}h=Rb(d+40|0);c=Vm(od(d+56|0)+8|0);v[22440]=0;R(791,h|0,c|0);c=v[22440];v[22440]=0;if((c|0)!=1){og(d+24|0,s);c=km(d+16|0,j,v[od(d+56|0)+4>>2]);v[22440]=0;e=da(792,k|0,v[d+24>>2],c|0,h|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break i}v[d+32>>2]=e;mk(d+32|0);s=v[d+32>>2];de(h);mk(d+56|0);continue}}break}g=P()|0;O()|0;de(h);break d}h=Sb(v[a+24>>2]+484344|0,o);c=Hj(v[v[h+48>>2]+12>>2]);v[22440]=0;t[d+40|0]=0;U(771,m|0,c|0,d+40|0);c=v[22440];v[22440]=0;if((c|0)!=1){p=v[d+76>>2];j:while(1){k:{if((i|0)==(p|0)){if(i){break g}z=Xb(v[n>>2],o),A=j,u[z>>1]=A;break g}q=1;r=0;p=p-1|0;g=Gf(h,p);while(1){if(q>>>0<16&Hj(v[v[h+48>>2]+12>>2])>>>0>r>>>0){c=Eb(v[m>>2],r);f=w[c|0];l:{m:{n:{switch(w[g+3|0]-19|0){case 1:e=w[g+5|0];if((e&240)==176){break m}break l;case 0:break n;default:break l}}e=w[g+5|0];if((e&240)!=96){break l}}t[c|0]=e&15;c=w[Eb(v[m>>2],r)|0];f=c?c:f}c=f&255;q=B(c?c+1|0:1,q);g=g+6|0;r=r+1|0;continue}else{o:{if(q>>>0<=1){continue j}e=Rb(d+40|0);v[22440]=0;R(791,e|0,q|0);c=v[22440];v[22440]=0;if((c|0)==1){break o}og(d+8|0,s);c=km(d+16|0,j,p);v[22440]=0;s=da(792,k|0,v[d+8>>2],c|0,e|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break k}de(e);continue j}}break}}break}g=P()|0;O()|0;de(e);break d}g=P()|0;O()|0;break d}j=j+1|0;continue}break}g=P()|0;O()|0}_c(n);break c}g=P()|0;O()|0}_b(m);S(g|0);L()}function OV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=cb-576|0;cb=e;sc(b);d=cb-16|0;cb=d;f=e+72|0;FC(d+8|0,f);g=v[d+12>>2];Yb(d,b,v[d+8>>2],g);k=v[d+4>>2];if((k|0)==(g|0)){Ob(b,v[d+12>>2])}cb=d+16|0;d=(g|0)==(k|0);if(!d){EC(f)}a:{if(!d){break a}if(!HC(e+72|0)){break a}b:{if(!c){break b}if(!Kb(b,wc(GC(w[e+182|0],w[e+183|0]),fb))){break a}ud(a,64);v[a+480260>>2]=112;v[a+480264>>2]=13696;v[a+480204>>2]=78e4;v[a+480196>>2]=4;u[a+480188>>1]=8;Gb(a+1074312|0,7,1);d=e+40|0;g=jc(d,14745);Cb(a+1298344|0,g);rb(g);d=jc(d,14778);Cb(a+1298356|0,d);rb(d);Kl(a+1298368|0,Mb(e+72|0,11122,2)?14773:14745);v[a+1298404>>2]=5;f=w[e+182|0];u[a+480190>>1]=f;g=1;while(1){k=g&65535;if(k>>>0<=f>>>0){f=cb-16|0;cb=f;d=e+40|0;Ub(f+8|0,d,25);j=v[f+12>>2];Yb(f,b,v[f+8>>2],j);i=v[f+4>>2];if((i|0)==(j|0)){Ob(b,v[f+12>>2])}cb=f+16|0;if((i|0)!=(j|0)){t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;t[d+24|0]=0;t[d+16|0]=0;t[d+17|0]=0;t[d+18|0]=0;t[d+19|0]=0;t[d+20|0]=0;t[d+21|0]=0;t[d+22|0]=0;t[d+23|0]=0;t[d+8|0]=0;t[d+9|0]=0;t[d+10|0]=0;t[d+11|0]=0;t[d+12|0]=0;t[d+13|0]=0;t[d+14|0]=0;t[d+15|0]=0}if((w[e+53|0]|w[e+54|0]<<8|(w[e+55|0]<<16|w[e+56|0]<<24))>>>0>67108863){break a}f=(B(k,104)+a|0)+484380|0;ed(f,0);v[f+24>>2]=8363;j=e+40|0;d=j;i=w[d+13|0]|w[d+14|0]<<8|(w[d+15|0]<<16|w[d+16|0]<<24);v[f>>2]=i;l=w[d+17|0]|w[d+18|0]<<8|(w[d+19|0]<<16|w[d+20|0]<<24);v[f+4>>2]=l;d=w[d+21|0]|w[d+22|0]<<8|(w[d+23|0]<<16|w[d+24|0]<<24);d=d>>>0>i>>>0?l?d:0:d;v[f+8>>2]=d;if(d){u[f+34>>1]=2;yk(f)}Wh(e+8|0,2,j);d=e+24|0;xc(d,v[e+8>>2],v[e+12>>2],w[e+16|0]);uc(((k<<5)+a|0)+946304|0,d);g=g+1|0;rb(d);f=x[a+480190>>1];continue}break}h=e+72|2;ef(e+24|0,3,h,36);d=e+40|0;xc(d,v[e+24>>2],v[e+28>>2],w[e+32|0]);tc(a+1298308|0,d);rb(d);g=0;DC(a+1298332|0,h,108,36,0);d=a+484360|0;CC(Nb(d),e+185|0,128);j=v[Nb(d)>>2];h=w[e+184|0];if(x[Xb(j,h)>>1]<w[e+183|0]){Qe(Nb(d),h)}while(1)if((g|0)==8){k=a+484344|0;wg(k,w[e+183|0]);n=c&1;f=0;while(1){if(w[e+183|0]<=f>>>0){h=1;if(!(c&2)){break a}c=Nc(e+40|0,8,1,0,1);g=1;while(1){d=g&65535;if(d>>>0>x[a+480190>>1]){break b}vg(c,(B(d,104)+a|0)+484380|0,b);g=g+1|0;continue}}c:{d:{if(n){if(nh(k,f&65535,64)){break d}}Ob(b,1536);break c}v[e+24>>2]=-1;v[e+28>>2]=-1;j=0;e:while(1){if((j|0)==64){d=(e+72|0)+f|0;if(w[d+369|0]<63){xe(Sb(k,f),yh(Pe(Je(e+40|0,14,0),w[d+369|0])))}xe(Sb(k,f),yh(Je(e+40|0,16,w[d+241|0])));break c}g=0;h=Gf(Sb(k,f),j);while(1){if((g|0)==8){j=j+1|0;continue e}i=e+40|0;Bq(i,b);d=Ec(i);m=Oe(i);l=w[d|0];d=w[i|0];if(d>>>0<=253){t[h|0]=(d>>>2|0)+37;t[h+1|0]=(d<<4&48|l>>>4)+1;t[(e+24|0)+g|0]=255;d=w[i|0]}if((d&255)!=255){t[h+2|0]=1;t[h+4|0]=(((l&15)<<6|8)>>>0)/15}d=w[m|0];if((d|0)!=255){t[(e+24|0)+g|0]=d}i=(e+24|0)+g|0;f:{g:{if(d&15?0:(d|0)!=48){break g}l=w[i|0];if((l|0)==255){break f}m=l<<24>>24;d=m&15;t[h+5|0]=d;h:{if((m|0)<0){break h}l=l>>>4|0;t[h+3|0]=w[l+26264|0];i:{switch(l-3|0){case 0:t[h+5|0]=d|32;break g;case 1:t[h+5|0]=d|m<<4;break f;case 2:break g;case 3:break i;default:break f}}j:{switch(d|0){case 0:t[h+5|0]=79;break f;case 1:break j;default:break h}}t[h+5|0]=244;break f}t[h+3|0]=0;break f}t[i|0]=255}h=h+6|0;g=g+1|0;continue}}}f=f+1|0;continue}}else{d=(g<<5)+a|0;$e(d+480280|0);u[d+480284>>1]=g&1?208:48;g=g+1|0;continue}}h=1}cb=e+576|0;return h|0}function Oea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=cb-192|0;cb=e;sc(b);a:{if(!XA(b,e+144|0)){break a}if(!dQ(e+144|0)){break a}if(!Kb(b,wc(cQ(w[e+175|0],w[e+177|0]),fb))){break a}b:{if(!c){break b}ud(a,256);g=e+32|0;Bj(g,2,e+144|0);d=e- -64|0;xc(d,v[e+32>>2],v[e+36>>2],w[e+40|0]);tc(a+1298308|0,d);rb(d);f=jc(d,15369);Cb(a+1298344|0,f);rb(f);d=jc(d,10139);Cb(a+1298356|0,d);rb(d);Xf(g,4274);v[22440]=0;R(255,e+128|0,e+175|0);d=v[22440];v[22440]=0;c:{d:{if((d|0)!=1){v[22440]=0;W(690,e- -64|0,e+32|0,e+174|0,e+128|0);d=v[22440];v[22440]=0;if((d|0)!=1){d=e- -64|0;Cb(a+1298368|0,d);rb(d);rb(e+128|0);Ab(e+32|0);v[a+1298404>>2]=5;d=Gb(a+1074312|0,107,1);v[a+480260>>2]=64;v[a+480264>>2]=32767;v[a+480188>>2]=2031620;Gb(d,107,1);f=w[e+176|0];d=w[e+175|0];if(d>>>0<=20){g=((f&255)>>>0)/10|0;f=g<<4|B(g,-10)+f}g=(f&255?f:96)&255;f=Fz(g);v[a+480196>>2]=g>>>4;v[a+480204>>2]=f;f=0;if(d>>>0>=11){t[e+64|0]=64;o=a,p=w[Tb(e+178|0,e- -64|0)|0]<<2,v[o+480200>>2]=p}while(1)if((f|0)==4){f=1;while(1){if((f|0)!=32){zt(b,e+32|0);d=w[e+44|0];if(d?(d|0)!=46:0){break c}g=cb-32|0;cb=g;d=(B(f,104)+a|0)+484380|0;ed(d,0);k=e+32|0;h=k;sk(g,2,h);i=g+16|0;xc(i,v[g>>2],v[g+4>>2],w[g+8|0]);pe(d+43|0,i);rb(i);j=h+24|0;v[d+24>>2]=w[j|0]|w[j+1|0]<<8;t[g+16|0]=w[h+22|0];t[g|0]=64;o=d,p=w[Tb(i,g)|0]<<2,u[o+30>>1]=p;i=h+16|0;i=w[i|0]|w[i+1|0]<<8;v[d>>2]=i;j=h+18|0;j=w[j|0]|w[j+1|0]<<8;v[d+4>>2]=j;h=h+20|0;h=w[h|0]|w[h+1|0]<<8;v[d+8>>2]=h;e:{if(i>>>0<=1){v[d>>2]=0;break e}if((h|0)==65535|i>>>0<=j>>>0|h>>>0<=j>>>0){break e}u[d+34>>1]=2;o=d,p=v[Bb(d+8|0,d)>>2],v[o+8>>2]=p}cb=g+32|0;sk(e+16|0,2,k);d=e+128|0;xc(d,v[e+16>>2],v[e+20>>2],w[e+24|0]);uc(((f<<5)+a|0)+946304|0,d);rb(d);u[((f<<1)+e|0)+62>>1]=w[e+46|0]|w[e+47|0]<<8;f=f+1|0;continue}break}d=a+484360|0;Zn(Nb(d),b,w[e+175|0]?128:64,65535,65535);f=0;if(!aQ(Nb(d))){break a}m=c&1;if(m){wg(a+484344|0,w[e+177|0])}j=a+484344|0;h=0;while(1){if(w[e+177|0]<=h>>>0){f=1;if(!(c&2)){break a}c=Nc(e+32|0,8,1,0,0);while(1){if((f|0)==32){break b}d=B(f,104)+a|0;g=d+484380|0;f:{if(!v[g>>2]|!x[d+484410>>1]){break f}d=x[((f<<1)+e|0)+62>>1];if(d>>>0<4){break f}if(!Tc(b,d<<4)){break f}vg(c,g,b)}f=f+1|0;continue}}f=0;g:{h:{if(m){if(nh(j,h&65535,64)){break h}}while(1){if((f|0)==256){break g}if((He(b)+2&255)>>>0<=252){Ob(b,3)}f=f+1|0;continue}}o=e,p=Pg(Sb(j,h)),v[o+128>>2]=p;u[e+14>>1]=65535;v[e+16>>2]=63;i=0;i:while(1){f=0;if((i|0)==64){d=x[e+14>>1];if((d|0)==65535){break g}xe(Sb(j,h),ym(Pe(Je(e+32|0,12,d&255),v[e+16>>2])));break g}while(1){j:{k:{l:{if((f&65535)>>>0<=3){d=0;k=0;l=0;n=0;m:{n:{o:{p:{g=He(b);switch(g-251|0){case 1:break j;case 0:break n;case 2:break p;default:break o}}t[v[e+128>>2]]=254;break j}d=e+32|0;Bq(d,b);k=w[Eb(d,0)|0];l=w[Eb(d,1)|0];n=w[Eb(d,2)|0];d=254;if((g|0)==254){break m}if(g>>>0>=96){break l}d=g}d=(B(d>>>4|0,12)+(d&15)|0)+37|0}g=d;d=v[e+128>>2];t[d|0]=g;break k}i=i+1|0;continue i}d=v[e+128>>2]}t[d+1|0]=(k&248)>>>3;g=l>>>1&120|k&7;if(g>>>0<=64){t[d+4|0]=g;t[d+2|0]=1}t[d+5|0]=n;$P(d,l&15,i,w[e+175|0],e+14|0,e+16|0)}f=f+1|0;Ki(e+128|0);continue}}}h=h+1|0;continue}}else{d=(f<<5)+a|0;$e(d+480280|0);u[d+480284>>1]=f&1?64:192;f=f+1|0;continue}}f=P()|0;O()|0;rb(e+128|0);break d}f=P()|0;O()|0}Ab(e+32|0);S(f|0);L()}f=0;break a}f=1}cb=e+192|0;return f|0}function ty(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0,C=0,D=0,E=0;f=cb-16|0;cb=f;l=B(b,872)+a|0;m=l+1075800|0;i=w[m|0];k=a+1074312|0;ub(f+8|0,k,23);g=c&15;a:{b:{c:{if(tb(v[v[f+8>>2]>>2],v[f+12>>2])){if(!(v[a+1074392>>2]|!w[(B(b,872)+a|0)+1075780|0])){t[m|0]=g;break c}e=w[m|0];if(e){h=e-1|0;t[m|0]=h;e=0;if(h&255){break c}}t[m|0]=g;e=1;break c}ub(f+8|0,k,52);d:{e:{h=c&256;if(!(!h|!tb(v[v[f+8>>2]>>2],v[f+12>>2]))){h=v[a+480208>>2]&4096;if(!h){break e}e=B(b,872)+a|0;if(w[e+1075781|0]){i=OS(w[e+1075780|0])?1:i}if(w[(B(b,872)+a|0)+1075784|0]?w[e+1075782|0]==1:0){break b}e=0;if(g>>>0>i>>>0){break c}if(!h){break d}if(Rc(w[(B(b,872)+a|0)+1075780|0])){break c}break d}j=v[a+480180>>2];if(j&16777250){e=!(i?(i>>>0)%((g?g:1)>>>0)|0:1);i=i+1|0;break c}f:{if((j|0)!=16){if((j|0)!=1){break f}h=y[a+1074392>>2]%y[a+1074416>>2]|0;if(!h){if(Rc(w[(B(b,872)+a|0)+1075780|0])){break a}}e=g?!((h>>>0)%(g>>>0)|0):e;break c}e=v[a+1074392>>2]==(g|0)&(g|0)!=0;break c}g:{if(!h){break g}e=B(b,872)+a|0;if(w[e+1075782|0]!=1){break g}g=(w[e+1075785|0]>15)+g|0}h:{if(v[a+480208>>2]&4096?h:1){g=g?g:1;e=0;e=!v[a+1074416>>2]|h?e:!(y[a+1074392>>2]%(g>>>0)|0);i=i+1|0;break h}e=0;i=j&1048580?0:i}if(!(!(w[(B(b,872)+a|0)+1075780|0]|!h?v[a+1074392>>2]:1)|(i&255)>>>0<g>>>0)){e=1}ub(f+8|0,k,52);if(!tb(v[v[f+8>>2]>>2],v[f+12>>2])|c){break c}e=!v[a+1074392>>2];break c}if(g>>>0>i>>>0){break c}}i=0;e=1}n=(B(b,872)+a|0)+1075068|0;i:{if(v[n>>2]){break i}ub(f+8|0,k,38);if(!tb(v[v[f+8>>2]>>2],v[f+12>>2])){break i}if(!dk(v[(B(b,872)+a|0)+1075648>>2])){break a}}ub(f+8|0,k,106);if(C=0,D=tb(v[v[f+8>>2]>>2],v[f+12>>2]),E=v[(B(b,872)+a|0)+1075688>>2],E?C:D){break a}if(e){h=B(b,872)+a|0;q=h+1075680|0;g=v[q>>2];v[f+4>>2]=g;e=c>>>4&15;j:{if(!e){e=v[h+1075080>>2];break j}ub(f+8|0,k,52);k:{if(C=tb(v[v[f+8>>2]>>2],v[f+12>>2]),D=0,E=w[(B(b,872)+a|0)+1075782|0]==1,E?C:D){break k}if(!(16191>>>e&1)){v[f+4>>2]=(B(g,t[e+33808|0])|0)/16;break k}v[f+4>>2]=g+(t[e+33824|0]<<2)}oe(f+4|0,0,256);g=(B(b,872)+a|0)+1075080|0;e=v[g>>2]|2097152;v[g>>2]=e}h=B(b,872)+a|0;r=h+1075692|0;s=v[r>>2];g=w[h+1075794|0];j=0;if(e&512){ub(f+8|0,k,108);j=tb(v[v[f+8>>2]>>2],v[f+12>>2])}if(!((j^-1)&v[a+480180>>2]==2|(!v[n>>2]|(g-1&255)>>>0>119))){jM(a,b,0,g,1)}e=l+1074992|0;l=h+1075080|0;l:{if(!(v[a+480180>>2]&1048580)){break l}u=(c|0)<256;if((c|0)>255){break l}h=w[(B(b,872)+a|0)+1075781|0];if(!h){break l}u=1;Ap(a,e,h,0,0,1)}o=B(b,872)+a|0;p=o+1075652|0;z=v[p>>2];A=v[l>>2];v[p>>2]=0;ub(f+8|0,k,23);h=1;m:{if(tb(v[v[f+8>>2]>>2],v[f+12>>2])){break m}h=0;if(v[a+480180>>2]!=2){break m}h=(j^1)&v[n>>2]!=0}Qs(a,e,g,h,u,0,b);if(!w[o+1075781|0]){v[p>>2]=z}if(!(!(A&4096)|v[a+480180>>2]!=4)){v[l>>2]=v[l>>2]|4096}j=o+1075780|0;v[q>>2]=v[f+4>>2];if(x[a+480192>>1]){t[j|0]=g;hM(a,b)}g=v[a+480180>>2];if(!(!(g&16777248)|(w[j|0]|!s))){v[r>>2]=s}if(h){v[e>>2]=0;v[e+4>>2]=0}g=g&16777250;n:{if(d-11>>>0<4294967286){break n}h=v[(B(b,872)+a|0)+1075096>>2];if(!h){break n}o:{if((d|0)==1){b=v[(B(b,872)+a|0)+1075656>>2];break o}j=(B(b,872)+a|0)+1075656|0;b=v[Ib(h+68|0,d-2|0)>>2];v[j>>2]=b}Gn(a,e,b)}i=g?i:0}a=f+8|0;ub(a,k,52);b=v[v[f+8>>2]>>2];d=v[f+12>>2];ub(a,k,23);if(tb(v[v[f+8>>2]>>2],v[f+12>>2])){break a}i=(tb(b,d)&c>>>8)+i|0}t[m|0]=i}cb=f+16|0}function Pv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=cb-96|0;cb=c;g=a+32|0;Cc(c+56|0,g,11);a:{if(k=1,l=tb(v[v[c+56>>2]>>2],v[c+60>>2]),m=v[a+8>>2],m?k:l){e=v[a+36>>2];b=v[a+76>>2]+v[a+20>>2]|0;f=v[a+16>>2];d=f+v[a+72>>2]|0;b=Xg(c+80|0,d,d>>>0<f>>>0?b+1|0:b);d=v[b+12>>2];v[c+24>>2]=v[b+8>>2];v[c+28>>2]=d;d=v[b+4>>2];v[c+16>>2]=v[b>>2];v[c+20>>2]=d;Uj(e,c+16|0);b=v[a+36>>2];if(Zj(v[v[b>>2]-12>>2]+b|0)){ph(a,2,256);break a}b=v[a+104>>2];d=a+52|0;f=v[d>>2];e=Ri(f,v[d+4>>2]);b:{if(b>>>0>e>>>0){i=cb-32|0;cb=i;f=b-e|0;e=v[xb(d)>>2];h=v[d+4>>2];c:{if(f>>>0<=(e-h|0)/24>>>0){e=cb-16|0;cb=e;b=mE(e,d,f);d=v[b+4>>2];f=v[b+8>>2];while(1){if((d|0)==(f|0)){dc(b);cb=e+16|0}else{lE(d);d=d+24|0;v[b+4>>2]=d;continue}break}break c}b=xb(d);e=sE(i+8|0,vE(d,Ri(v[d>>2],h)+f|0),Ri(v[d>>2],v[d+4>>2]),b);b=cb-16|0;cb=b;v[b>>2]=v[e+8>>2];h=v[e+8>>2];v[b+8>>2]=e+8;v[b+4>>2]=h+B(f,24);f=v[b>>2];while(1){if(v[b+4>>2]!=(f|0)){lE(f);f=v[b>>2]+24|0;v[b>>2]=f;continue}break}Gd(b);cb=b+16|0;rE(d,e);nE(e)}cb=i+32|0;break b}if(b>>>0<e>>>0){Nd(d,f+B(b,24)|0)}}i=a+40|0;dn(i,v[a+104>>2]<<2);d=0;d:{e:{while(1){if(y[a+104>>2]<=d>>>0){break d}e=v[a+36>>2];if(Zj(v[v[e>>2]-12>>2]+e|0)){ph(a,2,1024);break a}b=x[a+24>>1];u[c+32>>1]=b;if((b|0)==65535){Vv(e,c+32|0);b=x[c+32>>1]}e=Uc(v[a+40>>2],v[a+44>>2]);f=b&65535;f:{if(!f){b=0;break f}if(f>>>0>(e^-1)>>>0){break f}Si(i,e+f|0);Uk(v[a+36>>2],Eb(v[a+40>>2],e),f)}f=jf(v[a+52>>2],d);v[f>>2]=e;u[f+20>>1]=b;Cc(c+56|0,g,6);g:{if(tb(v[v[c+56>>2]>>2],v[c+60>>2])){Fk(v[a+36>>2],c+56|0);e=v[c+56>>2];b=v[c+60>>2];if(!Rv(e,b)){break g}f=jf(v[a+52>>2],d);v[f+8>>2]=e;v[f+12>>2]=b}e=v[a+8>>2];h:{if(e){b=jf(v[a+52>>2],d);v[b+16>>2]=e;break h}Cc(c+56|0,g,7);if(!tb(v[v[c+56>>2]>>2],v[c+60>>2])){b=jf(v[a+52>>2],d);break h}Fk(v[a+36>>2],c+56|0);e=v[c+56>>2];if(!Rv(e,v[c+60>>2])){break e}b=jf(v[a+52>>2],d);v[b+16>>2]=e}i:{if(v[b+16>>2]==-1){break i}Cc(c+56|0,g,6);if(tb(v[v[c+56>>2]>>2],v[c+60>>2])){break i}j:{if(!d){f=0;b=0;e=jf(v[a+52>>2],0);break j}h=v[a+52>>2];b=jf(h,d-1|0);f=v[b+16>>2];e=v[b+8>>2]+f|0;b=v[b+12>>2];b=e>>>0<f>>>0?b+1|0:b;f=e;e=jf(h,d)}v[e+8>>2]=f;v[e+12>>2]=b}Cc(c+56|0,g,8);if(tb(v[v[c+56>>2]>>2],v[c+60>>2])){u[c+78>>1]=0;Vv(v[a+36>>2],c+78|0);Cc(c+56|0,g,9);Vl(v[a+36>>2],x[c+78>>1]<<tb(v[v[c+56>>2]>>2],v[c+60>>2]))}d=d+1|0;continue}break}ph(a,2,2048);break a}ph(a,2,2048);break a}ke(c+56|0,v[a+36>>2]);b=v[c+68>>2];v[a+80>>2]=v[c+64>>2];v[a+84>>2]=b}b=c+56|0;Cc(b,g,4);Te(b,1);b=v[a+96>>2];f=v[a+100>>2];k:{if((b|0)==v[a+72>>2]&(f|0)==v[a+76>>2]){b=v[a+84>>2];e=v[a+80>>2];break k}d=b;e=b+v[a+16>>2]|0;b=f+v[a+20>>2]|0;b=d>>>0>e>>>0?b+1|0:b}d=e;v[a+88>>2]=d;v[a+92>>2]=b;e=v[a+36>>2];b=Xg(c+40|0,d,b);d=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=d;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;Uj(e,c);Cc(c+56|0,g,6);if(tb(v[v[c+56>>2]>>2],v[c+60>>2])){break a}Cc(c+32|0,g,7);if(!(k=1,l=tb(v[v[c+32>>2]>>2],v[c+36>>2]),m=v[a+8>>2],m?k:l)){break a}b=v[a+88>>2];d=v[a+16>>2];e=b-d|0;f=v[a+92>>2]-(v[a+20>>2]+(b>>>0<d>>>0)|0)|0;i=v[a+104>>2];d=0;while(1){if((d|0)==(i|0)){break a}b=jf(v[a+52>>2],d);h=b;j=v[b+8>>2];g=j+e|0;b=v[b+12>>2]+f|0;v[h+8>>2]=g;v[h+12>>2]=g>>>0<j>>>0?b+1|0:b;d=d+1|0;continue}}cb=c+96|0}function Jda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=cb-128|0;cb=e;a:{if(!Kb(c,8)){break a}Ob(c,4);while(1){m=Nt(c);if(m){break a}n=cb-288|0;cb=n;f=aO(n);i=cb-384|0;cb=i;g=i+96|0;aO(g);g=ic(f,g,282);f=0;b:{c:{d:{e:{f:{if(Ah(c,13725)){xg(c,4);j=be(i+72|0,c);v[22440]=0;k=Q(781,j|0,g|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break f}g:{if(!k){break g}k=w[g+26|0];v[22440]=0;k=Q(158,j|0,k|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break f}if(!k){break g}k=0;h:{while(1){if(w[g+26|0]<=f>>>0){f=0;v[22440]=0;k=k&65535;h=Q(158,j|0,k|0)|0;l=v[22440];v[22440]=0;if((l|0)==1){break d}if(!h){break g}v[22440]=0;Q(190,j|0,k|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break d}xg(j,bO(g));f=hh(i- -64|0);h=i+96|0;Zy(h);v[22440]=0;R(782,j|0,h|0);h=v[22440];v[22440]=0;if((h|0)!=1){u[i+118>>1]=0;u[i+120>>1]=0;f=_y(f,i+96|0,i+123|0);h=w[g+26|0];v[22440]=0;Q(190,j|0,h|0)|0;h=v[22440];v[22440]=0;if((h|0)!=1){break h}}f=P()|0;O()|0;break c}v[22440]=0;h=T(200,j|0)|0;l=v[22440];v[22440]=0;if((l|0)!=1){t[(f+g|0)+27|0]=h;f=f+1|0;k=h+k|0;continue}break}f=P()|0;O()|0;break c}l=f;f=g+27|0;l=_y(l,f,f+w[g+26|0]|0);v[22440]=0;U(192,i+16|0,j|0,k|0);f=v[22440];v[22440]=0;if((f|0)==1){break e}h=i+16|0;k=cc(i+40|0,h);sb(h);f=0;v[22440]=0;R(573,h|0,k|0);h=v[22440];v[22440]=0;if((h|0)==1){f=P()|0;O()|0;sb(k);break c}h=i+16|0;XB(i+8|0,h);o=l;l=v[i+8>>2];l=_y(o,l,Eb(l,v[i+12>>2]));vc(h);sb(k);if(v[l>>2]!=(w[g+22|0]|w[g+23|0]<<8|(w[g+24|0]<<16|w[g+25|0]<<24))){break g}f=bO(g);v[22440]=0;Q(190,c|0,f|0)|0;g=v[22440];v[22440]=0;f=1;if((g|0)==1){break d}}sb(j)}cb=i+384|0;break b}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}sb(j);S(f|0);L()}cb=n+288|0;if(f){continue}break}}t[d|0]=w[d|0]!=0|m;sc(c);i:{j:{k:{l:{m:{n:{if(m){i=Ag(c);d=e+80|0;Td(d,c,_e(c));f=cc(e+104|0,d);sb(d);b=x[a+34>>1]&-66|w[b|0]>15|(w[b+1|0]!=1)<<6;u[a+34>>1]=b;v[a>>2]=i>>>(b&1)>>>(b>>>6&1);v[e+76>>2]=0;v[e+72>>2]=0;v[22440]=0;R(573,d|0,f|0);b=v[22440];v[22440]=0;if((b|0)==1){break n}b=ce(e+80|0);d=v[e+80>>2];i=$z(b,Ei(d),e+76|0,e+72|0);v[22440]=0;c=v[e+76>>2];Q(190,f|0,c|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){if(!i){break j}Lg(a);b=b+c|0;d=d-c|0;m=v[e+72>>2];c=0;while(1){o:{if(m){if(!d|(m|0)!=1){break k}if(y[a>>2]>c>>>0){break o}break k}if(y[a>>2]<=c>>>0){break k}}if(!Sd(a)){break k}v[e+68>>2]=0;v[e+64>>2]=0;m=FR(i,b,Ei(d),e+68|0,e+60|0,e- -64|0);v[22440]=0;Q(190,f|0,m|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break m}Zh(e- -64|0,Ei(v[a>>2]-c|0));g=v[e+64>>2];p:{if((g|0)<=0){break p}j=v[e+68>>2];k=x[a+34>>1];if((zd(k)|0)!=(j|0)){break p}if(k&1){pg(e+48|0,v[a+20>>2]+(B(c,j)<<1)|0,j,g);pg(e+32|0,v[e+60>>2],v[e+68>>2],g);v[22440]=0;ka(574,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2]);j=v[22440];v[22440]=0;if((j|0)!=1){break p}break m}pg(e+16|0,v[a+20>>2]+B(c,j)|0,j,g);pg(e,v[e+60>>2],v[e+68>>2],g);v[22440]=0;ka(575,v[e+16>>2],v[e+20>>2],v[e+24>>2],v[e>>2],v[e+4>>2],v[e+8>>2]);j=v[22440];v[22440]=0;if((j|0)==1){break m}}d=d-m|0;b=b+m|0;c=c+g|0;m=ER(i);continue}}break m}vg(b,a,c);a=1;break i}c=P()|0;O()|0;break l}c=P()|0;O()|0;vc(e+80|0)}sb(f);S(c|0);L()}CR(i)}vc(e+80|0);sb(f);a=(i|0)!=0}cb=e+128|0;return a|0}function nY(){var a=0;Zd(465224);v[116306]=79944;v[116308]=0;v[116309]=0;hh(465240);t[465368]=0;v[22440]=0;X(1231);a=v[22440];v[22440]=0;if((a|0)==1){a=P()|0;O()|0;Uv(465232);S(a|0);L()}UE(30);v[22440]=0;Q(56,465376,14381)|0;a=v[22440];v[22440]=0;a:{b:{c:{if((a|0)!=1){Ac(465232);Zd(464912);v[116228]=81268;v[22440]=0;X(1200);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(464920);v[116230]=81300;v[22440]=0;X(1201);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(464928);v[116232]=79964;v[116234]=75904;t[464940]=0;v[22440]=0;X(1202);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(464944);v[116236]=80448;v[22440]=0;X(1203);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(464952);v[116238]=80596;v[22440]=0;X(1204);a=v[22440];v[22440]=0;if((a|0)==1){break c}v[22440]=0;X(1205);a=v[22440];v[22440]=0;if((a|0)==1){break c}v[22440]=0;X(1206);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(464976);v[116244]=80744;v[22440]=0;X(1207);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(464984);v[116246]=80860;v[22440]=0;X(1208);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(464992);u[232500]=11310;v[116248]=80064;Db(465004);v[22440]=0;X(1209);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(465016);v[116256]=46;v[116257]=44;v[116254]=80104;Db(465032);v[22440]=0;X(1210);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(465048);v[116262]=81332;v[22440]=0;X(1211);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(465056);v[116264]=81576;v[22440]=0;X(1212);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(465064);v[116266]=81788;v[22440]=0;X(1213);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(465072);v[116268]=82020;v[22440]=0;X(1214);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(465080);v[116270]=83004;v[22440]=0;X(1215);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(465088);v[116272]=83152;v[22440]=0;X(1216);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(465096);v[116274]=83268;v[22440]=0;X(1217);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(465104);v[116276]=83384;v[22440]=0;X(1218);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(465112);v[116278]=83500;v[22440]=0;X(1219);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(465120);v[116280]=83664;v[22440]=0;X(1220);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(465128);v[116282]=83828;v[22440]=0;X(1221);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(465136);v[116284]=83992;v[22440]=0;X(1222);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(465144);v[116288]=85248;v[116288]=82268;v[116286]=82220;v[22440]=0;X(1223);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(465160);v[116292]=85284;v[116292]=82532;v[116290]=82484;v[22440]=0;X(1224);a=v[22440];v[22440]=0;if((a|0)==1){break c}v[22440]=0;X(1225);a=v[22440];v[22440]=0;if((a|0)==1){break c}v[22440]=0;X(1226);a=v[22440];v[22440]=0;if((a|0)==1){break c}v[22440]=0;X(1227);a=v[22440];v[22440]=0;if((a|0)==1){break c}v[22440]=0;X(1228);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(465208);v[116302]=84156;v[22440]=0;X(1229);a=v[22440];v[22440]=0;if((a|0)==1){break c}Zd(465216);v[116304]=84276;v[22440]=0;X(1230);a=v[22440];v[22440]=0;if((a|0)==1){break c}break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;rb(465376)}Uv(465232);S(a|0);L()}v[115902]=465224}function UL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0;if(b){h=a+327720|0;c=cb-400|0;cb=c;_N(c+384|0,8);v[22440]=0;sa(783,c+368|0,9);i=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((i|0)!=1){v[22440]=0;i=Q(784,c+352|0,14)|0;e=v[22440];v[22440]=0;if((e|0)==1){break l}v[22440]=0;R(785,c+384|0,i|0);e=v[22440];v[22440]=0;if((e|0)==1){break k}v[22440]=0;R(785,c+368|0,i|0);e=v[22440];v[22440]=0;if((e|0)==1){break k}ZN(c+280|0,4900);ZN(c+208|0,32e3);SN(c+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);v[22440]=0;e=Q(786,c+104|0,c+384|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break j}_s(c+120|0,c+280|0,e);de(e);v[22440]=0;e=Q(786,c+72|0,c+368|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break i}_s(c+88|0,c+208|0,e);de(e);v[22440]=0;e=Q(786,c+40|0,c+120|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break h}_s(c+56|0,c+136|0,e);de(e);v[22440]=0;e=Q(786,c+8|0,c+88|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break g}g=c+24|0;_s(g,c+136|0,e);de(e);e=c+120|0;Hp(e);l=c+56|0;Hp(l);m=c+88|0;Hp(m);Hp(g);p=c+368|0;Hp(p);Gp(v[c+120>>2],v[c+124>>2],nj(h,0));Gp(v[c+56>>2],v[c+60>>2],nj(h,1));Gp(v[c+88>>2],v[c+92>>2],nj(h,2));Gp(v[c+24>>2],v[c+28>>2],nj(h,3));Gp(v[c+368>>2],v[c+372>>2],nj(h,4));de(g);de(l);de(m);de(e);ml(i);de(p);de(c+384|0);cb=c+400|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;de(c+56|0)}de(c+88|0)}de(c+120|0)}ml(i)}de(c+368|0)}de(c+384|0);S(a|0);L()}Tx(a+131112|0,9.6377,.97);Tx(a+196648|0,8.5,.5);Tx(a+262184|0,2.7625,.425)}c=a+368680|0;if(!(t=0,x=cL(c,a),y=b,y?t:x)){e=a+24|0;r=A[a+8>>3];g=w[a+16|0];h=cb+-64|0;cb=h;m:while(1){if((n|0)!=8193){s=+(n-4096|0)*.0001220703125;b=0;o=0;while(1)if((b|0)==8){j=1/o;l=n<<3;b=0;while(1)if((b|0)==8){n=n+1|0;continue m}else{m=e+(b+l<<1)|0;d=H(A[h+(b<<3)>>3]*32768*j+.5);d=d<-32768?-32768:F(d,32768);n:{if(D(d)<2147483648){i=~~d;break n}i=-2147483648}u[m>>1]=i;b=b+1|0;continue}}else{j=r;f=1;d=+(b|0)-s;q=d+-3.5;if(!(D(q)<1e-8)){o:{p:{switch(g|0){case 0:f=We(d*.8975979010256552)*-.5+.5;break o;case 1:f=We(d*.8975979010256552)*-.46+.54;break o;case 2:f=We(d*1.7951958020513104)*.08+(We(d*.8975979010256552)*-.5+.42);break o;case 3:f=We(d*1.7951958020513104)*.05677+(We(d*.8975979010256552)*-.49364+.44959);break o;case 4:f=We(d*1.7951958020513104)*.07922+(We(d*.8975979010256552)*-.49755+.42323);break o;case 5:f=We(d*1.7951958020513104);k=We(d*.8975979010256552);f=We(d*2.6927937030769655)*-.01168+(f*.14128+(k*-.48829+.35875));break o;case 6:f=We(d*1.7951958020513104);k=We(d*.8975979010256552);f=We(d*2.6927937030769655)*-.00183+(f*.09392+(k*-.49703+.40217));break o;case 7:break p;default:break o}}f=We(d*1.7951958020513104);k=We(d*.8975979010256552);f=We(d*2.6927937030769655)*-.00122+(f*.09831+(k*-.49804+.40243))}d=q*3.141592653589793;j=Bi(d*j)/d}j=f*j;A[h+(b<<3)>>3]=j;o=o+j;b=b+1|0;continue}}break}cb=h- -64|0;b=v[a+20>>2];v[c+16>>2]=v[a+16>>2];v[c+20>>2]=b;b=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=b;b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b}}function GJ(a){var b=C(0),c=0,d=C(0),e=C(0),f=0,g=C(0),h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=0,p=0,q=C(0),r=C(0),s=C(0),u=0,w=C(0);k=cb-16|0;cb=k;c=tj(C(z[a+4256>>2]*C(3)));v[a+4264>>2]=c;d=C(v[v[a+16>>2]+24620>>2]>>>((c>>>1^-1)&1)>>>0);z[a+4268>>2]=d;u=a,w=C(FJ(z[a+4244>>2])*C(.0061803399585187435)),z[u+4272>>2]=w;u=k,w=te(C(10),C(C(lx(z[a+4208>>2])+C(C(z[a+4228>>2]*C(11e3))+C(-1e4)))/C(2e3))),z[u+12>>2]=w;v[k+8>>2]=1065353216;u=a,w=C(z[$l(k+12|0,k+8|0)>>2]*C(.7609999775886536)),z[u+4280>>2]=w;b=te(C(10),C(C(lx(z[a+4212>>2])/C(100))/C(10)));if(b!=C(1)){d=cp(C(C(EJ(z[a+4252>>2])*C(6.2831854820251465))/d));g=C(b+b);e=C(b*b);m=Ny(C(C(C(C(d*g)+C(-2))+C(K(C(C(C(C(d*C(C(d*e)*C(4)))+C(b*C(8)))-C(e*C(4)))-C(C(d*b)*C(8))))))/C(g+C(-2))),C(0),C(1))}else{m=C(0)}z[a+4276>>2]=m;j=cb-16|0;cb=j;b=z[a+4268>>2];d=C(z[a+4232>>2]*C(.30000001192092896));z[j+12>>2]=z[a+4240>>2]*C(.10000000149011612);v[j+8>>2]=1000593162;g=z[ux(j+12|0,j+8|0)>>2];e=C(b*C(C(d+g)+C(.007000000216066837)));a:{if(C(D(e))<C(2147483648)){i=~~e;break a}i=-2147483648}v[a+4352>>2]=i;c=1;while(1){if((c|0)==12){u=j,w=C(C(C(FJ(z[a+4248>>2])/C(100))+C(.10000000149011612))*C(.9090999960899353)),z[u+12>>2]=w;v[j+8>>2]=1065353216;d=z[$l(j+12|0,j+8|0)>>2];g=C(b*C(C(d*C(75))/C(1e3)));d=C(b*C(C(d*C(67))/C(1e3)));c=0;while(1){if((c|0)==6){i=a+4348|0;d=C(b*C(.0035299998708069324));b:{if(C(D(d))<C(2147483648)){f=~~d;break b}f=-2147483648}v[i>>2]=f;i=a+4344|0;d=C(b*C(.0032500000670552254));c:{if(C(D(d))<C(2147483648)){f=~~d;break c}f=-2147483648}v[i>>2]=f;i=a+4340|0;b=C(b*C(.009999999776482582));d:{if(C(D(b))<C(2147483648)){f=~~b;break d}f=-2147483648}v[i>>2]=f}else{o=(c<<2)+a|0;i=o+4316|0;p=c+p|0;e=te(C(.9300000071525574),C(p|0));h=C(g*e);e:{if(C(D(h))<C(2147483648)){f=~~h;break e}f=-2147483648}v[i>>2]=f;i=o+4292|0;e=C(d*e);f:{if(C(D(e))<C(2147483648)){f=~~e;break f}f=-2147483648}v[i>>2]=f;c=c+1|0;continue}break}c=0;while(1){if((c|0)!=15){IJ((B(c,24)+a|0)+4504|0,v[((c<<2)+a|0)+4292>>2]);c=c+1|0;continue}break}cb=j+16|0}else{i=((B(c&1,24)+a|0)+(c<<1&-4)|0)+4352|0;e=C(b*C(C(g*z[(c<<2)+47008>>2])+d));g:{if(C(D(e))<C(2147483648)){f=~~e;break g}f=-2147483648}v[i>>2]=f;c=c+1|0;continue}break}c=cb-16|0;cb=c;d=sh(a,5);e=sh(a,11);b=C(d*sh(a,4));d=C(C(b*C(.03999999910593033))+C(C(d*C(.02250000089406967))+C(0)));g=C(e*sh(a,10));e=C(C(g*C(.03999999910593033))+C(C(e*C(.02250000089406967))+C(0)));if(t[a+4264|0]&1){h=sh(a,3);l=sh(a,9);h=C(b*h);b=C(h*sh(a,2));d=C(C(b*C(.1444000005722046))+C(C(h*C(.12250000238418579))+d));h=C(g*l);g=C(h*sh(a,8));e=C(C(g*C(.1444000005722046))+C(C(h*C(.12250000238418579))+e))}sh(a,12);h=z[a+4496>>2];l=sh(a,1);n=sh(a,7);r=sh(a,0);s=sh(a,6);u=c,w=te(C(10),C(C(lx(z[a+4208>>2])+C(C(z[a+4236>>2]*C(12e3))+C(-1e4)))/C(2e3))),z[u+12>>2]=w;v[c+8>>2]=1065353216;q=z[$l(c+12|0,c+8|0)>>2];m=b;b=C(h*h);h=C(l*C(m*b));l=C(r*h);b=C(n*C(g*b));g=C(s*b);n=C(C(C(l+g)*C(-.5))+C(1));z[a+4284>>2]=q*C(K(C(n/C(C(l*C(.1444000005722046))+C(C(b*C(.1444000005722046))+d)))));z[a+4288>>2]=q*C(K(C(n/C(C(g*C(.1444000005722046))+C(C(h*C(.1444000005722046))+e)))));cb=c+16|0;t[a+5046|0]=0;cb=k+16|0}function zha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=cb-176|0;cb=g;ke(g+160|0,b);e=cb-48|0;cb=e;v[e+44>>2]=0;nk(b,e+44|0);a:{b:{c:{if(v[e+44>>2]!=(Hm(14190)|0)){break c}v[e+40>>2]=0;f=cb-32|0;cb=f;v[f+28>>2]=0;Cv(f+8|0,f+28|0);kn(f+16|0,b,v[f+8>>2],v[f+12>>2]);v[f+16>>2]=v[f+28>>2];v[e+40>>2]=w[f+16|0]|w[f+17|0]<<8|(w[f+18|0]<<16|w[f+19|0]<<24);cb=f+32|0;f=-1;i=v[e+40>>2];if(i-3>>>0<4294967294){break c}d:{e:{f:{if(i>>>0<=1){i=Db(e+24|0);v[22440]=0;h=Y(496,b|0,i|0,256)|0;j=v[22440];v[22440]=0;if((j|0)==1){break b}if(!h){break e}v[22440]=0;U(11,e+8|0,d|0,i|0);h=v[22440];v[22440]=0;if((h|0)!=1){break f}break b}i=Db(e+24|0);v[22440]=0;h=Q(498,b|0,i|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break b}if(!h){break d}v[22440]=0;U(11,e+8|0,d|0,i|0);h=v[22440];v[22440]=0;if((h|0)==1){break b}}h=e+8|0;Cb(c,h);rb(h);rb(i);bg(b,h);i=0;v[e+24>>2]=0;nk(b,e+24|0);h=v[e+24>>2];if(h>>>0>50){break c}while(1){if((h|0)!=(i|0)){if(!vK(a,b,d)){break c}i=i+1|0;continue}break}v[e+24>>2]=0;nk(b,e+24|0);f=v[e+24>>2]==(Hm(14236)|0)?1:-1;break c}rb(i);break c}rb(i)}cb=e+48|0;break a}a=P()|0;O()|0;rb(i);S(a|0);L()}g:{if(f){break g}Ml(v[v[b>>2]-12>>2]+b|0,0);f=v[g+172>>2];v[g+8>>2]=v[g+168>>2];v[g+12>>2]=f;f=v[g+164>>2];v[g>>2]=v[g+160>>2];v[g+4>>2]=f;f=Tl(g+48|0,Uj(b,g));v[22440]=0;b=Q(462,g+32|0,14375)|0;e=v[22440];v[22440]=0;h:{if((e|0)!=1){v[22440]=0;v[g+24>>2]=3;v[g+28>>2]=0;U(463,f|0,b|0,g+24|0);e=v[22440];v[22440]=0;if((e|0)!=1){Ab(b);t[g+23|0]=0;v[22440]=0;b=Q(462,g+32|0,14831)|0;e=v[22440];v[22440]=0;if((e|0)!=1){v[22440]=0;U(464,f|0,g+23|0,b|0);e=v[22440];v[22440]=0;if((e|0)!=1){Ab(b);v[22440]=0;e=w[g+23|0];b=T(477,f|0)|0;i=v[22440];v[22440]=0;if((i|0)!=1){v[22440]=0;i=T(478,f|0)|0;h=v[22440];v[22440]=0;if((h|0)!=1){d=e?0:d;v[g+24>>2]=b;i:{j:{k:{l:{while(1){if(!Qb(b,i)){a=Gk(w[g+48|0]);jh(f);f=a?-1:1;break g}v[22440]=0;b=Q(462,g+32|0,15837)|0;e=v[22440];v[22440]=0;if((e|0)==1){break k}v[22440]=0;e=Y(479,f|0,v[g+24>>2],b|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break j}Ab(b);m:{n:{if(e){v[22440]=0;W(480,f|0,g+24|0,c|0,d|0);b=v[22440];v[22440]=0;if((b|0)!=1){break n}break i}v[22440]=0;b=Q(462,g+32|0,15507)|0;e=v[22440];v[22440]=0;o:{p:{if((e|0)!=1){v[22440]=0;e=Y(479,f|0,v[g+24>>2],b|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break p}Ab(b);if(!e){break o}v[22440]=0;U(481,f|0,g+24|0,g+20|0);b=v[22440];v[22440]=0;if((b|0)==1){break i}break n}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ab(b);break h}v[22440]=0;b=Q(462,g+32|0,15406)|0;e=v[22440];v[22440]=0;if((e|0)==1){break m}v[22440]=0;e=Y(479,f|0,v[g+24>>2],b|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break l}Ab(b);if(!e){break n}v[22440]=0;W(482,f|0,g+24|0,a|0,d|0);b=v[22440];v[22440]=0;if((b|0)==1){break i}}Fx(g+24|0);b=v[g+24>>2];continue}break}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ab(b);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ab(b);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ab(b);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ab(b);break h}a=P()|0;O()|0}jh(f);S(a|0);L()}cb=g+176|0;return f|0}function Oha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=cb-304|0;cb=e;g=cb-32|0;cb=g;d=g+8|0;yA(d,b);Au(g,d);v[22440]=0;U(476,e+144|0,v[g>>2],v[g+4>>2]);b=v[22440];v[22440]=0;a:{if((b|0)!=1){vc(g+8|0);cb=g+32|0;break a}a=P()|0;O()|0;vc(g+8|0);S(a|0);L()}v[22440]=0;U(459,e+32|0,v[e+144>>2],v[e+148>>2]);b=v[22440];v[22440]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((b|0)!=1){v[22440]=0;g=Q(91,e+160|0,e+32|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break z}rb(e+32|0);_b(e+144|0);if(c>>>0<2189){break g}b=Tl(e+32|0,g);v[22440]=0;c=Q(462,e+16|0,10143)|0;d=v[22440];v[22440]=0;if((d|0)==1){break x}v[22440]=0;v[e+8>>2]=19988487;v[e+12>>2]=0;U(463,b|0,c|0,e+8|0);d=v[22440];v[22440]=0;if((d|0)==1){break w}Ab(c);t[e+8|0]=0;v[22440]=0;c=Q(462,e+16|0,11016)|0;d=v[22440];v[22440]=0;if((d|0)==1){break i}v[22440]=0;U(464,b|0,e+8|0,c|0);d=v[22440];v[22440]=0;if((d|0)==1){break v}Ab(c);c=0;c=w[e+8|0]?c:v[a+1298404>>2];f=v[a+4>>2];v[22440]=0;d=Q(462,e+16|0,15837)|0;h=v[22440];v[22440]=0;if((h|0)==1){break u}v[22440]=0;W(465,b|0,f|0,d|0,c|0);f=v[22440];v[22440]=0;if((f|0)==1){break t}Ab(d);v[22440]=0;d=Q(462,e+16|0,15507)|0;f=v[22440];v[22440]=0;if((f|0)==1){break s}v[22440]=0;W(466,b|0,a|0,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break r}Ab(d);v[22440]=0;c=Q(462,e+16|0,15406)|0;d=v[22440];v[22440]=0;if((d|0)==1){break q}v[22440]=0;d=a+484360|0;U(467,b|0,d|0,c|0);f=v[22440];v[22440]=0;if((f|0)==1){break p}Ab(c);v[22440]=0;c=Q(462,e+16|0,26758)|0;f=v[22440];v[22440]=0;if((f|0)==1){break o}v[22440]=0;U(468,b|0,a+484344|0,c|0);f=v[22440];v[22440]=0;if((f|0)==1){break n}Ab(c);f=v[a+1298404>>2];v[22440]=0;c=Q(462,e+16|0,26764)|0;h=v[22440];v[22440]=0;if((h|0)==1){break m}v[22440]=0;W(469,b|0,d|0,c|0,f|0);d=v[22440];v[22440]=0;if((d|0)==1){break l}Ab(c);if(Gk(w[e+32|0])){v[22440]=0;c=Q(1,e+16|0,16316)|0;d=v[22440];v[22440]=0;if((d|0)==1){break k}a=v[a+1298464>>2];v[22440]=0;U(388,a|0,1,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break j}rb(c)}jh(b);break f}a=P()|0;O()|0;break y}a=P()|0;O()|0;rb(e+32|0)}_b(e+144|0);break b}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ab(c);break h}a=P()|0;O()|0;Ab(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ab(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ab(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ab(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ab(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ab(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;rb(c);break h}a=P()|0;O()|0}jh(b);break c}b=Db(e+32|0);d=v[a+1298404>>2];f=v[a+4>>2];v[22440]=0;d=da(470,f|0,g|0,b|0,d|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break e}A:{if((d|0)!=1){v[22440]=0;c=Q(1,e+16|0,16622)|0;d=v[22440];v[22440]=0;B:{if((d|0)!=1){a=v[a+1298464>>2];v[22440]=0;U(388,a|0,1,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break B}rb(c);break A}a=P()|0;O()|0;break d}a=P()|0;O()|0;rb(c);break d}d=v[a+1298404>>2];v[22440]=0;W(471,g|0,a|0,d|0,c>>>0<2188|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}}rb(b)}uf(g);cb=e+304|0;return}a=P()|0;O()|0}rb(b)}uf(g)}S(a|0);L()}function zb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=v[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=v[d>>2];d=d-b|0;if(d>>>0<y[114929]){break a}a=a+b|0;if(v[114930]!=(d|0)){if(b>>>0<=255){e=v[d+8>>2];b=b>>>3|0;c=v[d+12>>2];if((c|0)==(e|0)){i=459700,j=v[114925]&oka(-2,b),v[i>>2]=j;break b}v[e+12>>2]=c;v[c+8>>2]=e;break b}h=v[d+24>>2];b=v[d+12>>2];c:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break c}d:{e=d+20|0;c=v[e>>2];if(c){break d}e=d+16|0;c=v[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break b}e=v[d+28>>2];c=(e<<2)+460004|0;e:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break e}i=459704,j=v[114926]&oka(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break b}v[b+20>>2]=c;v[c+24>>2]=b;break b}b=v[f+4>>2];if((b&3)!=3){break b}v[114927]=a;v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=v[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(v[114931]==(f|0)){v[114931]=d;a=v[114928]+a|0;v[114928]=a;v[d+4>>2]=a|1;if(v[114930]!=(d|0)){break a}v[114927]=0;v[114930]=0;return}if(v[114930]==(f|0)){v[114930]=d;a=v[114927]+a|0;v[114927]=a;v[d+4>>2]=a|1;v[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=v[f+8>>2];b=b>>>3|0;c=v[f+12>>2];if((c|0)==(e|0)){i=459700,j=v[114925]&oka(-2,b),v[i>>2]=j;break g}v[e+12>>2]=c;v[c+8>>2]=e;break g}h=v[f+24>>2];b=v[f+12>>2];h:{if((f|0)!=(b|0)){c=v[f+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break h}i:{e=f+20|0;c=v[e>>2];if(c){break i}e=f+16|0;c=v[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break g}e=v[f+28>>2];c=(e<<2)+460004|0;j:{if(v[c>>2]==(f|0)){v[c>>2]=b;if(b){break j}i=459704,j=v[114926]&oka(-2,e),v[i>>2]=j;break g}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}v[b+24>>2]=h;c=v[f+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[f+20>>2];if(!c){break g}v[b+20>>2]=c;v[c+24>>2]=b}v[d+4>>2]=a|1;v[a+d>>2]=a;if(v[114930]!=(d|0)){break f}v[114927]=a;return}v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a}if(a>>>0<=255){a=a>>>3|0;b=(a<<3)+459740|0;c=v[114925];a=1<<a;k:{if(!(c&a)){v[114925]=a|c;a=b;break k}a=v[b+8>>2]}v[b+8>>2]=d;v[a+12>>2]=d;v[d+12>>2]=b;v[d+8>>2]=a;return}e=31;v[d+16>>2]=0;v[d+20>>2]=0;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}v[d+28>>2]=e;g=(e<<2)+460004|0;l:{m:{c=v[114926];b=1<<e;n:{if(!(c&b)){v[114926]=b|c;v[g>>2]=d;v[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[g>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=v[g+16>>2];if(b){continue}break}v[g+16>>2]=d;v[d+24>>2]=c}v[d+12>>2]=d;v[d+8>>2]=d;break l}a=v[c+8>>2];v[a+12>>2]=d;v[c+8>>2]=d;v[d+24>>2]=0;v[d+12>>2]=c;v[d+8>>2]=a}a=v[114933]-1|0;v[114933]=a?a:-1}}function Eg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;j=cb-112|0;cb=j;k=i&2147483647;l=e&2147483647;m=l;a:{b:{n=!(b|c);if(!(d|l?l-2147418112>>>0<2147549184:n)){p=k-2147418112|0;if(!h&(p|0)==-2147418112?f|g:(p|0)==-2147418112&(h|0)!=0|p>>>0>2147549184){break b}}if(!(!d&(m|0)==2147418112?n:m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(k|0)==2147418112?!(f|g):k>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(m^2147418112|c))){m=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:m;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(k^2147418112|g))){break a}if(!(b|d|(c|m))){if(f|h|(g|k)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|k)){break b}f=b;g=c;h=d;i=e;break a}l=(k|0)==(m|0);q=l&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:l&d>>>0<h>>>0|k>>>0>m>>>0;k=q;n=k?f:b;l=k?g:c;m=k?i:e;p=m;o=k?h:d;m=m&65535;e=k?e:i;r=e;h=k?d:h;d=e>>>16&32767;k=p>>>16&32767;if(!k){e=!(m|o);i=e<<6;k=E(e?n:o)+32|0;e=E(e?l:m);e=i+((e|0)==32?k:e)|0;Tf(j+96|0,n,l,o,m,e-15|0);o=v[j+104>>2];m=v[j+108>>2];n=v[j+96>>2];k=16-e|0;l=v[j+100>>2]}f=q?b:f;g=q?c:g;i=r&65535;if(!d){b=!(h|i);c=b<<6;d=E(b?f:h)+32|0;b=E(b?g:i);b=c+((b|0)==32?d:b)|0;Tf(j+80|0,f,g,h,i,b-15|0);h=v[j+88>>2];i=v[j+92>>2];f=v[j+80>>2];g=v[j+84>>2];d=16-b|0}c=h;b=i<<3|c>>>29;h=c<<3|g>>>29;i=b|524288;c=o;b=m<<3|c>>>29;e=c<<3|l>>>29;m=b;o=p^r;c=f;b=g<<3|c>>>29;c=c<<3;d=k-d|0;c:{if(!d){break c}if(d>>>0>127){h=0;i=0;b=0;c=1;break c}Tf(j- -64|0,c,b,h,i,128-d|0);qm(j+48|0,c,b,h,i,d);h=v[j+56>>2];i=v[j+60>>2];b=v[j+52>>2];c=v[j+48>>2]|(v[j+64>>2]|v[j+72>>2]|(v[j+68>>2]|v[j+76>>2]))!=0}f=b;m=m|524288;d=n;b=l<<3|d>>>29;d=d<<3;d:{if((o|0)<0){n=d-c|0;g=h;o=e-h|0;q=(b|0)==(f|0)&c>>>0>d>>>0|b>>>0<f>>>0;h=o-q|0;l=b-((c>>>0>d>>>0)+f|0)|0;i=(m-((e>>>0<g>>>0)+i|0)|0)-(o>>>0<q>>>0)|0;if(!(n|h|(l|i))){f=0;g=0;h=0;i=0;break a}if(i>>>0>524287){break d}b=!(h|i);c=b<<6;d=E(b?n:h)+32|0;b=E(b?l:i);b=c+((b|0)==32?d:b)|0;b=b-12|0;Tf(j+32|0,n,l,h,i,b);k=k-b|0;h=v[j+40>>2];i=v[j+44>>2];n=v[j+32>>2];l=v[j+36>>2];break d}b=b+f|0;g=c+d|0;b=g>>>0<d>>>0?b+1|0:b;n=g;d=g;l=b;f=(f|0)==(b|0)&c>>>0>d>>>0|b>>>0<f>>>0;b=i+m|0;c=e+h|0;b=c>>>0<h>>>0?b+1|0:b;d=c;c=f+c|0;h=c;i=c>>>0<d>>>0?b+1|0:b;if(!(i&1048576)){break d}n=n&1|((l&1)<<31|n>>>1);c=h;l=c<<31|l>>>1;k=k+1|0;h=(i&1)<<31|c>>>1;i=i>>>1|0}d=0;m=p&-2147483648;if((k|0)>=32767){h=d;i=m|2147418112;f=0;g=0;break a}c=0;e:{if((k|0)>0){c=k;break e}Tf(j+16|0,n,l,h,i,k+127|0);qm(j,n,l,h,i,1-k|0);n=v[j>>2]|(v[j+16>>2]|v[j+24>>2]|(v[j+20>>2]|v[j+28>>2]))!=0;l=v[j+4>>2];h=v[j+8>>2];i=v[j+12>>2]}e=h<<29;b=l>>>3|0;k=(l&7)<<29|n>>>3;l=n&7;g=l>>>0>4;f=k+g|0;e=b|e;b=e;b=f>>>0<g>>>0?b+1|0:b;g=b;e=(e|0)==(b|0)&f>>>0<k>>>0|b>>>0<e>>>0;b=i>>>3&65535;h=(i&7)<<29|h>>>3;i=c<<16;d=d|h;c=d+e|0;b=m|(b|i);h=c;i=c>>>0<d>>>0?b+1|0:b;f:{if((l|0)==4){d=0;b=g+d|0;e=f&1;c=f+e|0;b=c>>>0<f>>>0?b+1|0:b;f=c;g=b;c=(d|0)==(b|0)&c>>>0<e>>>0|b>>>0<d>>>0;b=c+h|0;i=b>>>0<c>>>0?i+1|0:i;h=b;break f}if(!l){break a}}}v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;cb=j+112|0}function hJ(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0;e=cb-128|0;cb=e;A[e+120>>3]=c;f=v[b+4>>2];a:{if(!f){break a}g=v[b>>2];h=w[Zk(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}fl(e+96|0,g,f,f-1|0);f=v[e+100>>2];v[b>>2]=v[e+96>>2];v[b+4>>2]=f}f=e+96|0;Od(f);g=v[e+96>>2];Od(e+80|0);h=Yk(g,v[e+84>>2],b);Od(f);f=v[b+4>>2];g=v[b>>2];b:{c:{d:{e:{if((h|0)==v[e+100>>2]){a=nc(e+112|0,21685);if(Hc(g,f,v[a>>2],v[a+4>>2])){d=aa(8)|0;v[22440]=0;R(983,e+80|0,e+120|0);a=v[22440];v[22440]=0;f:{g:{h:{if((a|0)!=1){v[22440]=0;U(986,e+96|0,17664,e+80|0);a=v[22440];v[22440]=0;if((a|0)==1){break h}oc(d,e+96|0);a=0;v[22440]=0;U(121,d|0,58712,975);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;rb(e+96|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}rb(e+80|0);if(!a){break c}}ba(d|0);break c}if(!d){break e}d=aa(8)|0;v[22440]=0;f=Q(985,e+48|0,b|0)|0;a=v[22440];v[22440]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[22440]=0;U(986,e- -64|0,17700,f|0);a=v[22440];v[22440]=0;if((a|0)==1){break q}v[22440]=0;R(988,e+80|0,e- -64|0);b=v[22440];v[22440]=0;a=1;if((b|0)==1){break p}v[22440]=0;R(983,e+32|0,e+120|0);a=v[22440];v[22440]=0;if((a|0)==1){break o}v[22440]=0;U(990,e+96|0,e+80|0,e+32|0);b=v[22440];v[22440]=0;a=1;if((b|0)==1){break n}oc(d,e+96|0);v[22440]=0;U(121,d|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}b=P()|0;O()|0;rb(e+96|0);a=0;break m}b=P()|0;O()|0;break i}b=P()|0;a=1;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}rb(e+32|0)}rb(e+80|0)}rb(e- -64|0)}rb(f);if(!a){break c}}ba(d|0);break c}d=nc(e+24|0,21685);if(Hc(g,f,v[d>>2],v[d+4>>2])){d=aa(8)|0;v[22440]=0;R(983,e+80|0,e+120|0);a=v[22440];v[22440]=0;r:{s:{t:{if((a|0)!=1){v[22440]=0;U(986,e+96|0,17664,e+80|0);a=v[22440];v[22440]=0;if((a|0)==1){break t}oc(d,e+96|0);a=0;v[22440]=0;U(121,d|0,58712,975);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;rb(e+96|0);break s}b=P()|0;O()|0;break r}b=P()|0;a=1;O()|0}rb(e+80|0);if(!a){break c}}ba(d|0);break c}f=v[b>>2];g=v[b+4>>2];d=nc(e+16|0,7719);if(Hc(f,g,v[d>>2],v[d+4>>2])){if(!Ed(w[a+28|0])){break e}if(c<=0|c>4){a=aa(8)|0;v[22440]=0;d=Q(56,e+96|0,7814)|0;b=v[22440];v[22440]=0;if((b|0)==1){break d}oc(a,d);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}b=P()|0;O()|0;rb(d);break c}b=Le(65536/c);a=a+24|0;v[v[a>>2]+480244>>2]=b;rp(v[a>>2]);break e}f=v[b>>2];g=v[b+4>>2];d=nc(e+8|0,7771);if(Hc(f,g,v[d>>2],v[d+4>>2])){if(!Ed(w[a+28|0])){break e}if(c<=0|c>4){a=aa(8)|0;v[22440]=0;d=Q(56,e+96|0,7835)|0;b=v[22440];v[22440]=0;if((b|0)!=1){oc(a,d);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}b=P()|0;O()|0;rb(d);break c}b=P()|0;O()|0;ba(a|0);break c}b=Le(c*65536);a=a+24|0;v[v[a>>2]+480240>>2]=b;rp(v[a>>2]);break e}d=v[b>>2];f=v[b+4>>2];b=nc(e,7789);if(!Hc(d,f,v[b>>2],v[b+4>>2])){break e}b=tl(c*65536);v[v[a+24>>2]+480236>>2]=b}cb=e+128|0;return}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function jJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=cb-176|0;cb=e;t[e+175|0]=c;f=v[b+4>>2];a:{if(!f){break a}g=v[b>>2];h=w[Zk(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}fl(e,g,f,f-1|0);f=v[e+4>>2];v[b>>2]=v[e>>2];v[b+4>>2]=f}Od(e);f=v[e>>2];Od(e+144|0);h=Yk(f,v[e+148>>2],b);Od(e);f=v[b+4>>2];g=v[b>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==v[e+4>>2]){a=nc(e+160|0,21685);if(Hc(g,f,v[a>>2],v[a+4>>2])){c=aa(8)|0;v[22440]=0;R(979,e+144|0,e+175|0);a=v[22440];v[22440]=0;if((a|0)==1){break g}v[22440]=0;U(986,e|0,17664,e+144|0);a=v[22440];v[22440]=0;if((a|0)==1){break f}oc(c,e);a=0;v[22440]=0;U(121,c|0,58712,975);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;rb(e);break e}if(!d){break h}c=aa(8)|0;v[22440]=0;d=Q(985,e+112|0,b|0)|0;a=v[22440];v[22440]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[22440]=0;U(986,e+128|0,17700,d|0);a=v[22440];v[22440]=0;if((a|0)==1){break p}v[22440]=0;R(988,e+144|0,e+128|0);b=v[22440];v[22440]=0;a=1;if((b|0)==1){break o}v[22440]=0;R(979,e+96|0,e+175|0);a=v[22440];v[22440]=0;if((a|0)==1){break n}v[22440]=0;U(990,e|0,e+144|0,e+96|0);b=v[22440];v[22440]=0;a=1;if((b|0)==1){break m}oc(c,e);v[22440]=0;U(121,c|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}b=P()|0;O()|0;rb(e);a=0;break l}b=P()|0;O()|0;break d}b=P()|0;a=1;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;a=1;O()|0;break k}b=P()|0;O()|0}rb(e+96|0)}rb(e+144|0)}rb(e+128|0)}rb(d);if(a){break d}break c}d=nc(e+88|0,21685);if(Hc(g,f,v[d>>2],v[d+4>>2])){c=aa(8)|0;v[22440]=0;R(979,e+144|0,e+175|0);a=v[22440];v[22440]=0;q:{r:{if((a|0)!=1){v[22440]=0;U(986,e|0,17664,e+144|0);a=v[22440];v[22440]=0;if((a|0)==1){break r}oc(c,e);a=0;v[22440]=0;U(121,c|0,58712,975);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;rb(e);break q}b=P()|0;O()|0;break d}b=P()|0;a=1;O()|0}rb(e+144|0);if(a){break d}break c}s:{f=v[b>>2];g=v[b+4>>2];d=nc(e+80|0,7422);if(!Hc(f,g,v[d>>2],v[d+4>>2])){f=v[b>>2];g=v[b+4>>2];d=nc(e+72|0,7404);if(!Hc(f,g,v[d>>2],v[d+4>>2])){break s}}t[a+60|0]=c;break h}t:{f=v[b>>2];g=v[b+4>>2];d=nc(e- -64|0,6937);if(!Hc(f,g,v[d>>2],v[d+4>>2])){f=v[b>>2];g=v[b+4>>2];d=nc(e+56|0,6918);if(!Hc(f,g,v[d>>2],v[d+4>>2])){break t}}t[a+61|0]=c;break h}f=v[b>>2];g=v[b+4>>2];d=nc(e+48|0,7021);if(Hc(f,g,v[d>>2],v[d+4>>2])){t[a+62|0]=c;break h}f=v[b>>2];g=v[b+4>>2];d=nc(e+40|0,6067);if(Hc(f,g,v[d>>2],v[d+4>>2])){t[a+63|0]=c;break h}f=v[b>>2];g=v[b+4>>2];d=nc(e+32|0,7471);if(Hc(f,g,v[d>>2],v[d+4>>2])){t[a+64|0]=c;break h}d=v[b>>2];f=v[b+4>>2];b=nc(e+24|0,13421);if(!Hc(d,f,v[b>>2],v[b+4>>2])){break h}d=a+24|0;b=v[d>>2];f=b+24664|0;g=v[f+4>>2];v[e+16>>2]=v[f>>2];v[e+20>>2]=g;f=b+24656|0;g=v[f+4>>2];v[e+8>>2]=v[f>>2];v[e+12>>2]=g;f=v[b+24652>>2];v[e>>2]=v[b+24648>>2];v[e+4>>2]=f;if(c){a=LI(v[a+56>>2])}else{a=0}v[e+20>>2]=a;a=v[d>>2];if(!dx(e,a+24648|0)){break h}fy(a,e)}cb=e+176|0;return}b=P()|0;O()|0;break d}b=P()|0;a=1;O()|0}rb(e+144|0);if(!a){break c}}ba(c|0)}S(b|0)}L()}function CS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=cb-128|0;cb=f;i=Jg(f+112|0);a:{b:{c:{if(d){v[22440]=0;U(483,a|0,i|0,c|0);c=v[22440];v[22440]=0;if((c|0)!=1){break c}break b}v[22440]=0;U(484,a|0,i|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}}k=Rb(f+96|0);n=b+480192|0;o=b+1298464|0;d=1;while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{l=d&65535;if(l>>>0<=x[n>>1]){v[22440]=0;u[f+94>>1]=0;R(485,a|0,f+94|0);c=v[22440];v[22440]=0;t:{u:{v:{w:{if((c|0)!=1){g=cb-16|0;cb=g;e=cb-16|0;cb=e;p=x[f+94>>1];c=Kd(i);j=bc(i);h=cb-16|0;cb=h;while(1){if(c){m=vA(c+16|0,p);j=m?j:c;c=v[(m?4:0)+c>>2];continue}break}c=v[ac(h+8|0,j)>>2];cb=h+16|0;v[e+8>>2]=c;x:{if(Qb(c,cg(i))){if(!wA(x[f+94>>1],od(e+8|0))){break x}}c=cg(i)}cb=e+16|0;c=v[ac(g+8|0,c)>>2];cb=g+16|0;v[f+88>>2]=c;j=((l<<2)+b|0)+900380|0;if(!v[j>>2]){break d}q=f,r=Af(i),v[q+72>>2]=r;if(!ih(f+88|0,f+72|0)){break u}c=od(f+88|0);v[22440]=0;c=Q(3,f+72|0,c+4|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break t}v[22440]=0;e=Q(1,f+56|0,16812)|0;g=v[22440];v[22440]=0;if((g|0)==1){break v}g=Yp(c,e);rb(e);if(g){break p}e=v[b+4>>2];v[22440]=0;e=Q(486,e|0,c|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break r}v[v[j>>2]+44>>2]=e;if(!v[v[j>>2]+44>>2]){break w}break e}d=P()|0;O()|0;break f}v[22440]=0;e=Q(1,f+56|0,13452)|0;g=v[22440];v[22440]=0;y:{z:{A:{if((g|0)!=1){B:{if(!Yp(c,e)){v[22440]=0;g=Q(1,f+40|0,13709)|0;h=v[22440];v[22440]=0;if((h|0)==1){break A}h=Yp(c,g);rb(g);rb(e);if(h){break B}break s}rb(e)}v[22440]=0;e=T(487,c|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break z}v[f+56>>2]=e;e=v[b+4>>2];bi(f+32|0,f+56|0);v[22440]=0;e=Q(488,e|0,v[f+32>>2])|0;g=v[22440];v[22440]=0;if((g|0)==1){break y}qg(f+56|0);if(e){break e}break s}d=P()|0;O()|0;break g}d=P()|0;O()|0;rb(e);break g}d=P()|0;O()|0;break g}d=P()|0;O()|0;qg(f+56|0);break g}d=P()|0;O()|0;break g}c=v[j>>2];if(!c){break d}v[c+44>>2]=0;break d}d=P()|0;O()|0;break f}ad(k);BS(i);cb=f+128|0;return}e=yb(v[k>>2]);h=yb(v[k+4>>2]);g=cb-16|0;cb=g;v[g+8>>2]=e;while(1){C:{if(!Qb(e,h)){break C}if(Yp(e,c)){break C}Vn(g+8|0);e=v[g+8>>2];continue}break}cb=g+16|0;if(Qb(e,yb(v[k+4>>2]))){break p}v[22440]=0;R(489,k|0,c|0);e=v[22440];v[22440]=0;if((e|0)!=1){break q}}d=P()|0;O()|0;break g}v[22440]=0;e=Q(1,f+16|0,17513)|0;g=v[22440];v[22440]=0;if((g|0)==1){break o}v[22440]=0;U(490,f+40|0,e|0,c|0);g=v[22440];v[22440]=0;if((g|0)==1){break n}v[22440]=0;g=Q(1,f|0,16365)|0;h=v[22440];v[22440]=0;if((h|0)==1){break m}v[22440]=0;U(2,f+56|0,f+40|0,g|0);h=v[22440];v[22440]=0;if((h|0)==1){break l}h=v[o>>2];v[22440]=0;U(388,h|0,2,f+56|0);h=v[22440];v[22440]=0;if((h|0)==1){break k}rb(f+56|0);rb(g);rb(f+40|0);rb(e)}v[v[j>>2]+44>>2]=0;break e}d=P()|0;O()|0;break g}d=P()|0;O()|0;break h}d=P()|0;O()|0;break i}d=P()|0;O()|0;break j}d=P()|0;O()|0;rb(f+56|0)}rb(g)}rb(f+40|0)}rb(e)}rb(c)}ad(k);break a}rb(c)}d=d+1|0;continue}}d=P()|0;O()|0}BS(i);S(d|0);L()}function L5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=cb-128|0;cb=e;a:{if(xd(b)){break a}f=w[OI(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+112|0;wv(f,b,0,vb(b)-1|0);tc(b,f);rb(f)}g=e+112|0;Od(g);f=v[e+112>>2];Od(e+96|0);f=NI(f,v[e+100>>2],b);Od(g);b:{c:{d:{e:{if((f|0)==v[e+116>>2]){if(ue(b,21685)){a=aa(8)|0;v[22440]=0;U(977,e+112|0,17664,c|0);b=v[22440];v[22440]=0;if((b|0)==1){break d}oc(a,e+112|0);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}b=P()|0;O()|0;rb(e+112|0);break c}if(!d){break e}a=aa(8)|0;v[22440]=0;U(977,e+80|0,17700,b|0);b=v[22440];v[22440]=0;f:{g:{h:{i:{j:{if((b|0)!=1){v[22440]=0;R(988,e+96|0,e+80|0);b=v[22440];v[22440]=0;if((b|0)==1){break j}v[22440]=0;U(542,e+112|0,e+96|0,c|0);b=v[22440];v[22440]=0;d=1;if((b|0)==1){break i}oc(a,e+112|0);v[22440]=0;U(121,a|0,58712,975);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;rb(e+112|0);d=0;break h}b=P()|0;O()|0;break f}b=P()|0;d=1;O()|0;break g}b=P()|0;O()|0}rb(e+96|0)}rb(e+80|0);if(!d){break c}}ba(a|0);break c}k:{switch(v[f+4>>2]){case 0:se(e+72|0,b);b=cb-192|0;cb=b;f=b+16|0;Cg(f,c);v[22440]=0;R(90,b+32|0,f|0);c=v[22440];v[22440]=0;l:{m:{n:{o:{p:{if((c|0)!=1){v[22440]=0;c=Q(91,b+48|0,b+32|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break p}rb(b+32|0);rb(b+16|0);f=v[v[c>>2]-12>>2];v[22440]=0;g=ha(63)|0;h=v[22440];v[22440]=0;if((h|0)==1){break n}v[22440]=0;U(64,b+8|0,f+(b+48|0)|0,g|0);f=v[22440];v[22440]=0;if((f|0)==1){break n}Pb(b+8|0);v[22440]=0;Q(1088,c|0,b+32|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break n}f=Zj(v[v[c>>2]-12>>2]+(b+48|0)|0);g=w[b+32|0];uf(c);cb=b+192|0;b=(f^-1)&(g|0)!=0;break l}a=P()|0;O()|0;break o}a=P()|0;O()|0;rb(b+32|0)}rb(b+16|0);break m}a=P()|0;O()|0;uf(c)}S(a|0);L()}c=v[e+76>>2];v[e>>2]=v[e+72>>2];v[e+4>>2]=c;jJ(a,e,b,d);break e;case 1:se(e- -64|0,b);b=cb-192|0;cb=b;f=b+16|0;Cg(f,c);v[22440]=0;R(90,b+32|0,f|0);c=v[22440];v[22440]=0;q:{r:{s:{t:{u:{if((c|0)!=1){v[22440]=0;c=Q(91,b+48|0,b+32|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break u}rb(b+32|0);rb(b+16|0);f=v[v[c>>2]-12>>2];v[22440]=0;g=ha(63)|0;h=v[22440];v[22440]=0;if((h|0)==1){break s}v[22440]=0;U(64,b+8|0,f+(b+48|0)|0,g|0);f=v[22440];v[22440]=0;if((f|0)==1){break s}Pb(b+8|0);v[22440]=0;Q(98,c|0,b+32|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break s}f=Zj(v[v[c>>2]-12>>2]+(b+48|0)|0);g=v[b+32>>2];h=v[b+36>>2];uf(c);cb=b+192|0;b=f?0:g;c=f?0:h;break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;rb(b+32|0)}rb(b+16|0);break r}a=P()|0;O()|0;uf(c)}S(a|0);L()}f=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=f;gJ(a,e+8|0,b,c,d);break e;case 2:se(e+56|0,b);i=eI(c);b=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=b;hJ(a,e+16|0,i,d);break e;case 3:break k;default:break e}}se(e+48|0,b);se(e+40|0,c);b=v[e+52>>2];v[e+32>>2]=v[e+48>>2];v[e+36>>2]=b;b=v[e+44>>2];v[e+24>>2]=v[e+40>>2];v[e+28>>2]=b;fJ(a,e+32|0,e+24|0,d)}cb=e+128|0;return}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function KG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=v[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=v[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=v[114930]){if(c>>>0<=255){e=v[a+8>>2];c=c>>>3|0;d=v[a+12>>2];if((d|0)!=(e|0)){break c}i=459700,j=v[114925]&oka(-2,c),v[i>>2]=j;break b}h=v[a+24>>2];c=v[a+12>>2];d:{if((c|0)!=(a|0)){d=v[a+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break d}e:{e=a+20|0;d=v[e>>2];if(d){break e}e=a+16|0;d=v[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=v[e>>2];if(d){continue}e=c+16|0;d=v[c+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break b}e=v[a+28>>2];d=(e<<2)+460004|0;f:{if(v[d>>2]==(a|0)){v[d>>2]=c;if(c){break f}i=459704,j=v[114926]&oka(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}v[c+24>>2]=h;d=v[a+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[a+20>>2];if(!d){break b}v[c+20>>2]=d;v[d+24>>2]=c;break b}c=v[f+4>>2];if((c&3)!=3){break b}v[114927]=b;v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[f>>2]=b;return}v[e+12>>2]=d;v[d+8>>2]=e}c=v[f+4>>2];g:{if(!(c&2)){if(v[114931]==(f|0)){v[114931]=a;b=v[114928]+b|0;v[114928]=b;v[a+4>>2]=b|1;if(v[114930]!=(a|0)){break a}v[114927]=0;v[114930]=0;return}if(v[114930]==(f|0)){v[114930]=a;b=v[114927]+b|0;v[114927]=b;v[a+4>>2]=b|1;v[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=v[f+8>>2];c=c>>>3|0;d=v[f+12>>2];if((d|0)==(e|0)){i=459700,j=v[114925]&oka(-2,c),v[i>>2]=j;break h}v[e+12>>2]=d;v[d+8>>2]=e;break h}h=v[f+24>>2];c=v[f+12>>2];i:{if((f|0)!=(c|0)){d=v[f+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break i}j:{d=f+20|0;e=v[d>>2];if(e){break j}d=f+16|0;e=v[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=v[d>>2];if(e){continue}d=c+16|0;e=v[c+16>>2];if(e){continue}break}v[g>>2]=0}if(!h){break h}e=v[f+28>>2];d=(e<<2)+460004|0;k:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break k}i=459704,j=v[114926]&oka(-2,e),v[i>>2]=j;break h}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}v[c+24>>2]=h;d=v[f+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[f+20>>2];if(!d){break h}v[c+20>>2]=d;v[d+24>>2]=c}v[a+4>>2]=b|1;v[a+b>>2]=b;if(v[114930]!=(a|0)){break g}v[114927]=b;return}v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[a+b>>2]=b}if(b>>>0<=255){b=b>>>3|0;c=(b<<3)+459740|0;d=v[114925];b=1<<b;l:{if(!(d&b)){v[114925]=b|d;b=c;break l}b=v[c+8>>2]}v[c+8>>2]=a;v[b+12>>2]=a;v[a+12>>2]=c;v[a+8>>2]=b;return}e=31;v[a+16>>2]=0;v[a+20>>2]=0;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}v[a+28>>2]=e;g=(e<<2)+460004|0;m:{d=v[114926];c=1<<e;n:{if(!(d&c)){v[114926]=c|d;v[g>>2]=a;v[a+24>>2]=g;break n}e=b<<((e|0)==31?0:25-(e>>>1|0)|0);c=v[g>>2];while(1){d=c;if((v[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=v[g+16>>2];if(c){continue}break}v[g+16>>2]=a;v[a+24>>2]=d}v[a+12>>2]=a;v[a+8>>2]=a;return}b=v[d+8>>2];v[b+12>>2]=a;v[d+8>>2]=a;v[a+24>>2]=0;v[a+12>>2]=d;v[a+8>>2]=b}}function qL(a,b){var c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=0,s=C(0),t=0;if(b){op(a);c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;v[a+24588>>2]=0;v[a+24592>>2]=0;wL(a)}pL(a+24648|0);p=v[a+24620>>2];f=cb-144|0;cb=f;e=a+397456|0;c=v[e+4>>2];if(c>>>0>=29){v[e+4>>2]=0;c=0}h=B(c,44)+47584|0;if(!(b?0:(h|0)==v[e+8>>2])){v[e+8>>2]=h;c=f+8|0;d=v[h+24>>2];v[c>>2]=d;i=v[h+16>>2];v[c+4>>2]=i;v[c+8>>2]=v[h+4>>2];k=(d|0)>(i|0)?d:i;if((k|0)<=-601){j=i;i=k+600|0;v[c+4>>2]=j-i;v[c>>2]=d-i}o=C(p>>>0);g=C(z[h+36>>2]*C(79.30999755859375));a:{if(C(D(g))<C(2147483648)){d=~~g;break a}d=-2147483648}v[c+16>>2]=d- -8192;g=C(C(C(z[h+32>>2]*C(.0036000001709908247))+C(.15000000596046448))*C(32767));b:{if(C(D(g))<C(2147483648)){d=~~g;break b}d=-2147483648}v[c+20>>2]=(d|0)<32512?d:32512;i=0;g=z[h+8>>2];n=C(C(F(z[h+20>>2],C(.10000000149011612)))*o);c:{if(C(D(n))<C(2147483648)){d=~~n;break c}d=-2147483648}j=(d|0)<96;k=j?96:d;l=k-7500|0;m=k>>>0<l>>>0?0:l;n=C(z[h+28>>2]*o);d:{if(C(D(n))<C(2147483648)){l=~~n;break d}l=-2147483648}j=m+(l+(j?d-96|0:0)|0)|0;l=(j|0)<128;d=l?128:j;q=d>>>0<3800?d:3800;v[c+24>>2]=q;l=l?j-128|0:0;g=C(g*o);e:{if(C(D(g))<C(2147483648)){m=~~g;break e}m=-2147483648}j=d-3800|0;j=(m+l|0)+(d>>>0<j>>>0?0:j)|0;v[c+32>>2]=j;l=k>>>0<7500?k:7500;while(1){if((i|0)==8){g=C(j|0);n=C(te(C(.0010000000474974513),(j|0)<4721?C(1):C(C(4720)/g))*C(32768));f:{if(C(D(n))<C(2147483648)){d=~~n;break f}d=-2147483648}v[c+12>>2]=d;g=C(z[h+12>>2]*g);r=c,s=te(C(.0010000000474974513),g<=C(4720)?C(1):C(C(4720)/g)),z[r+28>>2]=s}else{d=B(i,12);k=d+c|0;u[k+42>>1]=x[d+48874>>1];u[k+36>>1]=x[d+48868>>1];m=d+48870|0;m=x[m>>1]|x[m+2>>1]<<16;u[k+38>>1]=m;u[k+40>>1]=m>>>16;v[k+44>>2]=l+((B(v[d+48864>>2],q)+50|0)/100|0);i=i+1|0;continue}break}v[e+20>>2]=v[f+40>>2];c=uJ(vJ(v[f+16>>2]),o);u[e+86>>1]=c;u[e+84>>1]=c;c=x[f+24>>1]<<1;u[e+94>>1]=c;u[e+92>>1]=c;c=0;while(1){if((c|0)==8){v[e+49892>>2]=v[f+32>>2];c=v[f+12>>2];if((c|0)>-9e3){c=tJ(c)}else{c=0}v[e+80>>2]=c;d=e+49948|0;c=v[f+8>>2];if((c|0)>=-8999){c=tJ(c)}else{c=0}v[d>>2]=c;c=v[f+28>>2];d=e+49932|0;v[d>>2]=268464128;v[d+4>>2]=1879052288;c=c>>>0<32512?c:32512;u[e+49906>>1]=c;u[e+49904>>1]=c;u[e+49902>>1]=c;u[e+49900>>1]=c;v[f+4>>2]=v[f+20>>2];oe(f+4|0,0,32752);c=x[f+4>>1];u[e+49914>>1]=c;d=e+49910|0;u[d>>1]=0;u[d+2>>1]=0;u[e+49908>>1]=c;g=z[f+36>>2];r=f,t=uJ(C(g*g),o),v[r>>2]=t;oe(f,256,32512);c=x[f>>1];u[e+49922>>1]=c;d=e+49918|0;u[d>>1]=0;u[d+2>>1]=0;u[e+49916>>1]=c}else{d=(c<<4)+e|0;h=(f+8|0)+B(c,12)|0;i=v[h+44>>2];v[d+100>>2]=i;v[d+104>>2]=i;u[d+108>>1]=x[h+36>>1];u[d+110>>1]=x[h+42>>1];u[d+112>>1]=x[h+40>>1];u[d+114>>1]=x[h+38>>1];c=c+1|0;continue}break}}c=a+397448|0;d=a+397452|0;if(b){v[e+16>>2]=0;xJ(e,c,d)}b=B(p,5);if(b>>>0>y[e+20>>2]){v[e+20>>2]=b}cb=f+144|0;b=a+1298300|0;if(Bd(b)){fO(v[b>>2],v[a+24620>>2])}}function Xja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=cb-736|0;cb=d;sc(b);e=cb-16|0;cb=e;g=d+120|0;uU(e+8|0,g);i=b;b=v[e+12>>2];Yb(e,i,v[e+8>>2],b);h=v[e+4>>2];if((h|0)==(b|0)){Ob(i,v[e+12>>2])}cb=e+16|0;b=(b|0)==(h|0);if(!b){tU(g)}a:{if(!b){break a}if(!vU(d+120|0)){break a}b:{if(!c){break b}ud(a,67108864);eg(a);b=w[d+145|0];u[a+480190>>1]=31;u[a+480188>>1]=b;v[a+480228>>2]=256/(b>>>0);b=jc(d,8208);Cb(a+1298344|0,b);rb(b);b=jc(d,10794);Cb(a+1298356|0,b);rb(b);f=d+96|0;Xf(f,4177);e=w[d+144|0];v[d+72>>2]=e>>>4;b=0;v[22440]=0;v[d+116>>2]=e&15;W(309,d|0,f|0,d+72|0,d+116|0);f=v[22440];v[22440]=0;c:{d:{if((f|0)!=1){Cb(a+1298368|0,d);rb(d);Ab(d+96|0);v[a+1298404>>2]=2;pq(Nb(a+484360|0),d+168|0,w[d+167|0]+1|0);while(1){e:{if((b|0)==31){qu(i,a+1298308|0,32);f=1;break e}f=b+1|0;g=B(f,104)+a|0;h=g+484380|0;ed(h,1);e=(d+120|0)+(b<<2)|0;p=h,q=Wb(w[e+176|0]|w[e+177|0]<<8|(w[e+178|0]<<16|w[e+179|0]<<24)),v[p>>2]=q;j=Wb(w[e+300|0]|w[e+301|0]<<8|(w[e+302|0]<<16|w[e+303|0]<<24));v[g+484384>>2]=j;p=g+484388|0,q=Wb(w[e+424|0]|w[e+425|0]<<8|(w[e+426|0]<<16|w[e+427|0]<<24))+j|0,v[p>>2]=q;if(Wb(w[e+424|0]|w[e+425|0]<<8|(w[e+426|0]<<16|w[e+427|0]<<24))){e=g+484414|0;u[e>>1]=x[e>>1]|2}yk(h);b=(d+120|0)+b|0;t[d|0]=w[b+548|0];t[d+96|0]=64;p=g+484410|0,q=w[Tb(d,d+96|0)|0]<<2,u[p>>1]=q;t[g+484417|0]=w[b+579|0]<<4;b=f;continue}break}while(1){if((f|0)!=32){sU(i,((f<<5)+a|0)+946304|0,30);f=f+1|0;continue}break}m=c&1;if(m){wg(a+484344|0,w[d+166|0]+1|0)}j=a+484344|0;l=a+480188|0;e=0;while(1){if(w[d+166|0]<e>>>0){f=1;if(!(c&2)){break a}b=Nc(d,8,1,1,0);while(1){if((f|0)==32){break b}vg(b,(B(f,104)+a|0)+484380|0,i);f=f+1|0;continue}}h=ai(d+96|0);f:{g:{if(w[d+146|0]){v[22440]=0;b=T(278,i|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break f}v[22440]=0;U(192,d+72|0,i|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break f}break g}b=x[l>>1];v[22440]=0;U(192,d+72|0,i|0,b<<8);b=v[22440];v[22440]=0;if((b|0)==1){break d}}b=d+72|0;Sc(h,cc(d,b));sb(d);sb(b);h:{if(!m){break h}v[22440]=0;b=Y(229,j|0,e&65535,64)|0;f=v[22440];v[22440]=0;if((f|0)==1){break d}if(!b){break h}b=0;if(w[d+146|0]){g=0;v[22440]=0;R(310,h|0,d|0);b=v[22440];v[22440]=0;if((b|0)==1){break d}i:while(1){if((g|0)==64){break h}k=d+g|0;b=128;f=0;n=Gf(Sb(j,e),g);while(1){if(x[l>>1]<=f>>>0){g=g+1|0;continue i}j:{if(!(w[k|0]&b)){break j}v[22440]=0;R(311,h|0,B(f,6)+n|0);o=v[22440];v[22440]=0;if((o|0)!=1){break j}break d}b=b>>>1|0;f=f+1|0;continue}}}k:while(1){f=0;g=b&65535;if(g>>>0>=x[l>>1]){break h}while(1){if((f|0)==64){b=b+1|0;continue k}k=Zc(Sb(j,e),f,g);v[22440]=0;R(311,h|0,k|0);k=v[22440];v[22440]=0;if((k|0)!=1){f=f+1|0;continue}break}break}break d}e=e+1|0;sb(d+96|0);continue}break}break d}f=P()|0;O()|0;Ab(d+96|0);break c}f=P()|0;O()|0;sb(d+96|0)}S(f|0);L()}f=1}cb=d+736|0;return f|0}function J_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=cb-352|0;cb=d;f=cb-16|0;cb=f;v[a+4>>2]=0;t[a|0]=0;e=a+40|0;dn(e,32);t[f+15|0]=0;cn(e,f+15|0);cb=f+16|0;e=v[a+36>>2];a:{if(!Gh(v[v[e>>2]-12>>2]+e|0)){ph(a,2,16777216);break a}f=d+88|0;ke(f,e);e=v[f+12>>2];v[a+16>>2]=v[f+8>>2];v[a+20>>2]=e;v[f>>2]=3;h=v[a+36>>2];g=d+24|0;e=0;while(1){if(y[f>>2]>e>>>0){li(h,e+g|0);e=e+1|0;continue}break}if(Mb(g,26064,3)){ph(a,2,512);break a}t[d+351|0]=0;li(v[a+36>>2],d+351|0);Hb(d+88|0,0,256);f=w[d+351|0];b:{if(!f){e=d+88|0;break b}e=d+88|0;Uk(v[a+36>>2],e,f)}g=b;b=Lk(d+24|0,e,f);f=Wv(g,b);Ab(b);if(!f){ph(a,2,4096)}if(Gk(w[a|0])){break a}li(v[a+36>>2],d+87|0);g=w[d+87|0];b=g&3;u[a+24>>1]=(b|0)==3?4:b;if(Ti(g,6)){b=d+24|0;Cc(b,a+32|0,9);Te(b,1)}v[d+80>>2]=0;VE(v[a+36>>2],d+80|0);b=v[d+80>>2];t[d+79|0]=0;if(b>>>0>=2){li(v[a+36>>2],d+87|0);e=-1;if(!w[d+87|0]){li(v[a+36>>2],d+79|0);e=-2}Vl(v[a+36>>2],b+e|0)}v[d+64>>2]=0;v[d+68>>2]=0;c:{if(!Ti(g,4)){break c}Fk(v[a+36>>2],d- -64|0);b=v[d+68>>2];f=v[d+64>>2];v[a+64>>2]=f;v[a+68>>2]=b;e=v[c+4>>2];if((e|0)==(b|0)&y[c>>2]>=f>>>0|b>>>0<e>>>0){break c}ph(a,1,4)}if(Ti(g,5)){li(v[a+36>>2],d+87|0);Vl(v[a+36>>2],w[d+87|0])}c=w[d+79|0];d:{if(!Ti(c,0)){break d}li(v[a+36>>2],d+87|0);b=w[d+87|0];b=b&1?-1:b>>>1|0;u[a+24>>1]=b;if(b){break d}ph(a,1,2)}v[a+8>>2]=0;e=1;if(Ti(c,1)){VE(v[a+36>>2],a+8|0)}h=Ti(g,2);b=d+24|0;f=a+32|0;Cc(b,f,6);Te(b,h);h=Ti(g,3);Cc(b,f,7);Te(b,h);h=x[a+24>>1];Cc(b,f,5);Te(b,(h|0)!=0);g=Ti(g,7);Cc(b,f,8);Te(b,g);Cc(b,f,5);e:{if(tb(v[v[d+24>>2]>>2],v[d+28>>2])){break e}Cc(d+8|0,f,6);if(tb(v[v[d+8>>2]>>2],v[d+12>>2])){break e}Cc(d+56|0,f,7);if(tb(v[v[d+56>>2]>>2],v[d+60>>2])){break e}Cc(d+48|0,f,8);e=tb(v[v[d+48>>2]>>2],v[d+52>>2])}b=d+40|0;Cc(b,f,11);Te(b,e);Cc(d+24|0,f,11);if(Ti(c,2)){u[d+8>>1]=0;Vv(v[a+36>>2],d+8|0);b=v[a+36>>2];e=x[d+8>>1];Cc(d+24|0,f,9);Vl(b,B(e,tb(v[v[d+24>>2]>>2],v[d+28>>2])?2:1))}if(Ti(c,3)){Vl(v[a+36>>2],5)}Fk(v[a+36>>2],d- -64|0);c=v[d+68>>2];b=v[d+64>>2];if(!c&b>>>0>=16001|c){ph(a,2,8192);break a}v[a+104>>2]=b;if(!b){ph(a,1,1)}Cc(d+24|0,f,11);f:{if(!tb(v[v[d+24>>2]>>2],v[d+28>>2])){break f}Fk(v[a+36>>2],d- -64|0);if(Rv(v[d+64>>2],v[d+68>>2])){break f}ph(a,2,2048);break a}b=d+8|0;ke(b,v[a+36>>2]);c=v[a+16>>2];e=v[a+20>>2];g=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=g;g=v[b+12>>2];v[d+32>>2]=v[b+8>>2];v[d+36>>2]=g;b=v[d+32>>2];e=v[d+36>>2]-(e+(c>>>0>b>>>0)|0)|0;v[d+32>>2]=b-c;v[d+36>>2]=e;c=v[d+32>>2];b=v[d+36>>2];if((b|0)<0){ph(a,2,16384);break a}v[a+96>>2]=c;v[a+100>>2]=b;b=d+24|0;Cc(b,f,11);c=tb(v[v[d+24>>2]>>2],v[d+28>>2])?d- -64|0:a+96|0;e=v[c+4>>2];v[a+72>>2]=v[c>>2];v[a+76>>2]=e;Cc(b,f,11);if(!tb(v[v[d+24>>2]>>2],v[d+28>>2])){b=v[a+100>>2]+v[a+20>>2]|0;e=v[a+16>>2];c=e+v[a+96>>2]|0;v[a+80>>2]=c;v[a+84>>2]=c>>>0<e>>>0?b+1|0:b}a=d+24|0;Cc(a,f,10);Te(a,1)}cb=d+352|0}function $V(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0;e=cb-32|0;cb=e;v[e+28>>2]=b;a:{if((d|0)<=0){break a}v[e+8>>2]=d;v[e+16>>2]=214748364;u=e,x=B(v[Bb(e+28|0,e+16|0)>>2],20),v[u+20>>2]=x;dn(c,v[Bb(e+8|0,e+20|0)>>2]);v[e+12>>2]=b;v[e+8>>2]=a;while(1){b:{c:{d:{e:{if((d|0)<=0){break e}g=oh(a,b,h);i=oh(a,b,h+4|0);f=oh(a,b,h+5|0);u=e,x=oh(a,b,h+6|0)<<8|oh(a,b,h+7|0),v[u+24>>2]=x;n=f|i<<8;s=h+8|0;f:{g:{switch(g|0){case 0:h=0;if((d|0)<(n|0)){h=aa(8)|0;v[22440]=0;T(195,h|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break f}break d}while(1){if((h|0)!=(n|0)){u=e,x=oh(a,b,h+s|0),t[u+20|0]=x;cn(c,e+20|0);h=h+1|0;continue}break};r=n;break b;case 1:break g;default:break e}}Zh(e+24|0,d);r=v[e+24>>2];o=oh(a,b,h+10|0);t[e+20|0]=o;cn(c,e+20|0);j=h+11|0;n=n+3&65532;h=r-1|0;i=0;l=0;p=0;m=0;while(1){if((h|0)<=0){break c}f=zg(j,i,1,e+8|0);h:{i:{j:{k:{l:{if((l|0)<=7){if(f){g=i;break i}g=i+1|0;m=8;break l}g=i+1|0;m:{if(!f){if(!zg(j,g,1,e+8|0)){break i}k=2;n:{o:{f=i+2|0;if(!zg(j,f,1,e+8|0)){break o}k=3;f=i+3|0;if(!zg(j,f,1,e+8|0)){break o}k=zg(j,f,3,e+8|0);g=i+6|0;break n}g=f+1|0}f=4;p:{q:{r:{i=((m<<3)+k|0)-17|0;s:{if((i|0)<0){a=aa(8)|0;v[22440]=0;T(195,a|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break r}break s}if(i>>>0<56){break p}a=aa(8)|0;v[22440]=0;T(195,a|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break q}}b=P()|0;O()|0;ba(a|0);S(b|0);L()}ia(a|0,26168,170);L()}ia(a|0,26168,170);L()}m=w[i+26208|0];if((m|0)!=8){break k}break m}f=4;if((m|0)!=8){break k}}m=8;f=1;if((p|0)>19){break k}}f=0;break j}p=p+8|0}while(1){if(!((f|0)<0|(h|0)<=0)){k=(g|0)/8|0;i=k+j|0;q=oh(v[e+8>>2],v[e+12>>2],i);o=o-bd((oh(v[e+8>>2],v[e+12>>2],i+1|0)<<8|q<<16|oh(v[e+8>>2],v[e+12>>2],i+2|0))<<(g-(k<<3)|0)+8,32-m|0)|0;t[e+20|0]=o;cn(c,e+20|0);f=f-1|0;h=h-1|0;g=g+m|0;continue}break}l=(l|0)==31?31:l+1|0;i=g;break h}t:{u:{v:{f=g+1|0;if(!zg(j,f,1,e+8|0)){i=2;break v}f=g+2|0;if(!zg(j,f,1,e+8|0)){i=4;break v}f=g+3|0;if(!zg(j,f,1,e+8|0)){i=6;break v}f=g+5|0;if(!zg(j,g+4|0,1,e+8|0)){g=g+8|0;f=zg(j,f,3,e+8|0)+8|0;break t}g=g+10|0;i=16;f=zg(j,f,5,e+8|0);break u}g=f+2|0;f=zg(j,f+1|0,1,e+8|0)}f=f+i|0}w:{if(zg(j,g,1,e+8|0)){k=-256;i=12;break w}g=g+1|0;i=zg(j,g,1,e+8|0);k=i?-4352:0;i=i?14:8}q=g+1|0;g=zg(j,q,i,e+8|0);if(f>>>0>=3){l=l-((f|0)!=3)|0;l=((l|0)>1?l:1)-1|0}k=(g^-1)+k|0;g=Uc(v[c>>2],v[c+4>>2])+k|0;if(g>>>0<k>>>0){i=i+q|0;while(1){if((f|0)<=0|(h|0)<=0){break h}o=w[Eb(v[c>>2],g)|0];t[e+20|0]=o;cn(c,e+20|0);h=h-1|0;g=g+1|0;f=f-1|0;continue}}h=aa(8)|0;v[22440]=0;T(195,h|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break d}ia(h|0,26168,170);L()}p=p-(p>>3)|0;continue}}ia(h|0,26168,170);L()}h=hc(v[c>>2],v[c+4>>2])^1;break a}a=P()|0;O()|0;ba(h|0);S(a|0);L()}v[e+24>>2]=h}d=d-r|0;h=n+s|0;continue}}cb=e+32|0;return h|0}function Tda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=cb-32|0;cb=j;a:{if(ft(a)>>>0<b>>>0){m=Nn(j+16|0);v[22440]=0;R(752,m|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}kk(j+8|0,v[a>>2]);pl(j,v[a>>2],v[a+4>>2]);n=cb-48|0;cb=n;f=v[m+4>>2];c=$b(n+40|0,v[j+8>>2],v[j+12>>2]);e=$b(n+32|0,v[j>>2],v[j+4>>2]);b=cb-16|0;cb=b;c=$b(b+8|0,v[c>>2],v[c+4>>2]);e=$b(b,v[e>>2],v[e+4>>2]);c=yQ(v[c>>2],v[c+4>>2],v[e>>2],v[e+4>>2]);cb=b+16|0;c=c+v[m+4>>2]|0;v[m+4>>2]=c;b:{c:{if(!f){b=c-1|0;break c}b=c-1|0;if((b^f-1)>>>0<32){break b}}v[v[m>>2]+((c>>>0<33?0:b>>>5|0)<<2)>>2]=0}e=$b(n+24|0,v[j+8>>2],v[j+12>>2]);c=$b(n+16|0,v[j>>2],v[j+4>>2]);b=n+8|0;to(b,v[m>>2],f);f=v[e>>2];o=cb-48|0;cb=o;e=v[e+4>>2];d:{if((e|0)==v[b+4>>2]){e=$b(o+40|0,f,e);c=$b(o+32|0,v[c>>2],v[c+4>>2]);b=$b(o+24|0,v[b>>2],v[b+4>>2]);f=cb-16|0;cb=f;g=v[e>>2];d=v[e+4>>2];c=ol(v[c>>2],v[c+4>>2],g,d);v[f+12>>2]=c;e:{if((c|0)<=0){c=v[b>>2];break e}if(d){i=32-d|0;v[f+8>>2]=i;k=c;c=v[ld(f+8|0,f+12|0)>>2];v[f+12>>2]=k-c;h=v[b>>2];d=-1<<d&-1>>>i-c;v[h>>2]=v[h>>2]&(d^-1)|d&v[g>>2];c=c+v[b+4>>2]|0;v[b+4>>2]=c&31;v[b>>2]=h+(c>>>3&536870908);g=v[e>>2]+4|0;v[e>>2]=g;c=v[f+12>>2]}k=g;d=(c|0)/32|0;g=d<<2;gj(v[b>>2],k,g);d=c-(d<<5)|0;v[f+12>>2]=d;c=g+v[b>>2]|0;v[b>>2]=c;if((d|0)<=0){break e}c=e;e=g+v[e>>2]|0;v[c>>2]=e;c=v[b>>2];g=-1>>>32-d|0;v[c>>2]=v[c>>2]&(g^-1)|g&v[e>>2];v[b+4>>2]=v[f+12>>2]}$b(n,c,v[b+4>>2]);break d}g=$b(o+16|0,f,e);c=$b(o+8|0,v[c>>2],v[c+4>>2]);e=$b(o,v[b>>2],v[b+4>>2]);f=cb-16|0;cb=f;k=v[c>>2];d=v[c+4>>2];b=v[g>>2];c=v[g+4>>2];d=ol(k,d,b,c);v[f+12>>2]=d;f:{if((d|0)<=0){c=v[e+4>>2];break f}g:{if(!c){c=v[e+4>>2];break g}l=32-c|0;v[f+8>>2]=l;i=f+8|0;h=v[ld(i,f+12|0)>>2];v[f+12>>2]=d-h;d=v[e+4>>2];p=v[b>>2];v[f+8>>2]=h;k=32-d|0;v[f+4>>2]=k;b=v[e>>2];q=v[b>>2];i=v[Bb(i,f+4|0)>>2];l=p&(-1<<c&-1>>>l-h);v[b>>2]=(-1<<d&-1>>>k-i^-1)&q|(c>>>0<d>>>0?l<<d-c:l>>>c-d|0);d=d+i|0;c=d&31;v[e+4>>2]=c;d=b+(d>>>3&536870908)|0;v[e>>2]=d;b=h-i|0;if((b|0)>0){v[d>>2]=v[d>>2]&(-1>>>32-b^-1)|l>>>i+v[g+4>>2];v[e+4>>2]=b;c=b}b=v[g>>2]+4|0;v[g>>2]=b;d=v[f+12>>2]}h=32-c|0;i=-1<<c;l=i^-1;while(1){if((d|0)>=32){d=v[e>>2];b=v[b>>2];v[d>>2]=l&v[d>>2]|b<<c;v[e>>2]=d+4;v[d+4>>2]=i&v[d+4>>2]|b>>>h;d=v[f+12>>2]-32|0;v[f+12>>2]=d;b=v[g>>2]+4|0;v[g>>2]=b;continue}break}if((d|0)<=0){break f}l=v[b>>2];v[f+8>>2]=h;g=v[e>>2];b=v[g>>2];k=b;b=v[ld(f+12|0,f+8|0)>>2];k=k&(i&-1>>>h-b^-1);h=l&-1>>>32-d;v[g>>2]=k|h<<c;d=b+c|0;c=d&31;v[e+4>>2]=c;g=g+(d>>>3&536870908)|0;v[e>>2]=g;d=v[f+12>>2]-b|0;v[f+12>>2]=d;if((d|0)<=0){break f}v[g>>2]=v[g>>2]&(-1>>>32-d^-1)|h>>>b;c=v[f+12>>2];v[e+4>>2]=c}$b(n,v[e>>2],c)}cb=f+16|0;cb=o+48|0;cb=n+48|0;pt(a,m);Re(m)}cb=j+32|0;return}a=P()|0;O()|0;Re(m);S(a|0);L()}function fW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=cb-160|0;cb=d;sc(b);Fo(a);a:{if(!fv(b,d+120|0)){break a}if(!gD(d+120|0)){break a}j=v[b+8>>2];b:{if(!Tc(b,w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))){break b}while(1){c:{if((w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))>>>0>k>>>0){if(Kb(b,5)){break c}}e=h&1;break b}g=0;e=1;d:{if((w[d+124|0]|w[d+125|0]<<8)>>>0>=64){if((wi(b)|0)<=0){break d}}while(1){l=He(b);if(l){m=g>>>0>4;f=m&e;if(!((e^1)&1|m)){f=(Dp(l<<24>>24)&255)==w[g+13133|0]}e=f;g=g+1|0;continue}break}Ob(b,4);h=(g|0)==5?e&1?1:h:h}k=k+1|0;continue}}Tc(b,j);if(!e){break a}if(!Kb(b,fD(d+120|0))){break a}if(!c){i=1;break a}e=cb-16|0;cb=e;h=d+120|0;g=h;c=g+16|0;Tc(b,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));k=d+104|0;i=Rb(k);f=g+12|0;c=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[22440]=0;R(183,i|0,c|0);c=v[22440];v[22440]=0;e:{f:{g:{if((c|0)!=1){g=g+4|0;c=0;h:{i:{while(1){if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<=c>>>0){break h}v[22440]=0;j=Q(158,b|0,5)|0;l=v[22440];v[22440]=0;if((l|0)==1){break g}if(!j){break h}j=w[g|0]|w[g+1|0]<<8;v[22440]=0;U(184,e|0,b|0,j|0);j=v[22440];v[22440]=0;if((j|0)!=1){v[22440]=0;R(185,i|0,e|0);j=v[22440];v[22440]=0;if((j|0)==1){break i}c=c+1|0;rb(e);continue}break}c=P()|0;O()|0;break f}c=P()|0;O()|0;rb(e);break f}cb=e+16|0;break e}c=P()|0;O()|0;break f}c=P()|0;O()|0}ad(i);S(c|0);L()}v[22440]=0;W(178,d+88|0,b|0,h|0,k|0);c=v[22440];v[22440]=0;j:{if((c|0)!=1){c=w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24);v[22440]=0;Q(157,b|0,c|0)|0;c=v[22440];v[22440]=0;k:{if((c|0)!=1){g=d+36|0;i=0;l:{m:{n:{o:{while(1){p:{q:{if((w[d+140|0]|w[d+141|0]<<8|(w[d+142|0]<<16|w[d+143|0]<<24))>>>0>i>>>0){v[22440]=0;c=Q(158,b|0,8)|0;f=v[22440];v[22440]=0;if((f|0)==1){break q}if(c){break p}}i=hc(v[a>>2],v[a+4>>2])^1;fc(d+88|0);ad(d+104|0);break a}b=P()|0;O()|0;break k}v[22440]=0;ga(179,d- -64|0,b|0,d+120|0,d+88|0,d+104|0);c=v[22440];v[22440]=0;if((c|0)!=1){c=d- -64|0;e=Go(c);v[22440]=0;f=T(180,c|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break o}if(f){v[22440]=0;f=T(181,d+24|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break n}e=v[e>>2];r:{if((e|0)<0){break r}h=v[d+104>>2];if(gd(h,v[d+108>>2])>>>0<=e>>>0){break r}v[22440]=0;U(11,d+8|0,2,rd(h,e)|0);e=v[22440];v[22440]=0;if((e|0)==1){break m}e=d+8|0;Cb(d+24|0,e);rb(e)}ev(g,c);v[22440]=0;R(182,a|0,f|0);c=v[22440];v[22440]=0;if((c|0)==1){break m}Mq(f)}i=i+1|0;sb(d- -64|0);continue}break}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=P()|0;O()|0;Mq(f)}sb(d- -64|0);break k}b=P()|0;O()|0}fc(d+88|0);break j}b=P()|0;O()|0}ad(d+104|0);S(b|0);L()}cb=d+160|0;return i|0}function hE(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=cb-144|0;cb=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((c|0)<=5){Bv(a+96|0,c);v[22440]=0;c=Q(1,a+80|0,17800)|0;d=v[22440];v[22440]=0;if((d|0)==1){break E}v[22440]=0;U(2,a+112|0,a+96|0,c|0);d=v[22440];v[22440]=0;if((d|0)==1){break D}v[22440]=0;d=Q(3,a+48|0,e|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break C}v[22440]=0;e=Q(1,a+32|0,19628)|0;f=v[22440];v[22440]=0;if((f|0)==1){break B}v[22440]=0;U(4,a- -64|0,d|0,e|0);f=v[22440];v[22440]=0;if((f|0)==1){break A}v[22440]=0;U(2,a+128|0,a+112|0,a- -64|0);f=v[22440];v[22440]=0;if((f|0)==1){break z}rb(a- -64|0);rb(e);rb(d);d=a+112|0;rb(d);rb(c);rb(a+96|0);c=v[b>>2];v[22440]=0;U(5,d|0,1,(c?c:21685)|0);c=v[22440];v[22440]=0;if((c|0)==1){break t}c=v[b+4>>2];v[22440]=0;U(5,a+96|0,1,(c?c:21685)|0);c=v[22440];v[22440]=0;if((c|0)==1){break s}b=v[b+8>>2];v[22440]=0;v[a+64>>2]=b;R(6,a+80|0,a- -64|0);b=v[22440];v[22440]=0;if((b|0)==1){break r}v[22440]=0;Z(7,17679);b=v[22440];v[22440]=0;if((b|0)==1){break q}v[22440]=0;U(8,a- -64|0,0,a+112|0);b=v[22440];v[22440]=0;if((b|0)==1){break p}v[22440]=0;Z(9,a- -64|0);b=v[22440];v[22440]=0;if((b|0)==1){break o}v[22440]=0;Z(7,17473);b=v[22440];v[22440]=0;if((b|0)==1){break o}v[22440]=0;U(8,a+32|0,0,a+80|0);b=v[22440];v[22440]=0;if((b|0)==1){break n}v[22440]=0;Z(9,a+32|0);b=v[22440];v[22440]=0;if((b|0)==1){break m}v[22440]=0;Z(7,17471);b=v[22440];v[22440]=0;if((b|0)==1){break m}v[22440]=0;Z(7,17800);b=v[22440];v[22440]=0;if((b|0)==1){break m}v[22440]=0;U(8,a+16|0,0,a+128|0);b=v[22440];v[22440]=0;if((b|0)==1){break l}v[22440]=0;Z(9,a+16|0);b=v[22440];v[22440]=0;if((b|0)==1){break k}v[22440]=0;Z(7,13478);b=v[22440];v[22440]=0;if((b|0)==1){break k}v[22440]=0;U(8,a|0,0,a+96|0);b=v[22440];v[22440]=0;if((b|0)==1){break j}v[22440]=0;Z(9,a|0);b=v[22440];v[22440]=0;if((b|0)==1){break i}v[22440]=0;Z(7,13476);b=v[22440];v[22440]=0;if((b|0)==1){break i}v[22440]=0;X(10);b=v[22440];v[22440]=0;if((b|0)==1){break i}rb(a);rb(a+16|0);rb(a+32|0);rb(a- -64|0);rb(a+80|0);rb(a+96|0);rb(a+112|0);rb(a+128|0)}cb=a+144|0;return}b=P()|0;O()|0;break u}b=P()|0;O()|0;break v}b=P()|0;O()|0;break w}b=P()|0;O()|0;break x}b=P()|0;O()|0;break y}b=P()|0;O()|0;rb(a- -64|0)}rb(e)}rb(d)}rb(a+112|0)}rb(c)}rb(a+96|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;rb(a)}rb(a+16|0)}rb(a+32|0)}rb(a- -64|0)}rb(a+80|0)}rb(a+96|0)}rb(a+112|0)}rb(a+128|0)}S(b|0);L()}function uea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,B=0,C=0;f=cb-4144|0;cb=f;a:{h=a+14|0;h=wb(w[h|0]|w[h+1|0]<<8);b:{if(!h|h>>>0>20){break b}k=b+480190|0;h=a;if(x[k>>1]<=w[a+23|0]){break b}ed(d,32);u[d+34>>1]=1;a=f+24|0;j=h+20|0;v[a>>2]=j;B=a,C=Gt(j,j+80|0),v[B+4>>2]=C;GP(f+4136|0,v[f+24>>2],v[f+28>>2],wb(w[h+14|0]|w[h+15|0]<<8));j=v[f+4136>>2];g=w[Ib(j,0)+3|0];v[f+24>>2]=1;g=v[Pc(Fi(b,g+1|0)+24|0,a)>>2];i=a;a=v[f+4140>>2];GP(i,j,a,c?a:1);q=1/+(g>>>0);a=v[f+24>>2];j=Ib(a,v[f+28>>2]);g=v[f+4136>>2];k=x[k>>1];while(1){if((a|0)==(j|0)){c:{r=Lg(d);if(!r){break c}k=(e<<12>>>0)/1e4|0;e=v[f+4140>>2];a=f+4120|0;j=yd(a);d:{if(!e){break d}v[22440]=0;R(744,a|0,e|0);g=v[22440];v[22440]=0;if((g|0)!=1){v[22440]=0;xP(a,e);e=v[22440];v[22440]=0;if((e|0)!=1){break d}}break a}j=a;s=v[a>>2];n=v[f+4136>>2];z=v[f+4140>>2];A=b+480190|0;a=0;i=0;while(1){if((a|0)==(z|0)){k=b+24648|0}else{g=Ib(n,a);e=FP(s,a);l=w[g+3|0];e:{if(l>>>0>=x[A>>1]){break e}o=t[g+1|0];if((o|0)<0){break e}m=0;g=w[g+2|0];if((g+14&255)>>>0<=5){m=t[g+26910|0]}g=Fi(b,l+1|0);l=v[g+24>>2];p=q*(ni(+(m<<24>>24)/96+ +(o-t[Ib(n,0)+1|0]|0)/12)*+(l>>>0));if(p<=0){break e}m=EP(p);v[e+8>>2]=m;l=fb;v[e+12>>2]=l;v[e+16>>2]=v[g+20>>2];o=v[g>>2];v[e+76>>2]=o;v[e+88>>2]=x[g+34>>1]&1023;f:{if(c){v[e+664>>2]=i;i=Le(+(o>>>0)/Az(m,l))+i|0;g=k;break f}g=(k>>>0)/(wb(w[h+14|0]|w[h+15|0]<<8)>>>0)|0}v[e+20>>2]=g;v[e+24>>2]=g}a=a+1|0;continue}break}b=0;while(1){g:{a=v[d>>2];if(a>>>0>b>>>0){Hb(f+24|0,0,4096);v[f+16>>2]=512;v[f+12>>2]=a-b;c=v[Bb(f+16|0,f+12|0)>>2];B=f,C=yb(v[j>>2]),v[B+16>>2]=C;g=yb(v[j+4>>2]);while(1){a=v[f+16>>2];if(!Qb(a,g)){break g}h:{i:{if(!v[a+16>>2]){break i}e=v[a+664>>2];if(e>>>0>=c>>>0){v[a+664>>2]=e-c;break i}h=v[a+88>>2];v[f+12>>2]=c-e;B=f,C=Le((+y[a+76>>2]-Az(v[a>>2],v[a+4>>2]))/Az(v[a+8>>2],v[a+12>>2])),v[B+8>>2]=C;i=v[Bb(f+12|0,f+8|0)>>2];v[22440]=0;W(v[((h&1|(h&64?18:16))<<2)+27504>>2],a|0,k|0,(f+24|0)+(e<<3)|0,i|0);e=v[22440];v[22440]=0;if((e|0)==1){break h}v[a+664>>2]=0;if(y[a+76>>2]>y[a+4>>2]){break i}v[a+16>>2]=0}v[f+16>>2]=v[f+16>>2]+872;continue}break}break a}Tp(j);break c}e=v[d+20>>2]+(b<<1)|0;i=f+24|0;a=cb-16|0;cb=a;v[a+12>>2]=c;qc(a+12|0,512);g=v[a+12>>2];while(1){if(g){h=bd(v[i>>2]+2048|0,12);h=(h|0)<32767?h:32767;u[e>>1]=(h|0)>-32768?h:-32768;i=i+8|0;e=e+2|0;g=g-1|0;continue}break}cb=a+16|0;b=b+c|0;continue}}g=(r|0)!=0}else{i=w[a+3|0];j:{if(i>>>0>=k>>>0){break j}n=t[a+1|0];if((n|0)<0){break j}i=Fi(b,i+1|0);m=v[i>>2];p=ni(+(n-t[Ib(g,0)+1|0]|0)/-12);B=d,C=v[d>>2]+Le(q*(p*+(m>>>0)*+y[i+24>>2]))|0,v[B>>2]=C}a=a+4|0;continue}break}}cb=f+4144|0;return g|0}a=P()|0;O()|0;Tp(j);S(a|0);L()}function DJ(a){var b=C(0),c=C(0),d=0,e=C(0),f=C(0),g=0,h=0,i=C(0),k=0,m=C(0),r=C(0),s=0,t=C(0),u=0,w=C(0),x=C(0);d=a+4208|0;bN(d,z[a+4272>>2]);b=C(C(z[d>>2]*C(15920))+C(80));t=te(C(10),C(C(C(z[a+4216>>2]+C(-.5))*C(30))/C(40)));c=C(C(b/C(y[v[a+16>>2]+24620>>2]))*C(6.2831854820251465));b=WJ(c);w=cp(c);x=b;f=C(C(c*C(C(C(z[a+4212>>2]*C(35))+C(1))*C(.02888113260269165)))/b);m=(l(2,(p(f),j(2))&-2147483648|1056964608),q());g=(p(f),j(2))&2147483647;c=(l(2,g),q());a:{if(g>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(p(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=C(-1);if((h|0)<0){break b}if(!(c>C(88.7216796875))){break g}b=C(c*C(1.7014118346046923e38));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=C(905800061445916e-20);b=C(c+C(-.6931381225585938));break f}d=-1;e=C(-905800061445916e-20);b=C(c+C(.6931381225585938));break f}b=C(C(c*C(1.4426950216293335))+(l(2,(p(c),j(2))&-2147483648|1056964608),q()));h:{if(C(D(b))<C(2147483648)){d=~~b;break h}d=-2147483648}b=C(d|0);e=C(b*C(905800061445916e-20));b=C(c+C(b*C(-.6931381225585938)))}c=C(b-e);e=C(C(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=C(c*C(.5));i=C(c*b);r=C(C(i*C(C(i*C(.0015807170420885086))+C(-.03333321213722229)))+C(1));b=C(C(3)-C(r*b));r=C(i*C(C(r-b)/C(C(6)-C(c*b))));b=C(c-C(C(c*r)-i));if(!d){break b}e=C(C(C(c*C(r-e))-e)-i);i:{switch(d+1|0){case 0:b=C(C(C(c-e)*C(.5))+C(-.5));break b;case 2:b=C(C(e-C(c+C(.5)))*C(-2));if(c<C(-.25)){break b}b=C(c-e);b=C(C(b+b)+C(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),q());if(d>>>0>=57){c=C(C(c-e)+C(1));b=C(((d|0)==128?C(C(c+c)*C(1.7014118346046923e38)):C(c*b))+C(-1));break b}i=(l(2,1065353216-h|0),q());c=C((d>>>0<=22?C(C(C(1)-i)+C(c-e)):C(C(c-C(e+i))+C(1)))*b)}b=c}if(g>>>0<=1065353215){if(g>>>0<964689920){break a}f=C(m*C(C(b+b)-C(C(b*b)/C(b+C(1)))));break a}f=C(m*C(b+C(b/C(b+C(1)))));break a}m=C(C(m+m)*C(1.661534994731145e35));b=C(c+C(-162.88958740234375));d=Fw(b)&2047;j:{k:{if(Fw(C(88))>>>0>d>>>0){break k}c=C(0);if(((p(b),j(2))|0)==-8388608){break j}c=C(b+b);if(Fw(C(N))>>>0<=d>>>0){break j}if(b>C(88.72283172607422)){c=TD(0);break j}if(!(b<C(-103.97207641601562))){break k}c=tD(0);break j}k=A[165]*+b;s=A[164];u=k+s;k=k-(u-s);s=(A[166]*k+A[167])*(k*k)+(A[168]*k+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+1024|0;g=v[d>>2];d=v[d+4>>2]+h|0;l(0,g|0);l(1,(g>>>0<g>>>0?d+1|0:d)|0);c=C(s*+n())}f=C(C(m*c)*C(1.661534994731145e35))}c=C(x*f);f=C(c/t);b=C(f+C(1));z[a+4236>>2]=C(C(1)-f)/b;f=C(C(w*C(-2))/b);z[a+4232>>2]=f;c=C(c*t);z[a+4228>>2]=C(C(1)-c)/b;z[a+4224>>2]=f;z[a+4220>>2]=C(c+C(1))/b}function d2(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=cb-192|0;cb=d;v[d+184>>2]=c;a:{b:{c:{if(b>=.8){v[22440]=0;c=ha(1101)|0;e=v[22440];v[22440]=0;d:{e:{f:{if((e|0)!=1){v[d+80>>2]=c;c=v[d+184>>2];v[22440]=0;c=T(1102,c|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break e}v[d+176>>2]=c;rn(v[d+80>>2],v[d+176>>2]);c=v[d+80>>2];a=be(d+152|0,a);v[22440]=0;g=v[a+12>>2];e=d- -64|0;v[e>>2]=v[a+8>>2];v[e+4>>2]=g;v[d+72>>2]=v[a+16>>2];e=v[a+4>>2];v[d+56>>2]=v[a>>2];v[d+60>>2]=e;a=Y(1094,c|0,d+56|0,15)|0;c=v[22440];v[22440]=0;if((c|0)==1){break f}if(a){a=v[d+80>>2];v[22440]=0;Z(837,a|0);a=v[22440];v[22440]=0;f=1;if((a|0)==1){break f}}pi(d+176|0);qi(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;pi(d+176|0);break d}c=V(0)|0;O()|0}qi(d+80|0);break c}if(b>=.6){v[22440]=0;c=ha(1101)|0;e=v[22440];v[22440]=0;g:{h:{i:{if((e|0)!=1){v[d+80>>2]=c;c=v[d+184>>2];v[22440]=0;c=T(1102,c|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break h}v[d+176>>2]=c;rn(v[d+80>>2],v[d+176>>2]);c=v[d+80>>2];a=be(d+128|0,a);v[22440]=0;e=v[a+12>>2];v[d+40>>2]=v[a+8>>2];v[d+44>>2]=e;v[d+48>>2]=v[a+16>>2];e=v[a+4>>2];v[d+32>>2]=v[a>>2];v[d+36>>2]=e;a=Y(1094,c|0,d+32|0,2)|0;c=v[22440];v[22440]=0;if((c|0)==1){break i}if(a){a=v[d+80>>2];v[22440]=0;Z(837,a|0);a=v[22440];v[22440]=0;f=.8;if((a|0)==1){break i}}pi(d+176|0);qi(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;pi(d+176|0);break g}c=V(0)|0;O()|0}qi(d+80|0);break c}f=.2;if(b>=.2){v[22440]=0;c=ha(1101)|0;e=v[22440];v[22440]=0;j:{k:{l:{if((e|0)!=1){v[d+80>>2]=c;c=v[d+184>>2];v[22440]=0;c=T(1102,c|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break k}v[d+176>>2]=c;rn(v[d+80>>2],v[d+176>>2]);c=v[d+80>>2];a=be(d+104|0,a);v[22440]=0;e=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=e;v[d+24>>2]=v[a+16>>2];e=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=e;a=Y(1094,c|0,d+8|0,0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break l}f=0;if(a){a=v[d+80>>2];v[22440]=0;Z(837,a|0);a=v[22440];v[22440]=0;f=.6;if((a|0)==1){break l}}pi(d+176|0);qi(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;pi(d+176|0);break j}c=V(0)|0;O()|0}qi(d+80|0);break c}if(!(b>=.1)){break b}v[22440]=0;U(205,d+80|0,a|0,2048);c=v[22440];v[22440]=0;if((c|0)!=1){c=ce(d+80|0);v[22440]=0;e=v[d+80>>2];a=T(162,a|0)|0;g=v[22440];v[22440]=0;m:{if((g|0)==1){break m}v[22440]=0;a=Ja(1103,c|0,e|0,a|0,0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break m}f=A[(a<<3)+58440>>3];vc(d+80|0);break b}c=V(0)|0;O()|0;vc(d+80|0);break c}c=V(0)|0;O()|0}_(c|0)|0;v[22440]=0;X(18);a=v[22440];v[22440]=0;f=0;if((a|0)==1){break a}}Ae(d+184|0);cb=d+192|0;return+f}a=P()|0;O()|0;Ae(d+184|0);S(a|0);L()}function wE(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;i=cb-48|0;cb=i;o(+a);e=j(1)|0;d=j(0)|0;a:{b:{h=e;k=e&2147483647;c:{if(k>>>0<=1074752122){if((h&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+-6.077100506506192e-11;d=1;break a}a=a+1.5707963267341256;c=a+6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+6.077100506506192e-11;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6.077100506506192e-11;p=c-g;e=p<-.7853981633974483;if(D(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6.077100506506192e-11;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6.077100506506192e-11;c=a+f*-1.5707963267341256}a=c-g;A[b>>3]=a;o(+a);h=j(1)|0;j(0)|0;e=k>>>20|0;e:{if((e-(h>>>20&2047)|0)<17){break e}g=c;a=f*6.077100506303966e-11;c=c-a;g=f*2.0222662487959506e-21-(g-c-a);a=c-g;A[b>>3]=a;h=e;o(+a);e=j(1)|0;j(0)|0;if((h-(e>>>20&2047)|0)<50){break e}g=c;a=f*2.0222662487111665e-21;c=c-a;g=f*8.4784276603689e-32-(g-c-a);a=c-g;A[b>>3]=a}A[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;A[b>>3]=a;A[b+8>>3]=a;d=0;break a}l(0,d|0);l(1,e&1048575|1096810496);a=+n();d=0;h=1;while(1){m=(i+16|0)+(d<<3)|0;if(D(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);A[m>>3]=c;a=(a-c)*16777216;d=1;m=h&1;h=0;if(m){continue}break}A[i+32>>3]=a;f:{if(a!=0){d=2;break f}h=1;while(1){d=h;h=d-1|0;if(A[(i+16|0)+(d<<3)>>3]==0){continue}break}}d=RG(i+16|0,i,(k>>>20|0)-1046|0,d+1|0,1);a=A[i>>3];if((e|0)<0){A[b>>3]=-a;A[b+8>>3]=-A[i+8>>3];d=0-d|0;break a}A[b>>3]=a;A[b+8>>3]=A[i+8>>3]}cb=i+48|0;return d}function xaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;v[a+24588>>2]=0;v[a+24592>>2]=0;v[a+8>>2]=43680;v[a+4>>2]=0;v[a>>2]=32288;b=a+24596|0;v[b>>2]=0;v[b+4>>2]=0;Op(a+24604|0);YL(a+24648|0,0);v[a+397448>>2]=0;v[a+397452>>2]=0;b=a+397456|0;v[b>>2]=8;v[b+4>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;t[b+12|0]=0;v[b+8>>2]=0;u[b+24>>1]=0;Hb(b+28|0,0,40);Hb(b+68|0,0,49824);Hb(b+49892|0,0,32832);t[a+480224|0]=0;u[a+480212>>1]=0;v[a+480204>>2]=0;v[a+480208>>2]=0;v[a+480180>>2]=0;v[a+480184>>2]=0;b=a+480186|0;u[b>>1]=0;u[b+2>>1]=0;u[b+4>>1]=0;u[b+6>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;k=bf(a+480248|0);v[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;while(1){t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;AC(b+9|0);b=b+32|0;if((c|0)!=(b|0)){continue}break}f=a+484344|0;Rb(f);v[f+12>>2]=a;v[22440]=0;h=a+484360|0;Q(832,h|0,a|0)|0;b=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){c=a+900380|0;b=a+484380|0;while(1){v[22440]=0;b=T(699,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break i}b=b+104|0;if((c|0)!=(b|0)){continue}break}v[22440]=0;T(833,a+901404|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break h}c=a+946300|0;d=a+906300|0;b=d;while(1){b=XL(b)+160|0;if((c|0)!=(b|0)){continue}break}v[a+946300>>2]=0;g=a+1074304|0;e=a+946304|0;b=e;while(1){b=ct(b)+32|0;if((g|0)!=(b|0)){continue}break}v[a+1074304>>2]=0;v[a+1074308>>2]=0;qy(a+1074312|0);v[22440]=0;X(834);b=v[22440];v[22440]=0;if((b|0)==1){break g}r=a,s=TL(),v[r+1074328>>2]=s;b=a+1074332|0;v[b+12>>2]=1065353216;IL(b,4);v[22440]=0;g=T(835,a+1074376|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;i=a+1298264|0;Y(597,i|0,a|0,255)|0;b=v[22440];v[22440]=0;if((b|0)==1){break f}l=If(a+1298300|0);m=If(a+1298304|0);n=Db(a+1298308|0);o=Db(a+1298320|0);j=a+1298332|0;Db(j);p=WL(a+1298344|0);q=Rb(a+1298408|0);t[a+1298420|0]=0;b=a+1298424|0;v[b>>2]=0;v[b+4>>2]=0;v[b+32>>2]=0;v[b+36>>2]=1072693248;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[a+1298464>>2]=0;tp(a+12|0);py(a+8204|0);py(a+12300|0);b=a+1074408|0;v[b>>2]=4;v[b+4>>2]=16;v[a+480216>>2]=4;v[a+480220>>2]=16;Hb(a+900380|0,0,1024);SL(e);v[22440]=0;b=T(836,12)|0;e=v[22440];v[22440]=0;if((e|0)==1){break e}v[b>>2]=0;v[b+4>>2]=0;v[b+8>>2]=0;bf(b);v[a+4>>2]=b;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;oy(q);Gs(p);rb(j);rb(o);rb(n);Fs(m);Es(l);xp(i)}Ms(g)}while(1){c=up(c-160|0);if((d|0)!=(c|0)){continue}break}}qO(h)}ny(f);fc(k);S(b|0);L()}function nm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=cb-80|0;cb=c;h=Rb(a);v[22440]=0;a=T(286,b|0)|0;d=v[22440];v[22440]=0;a:{b:{c:{d:{e:{if((d|0)==1){break e}v[22440]=0;d=Q(158,b|0,a|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break e}if(d){break d}v[22440]=0;a=T(204,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break e}v[22440]=0;Q(190,b|0,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break c}}a=P()|0;O()|0;break a}v[22440]=0;U(192,c+32|0,b|0,a|0);b=v[22440];v[22440]=0;f:{g:{h:{if((b|0)!=1){b=c+32|0;d=cc(c+56|0,b);sb(b);if(a>>>0<10){break g}v[22440]=0;b=T(726,d|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break b}if(!b){break g}v[22440]=0;b=T(286,d|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break b}v[c+28>>2]=b;a=a-10|0;qc(c+28|0,a>>>0>25264513?-1:B(a,170));v[22440]=0;e=v[c+28>>2];R(292,h|0,e|0);a=v[22440];v[22440]=0;if((a|0)!=1){break h}break b}a=P()|0;O()|0;break a}b=0;i:while(1){g=0;j:{k:{while(1){if(g){break j}v[22440]=0;a=T(727,d|0)|0;g=v[22440];v[22440]=0;l:{m:{n:{o:{if((g|0)!=1){if(a){break j}v[22440]=0;a=T(532,d|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break b}g=1;switch(a|0){case 3:break l;case 2:break m;case 1:break n;case 0:break o;default:continue}}break b}v[22440]=0;a=T(208,d|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break b}if(a>>>0>e>>>0){continue}v[22440]=0;f=Q(158,d|0,a|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break b}if(!f){continue}qe(c+32|0,v[h>>2],v[h+4>>2]);jq(c+16|0,v[c+32>>2],v[c+36>>2],b,a);v[22440]=0;W(472,c+8|0,d|0,v[c+16>>2],v[c+20>>2]);g=v[22440];v[22440]=0;if((g|0)!=1){e=e-a|0;b=a+b|0;continue i}break b}v[22440]=0;a=T(208,d|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break b}f=a<<2;if(f>>>0>e>>>0){continue}v[22440]=0;i=Q(728,d|0,c+24|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break b}if(!i){continue}while(1){if(!(a&255)){break k}g=c+24|0;i=bc(g);k=c,l=yb(v[h>>2]),v[k+32>>2]=l;rt(g,i,je(c+32|0,b));b=b+4|0;a=a-1|0;continue}}if(e>>>0<8){continue}v[22440]=0;a=Q(728,d|0,c+24|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break b}if(!a){continue}a=c+24|0;g=bc(a);k=c,l=yb(v[h>>2]),v[k+32>>2]=l;f=c+32|0;rt(a,g,je(f,b));k=c,l=yb(v[h>>2]),v[k+8>>2]=l;k=c,l=je(c+8|0,b),v[k+32>>2]=l;rt(a,g,je(f,4));e=e-8|0;b=b+8|0;continue i}v[22440]=0;a=T(208,d|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break b}if(a>>>0>e>>>0){continue}break}e=e-a|0;b=a+b|0;continue}e=e-f|0;continue}break}if(!e){break f}a=Rb(c+32|0);pt(a,h);_b(a);break f}v[22440]=0;U(336,d|0,h|0,a|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}}sb(d)}cb=c+80|0;return}a=P()|0;O()|0;sb(d)}_b(h);S(a|0);L()}function gJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=cb-128|0;cb=f;v[f+120>>2]=c;v[f+124>>2]=d;g=v[b+4>>2];a:{if(!g){break a}h=v[b>>2];i=w[Zk(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}fl(f+96|0,h,g,g-1|0);g=v[f+100>>2];v[b>>2]=v[f+96>>2];v[b+4>>2]=g}g=f+96|0;Od(g);h=v[f+96>>2];Od(f+80|0);i=Yk(h,v[f+84>>2],b);Od(g);g=v[b+4>>2];h=v[b>>2];b:{c:{d:{e:{f:{g:{h:{if((i|0)==v[f+100>>2]){a=nc(f+112|0,21685);if(Hc(h,g,v[a>>2],v[a+4>>2])){a=aa(8)|0;v[22440]=0;R(981,f+80|0,f+120|0);b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;U(986,f+96|0,17664,f+80|0);b=v[22440];v[22440]=0;if((b|0)==1){break f}oc(a,f+96|0);e=0;v[22440]=0;U(121,a|0,58712,975);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;rb(f+96|0);break e}if(!e){break h}a=aa(8)|0;v[22440]=0;c=Q(985,f+48|0,b|0)|0;b=v[22440];v[22440]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){v[22440]=0;U(986,f- -64|0,17700,c|0);b=v[22440];v[22440]=0;if((b|0)==1){break p}v[22440]=0;R(988,f+80|0,f- -64|0);b=v[22440];v[22440]=0;e=1;if((b|0)==1){break o}v[22440]=0;R(981,f+32|0,f+120|0);b=v[22440];v[22440]=0;if((b|0)==1){break n}v[22440]=0;U(990,f+96|0,f+80|0,f+32|0);b=v[22440];v[22440]=0;if((b|0)==1){break m}oc(a,f+96|0);v[22440]=0;U(121,a|0,58712,975);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;rb(f+96|0);e=0;break l}b=P()|0;O()|0;break d}b=P()|0;e=1;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0}rb(f+32|0)}rb(f+80|0)}rb(f- -64|0)}rb(c);if(e){break d}break c}e=nc(f+24|0,21685);if(Hc(h,g,v[e>>2],v[e+4>>2])){a=aa(8)|0;v[22440]=0;R(981,f+80|0,f+120|0);b=v[22440];v[22440]=0;q:{r:{if((b|0)!=1){v[22440]=0;U(986,f+96|0,17664,f+80|0);b=v[22440];v[22440]=0;if((b|0)==1){break r}oc(a,f+96|0);e=0;v[22440]=0;U(121,a|0,58712,975);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;rb(f+96|0);break q}b=P()|0;O()|0;break d}b=P()|0;e=1;O()|0}rb(f+80|0);if(e){break d}break c}g=v[b>>2];h=v[b+4>>2];e=nc(f+16|0,10943);if(Hc(g,h,v[e>>2],v[e+4>>2])){_I(a,yc(c,d));break h}e=v[b>>2];g=v[b+4>>2];b=nc(f+8|0,8656);if(!Hc(e,g,v[b>>2],v[b+4>>2])){break h}b=Oy(c,d);c=cb-16|0;cb=c;a=v[a+32>>2];b=b>>>0<4?b:1;s:{if((cx(a)|0)==(b|0)){d=a+120|0;oi(d);b=cb-16|0;cb=b;v[b+8>>2]=c+8;a=cb-16|0;cb=a;e=v[14607];v[a+8>>2]=v[14606];v[a+12>>2]=e;e=v[14605];v[a>>2]=v[14604];v[a+4>>2]=e;gb[v[Lh(a,bh(w[d+20|0]))>>2]](b+8|0,d);cb=a+16|0;cb=b+16|0;break s}JI(a,b,KI(a))}cb=c+16|0}cb=f+128|0;return}b=P()|0;O()|0;break d}b=P()|0;e=1;O()|0}rb(f+80|0);if(!e){break c}}ba(a|0)}S(b|0)}L()}function Iaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;j=cb-32|0;cb=j;r=a+4|0;s=v[r>>2];i=Xe(v[a+8>>2],b);y=v[i>>2];a:{if(y+1>>>0<2){break a}e=B(b,872)+s|0;if(!(I=1,J=zi(v[e+624>>2],v[e+628>>2]),K=w[i+4|0],K?I:J)){break a}g=B(b,872)+s|0;if(!v[g+720>>2]){break a}i=e+616|0;h=v[g+704>>2]&2;e=v[(h?g+700|0:g+692|0)>>2];n=v[g+700>>2];f=v[g+696>>2];ub(j+8|0,v[a>>2]+1074312|0,31);z=tb(v[v[j+8>>2]>>2],v[j+12>>2]);m=dv(v[g+624>>2],v[g+628>>2],c);p=m;l=w[g+704|0]&128;m=l?0-m|0:m;k=fb;l=l?0-(k+((p|0)!=0)|0)|0:k;k=0;E=k;p=e;A=h?k:0;e=f;q=h?e:0;k=n-e|0;F=k<<1;G=g+1316|0;o=g+1467|0;D=g+1362|0;H=(w[D|0]&17)!=1;b:{while(1){if((u|0)==(y|0)){break b}c:{if(d>>>0>u>>>0){f=(w[D|0]&17)==1;break c}t[o|0]=w[o|0]&254;h=v[a>>2];e=Zc(Sb(h+484344|0,x[v[r>>2]+70>>1]),v[v[r>>2]+48>>2],b);n=w[e+3|0];if(w[e+2|0]==11){f=j+8|0;Jy(f,h,e,0);h=Oe(f);zn(v[a>>2],i,x[f>>1]);f=1;if(w[h|0]){break c}}f=1;d:{switch(n-4|0){case 0:zn(v[a>>2],i,w[e+5|0]);break c;case 2:break d;default:break c}}zn(v[a>>2],i,0)}v[j+28>>2]=v[G>>2];if(z){Ns(v[a>>2],i)}if(!H){DM(v[a>>2],i,j+28|0);f=1}if(!z){Ns(v[a>>2],i)}v[j+24>>2]=0;CM(i,j+24|0);e:{f:{if(w[g+705|0]&2){break f}g:{if(!f){if(!w[Xe(v[a+8>>2],b)+4|0]){break g}}if(w[o|0]&96){GO(i,C(1),0,v[a>>2]);e=w[o|0];t[o|0]=(e&64?-65:-33)&e}Ky(j+8|0,v[a>>2],i,v[j+28>>2],0);e=v[j+12>>2];v[g+624>>2]=v[j+8>>2];v[g+628>>2]=e;I=Xe(v[a+8>>2],b),J=0,t[I+4|0]=J;e=dv(v[g+624>>2],v[g+628>>2],c);f=w[g+704|0]&128;m=f?0-e|0:e;h=fb;l=f?0-(h+((e|0)!=0)|0)|0:h}Jb(i,m,l);n=v[i>>2];e=v[i+4>>2];if((n>>>0<E>>>0&(e|0)<=(p|0)|(e|0)<(p|0))&((e|0)>=(q|0)&n>>>0>=A>>>0|(e|0)>(q|0)|((l|0)>0|(l|0)>=0))){break f}h=v[g+704>>2];if(!(h&2)){break e}if(h&4){f=v[g+696>>2];if(n>>>0<A>>>0&(e|0)<=(q|0)|(e|0)<(q|0)){I=i,J=Tg(0,f<<1,n,e),v[I>>2]=J;e=fb;v[i+4>>2]=e;v[g+704>>2]=h^128;h=m;m=0-h|0;l=0-(((h|0)!=0)+l|0)|0}ub(j+8|0,v[a>>2]+1074312|0,33);e=(e-f>>>0)%(F-tb(v[v[j+8>>2]>>2],v[j+12>>2])>>>0)|0;h:{if(e>>>0<k>>>0){f=e+v[g+696>>2]|0;break h}f=v[g+700>>2]+(k-e|0)|0}v[i+4>>2]=f;f=v[g+704>>2];if((f&128)>>>7^e>>>0<k>>>0){break f}v[g+704>>2]=f^128;e=m;m=0-e|0;l=0-(((e|0)!=0)+l|0)|0;break f}f=e;h=v[g+700>>2];if(e>>>0>=h+k>>>0){f=h+((f-h>>>0)%(k>>>0)|0)|0}while(1){e=f;f=e-k|0;if(e>>>0>=h>>>0){continue}break}v[i>>2]=n;v[i+4>>2]=e}u=u+1|0;continue}break}IO(i);v[(B(b,872)+s|0)+1324>>2]=0}I=Xe(v[a+8>>2],b),J=0,v[I>>2]=J}cb=j+32|0}function Lda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=cb+-64|0;cb=d;u[d+62>>1]=c;Kf(d+62|0,32);j=Rb(a);v[22440]=0;o=x[d+62>>1];R(536,j|0,o|0);a=v[22440];v[22440]=0;a:{b:{if((a|0)!=1){k=b+480190|0;p=b+480192|0;c:{d:{while(1){if((q&65535)>>>0>=o>>>0){break d}a=x[k>>1];e=a+1|0;u[d+60>>1]=e;e:{f:{g:{if((e&65535)>>>0<4e3){break g}c=1;h:{while(1){u[d+48>>1]=c;f=c&65535;if(f>>>0>(a&65535)>>>0){break h}i:{if(!Sd(Fi(b,f))){if(!Qb(Oz(yb(v[j>>2]),yb(v[j+4>>2]),d+48|0),yb(v[j+4>>2]))){break i}a=x[k>>1]}c=c+1|0;continue}break}u[d+60>>1]=c;e=1;while(1){a=e&65535;if(a>>>0>x[p>>1]){e=c;break h}j:{a=v[((a<<2)+b|0)+900380>>2];if(!a){break j}a=a+236|0;i=et(a);while(1){if((a|0)==(i|0)){break j}if((f|0)==x[a>>1]){u[a>>1]=0}a=a+2|0;continue}}e=e+1|0;continue}}if((e&65535)>>>0<4e3){break g}i=Nn(d+48|0);v[22440]=0;a=Q(768,b|0,i|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break b}if(!a){break e}v[22440]=0;Q(769,b|0,i|0)|0;a=v[22440];v[22440]=0;c=1;if((a|0)==1){break b}while(1){a=c&65535;if(a>>>0<=x[p>>1]){k:{a=v[((a<<2)+b|0)+900380>>2];if(!a){break k}a=a+236|0;e=et(a);while(1){if((a|0)==(e|0)){break k}f=x[a>>1];l:{if(f>>>0>=y[d+52>>2]){break l}ub(d+40|0,v[d+48>>2],f);if(tb(v[v[d+40>>2]>>2],v[d+44>>2])){break l}u[a>>1]=0}a=a+2|0;continue}}c=c+1|0;continue}break}kk(d+24|0,v[d+48>>2]);XO(d+32|0,v[d+24>>2],v[d+28>>2],1);pl(d+16|0,v[d+48>>2],v[d+52>>2]);m=cb-16|0;cb=m;f=d+40|0;c=$b(m,v[d+32>>2],v[d+36>>2]);a=ol(v[d+16>>2],v[d+20>>2],v[d+32>>2],v[d+36>>2]);e=cb-16|0;cb=e;v[e+12>>2]=a;g=v[c+4>>2];m:{if(g){h=32-g|0;v[e+8>>2]=h;n=v[Bb(e+8|0,e+12|0)>>2];l=-1<<g&-1>>>h-n;h=v[c>>2];l=l&(v[h>>2]^-1);if(l){$b(f,h,jka(l));break m}if((a|0)==(n|0)){XO(f,h,g,a);break m}a=a-n|0;v[e+12>>2]=a;v[c>>2]=h+4}while(1){if(a>>>0>=32){g=v[c>>2];h=v[g>>2];if((h|0)!=-1){$b(f,g,jka(h^-1));break m}else{v[c>>2]=g+4;a=a-32|0;v[e+12>>2]=a;continue}}break}if(!a){$b(f,v[c>>2],0);break m}c=v[c>>2];g=(v[c>>2]^-1)&-1>>>32-a;if(!g){$b(f,c,a);break m}$b(f,c,jka(g))}cb=e+16|0;cb=m+16|0;kk(d+8|0,v[d+48>>2]);e=ol(v[d+40>>2],v[d+44>>2],v[d+8>>2],v[d+12>>2]);u[d+60>>1]=e;Re(i);if((e&65535)>>>0>3999){break f}}v[22440]=0;R(263,j|0,d+60|0);a=v[22440];v[22440]=0;if((a|0)==1){break c}if(x[k>>1]>=(e&65535)>>>0){break f}u[k>>1]=e}q=q+1|0;continue}break}Re(i)}cb=d- -64|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Re(i)}_c(j);S(a|0);L()}function B9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=cb-48|0;cb=c;a:{b:{if(!Vh(b)){break b}l=v[b+12>>2];k=Hj(v[v[b+48>>2]+12>>2]);e=k;d=c+32|0;f=yd(d);c:{if(e){v[22440]=0;R(461,d|0,e|0);g=v[22440];v[22440]=0;if((g|0)==1){break a}g=cb-16|0;cb=g;f=nq(g,d,e);e=v[f+4>>2];h=v[f+8>>2];while(1){if((e|0)==(h|0)){dc(f);cb=g+16|0}else{t[e|0]=0;t[e+1|0]=0;t[e+2|0]=0;t[e+3|0]=0;t[e+4|0]=0;t[e+5|0]=0;tg(e);e=e+6|0;v[f+4>>2]=e;continue}break}}f=d;break c}while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if(j>>>0>=l>>>0){break s}if(!Gh(v[v[a>>2]-12>>2]+a|0)){break s}v[22440]=0;t[c+31|0]=0;Q(900,a|0,c+31|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}d=t[c+31|0];if(!d){j=j+1|0;continue}t[c+30|0]=0;t:{if((d|0)>=0){break t}v[22440]=0;Q(900,a|0,c+30|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){break t}break a}t[c+29|0]=0;Ej(c+16|0);u:{d=d&127;g=(d?d-1|0:0)&65535;i=g>>>0>=k>>>0;v:{w:{if(!i){h=Zc(b,j,g);e=w[c+30|0];if(e&1){break w}d=Cd(v[f>>2],g);break v}h=c+16|0;e=w[c+30|0];if(!(e&1)){break u}}v[22440]=0;Q(900,a|0,c+29|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}if(i){break u}d=Cd(v[f>>2],g);t[d|0]=w[c+29|0]}t[h|0]=w[d|0];e=w[c+30|0];if(!(e&2)){break q}break r}if(e&2){break r}break p}Th(f);break b}v[22440]=0;Q(900,a|0,c+29|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}if(i){break p}d=Cd(v[f>>2],g);t[d+1|0]=w[c+29|0]}t[h+1|0]=w[d+1|0];if(e&4){break o}break n}if(!(e&4)){break m}}v[22440]=0;Q(900,a|0,c+29|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}if(i){break m}d=Cd(v[f>>2],g);t[d+2|0]=w[c+29|0]}t[h+2|0]=w[d+2|0];if(!(e&8)){break k}break l}if(!(e&8)){break j}}v[22440]=0;Q(900,a|0,c+29|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}if(i){break j}d=Cd(v[f>>2],g);t[d+4|0]=w[c+29|0]}t[h+4|0]=w[d+4|0];if(e&16){break i}break h}if(!(e&16)){break g}}v[22440]=0;Q(900,a|0,c+29|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}if(i){break g}d=Cd(v[f>>2],g);t[d+3|0]=w[c+29|0]}t[h+3|0]=w[d+3|0];if(!(e&32)){break e}break f}if(!(e&32)){break d}}v[22440]=0;Q(900,a|0,c+29|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}if(i){break d}d=Cd(v[f>>2],g);t[d+5|0]=w[c+29|0]}t[h+5|0]=w[d+5|0]}if(!(e&64)){continue}v[22440]=0;Q(900,a|0,c+15|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){v[22440]=0;Q(901,a|0,w[c+15|0])|0;d=v[22440];v[22440]=0;if((d|0)!=1){continue}}break}break a}cb=c+48|0;return}a=P()|0;O()|0;Th(f);S(a|0);L()}function Jga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;e=cb-32|0;cb=e;a:{b:{if(!c){break b}s=e,u=He(a),t[s+16|0]=u;cn(b,e+16|0);k=c-1|0;c=0;while(1){g=1;if(!k){break a}c:{d:{d=c<<1;c=d&254;if(!c){if(!mf(a,e+16|0)){break b}f=1;d=w[e+16|0]<<1|1;c=d&255;if(d>>>0<=255){break d}break c}if((d&65535)>>>0<=255){break d}f=1;break c}if(!mf(a,e+16|0)){break b}MT(b,e+16|0);k=k-1|0;continue}while(1){e:{f:{g:{d=c<<1&254;h:{if(d){c=(c&65535)>>>0>127}else{if(!mf(a,e+16|0)){break h}c=w[e+16|0]<<1|1;d=c&255;c=c>>>0>255}f=Xp(f,1)+c|0;c=d<<1&254;if(c){break f}if(mf(a,e+16|0)){break g}}c=0;break e}d=w[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break e}if(d>>>0>127){continue}}break}i:{if((f|0)<=2){h=0;f=f-2|0;break i}if(!mf(a,e+16|0)){break b}d=Xp(f-3|0,8)|w[e+16|0];h=((d|0)>1279?2:1)+((d|0)>31999)|0;m=d^-1;f=0}d=c<<1&254;if(d){g=c>>>0>127}else{if(!mf(a,e+16|0)){break b}c=w[e+16|0]<<1|1;d=c&255;g=c>>>0>255}i=Xp(f,1);c=d<<1&254;if(c){d=d>>>0>127}else{if(!mf(a,e+16|0)){break b}d=w[e+16|0]<<1|1;c=d&255;d=d>>>0>255}f=1;d=Xp(g+i|0,1)+d|0;if(!d){while(1){j:{k:{l:{d=c<<1&254;m:{if(d){c=(c&65535)>>>0>127}else{if(!mf(a,e+16|0)){break m}c=w[e+16|0]<<1|1;d=c&255;c=c>>>0>255}f=Xp(f,1)+c|0;c=d<<1&254;if(c){break k}if(mf(a,e+16|0)){break l}}c=0;break j}d=w[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break j}if(d>>>0>127){continue}}break}d=f+2|0}f=d+h|0;g=0;if(f>>>0>k>>>0|(f|0)<=0|(m|0)>=0){break a}d=v[b+4>>2];g=0;if((0-Uc(v[b>>2],d)|0)>(m|0)){break a}ac(e+24|0,yb(d));t[e+16|0]=0;g=e+16|0;n=cb-32|0;cb=n;d=v[b>>2];h=$n(v[e+24>>2],yb(d))+d|0;d=v[xb(b)>>2];i=v[b+4>>2];n:{if(f>>>0<=d-i>>>0){d=f;j=i-h|0;if(d>>>0>j>>>0){Jm(b,f-j|0,g);d=j;if(!d){break n}}o=cb-16|0;cb=o;r=i;q=v[b+4>>2];j=(q-(f+h|0)|0)+h|0;p=Ok(o,b,i-j|0);l=v[p+4>>2];i=j;while(1){if(i>>>0>=r>>>0){dc(p);iq(h,j,q);cb=o+16|0}else{kd(l,w[i|0]);l=l+1|0;v[p+4>>2]=l;i=i+1|0;continue}break}if(h>>>0<=g>>>0){g=(y[b+4>>2]>g>>>0?f:0)+g|0}_h(h,d,g);break n}d=xb(b);d=Sl(n+8|0,Ol(b,Uc(v[b>>2],i)+f|0),h-v[b>>2]|0,d);oS(d,f,g);h=NT(b,d,h);Rl(d)}yb(h);cb=n+32|0;s=e,u=yb(v[b+4>>2]),v[s>>2]=u;s=e,u=_z(e,f),v[s+8>>2]=u;s=e,u=je(e+8|0,m),v[s+16>>2]=u;s=e,u=yb(v[b+4>>2]),v[s>>2]=u;s=e,u=_z(e,f),v[s+8>>2]=u;d=f;while(1){h=w[BR(e+16|0)|0];s=BR(e+8|0),u=h,t[s|0]=u;h=d>>>0>1;d=d-1|0;if(h){continue}break}k=k-f|0;continue}}g=0}cb=e+32|0;return g|0}
function S5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=cb-112|0;cb=e;d=v[b+4>>2];a:{if(!d){break a}f=v[b>>2];g=w[Zk(f,d)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}fl(e+88|0,f,d,d-1|0);d=v[e+92>>2];v[b>>2]=v[e+88>>2];v[b+4>>2]=d}f=e+88|0;Od(f);d=v[e+88>>2];Od(e+72|0);d=Yk(d,v[e+76>>2],b);Od(f);b:{c:{d:{e:{if((d|0)==v[e+92>>2]){d=v[b>>2];f=v[b+4>>2];a=nc(e+104|0,21685);if(Hc(d,f,v[a>>2],v[a+4>>2])){a=aa(8)|0;v[22440]=0;c=Q(56,e+88|0,10501)|0;b=v[22440];v[22440]=0;if((b|0)==1){break d}oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}b=P()|0;O()|0;rb(c);break c}d=0;if(!c){break e}c=aa(8)|0;v[22440]=0;d=Q(985,e+72|0,b|0)|0;a=v[22440];v[22440]=0;f:{g:{h:{if((a|0)!=1){v[22440]=0;U(986,e+88|0,17700,d|0);a=v[22440];v[22440]=0;if((a|0)==1){break h}oc(c,e+88|0);a=0;v[22440]=0;U(121,c|0,58712,975);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;rb(e+88|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}rb(d);if(!a){break c}}ba(c|0);break c}if(v[d+4>>2]){a=aa(8)|0;v[22440]=0;c=Q(56,e+88|0,11620)|0;b=v[22440];v[22440]=0;if((b|0)!=1){oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}b=P()|0;O()|0;rb(c);break c}b=P()|0;O()|0;ba(a|0);break c}d=v[b>>2];f=v[b+4>>2];c=nc(e- -64|0,21685);if(Hc(d,f,v[c>>2],v[c+4>>2])){a=aa(8)|0;v[22440]=0;c=Q(56,e+88|0,10501)|0;b=v[22440];v[22440]=0;if((b|0)!=1){oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}b=P()|0;O()|0;rb(c);break c}b=P()|0;O()|0;ba(a|0);break c}i:{d=v[b>>2];f=v[b+4>>2];c=nc(e+56|0,7422);if(!Hc(d,f,v[c>>2],v[c+4>>2])){d=v[b>>2];f=v[b+4>>2];c=nc(e+48|0,7404);if(!Hc(d,f,v[c>>2],v[c+4>>2])){break i}}d=w[a+60|0]!=0;break e}j:{d=v[b>>2];f=v[b+4>>2];c=nc(e+40|0,6937);if(!Hc(d,f,v[c>>2],v[c+4>>2])){d=v[b>>2];f=v[b+4>>2];c=nc(e+32|0,6918);if(!Hc(d,f,v[c>>2],v[c+4>>2])){break j}}d=w[a+61|0]!=0;break e}d=v[b>>2];f=v[b+4>>2];c=nc(e+24|0,7021);if(Hc(d,f,v[c>>2],v[c+4>>2])){d=w[a+62|0]!=0;break e}d=v[b>>2];f=v[b+4>>2];c=nc(e+16|0,6067);if(Hc(d,f,v[c>>2],v[c+4>>2])){d=w[a+63|0]!=0;break e}d=v[b>>2];f=v[b+4>>2];c=nc(e+8|0,7471);if(Hc(d,f,v[c>>2],v[c+4>>2])){d=w[a+64|0]!=0;break e}c=v[b>>2];f=v[b+4>>2];b=nc(e,13421);d=0;if(!Hc(c,f,v[b>>2],v[b+4>>2])){break e}d=v[v[a+24>>2]+24668>>2]!=0}cb=e+112|0;return d|0}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function $fa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0;f=cb-560|0;cb=f;a:{if(!Tc(b,1464)){break a}if(!Wn(b,f+556|0)){break a}ud(a,1);Gb(Gb(Vf(a+1074312|0,83),84,1),85,1);b:{if(me(f+556|0,27001)){d=f+32|0;e=jc(d,8459);Cb(a+1298344|0,e);rb(e);e=jc(d,14912);Cb(a+1298356|0,e);rb(e);d=jc(d,14977);Cb(a+1298368|0,d);break b}if(!me(f+556|0,15563)){break a}d=f+32|0;e=jc(d,8633);Cb(a+1298344|0,e);rb(e);e=jc(d,12308);Cb(a+1298356|0,e);rb(e);d=jc(d,15470);Cb(a+1298368|0,d)}rb(d);v[a+1298404>>2]=2;Tc(b,0);BA(b,a+1298308|0,20);u[a+480190>>1]=31;d=1;while(1){if((d|0)==32){c:{d=0;if(g>>>0>40){break a}l=f+552|0;Nu(l,b);n=Ec(l);if(w[l|0]>128){break a}d=f+32|0;e=cb-16|0;cb=e;d:{if(!Kb(b,512)){dR(d);break d}ru(e+8|0,d);md(e,b,v[e+8>>2],v[e+12>>2])}cb=e+16|0;e=f+544|0;i=w[n|0];e:{while(1){if((d|0)==(e|0)){break e}g=w[d|0];d=d+1|0;if(g>>>0<=i>>>0){continue}break}d=0;break a}if(!c){break c}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|18874368;mh(a,0);o=a+484360|0;Ff(Nb(o),w[l|0]);m=a+484344|0;wg(m,w[l|0]);e=0;while(1){if(w[l|0]<=e>>>0){if(!(c&2)){break c}Tc(b,(w[n|0]<<8)+1468|0);d=1;while(1){if((d|0)==32){break c}c=(B(d,104)+a|0)+484380|0;if(v[c>>2]){vg(Nc(f+8|0,8,1,0,0),c,b)}d=d+1|0;continue}}s=Xb(v[Nb(o)>>2],e),x=e,u[s>>1]=x;f:{if(!nh(m,e&65535,64)){break f}r=e<<2;i=0;g:while(1){if((i|0)==4){s=f,x=Pg(Sb(m,e)),v[s+24>>2]=x;i=0;while(1){if((i|0)==64){break f}d=0;h:{while(1){if((d&65535)>>>0>=4){i:{t[f+31|0]=p;t[f+30|0]=q;d=h&255;if(d){break i}h=0;break h}}else{g=v[f+24>>2];j:{if((w[g+3|0]&254)!=16){break j}t[g+3|0]=16;h=0;k=w[g+5|0];if(k>>>0<16){break j}h=k>>>4|0;t[g+5|0]=h;j=h;h=k&15;g=(j|0)==(h|0)|!h;q=g?q:j;p=g?p:h;h=!g}d=d+1|0;Ki(f+24|0);continue}break}xe(Sb(m,e),Pe(Je(f+8|0,16,w[(d+f|0)+29|0]),i));h=h+1|0;h=(h&255)==3?1:h}i=i+1|0;continue}}Tc(b,(w[f+32+(i+r)|0]<<8)+1468|0);g=0;d=Zc(Sb(m,e),0,i&65535);while(1)if((g|0)==64){i=i+1|0;continue g}else{j=f+8|0;lu(j,b,d);k=w[j|0];j=w[Ec(j)|0];k:{if(!(!(k|j)|(k-5&255)>>>0<5|(k|0)==14&j>>>0>15)){Ef(d,k,j);break k}t[d+3|0]=0}d=d+24|0;g=g+1|0;continue}}}e=e+1|0;continue}}}else{g=Vz(b,f+32|0,(B(d,104)+a|0)+484380|0,((d<<5)+a|0)+946304|0,1)+g|0;d=d+1|0;continue}break}d=1}cb=f+560|0;return d|0}function G2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=cb-192|0;cb=d;g=d+176|0;zI(g);v[g>>2]=49396;Rb(g+4|0);h=a+24|0;rn(v[h>>2],g);i=w[a+62|0];e=w[a+61|0];f=w[a+60|0];k=v[h>>2];b=be(d+152|0,b);v[22440]=0;j=v[b+12>>2];v[d+16>>2]=v[b+8>>2];v[d+20>>2]=j;v[d+24>>2]=v[b+16>>2];j=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=j;b=f?13:15;b=e?b&14:b;b=Y(1094,k|0,d+8|0,(i?b&3:b)|0)|0;i=v[22440];v[22440]=0;a:{b:{c:{d:{e:{if((i|0)==1){break e}if(!b){b=aa(8)|0;v[22440]=0;c=Q(56,d+136|0,12046)|0;a=v[22440];v[22440]=0;if((a|0)!=1){oc(b,c);v[22440]=0;U(121,b|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;rb(c);break b}a=P()|0;O()|0;ba(b|0);break b}if(!w[a+63|0]){v[22440]=0;R(1095,a|0,a+36|0);b=v[22440];v[22440]=0;if((b|0)==1){break e}}t[a+28|0]=1;rn(v[h>>2],v[a+4>>2]);v[22440]=0;R(1096,d+136|0,g|0);b=v[22440];v[22440]=0;if((b|0)==1){break c}l=d,m=yb(v[d+136>>2]),v[l+128>>2]=m;h=a+68|0;i=yb(v[d+140>>2]);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{while(1){b=v[d+128>>2];if(!Qb(b,i)){l=d,m=qk(c),v[l+112>>2]=m;l=d,m=Af(c),v[l+96>>2]=m;while(1){if(!ih(d+112|0,d+96|0)){break d}c=od(d+112|0);v[22440]=0;b=Q(55,d+32|0,c|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break h}v[22440]=0;W(987,a|0,b|0,c+12|0,0);c=v[22440];v[22440]=0;if((c|0)==1){break g}rb(b);mk(d+112|0);continue}}e=v[b>>2];v[22440]=0;f=e;e=b+4|0;U(1097,a|0,f|0,e|0);f=v[22440];v[22440]=0;if((f|0)!=1){b=v[b>>2];v[22440]=0;R(1098,d- -64|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break r}v[22440]=0;R(1033,d+80|0,d- -64|0);b=v[22440];v[22440]=0;if((b|0)==1){break q}v[22440]=0;b=Q(56,d+48|0,17800)|0;f=v[22440];v[22440]=0;if((f|0)==1){break p}v[22440]=0;U(990,d+96|0,d+80|0,b|0);f=v[22440];v[22440]=0;if((f|0)==1){break o}v[22440]=0;U(542,d+112|0,d+96|0,e|0);e=v[22440];v[22440]=0;if((e|0)==1){break n}v[22440]=0;R(185,h|0,d+112|0);e=v[22440];v[22440]=0;if((e|0)==1){break m}rb(d+112|0);rb(d+96|0);rb(b);rb(d+80|0);rb(d- -64|0);Sp(d+128|0);continue}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;break j}a=P()|0;O()|0;break k}a=P()|0;O()|0;break l}a=P()|0;O()|0;rb(d+112|0)}rb(d+96|0)}rb(b)}rb(d+80|0)}rb(d- -64|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;rb(b)}_r(d+136|0);break b}a=P()|0;O()|0;break b}_r(d+136|0);Xr(g);cb=d+192|0;return}a=P()|0;O()|0}Xr(g);S(a|0)}L()}function vfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;h=cb-32|0;cb=h;a:{if(!Kb(a,2)){nh(c+484344|0,b,64);break a}l=c+484344|0;m=wd(Ii(a),1,1024);if(!nh(l,b,m)){break a}p=x[c+480188>>1];q=c+480190|0;b:while(1){if((k|0)==(m|0)){break a}i=0;n=Gf(Sb(l,b),k);while(1)if((i|0)==(p|0)){k=k+1|0;continue b}else{g=h+24|0;Gm(g,a);e=B(i,6)+n|0;r=Oe(g);f=Li(g);g=w[g|0];c:{if((g-1&255)>>>0>35){break c}t[e|0]=g+48;o=w[Ec(h+24|0)|0];g=o+1|0;t[e+1|0]=g;j=g;g=g&255;if((j|0)!=(g|0)|g>>>0>x[q>>1]){break c}g=Fi(c,g);j=Eb(d,i);if(!(!w[j|0]|x[g+30>>1]>255)){t[e+4|0]=64;t[e+2|0]=1}g=v[Ib(g+68|0,0)>>2];if(!(w[j|0]|g?w[j|0]?(g|0)==1:0:1)){break c}t[e+1|0]=o+101}d:{e:{switch(w[r|0]){case 1:if(!w[f|0]){break d}t[e+3|0]=2;t[e+5|0]=w[f|0];break d;case 2:if(!w[f|0]){break d}t[e+3|0]=3;t[e+5|0]=w[f|0];break d;case 12:if(!w[f|0]){break d}t[e+3|0]=1;t[e+5|0]=w[f|0];break d;case 13:if(!w[f|0]){break d}t[e+3|0]=39;t[h+23|0]=15;s=e,u=w[Tb(h+23|0,f)|0]|16,t[s+5|0]=u;break d;case 30:if(!w[f|0]){break d}t[e+3|0]=38;t[h+22|0]=15;s=e,u=w[Tb(h+22|0,f)|0]|16,t[s+5|0]=u;break d;case 21:if(!w[f|0]){break d}t[e+3|0]=39;t[h+21|0]=15;s=e,u=w[Tb(h+21|0,f)|0]|80,t[s+5|0]=u;break d;case 17:if(!w[f|0]){break d}t[e+3|0]=38;t[h+20|0]=15;s=e,u=w[Tb(h+20|0,f)|0]|80,t[s+5|0]=u;break d;case 15:t[e+3|0]=19;t[e+5|0]=w[f|0]!=0;break d;case 25:t[e+3|0]=12;t[e+5|0]=w[f|0];break d;case 27:Rn(e);t[e|0]=255;break d;case 28:if(w[f|0]>31){break d}t[e+3|0]=16;t[e+5|0]=w[f|0];break d;case 31:g=w[f|0];if(g&15){s=e,u=w[Eb(d,i)|0]?22:11,t[s+3|0]=u;t[e+5|0]=w[f|0]&15;g=w[f|0]}f:{g:{switch(g>>>4|0){case 4:if((g|0)!=64){break f}case 0:case 1:case 2:case 3:if(w[Eb(d,i)|0]){t[e+3|0]=21;t[e+5|0]=w[f|0];break f}t[e+2|0]=1;f=w[f|0];t[e+3|0]=0;t[e+4|0]=f;break f;case 5:t[e+5|0]=w[e+5|0]<<4;break f;case 6:t[h+19|0]=w[e+5|0];t[h+18|0]=14;s=e,u=w[Tb(h+19|0,h+18|0)|0]|240,t[s+5|0]=u;break f;case 7:t[h+17|0]=w[e+5|0];t[h+16|0]=14;s=e,u=w[Tb(h+17|0,h+16|0)|0]<<4|15,t[s+5|0]=u;break f;default:break g}}t[e+3|0]=0}if((w[e+3|0]-21&255)>>>0>1){break d}f=B(t[Eb(d,i)|0]+i|0,6)+n|0;uq(h+14|0,w[f+3|0],w[f+5|0],1);if(w[h+14|0]){g=x[h+14>>1];t[f+4|0]=g>>>8;t[f+2|0]=g}t[f+3|0]=w[e+3|0];t[f+5|0]=w[e+5|0];break d;case 0:break d;default:break e}}t[e+3|0]=0}i=i+1|0;continue}}}cb=h+32|0}function Kba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0;g=cb+-64|0;cb=g;r=v[a+16>>2];h=ee(g+32|0);v[h+8>>2]=a+112;e=v[a+128>>2];v[h+16>>2]=e;D=h,E=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[D+12>>2]=E;b=0;if(e){D=h,E=kg(v[a+8>>2],v[a+12>>2],e),v[D>>2]=E;v[h+4>>2]=fb}while(1){if((b|0)!=2){e=b<<3;f=e+(g+16|0)|0;e=a+e|0;v[f>>2]=v[e+44>>2];v[f+4>>2]=v[e+48>>2];b=b+1|0;continue}break}k=v[a+40>>2];l=v[a+36>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;s=v[a+8>>2];u=v[a+12>>2];while(1){if(d){b=v[g+12>>2];e=v[g+8>>2];v[g+56>>2]=e;v[g+60>>2]=0;m=(((b&2147483647)<<1|e>>>31)&-2)+r|0;e=v[h+16>>2];a:{b:while(1){c:{if((e|0)<=0){b=v[h+8>>2];e=v[b+8>>2];Jb(b,e,v[b+12>>2]);e=v[h+8>>2];j=v[e+4>>2];if(!j){break a}o=((v[g+60>>2]&2147483647)<<1|v[g+56>>2]>>>31)&-2;f=0;b=0;break c}j=((v[g+60>>2]&2147483647)<<1|v[g+56>>2]>>>31)&-2;b=0;f=0;while(1)if((b|0)==2){Jd(v[h+8>>2],(f|0)/8<<16>>16);Id(v[h+8>>2],4);Jb(g+56|0,v[h>>2],v[h+4>>2]);e=e-1|0;continue b}else{f=(t[m+(b+j|0)|0]<<8)+f|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){f=(t[m+(b+o|0)|0]<<8)+f|0;b=b+1|0;continue}break}Jd(e,(f|0)/8<<16>>16);Id(v[h+8>>2],j);e=v[h+8>>2];b=e;f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}d=d-1|0;b=ig(e,v[h+12>>2]);v[g+4>>2]=b;v[g>>2]=b;m=v[a+72>>2];b=v[a+68>>2];j=b;o=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+g|0;f=v[p>>2];e=(g+16|0)+(b<<3)|0;n=v[e+4>>2];i=v[e>>2];v[e+4>>2]=i;q=f<<8;f=q;f=kka(y,z,f,f>>31);A=fb;C=e;e=Vb(i,-16777216,16776704);i=kka(w,x,e,e>>31);f=i+f|0;e=fb+A|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=Vb(n,-16777216,16776704);n=kka(j,o,f,f>>31);f=i+n|0;e=fb+e|0;e=f>>>0<n>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Mc(f,e,24);v[C>>2]=e-(m&q);v[p>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];l=v[a+28>>2]+l|0;v[c>>2]=v[c>>2]+B(v[g>>2],l>>12);k=b+k|0;v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],k>>12);Jb(g+8|0,s,u);c=c+8|0;continue}break}b=v[g+12>>2];c=v[g+8>>2];v[a+36>>2]=l;v[a>>2]=c;v[a+4>>2]=b;v[a+40>>2]=k;v[a+20>>2]=l>>12;v[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}cb=g- -64|0}function m3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Db(a);v[22440]=0;X(107);c=v[22440];v[22440]=0;a:{b:{if((c|0)==1){c=Sa(58712,88360,88932,0)|0;d=O()|0;c:{d:{e:{if((fa(58712)|0)==(d|0)){c=_(c|0)|0;v[22440]=0;b=Q(960,a|0,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break e}v[22440]=0;b=Q(960,b|0,17800)|0;d=v[22440];v[22440]=0;if((d|0)==1){break e}v[22440]=0;d=Q(960,b|0,17776)|0;b=v[22440];v[22440]=0;if((b|0)==1){break e}b=gb[v[v[c>>2]+8>>2]](c)|0;v[22440]=0;Q(960,d|0,(b?b:21685)|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break e}v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}f:{if((fa(88360)|0)==(d|0)){c=_(c|0)|0;v[22440]=0;b=Q(960,a|0,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break f}v[22440]=0;b=Q(960,b|0,17800)|0;d=v[22440];v[22440]=0;if((d|0)==1){break f}v[22440]=0;d=Q(960,b|0,17751)|0;b=v[22440];v[22440]=0;if((b|0)==1){break f}b=gb[v[v[c>>2]+8>>2]](c)|0;v[22440]=0;Q(960,d|0,(b?b:21685)|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break f}v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}e=fa(88932)|0;c=_(c|0)|0;g:{if((d|0)==(e|0)){v[22440]=0;b=Q(960,a|0,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break g}v[22440]=0;b=Q(960,b|0,17800)|0;d=v[22440];v[22440]=0;if((d|0)==1){break g}v[22440]=0;d=Q(960,b|0,17767)|0;b=v[22440];v[22440]=0;if((b|0)==1){break g}b=gb[v[v[c>>2]+8>>2]](c)|0;v[22440]=0;Q(960,d|0,(b?b:21685)|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}v[22440]=0;b=Q(960,a|0,b|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break d}v[22440]=0;b=Q(960,b|0,17800)|0;c=v[22440];v[22440]=0;if((c|0)==1){break d}v[22440]=0;Q(960,b|0,13796)|0;b=v[22440];v[22440]=0;if((b|0)==1){break d}v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;v[22440]=0;X(18);c=v[22440];v[22440]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[22440]=0;X(18);c=v[22440];v[22440]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[22440]=0;X(18);c=v[22440];v[22440]=0;if((c|0)==1){break c}break a}b=P()|0;O()|0;v[22440]=0;X(18);c=v[22440];v[22440]=0;if((c|0)!=1){break a}}V(0)|0;O()|0;Lb()}L()}return}rb(a);S(b|0);L()}function Us(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=cb-32|0;cb=h;g=v[a+24>>2];i=Xy(g,w[a+32|0]);j=v[i>>2];a:{if(Fc(j,v[i+4>>2])>>>0<=b>>>0){break a}if(NN(a,x[Xb(j,b)>>1])>>>0<=c>>>0){break a}i=v[a>>2];b:{if(gd(i,v[a+4>>2])>>>0>b>>>0){if(y[rd(i,b)+4>>2]>c>>>0){break b}}In(a,0);if(gd(v[a>>2],v[a+4>>2])>>>0<=b>>>0){break a}g=v[a+24>>2]}m=h+16|0;Ub(m,v[d>>2],x[g+480188>>1]);d=h+24|0;i=v[h+16>>2];g=e?-2046629010:-2078137563;e=e?-1352371636:-873292572;j=v[h+20>>2];while(1){if(!f&(k|0)==(j|0)){v[d>>2]=g;v[d+4>>2]=e}else{l=w[FP(i,k)+841|0];n=l^kka(g^k,e^f,435,256);l=!l;g=(o=g,p=kka(n,fb,435,256),q=l,q?o:p);e=l?e:fb;k=k+1|0;f=k?f:f+1|0;continue}break}e=d;d=km(m,b,c);j=cb-16|0;cb=j;f=cb-16|0;cb=f;k=a+12|0;g=k;i=BN(x[d>>1],v[d+4>>2],Kd(g),bc(g));v[f+8>>2]=i;c:{if(Qb(i,cg(g))){if(!Ws(x[d>>1],v[d+4>>2],od(f+8|0))){break c}}i=cg(g)}cb=f+16|0;d=v[ac(j+8|0,i)>>2];cb=j+16|0;v[h+8>>2]=d;o=h,p=Af(k),v[o+16>>2]=p;d=0;if(ih(h+8|0,m)){d=od(h+8|0);d=hc(v[d+8>>2],v[d+12>>2])^1}i=v[e>>2]!=-2078137563|v[e+4>>2]!=-873292572;ub(h+16|0,v[rd(v[a>>2],b)>>2],c);m=1;f=d|i;l=tb(v[v[h+16>>2]>>2],v[h+20>>2])^1;if(!(l?1:f)){break a}d:{e:{f:{g:{if(d){j=od(h+8|0);g=yb(v[j+8>>2]);n=yb(v[j+12>>2]);f=cb-16|0;cb=f;v[f+8>>2]=g;while(1){if(!(!Qb(g,n)|v[g>>2]==v[e>>2]&v[g+4>>2]==v[e+4>>2])){Ys(f+8|0);g=v[f+8>>2];continue}break}cb=f+16|0;if(Qb(g,yb(v[j+12>>2]))){break a}if(!i){break e}break g}if(i){break g}if(!f){break d}break f}v[a+28>>2]=v[a+28>>2]+1}if(d|l){break e}d=zN(k,km(h+16|0,b,c));h:{if(y[d+4>>2]<y[xb(d)>>2]){f=cb-16|0;cb=f;d=yN(f,d);wN(v[d+4>>2]);v[d+4>>2]=v[d+4>>2]+8;dc(d);cb=f+16|0;break h}g=cb-32|0;cb=g;f=xb(d);f=Qq(g+8|0,Rq(d,Vg(v[d>>2],v[d+4>>2])+1|0),Vg(v[d>>2],v[d+4>>2]),f);wN(v[f+8>>2]);v[f+8>>2]=v[f+8>>2]+8;Ad(d,f);Pq(f);cb=g+32|0}}d=zN(k,km(h+16|0,b,c));i:{if(y[d+4>>2]<y[xb(d)>>2]){f=cb-16|0;cb=f;d=yN(f,d);xN(v[d+4>>2],v[e>>2],v[e+4>>2]);v[d+4>>2]=v[d+4>>2]+8;dc(d);cb=f+16|0;break i}g=cb-32|0;cb=g;f=xb(d);f=Qq(g+8|0,Rq(d,Vg(v[d>>2],v[d+4>>2])+1|0),Vg(v[d>>2],v[d+4>>2]),f);xN(v[f+8>>2],v[e>>2],v[e+4>>2]);v[f+8>>2]=v[f+8>>2]+8;Ad(d,f);Pq(f);cb=g+32|0}}d=h+16|0;ub(d,v[rd(v[a>>2],b)>>2],c);Te(d,1);m=0}cb=h+32|0;return m|0}function oV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;e=cb-32|0;cb=e;j=tg(e+24|0);q=j+3|0;r=j+5|0;s=j+4|0;x=j+2|0;z=j+1|0;h=e+16|0;A=h|5;C=h|3;while(1){a:{if(y[a+12>>2]>m>>>0){D=Gf(a,m);b:while(1){if(!Kb(c,1)){break a}k=He(c);if((k|0)==255){break a}d=k&31;h=Hj(v[v[a+48>>2]+12>>2])>>>0>d>>>0;f=B(d,6)+D|0;g=1;if(!(k&64)){d=He(c);i=d<<24>>24;g=255;d=d&127;c:{d:{if((d|0)==1){break d}g=d-1|0;if(b?g>>>0<=120:0){break d}if((d-109&255)>>>0<159|b){break c}g=d+13|0}t[(h?f:e+24|0)|0]=g}F=h?f+1|0:z,G=He(c),t[F|0]=G;g=(i|0)<0}p=h?f:j;i=h?f+3|0:q;d=h?f+5|0:r;n=h?f+4|0:s;l=h?f+2|0:x;h=h?f:e+24|0;while(1){e:{f:{g:{if(g&1){v[e+16>>2]=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);u[e+20>>1]=w[h+4|0]|w[h+5|0]<<8;o=He(c);g=o&63;if(o&64){t[l|0]=1;t[n|0]=g;break e}f=He(c);t[d|0]=f;if(g>>>0<=15){Ef(p,g,f);h:{i:{j:{f=w[i|0];switch(f-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}t[i|0]=9;t[d|0]=B(w[d|0]&15,17);break f}t[i|0]=0;t[l|0]=1;v[e+12>>2]=w[d|0]+1>>>1;v[e+8>>2]=64;F=n,G=v[ld(e+12|0,e+8|0)>>2],t[F|0]=G;break f}if((f|0)!=19){break f}if(w[d|0]==128){break g}Cu(p);break f}if(g>>>0>44){break f}t[i|0]=w[g+26320|0];k:{switch(g-16|0){case 0:if(f>>>0>1){break g}t[d|0]=f|158;break f;case 1:case 2:t[e+12|0]=15;F=d,G=w[Tb(e+12|0,d)|0]|224,t[F|0]=G;break f;case 5:case 6:v[e+12>>2]=16;v[e+8>>2]=f+1;F=d,G=v[ld(e+12|0,e+8|0)>>2]/2|240,t[F|0]=G;break f;case 14:l:{m:{n:{o:{p:{g=f>>>4|0;switch(g-1|0){case 1:break n;case 0:break o;default:break p}}switch(g-10|0){case 1:break l;case 0:break m;default:break g}}t[i|0]=2;t[d|0]=f|240;break f}t[i|0]=3;t[d|0]=f|240;break f}t[i|0]=11;t[d|0]=(f<<3&120)+8|15;break f}t[i|0]=11;t[d|0]=(f&15)+1>>>1|240;break f;case 12:break k;default:break f}}v[e+12>>2]=f+1>>>1;v[e+8>>2]=64;F=d,G=v[ld(e+12|0,e+8|0)>>2],t[F|0]=G;break f}if(!(k&128)){continue b}break a}t[i|0]=0}Bu(i,d,C,A);f=w[e+19|0];E=Ji(f);g=w[i|0];if(E>>>0<=Ji(g)>>>0){break e}if(!w[l|0]){uq(e,g,w[d|0],1);g=w[e+1|0];t[l|0]=w[e|0];t[n|0]=g}t[i|0]=f;t[d|0]=w[e+21|0]}g=o>>>7|0;continue}}}cb=e+32|0;return}m=m+1|0;continue}}function KV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=cb-384|0;cb=f;sc(b);d=cb-16|0;cb=d;h=f+344|0;wC(d+8|0,h);e=v[d+12>>2];Yb(d,b,v[d+8>>2],e);i=v[d+4>>2];if((i|0)==(e|0)){Ob(b,v[d+12>>2])}cb=d+16|0;d=(e|0)==(i|0);if(!d){vC(h)}a:{if(!d){break a}if(!yC(f+344|0)){break a}if(!Kb(b,wc(xC(w[f+379|0]),fb))){break a}b:{if(!c){break b}ud(a,2097152);eg(a);mh(a,1);u[a+480188>>1]=8;v[a+480196>>2]=w[f+376|0];v[a+480204>>2]=B(w[f+377|0],1e4);l=a+480190|0;u[l>>1]=w[f+378|0];d=w[f+381|0];if(d>>>0<w[f+380|0]){Qe(Nb(a+484360|0),d)}d=f+80|0;g=jc(d,6522);Cb(a+1298344|0,g);rb(g);g=jc(d,11118);Cb(a+1298356|0,g);rb(g);v[a+1298404>>2]=5;Ou(b,d);zq(Nb(a+484360|0),d,w[f+380|0],65535,65535);g=1;while(1){k=g&65535;if(k>>>0>x[l>>1]){Ob(b,B(64-w[f+378|0]|0,37));h=a+484344|0;wg(h,w[f+379|0]);i=c&1;g=0;while(1){if(w[f+379|0]<=g>>>0){if(!(c&2)){break b}c=Nc(f+40|0,8,1,0,0);d=a+480190|0;g=1;while(1){e=g&65535;if(e>>>0>x[d>>1]){break b}vg(c,(B(e,104)+a|0)+484380|0,b);g=g+1|0;continue}}c:{d:{if(i){if(nh(h,g&65535,64)){break d}}Ob(b,2048);break c}d=Sb(h,g);o=f,p=Pg(d),v[o+40>>2]=p;j=Og(d);while(1){e=v[f+40>>2];if(!Qb(e,j)){break c}d=f+24|0;Gm(d,b);k=Ec(d);l=Oe(d);m=Li(d);d=w[d|0];if((d-1&255)>>>0<=106){t[e|0]=d+13}t[e+1|0]=w[k|0];Ef(e,w[l|0],w[m|0]);Ki(f+40|0);continue}}g=g+1|0;continue}}else{i=f+40|0;uC(b,i);j=cb-16|0;cb=j;h=(B(k,104)+a|0)+484380|0;ed(h,0);t[h+37|0]=w[i+22|0]<<4;t[j+15|0]=w[i+23|0];t[j+14|0]=64;o=h,p=w[Tb(j+15|0,j+14|0)|0]<<2,u[o+30>>1]=p;t[h+36|0]=w[i+24|0];e=i+25|0;v[h>>2]=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);d=i+33|0;m=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);e:{if(m>>>0<3){break e}n=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=i+29|0;if(n>>>0<m+(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0){break e}u[h+34>>1]=x[h+34>>1]|2;v[h+4>>2]=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[h+8>>2]=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))}cb=j+16|0;Bl(f+8|0,2,i);d=f+24|0;xc(d,v[f+8>>2],v[f+12>>2],w[f+16|0]);uc(((k<<5)+a|0)+946304|0,d);g=g+1|0;rb(d);continue}}}g=1}cb=f+384|0;return g|0}function Jba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0;g=cb+-64|0;cb=g;p=v[a+16>>2];h=ee(g+32|0);v[h+8>>2]=a+112;e=v[a+128>>2];v[h+16>>2]=e;D=h,E=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[D+12>>2]=E;b=0;if(e){D=h,E=kg(v[a+8>>2],v[a+12>>2],e),v[D>>2]=E;v[h+4>>2]=fb}while(1){if((b|0)!=2){e=b<<3;i=e+(g+16|0)|0;e=a+e|0;v[i>>2]=v[e+44>>2];v[i+4>>2]=v[e+48>>2];b=b+1|0;continue}break}i=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;q=v[a+8>>2];r=v[a+12>>2];a:while(1){if(d){b=v[g+12>>2];e=v[g+8>>2];v[g+56>>2]=e;v[g+60>>2]=0;e=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+p|0;b=v[h+16>>2];while(1)if((b|0)<=0){b=v[h+8>>2];f=v[b+8>>2];Jb(b,f,v[b+12>>2]);b=v[h+8>>2];f=v[b+4>>2];if(f){k=b;b=(v[g+60>>2]&2147483647)<<1|v[g+56>>2]>>>31;Jd(k,(u[(b<<1|2)+e>>1]+u[e+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[h+8>>2],f);b=v[h+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}d=d-1|0;b=ig(b,v[h+12>>2]);v[g+4>>2]=b;v[g>>2]=b;s=v[a+72>>2];b=v[a+68>>2];t=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;b=0;while(1){if((b|0)!=2){n=(b<<2)+g|0;f=v[n>>2];e=(g+16|0)+(b<<3)|0;m=v[e+4>>2];l=v[e>>2];v[e+4>>2]=l;o=f<<8;f=o;f=kka(z,A,f,f>>31);k=fb;C=e;e=Vb(l,-16777216,16776704);l=kka(x,y,e,e>>31);f=l+f|0;e=fb+k|0;e=f>>>0<l>>>0?e+1|0:e;k=f;f=Vb(m,-16777216,16776704);m=kka(t,w,f,f>>31);f=k+m|0;e=fb+e|0;e=f>>>0<m>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Mc(f,e,24);v[C>>2]=e-(s&o);v[n>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];j=v[a+28>>2]+j|0;v[c>>2]=v[c>>2]+B(v[g>>2],j>>12);i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],i>>12);Jb(g+8|0,q,r);c=c+8|0;continue a}else{f=(v[g+60>>2]&2147483647)<<1|v[g+56>>2]>>>31;Jd(v[h+8>>2],(u[(f<<1|2)+e>>1]+u[e+((f&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[h+8>>2],4);Jb(g+56|0,v[h>>2],v[h+4>>2]);b=b-1|0;continue}}break}b=v[g+12>>2];c=v[g+8>>2];v[a+36>>2]=j;v[a>>2]=c;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+24>>2]=i>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}cb=g- -64|0}function Nha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=cb-48|0;cb=d;a:{b:{c:{d:{e:{h=a+24|0;f:{if(Bd(h)){break f}g=a+4|0;i=vb(g);a=cb-32|0;cb=a;f=a+24|0;c=f;v[c>>2]=-1;v[c+4>>2]=-1;v[22440]=0;c=pE(38);b=v[22440];v[22440]=0;if((b|0)==1){break a}v[a>>2]=c;v[a+4>>2]=fb;c=cb-16|0;cb=c;k=c,l=kka(v[a>>2],v[a+4>>2],1e3,0),v[k>>2]=l;v[c+4>>2]=fb;b=mt(c+8|0,c);e=v[b+4>>2];cb=c+16|0;v[a+8>>2]=v[b>>2];v[a+12>>2]=e;c=a+8|0;b=lA(v[c>>2],v[c+4>>2]);t[a+16|0]=b;t[a+17|0]=b>>>8;t[a+18|0]=b>>>16;t[a+19|0]=b>>>24;b=fb;t[a+20|0]=b;t[a+21|0]=b>>>8;t[a+22|0]=b>>>16;t[a+23|0]=b>>>24;b=v[a+20>>2];v[a+8>>2]=v[a+16>>2];v[a+12>>2]=b;f=PR(f,c,xb(c));v[22440]=0;b=pE(39);e=v[22440];v[22440]=0;if((e|0)==1){break a}v[a>>2]=b;v[a+4>>2]=fb;b=cb-16|0;cb=b;e=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=e;e=mt(b+8|0,b);j=v[e+4>>2];cb=b+16|0;v[a+8>>2]=v[e>>2];v[a+12>>2]=j;b=lA(v[c>>2],v[c+4>>2]);t[a+16|0]=b;t[a+17|0]=b>>>8;t[a+18|0]=b>>>16;t[a+19|0]=b>>>24;b=fb;t[a+20|0]=b;t[a+21|0]=b>>>8;t[a+22|0]=b>>>16;t[a+23|0]=b>>>24;b=v[a+20>>2];v[a+8>>2]=v[a+16>>2];v[a+12>>2]=b;c=PR(f,c,xb(c));b=v[c>>2];f=v[c+4>>2];cb=a+32|0;if(i){c=Rb(d+32|0);v[22440]=0;v[d+16>>2]=f;R(32,c|0,d+16|0);a=v[22440];v[22440]=0;if((a|0)==1){break c}v[22440]=0;v[d+16>>2]=b;R(32,c|0,d+16|0);a=v[22440];v[22440]=0;if((a|0)==1){break d}a=0;g:{while(1){if(vb(g)>>>0<=a>>>0){a=yb(v[c>>2]);b=yb(v[c+4>>2]);v[22440]=0;b=Y(33,d+16|0,a|0,b|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break g}a=P()|0;O()|0;break b}b=w[rc(g,a)|0];v[22440]=0;v[d+16>>2]=b;R(32,c|0,d+16|0);b=v[22440];v[22440]=0;if((b|0)!=1){a=a+1|0;continue}break}a=P()|0;O()|0;break b}v[22440]=0;a=T(34,b|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){v[d+8>>2]=a;a=d+8|0;mA(h,a);sl(a);fc(b);fc(c);break f}a=P()|0;O()|0;fc(b);break b}fb=b;v[d+16>>2]=f;v[d+20>>2]=fb;c=d+32|0;a=Rb(c);v[22440]=0;U(37,c|0,d+16|0,d+24|0);b=v[22440];v[22440]=0;if((b|0)==1){c=P()|0;O()|0;fc(a);S(c|0);L()}v[22440]=0;a=T(34,c|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break e}v[d+8>>2]=a;a=d+8|0;mA(h,a);sl(a);fc(c)}cb=d+48|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0}fc(c);S(a|0);L()}V(0)|0;O()|0;Lb();L()}function Oba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0;g=cb+-64|0;cb=g;p=v[a+16>>2];h=ee(g+32|0);v[h+8>>2]=a+112;e=v[a+128>>2];v[h+16>>2]=e;D=h,E=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[D+12>>2]=E;b=0;if(e){D=h,E=kg(v[a+8>>2],v[a+12>>2],e),v[D>>2]=E;v[h+4>>2]=fb}while(1){if((b|0)!=2){e=b<<3;f=e+(g+16|0)|0;e=a+e|0;v[f>>2]=v[e+44>>2];v[f+4>>2]=v[e+48>>2];b=b+1|0;continue}break}q=v[a+24>>2];r=v[a+20>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;s=v[a+8>>2];u=v[a+12>>2];while(1){if(d){b=v[g+12>>2];e=v[g+8>>2];v[g+56>>2]=e;v[g+60>>2]=0;k=(((b&2147483647)<<1|e>>>31)&-2)+p|0;e=v[h+16>>2];a:{b:while(1){c:{if((e|0)<=0){b=v[h+8>>2];e=v[b+8>>2];Jb(b,e,v[b+12>>2]);e=v[h+8>>2];j=v[e+4>>2];if(!j){break a}m=((v[g+60>>2]&2147483647)<<1|v[g+56>>2]>>>31)&-2;f=0;b=0;break c}j=((v[g+60>>2]&2147483647)<<1|v[g+56>>2]>>>31)&-2;b=0;f=0;while(1)if((b|0)==2){Jd(v[h+8>>2],(f|0)/8<<16>>16);Id(v[h+8>>2],4);Jb(g+56|0,v[h>>2],v[h+4>>2]);e=e-1|0;continue b}else{f=(t[k+(b+j|0)|0]<<8)+f|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){f=(t[k+(b+m|0)|0]<<8)+f|0;b=b+1|0;continue}break}Jd(e,(f|0)/8<<16>>16);Id(v[h+8>>2],j);e=v[h+8>>2];b=e;f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}d=d-1|0;b=ig(e,v[h+12>>2]);v[g+4>>2]=b;v[g>>2]=b;k=v[a+72>>2];b=v[a+68>>2];j=b;m=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){n=(b<<2)+g|0;f=v[n>>2];e=(g+16|0)+(b<<3)|0;l=v[e+4>>2];i=v[e>>2];v[e+4>>2]=i;o=f<<8;f=o;f=kka(y,z,f,f>>31);A=fb;C=e;e=Vb(i,-16777216,16776704);i=kka(w,x,e,e>>31);f=i+f|0;e=fb+A|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=Vb(l,-16777216,16776704);l=kka(j,m,f,f>>31);f=i+l|0;e=fb+e|0;e=f>>>0<l>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Mc(f,e,24);v[C>>2]=e-(k&o);v[n>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],q);Jb(g+8|0,s,u);c=c+8|0;continue}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}cb=g- -64|0}function Q9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=cb-16|0;cb=h;v[22440]=0;e=T(616,a|0)|0;f=v[22440];v[22440]=0;a:{b:{if((f|0)!=1){if(e){break b}v[22440]=0;e=T(208,a|0)|0;f=v[22440];v[22440]=0;c:{if((f|0)==1){break c}v[22440]=0;j=d+484344|0;k=wd(e+1|0,1,1024);e=Y(229,j|0,b|0,k|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break c}if(!e){break b}d=x[d+480188>>1];if(!d){break b}l=d-1|0;d=0;while(1){if(d>>>0>=k>>>0){break b}v[22440]=0;e=Q(158,a|0,1)|0;f=v[22440];v[22440]=0;d:{if((f|0)!=1){if(!e){break b}v[22440]=0;i=T(208,a|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break a}if(i){break d}d=d+1|0;continue}break a}f=Sb(j,b);u[h+14>>1]=i&31;u[h+12>>1]=l;f=Zc(f,d,x[Kc(h+14|0,h+12|0)>>1]);if(!(i&224)){continue}e:{if(!(i&128)){break e}v[22440]=0;g=T(208,a|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break a}t[f+5|0]=g;v[22440]=0;g=T(208,a|0)|0;e=v[22440];v[22440]=0;f:{g:{if((e|0)!=1){if(g>>>0<26){break g}break f}break a}e=w[g+42800|0];t[f+3|0]=e;h:{switch(e-1|0){case 0:if(!w[f+5|0]){break f}break e;case 12:if(w[f+2|0]){break e}t[f+2|0]=1;e=w[f+5|0];t[f+5|0]=0;t[f+3|0]=0;m=f,n=wd(e,0,64),t[m+4|0]=n;break e;case 5:case 6:case 10:case 23:case 28:e=w[f+5|0]&240;if(!e){break e}t[f+5|0]=e;break e;case 8:e=w[f+5|0];if(e>>>0<=128){m=f,n=rg(e<<1),t[m+5|0]=n;break e}if((e|0)!=164){break e}t[f+5|0]=145;t[f+3|0]=20;break e;case 13:e=w[f+5|0];t[f+5|0]=B(e>>>4|0,10)+(e&15);break e;case 18:Cu(f);break e;case 16:if(w[f+5|0]>31){break e}t[f+3|0]=16;break e;case 27:break h;default:break e}}g=w[f+5|0];e=g&240;i:{if((e|0)==16){e=2}else{if((e|0)!=32){break i}e=3}t[f+3|0]=e}t[f+5|0]=g&15|224;break e}t[f+3|0]=0}j:{k:{if(!(i&64)){break k}v[22440]=0;R(267,h+8|0,a|0);e=v[22440];v[22440]=0;if((e|0)==1){break j}e=h+8|0;t[f+1|0]=w[e|0];g=w[Ec(e)|0];t[f|0]=g;e=255;if((g|0)!=128){e=253;if(g>>>0<129){break k}}t[f|0]=e}if(!(i&32)){continue}t[f+2|0]=1;v[22440]=0;g=T(208,a|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break a}t[f+4|0]=g;if(!c){continue}t[f+4|0]=(g<<6>>>0)/127;continue}break}break a}break a}break a}sb(a);cb=h+16|0;return}b=P()|0;O()|0;sb(a);S(b|0);L()}function nx(a){a=a|0;var b=0,c=0,d=C(0),e=0;Hb(a+4960|0,0,76);t[a+5044|0]=0;v[a+5036>>2]=0;v[a+5040>>2]=0;b=v[a+4292>>2];d=z[a+4268>>2];v[22440]=0;e=a+4504|0;if(d<C(4294967296)&d>=C(0)){c=~~d>>>0}else{c=0}ga(948,e|0,67,5,c|0,b|0);b=v[22440];v[22440]=0;a:{if((b|0)==1){break a}b=v[a+4296>>2];v[22440]=0;ga(948,a+4528|0,62,5,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}b=v[a+4300>>2];v[22440]=0;ga(948,a+4552|0,53,5,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}b=v[a+4304>>2];v[22440]=0;ga(948,a+4576|0,43,5,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}b=v[a+4308>>2];v[22440]=0;ga(948,a+4600|0,32,5,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}b=v[a+4312>>2];v[22440]=0;ga(948,a+4624|0,22,5,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}b=v[a+4316>>2];v[22440]=0;ga(948,a+4648|0,75,5,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}b=v[a+4320>>2];v[22440]=0;ga(948,a+4672|0,69,5,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}b=v[a+4324>>2];v[22440]=0;ga(948,a+4696|0,60,5,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}b=v[a+4328>>2];v[22440]=0;ga(948,a+4720|0,48,5,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}b=v[a+4332>>2];v[22440]=0;ga(948,a+4744|0,36,5,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}b=v[a+4336>>2];v[22440]=0;ga(948,a+4768|0,25,5,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}v[22440]=0;ga(948,a+4792|0,0,0,0,0);b=v[22440];v[22440]=0;if((b|0)==1){break a}b=v[a+4344>>2];v[22440]=0;ga(948,a+4816|0,3,0,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}b=v[a+4348>>2];v[22440]=0;ga(948,a+4840|0,3,0,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}v[22440]=0;ga(948,a+4864|0,407,1,c|0,0);b=v[22440];v[22440]=0;if((b|0)==1){break a}v[22440]=0;ga(948,a+4888|0,400,1,c|0,0);b=v[22440];v[22440]=0;if((b|0)==1){break a}v[22440]=0;ga(948,a+4912|0,10,0,c|0,-1);b=v[22440];v[22440]=0;if((b|0)==1){break a}v[22440]=0;ga(948,a+4936|0,10,0,c|0,-1);c=v[22440];v[22440]=0;if((c|0)==1){break a}t[a+5045|0]=1;return}c=V(88360)|0;if((O()|0)==(fa(88360)|0)){_(c|0)|0;t[a+5045|0]=0;$();return}S(c|0);L()}function oea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=cb-128|0;cb=d;a:{b:{c:{d:{switch(w[a|0]-23|0){case 0:e=t[a+1|0];f=d,g=PA(v[c+480208>>2],+w[a+2|0]*1e4/240),t[f|0]=g;v[d+96>>2]=127;v[d+80>>2]=(B(w[a+3|0],127)>>>0)/185;f=d,g=v[ld(d+96|0,d+80|0)>>2],t[f+127|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:nu(d+80|0,15638);v[22440]=0;R(557,d- -64|0,d|0);a=v[22440];v[22440]=0;f:{g:{h:{i:{if((a|0)!=1){v[22440]=0;R(557,d+48|0,d+127|0);a=v[22440];v[22440]=0;if((a|0)==1){break i}v[22440]=0;W(558,d+96|0,d+80|0,d- -64|0,d+48|0);a=v[22440];v[22440]=0;if((a|0)==1){break h}a=d+96|0;se(d+112|0,a);df(b,v[d+112>>2],v[d+116>>2]);rb(a);rb(d+48|0);rb(d- -64|0);Ab(d+80|0);break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;rb(d+48|0)}rb(d- -64|0)}break c;case 1:nu(d+80|0,15578);v[22440]=0;R(557,d- -64|0,d|0);a=v[22440];v[22440]=0;j:{k:{l:{m:{if((a|0)!=1){v[22440]=0;R(557,d+48|0,d+127|0);a=v[22440];v[22440]=0;if((a|0)==1){break m}v[22440]=0;W(558,d+96|0,d+80|0,d- -64|0,d+48|0);a=v[22440];v[22440]=0;if((a|0)==1){break l}a=d+96|0;se(d+40|0,a);df(b,v[d+40>>2],v[d+44>>2]);rb(a);rb(d+48|0);rb(d- -64|0);Ab(d+80|0);break b}a=P()|0;O()|0;break j}a=P()|0;O()|0;break k}a=P()|0;O()|0;rb(d+48|0)}rb(d- -64|0)}break c;default:break e}}a=nc(d+32|0,15665);df(b,v[a>>2],v[a+4>>2]);break b;case 1:break d;default:break a}}c=t[a+1|0];t[d+127|0]=(c|0)<5?c:0;c=t[a+2|0];t[d+31|0]=(c|0)>=0?c:127;a=t[a+3|0];t[d+30|0]=(a|0)>=0?a:127;a=cb-16|0;cb=a;c=Bc(a,4051);zc(d+80|0,c);rb(c);cb=a+16|0;v[22440]=0;R(557,d- -64|0,d+127|0);a=v[22440];v[22440]=0;n:{o:{p:{q:{r:{s:{if((a|0)!=1){v[22440]=0;R(557,d+48|0,d+31|0);a=v[22440];v[22440]=0;if((a|0)==1){break s}v[22440]=0;R(557,d|0,d+30|0);a=v[22440];v[22440]=0;if((a|0)==1){break r}v[22440]=0;ga(730,d+96|0,d+80|0,d- -64|0,d+48|0,d|0);a=v[22440];v[22440]=0;if((a|0)==1){break q}a=d+96|0;se(d+16|0,a);df(b,v[d+16>>2],v[d+20>>2]);rb(a);rb(d);rb(d+48|0);rb(d- -64|0);Ab(d+80|0);break b}a=P()|0;O()|0;break n}a=P()|0;O()|0;break o}a=P()|0;O()|0;break p}a=P()|0;O()|0;rb(d)}rb(d+48|0)}rb(d- -64|0)}}Ab(d+80|0);S(a|0);L()}e=1}cb=d+128|0;return e|0}function vP(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=cb-128|0;cb=j;a:{b:{c:{if(!wm(f,g,h,i,0,0,0,0)){break c}m=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){l=4;if(n){break e}l=f|h|(g|m)?3:2;break d}l=!(f|h|(g|m))}}r=e>>>16|0;o=r&32767;if((o|0)==32767){break c}if(l){break b}}Fd(j+16|0,b,c,d,e,f,g,h,i);e=v[j+16>>2];d=v[j+20>>2];c=v[j+24>>2];b=v[j+28>>2];_P(j,e,d,c,b,e,d,c,b);d=v[j+8>>2];e=v[j+12>>2];h=v[j>>2];i=v[j+4>>2];break a}m=e&65535|o<<16;p=m;l=d;m=h;q=i>>>16&32767;k=i&65535|q<<16;if((wm(b,c,l,p,f,g,h,k)|0)<=0){if(wm(b,c,l,p,f,g,m,k)){h=b;i=c;break a}Fd(j+112|0,b,c,d,e,0,0,0,0);d=v[j+120>>2];e=v[j+124>>2];h=v[j+112>>2];i=v[j+116>>2];break a}if(o){i=c;h=b}else{Fd(j+96|0,b,c,l,p,0,0,0,1081540608);h=v[j+108>>2];p=h;l=v[j+104>>2];o=(h>>>16|0)-120|0;i=v[j+100>>2];h=v[j+96>>2]}if(!q){Fd(j+80|0,f,g,m,k,0,0,0,1081540608);f=v[j+92>>2];k=f;m=v[j+88>>2];q=(k>>>16|0)-120|0;g=v[j+84>>2];f=v[j+80>>2]}s=k&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){t=l-m|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=(p-((l>>>0<m>>>0)+s|0)|0)-(t>>>0<k>>>0)|0;k=t-k|0;f:{if((n|0)>0|(n|0)>=0){l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(!(h|k|(i|n))){Fd(j+32|0,b,c,d,e,0,0,0,0);d=v[j+40>>2];e=v[j+44>>2];h=v[j+32>>2];i=v[j+36>>2];break a}n=n<<1|k>>>31;l=k<<1|i>>>31;p=n;break f}n=p<<1|l>>>31;l=l<<1|i>>>31;p=n}n=i<<1|h>>>31;h=h<<1;i=n;o=o-1|0;if((q|0)<(o|0)){continue}break}o=q}q=l-m|0;n=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=(p-((l>>>0<m>>>0)+s|0)|0)-(q>>>0<n>>>0)|0;m=q-n|0;g:{if((k|0)<0){m=l;k=p;break g}l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(h|m|(i|k)){break g}Fd(j+48|0,b,c,d,e,0,0,0,0);d=v[j+56>>2];e=v[j+60>>2];h=v[j+48>>2];i=v[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m;k=k<<1|b>>>31;m=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((o|0)<=0){Fd(j- -64|0,h,i,m,k&65535|(b|o+120)<<16,0,0,0,1065811968);d=v[j+72>>2];e=v[j+76>>2];h=v[j+64>>2];i=v[j+68>>2];break a}d=m;e=k&65535|(b|o)<<16}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=e;cb=j+128|0}function uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=cb-16|0;cb=h;c=rf(a,c);ke(h,v[a+36>>2]);j=a;a:{if(!c){Cc(h,a+32|0,5);e=0;if(tb(v[v[h>>2]>>2],v[h+4>>2])){break a}}e=cb-160|0;cb=e;g=Tl(e+48|0,v[a+36>>2]);v[22440]=0;f=Q(462,e+32|0,27912)|0;a=v[22440];v[22440]=0;b:{c:{d:{e:{if((a|0)!=1){v[22440]=0;v[e+16>>2]=19988487;v[e+20>>2]=0;U(463,g|0,f|0,e+16|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}Ab(f);if(!Gk(w[e+48|0])){break d}break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;Ab(f);break c}t[e+31|0]=0;v[22440]=0;f=Q(462,e+32|0,5508)|0;a=v[22440];v[22440]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[22440]=0;U(464,g|0,e+31|0,f|0);a=v[22440];v[22440]=0;if((a|0)==1){break q}Ab(f);f=Db(e+32|0);v[22440]=0;a=Q(462,e+16|0,10113)|0;i=v[22440];v[22440]=0;if((i|0)==1){break p}v[22440]=0;U(777,g|0,f|0,a|0);i=v[22440];v[22440]=0;if((i|0)==1){break o}Ab(a);v[22440]=0;U(11,e+16|0,(w[e+31|0]?0:d)|0,f|0);d=v[22440];v[22440]=0;if((d|0)==1){break n}v[22440]=0;R(280,b|0,e+16|0);d=v[22440];v[22440]=0;if((d|0)==1){break m}d=e+16|0;rb(d);u[e+14>>1]=0;v[22440]=0;d=Q(462,d|0,10773)|0;a=v[22440];v[22440]=0;if((a|0)==1){break g}v[22440]=0;Y(492,g|0,e+14|0,d|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break l}Ab(d);Kf(e+14|0,4e3);v[22440]=0;d=Q(462,e+16|0,13450)|0;a=v[22440];v[22440]=0;if((a|0)==1){break k}i=x[e+14>>1];a=v[ac(e+8|0,i)>>2];v[22440]=0;W(778,g|0,b|0,d|0,a|0);a=v[22440];v[22440]=0;if((a|0)==1){break j}Ab(d);u[e+6>>1]=65535;v[22440]=0;d=Q(462,e+16|0,8993)|0;a=v[22440];v[22440]=0;if((a|0)==1){break i}v[22440]=0;k=Y(492,g|0,e+6|0,d|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break h}a=x[e+6>>1];Ab(d);if(a>>>0<i>>>0&k){Qe(b,a)}rb(f);break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;Ab(f);break c}b=P()|0;O()|0;break f}b=P()|0;O()|0;Ab(a);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;rb(e+16|0);break f}b=P()|0;O()|0;Ab(d);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;Ab(d);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;Ab(d);break f}b=P()|0;O()|0}rb(f)}jh(g);S(b|0);L()}jh(g);cb=e+160|0;e=c}Se(j,e);cb=h+16|0}function L7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=0,h=C(0),i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,t=0,u=0,x=0,y=0,A=0,B=C(0),E=0,F=0,G=C(0),H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=C(0),P=0,Q=C(0);a:{if(!v[a+4316>>2]){break a}m=a+44|0;if(!Yh(m)){break a}t=Ud(m,0);u=Ud(m,1);x=jd(m,0);y=jd(m,1);K=gb[v[v[a>>2]+192>>2]](a)|0;e=C(gb[v[v[a>>2]+200>>2]](a));G=C(gb[v[v[a>>2]+188>>2]](a));A=gb[v[v[a>>2]+212>>2]](a)|0;H=a+4264|0;r=w[a+4260|0];L=r?a+4276|0:H;I=a+4300|0;J=a+4288|0;B=C(e/C(100));M=A&1;N=a+4316|0;j=r;E=d;while(1){if(E){p=z[u>>2];l=z[t>>2];n=v[N>>2];o=v[a+4312>>2];F=v[a+4256>>2];k=vn(n,o+F|0);q=vn(n,o);i=j&255;b:{if(i){j=v[a+4328>>2];P=Ib(J,j),Q=l,z[P>>2]=Q;P=Ib(I,j),Q=p,z[P>>2]=Q;g=v[a+4264>>2];j=Ib(g,k);P=Ib(g,q),Q=C(C(z[j>>2]*B)+l),z[P>>2]=Q;j=v[a+4276>>2];h=C(C(z[Ib(j,k)>>2]*B)+p);break b}g=v[H>>2];h=C(C(z[Ib(g,k)>>2]*B)+C(C(l+p)*C(.5)));j=g}P=Ib(j,q),Q=h,z[P>>2]=Q;c:{if(K){e=z[a+4244>>2];h=C(e+z[a+4236>>2]);z[a+4236>>2]=h;f=C(e+z[a+4240>>2]);z[a+4240>>2]=f;if(h>C(1)){h=C(h+C(-2));z[a+4236>>2]=h}if(f>C(1)){f=C(f+C(-2));z[a+4240>>2]=f}e=C(D(h));h=C(C(e+e)+C(-1));e=C(D(f));f=C(C(e+e)+C(-1));break c}f=z[a+4240>>2];e=z[a+4244>>2];h=C(C(f*e)+z[a+4236>>2]);z[a+4236>>2]=h;f=C(f-C(h*e));z[a+4240>>2]=f}s=v[a+4328>>2];j=0;d:{if(!i){break d}i=(s+2|0)%3|0;l=z[Ib(J,i)>>2];if(!r){break d}p=z[Ib(I,i)>>2];j=r}k=v[a+4320>>2];i=Ib(g,vn(n,k+o|0));q=o+4096|0;O=z[Ib(g,vn(n,q+k|0))>>2];e=z[i>>2];z[x>>2]=C(C(C(C(C(O-e)*C(C(k&4095)*C(.000244140625)))+e)-l)*G)+l;i=v[L>>2];k=v[a+4324>>2];g=Ib(i,vn(n,k+o|0));l=z[Ib(i,vn(n,k+q|0))>>2];e=z[g>>2];z[y>>2]=C(C(C(C(C(l-e)*C(C(k&4095)*C(.000244140625)))+e)-p)*G)+p;v[a+4328>>2]=((s|0)<=0?s+3|0:s)-1;v[a+4312>>2]=(((o|0)>0?0:n<<12)+o|0)-4096;e=M?f:h;f=z[a+4248>>2];e=C(e*f);e:{if(C(D(e))<C(2147483648)){g=~~e;break e}g=-2147483648}v[a+4324>>2]=(A>>>0>1?g:0-g|0)+F;g=A>>>0<4;u=u+4|0;t=t+4|0;e=C(h*f);f:{if(C(D(e))<C(2147483648)){i=~~e;break f}i=-2147483648}v[a+4320>>2]=(g?i:0-i|0)+F;E=E-1|0;y=y+4|0;x=x+4|0;continue}else{ti(a,b,c,jd(m,0),jd(m,1),d)}break}}}function C5(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=cb-80|0;cb=j;a:{b:{c:{k=ap(1,32);d:{e:{if(!k){a=aa(4)|0;tn(a);v[22440]=0;U(121,a|0,88360,26);a=v[22440];v[22440]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:952;c=Jg(j- -64|0);f:{g:{h:{if(!i){break h}while(1){d=v[i>>2];if(!d){break h}e=v[i+4>>2];i:{if(e){v[22440]=0;d=Q(56,j+48|0,d|0)|0;f=v[22440];v[22440]=0;j:{if((f|0)!=1){v[22440]=0;f=Q(963,c|0,d|0)|0;l=v[22440];v[22440]=0;if((l|0)==1){break j}v[22440]=0;Q(277,f|0,e|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;rb(d);break f}v[22440]=0;d=Q(56,j+48|0,d|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break g}es(c,d)}rb(d);i=i+8|0;continue}}d=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[22440]=0;a=T(836,96)|0;i=v[22440];v[22440]=0;k:{l:{m:{if((i|0)!=1){v[j+44>>2]=d;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;b=v[k+4>>2];d=v[k>>2];v[22440]=0;b=Q(964,d|0,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break m}v[j+48>>2]=b;b=v[bp(j+24|0,j+48|0)>>2];d=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=d;v[22440]=0;d=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=d;da(994,a|0,j+8|0,b|0,c|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break l}v[k+28>>2]=a;Ae(j+48|0);a=v[k+28>>2];v[k+24>>2]=a?a+8|0:0;gl(c);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;Ae(j+48|0)}zb(a);break f}i=V(0)|0;O()|0}gl(c);_(i|0)|0;v[22440]=0;W(958,11376,k|0,g|0,h|0);a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)!=1){a=v[k+28>>2];if(a){gb[v[v[a>>2]+4>>2]](a)}v[k+24>>2]=0;v[k+28>>2]=0;a=v[k+20>>2];if(a){zb(a);v[k+20>>2]=0}zb(k);k=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)==1){break b}}_(i|0)|0;k=0;v[22440]=0;W(958,11376,0,g|0,h|0);a=v[22440];v[22440]=0;if((a|0)==1){break c}$()}cb=j+80|0;return k|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Lb()}L()}function Q5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=cb-80|0;cb=e;d=v[b+4>>2];a:{if(!d){break a}f=v[b>>2];h=w[Zk(f,d)|0];if((h|0)==33){c=1}else{if((h|0)!=63){break a}c=0}fl(e+56|0,f,d,d-1|0);d=v[e+60>>2];v[b>>2]=v[e+56>>2];v[b+4>>2]=d}f=e+56|0;Od(f);d=v[e+56>>2];Od(e+40|0);d=Yk(d,v[e+44>>2],b);Od(f);b:{c:{d:{e:{if((d|0)==v[e+60>>2]){d=v[b>>2];f=v[b+4>>2];a=nc(e+72|0,21685);if(Hc(d,f,v[a>>2],v[a+4>>2])){a=aa(8)|0;v[22440]=0;c=Q(56,e+56|0,10501)|0;b=v[22440];v[22440]=0;if((b|0)==1){break d}oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}b=P()|0;O()|0;rb(c);break c}g=0;if(!c){break e}a=aa(8)|0;v[22440]=0;d=Q(985,e+40|0,b|0)|0;b=v[22440];v[22440]=0;f:{g:{h:{if((b|0)!=1){v[22440]=0;U(986,e+56|0,17700,d|0);b=v[22440];v[22440]=0;if((b|0)==1){break h}oc(a,e+56|0);c=0;v[22440]=0;U(121,a|0,58712,975);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;rb(e+56|0);break g}b=P()|0;O()|0;break f}b=P()|0;c=1;O()|0}rb(d);if(!c){break c}}ba(a|0);break c}if(v[d+4>>2]!=2){a=aa(8)|0;v[22440]=0;c=Q(56,e+56|0,11620)|0;b=v[22440];v[22440]=0;if((b|0)!=1){oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}b=P()|0;O()|0;rb(c);break c}b=P()|0;O()|0;ba(a|0);break c}d=v[b>>2];f=v[b+4>>2];c=nc(e+32|0,21685);if(Hc(d,f,v[c>>2],v[c+4>>2])){a=aa(8)|0;v[22440]=0;c=Q(56,e+56|0,10501)|0;b=v[22440];v[22440]=0;if((b|0)!=1){oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}b=P()|0;O()|0;rb(c);break c}b=P()|0;O()|0;ba(a|0);break c}d=v[b>>2];f=v[b+4>>2];c=nc(e+24|0,7719);if(Hc(d,f,v[c>>2],v[c+4>>2])){g=1;if(!Ed(w[a+28|0])){break e}g=65536/+y[v[a+24>>2]+480244>>2];break e}d=v[b>>2];f=v[b+4>>2];c=nc(e+16|0,7771);if(Hc(d,f,v[c>>2],v[c+4>>2])){g=1;if(!Ed(w[a+28|0])){break e}g=+y[v[a+24>>2]+480240>>2]*152587890625e-16;break e}c=v[b>>2];d=v[b+4>>2];b=nc(e+8|0,7789);g=0;if(!Hc(c,d,v[b>>2],v[b+4>>2])){break e}g=+y[v[a+24>>2]+480236>>2]*152587890625e-16}cb=e+80|0;return+g}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function Nba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0;g=cb+-64|0;cb=g;n=v[a+16>>2];h=ee(g+32|0);v[h+8>>2]=a+112;e=v[a+128>>2];v[h+16>>2]=e;D=h,E=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[D+12>>2]=E;b=0;if(e){D=h,E=kg(v[a+8>>2],v[a+12>>2],e),v[D>>2]=E;v[h+4>>2]=fb}while(1){if((b|0)!=2){e=b<<3;f=e+(g+16|0)|0;e=a+e|0;v[f>>2]=v[e+44>>2];v[f+4>>2]=v[e+48>>2];b=b+1|0;continue}break}o=v[a+24>>2];p=v[a+20>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;q=v[a+8>>2];r=v[a+12>>2];a:while(1){if(d){b=v[g+12>>2];e=v[g+8>>2];v[g+56>>2]=e;v[g+60>>2]=0;e=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+n|0;b=v[h+16>>2];while(1)if((b|0)<=0){b=v[h+8>>2];f=v[b+8>>2];Jb(b,f,v[b+12>>2]);b=v[h+8>>2];f=v[b+4>>2];if(f){i=b;b=(v[g+60>>2]&2147483647)<<1|v[g+56>>2]>>>31;Jd(i,(u[(b<<1|2)+e>>1]+u[e+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[h+8>>2],f);b=v[h+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}d=d-1|0;b=ig(b,v[h+12>>2]);v[g+4>>2]=b;v[g>>2]=b;s=v[a+72>>2];b=v[a+68>>2];t=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;b=0;while(1){if((b|0)!=2){l=(b<<2)+g|0;f=v[l>>2];e=(g+16|0)+(b<<3)|0;k=v[e+4>>2];j=v[e>>2];v[e+4>>2]=j;m=f<<8;f=m;f=kka(z,A,f,f>>31);i=fb;C=e;e=Vb(j,-16777216,16776704);j=kka(x,y,e,e>>31);f=j+f|0;e=fb+i|0;e=f>>>0<j>>>0?e+1|0:e;i=f;f=Vb(k,-16777216,16776704);k=kka(t,w,f,f>>31);f=i+k|0;e=fb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Mc(f,e,24);v[C>>2]=e-(s&m);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g>>2],p);v[c+4>>2]=v[c+4>>2]+B(o,v[g+4>>2]);Jb(g+8|0,q,r);c=c+8|0;continue a}else{f=(v[g+60>>2]&2147483647)<<1|v[g+56>>2]>>>31;Jd(v[h+8>>2],(u[(f<<1|2)+e>>1]+u[e+((f&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[h+8>>2],4);Jb(g+56|0,v[h>>2],v[h+4>>2]);b=b-1|0;continue}}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}cb=g- -64|0}function VN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;c=cb-176|0;cb=c;h=1;k=2;d=v[a+12>>2];q=1<<d;m=q;a:while(1){if(d>>>0>=k>>>0){m=m>>>2|0;w=B(h,3);x=h<<1;i=0;b:while(1){if((i|0)==(m|0)){k=k+2|0;h=h<<2;d=v[a+12>>2];continue a}d=sd(v[a>>2],i<<1);bL(c+160|0,A[d>>3],A[d+8>>3]);d=sd(v[a>>2],i);bL(c+144|0,A[d>>3],A[d+8>>3]);xi(c+128|0,A[c+144>>3],A[c+152>>3],A[c+160>>3],A[c+168>>3]);d=i<<k;f=h+d|0;y=d>>>0>f>>>0?d:f;while(1)if((d|0)==(y|0)){i=i+1|0;continue b}else{f=v[b>>2];e=sd(f,d);j=v[e+12>>2];v[c+120>>2]=v[e+8>>2];v[c+124>>2]=j;j=v[e+4>>2];v[c+112>>2]=v[e>>2];v[c+116>>2]=j;l=d+h|0;e=sd(f,l);n=A[e+8>>3];o=A[e>>3];r=d+x|0;e=sd(f,r);j=v[e+12>>2];v[c+104>>2]=v[e+8>>2];v[c+108>>2]=j;j=v[e+4>>2];v[c+96>>2]=v[e>>2];v[c+100>>2]=j;s=d+w|0;f=sd(f,s);t=A[f+8>>3];u=A[f>>3];e=c+80|0;f=c+112|0;al(e,f,o,n);j=c- -64|0;ij(j,f,o,n);g=c+96|0;al(c+48|0,g,u,t);f=c+16|0;ij(f,g,u,t);xi(c+32|0,0,1,A[c+16>>3],A[c+24>>3]);al(f,e,A[c+48>>3],A[c+56>>3]);g=sd(v[b>>2],d);p=v[c+28>>2];v[g+8>>2]=v[c+24>>2];v[g+12>>2]=p;p=v[c+20>>2];v[g>>2]=v[c+16>>2];v[g+4>>2]=p;al(c,j,A[c+32>>3],A[c+40>>3]);xi(f,A[c+160>>3],A[c+168>>3],A[c>>3],A[c+8>>3]);g=sd(v[b>>2],l);l=v[c+28>>2];v[g+8>>2]=v[c+24>>2];v[g+12>>2]=l;l=v[c+20>>2];v[g>>2]=v[c+16>>2];v[g+4>>2]=l;ij(c,e,A[c+48>>3],A[c+56>>3]);xi(f,A[c+144>>3],A[c+152>>3],A[c>>3],A[c+8>>3]);e=sd(v[b>>2],r);g=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=g;g=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=g;ij(c,j,A[c+32>>3],A[c+40>>3]);xi(f,A[c+128>>3],A[c+136>>3],A[c>>3],A[c+8>>3]);f=sd(v[b>>2],s);e=v[c+28>>2];v[f+8>>2]=v[c+24>>2];v[f+12>>2]=e;e=v[c+20>>2];v[f>>2]=v[c+16>>2];v[f+4>>2]=e;d=d+1|0;continue}}}break}c:{if(!(d&1)){break c}a=q>>>1|0;d=0;while(1){if((a|0)==(d|0)){break c}i=v[b>>2];k=a+d|0;h=sd(i,k);m=sd(i,d);n=A[h>>3];o=A[h+8>>3];ij(c+160|0,m,n,o);h=sd(v[b>>2],k);i=v[c+172>>2];v[h+8>>2]=v[c+168>>2];v[h+12>>2]=i;i=v[c+164>>2];v[h>>2]=v[c+160>>2];v[h+4>>2]=i;Rx(sd(v[b>>2],d),n,o);d=d+1|0;continue}}cb=c+176|0}function nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0;f=cb-32|0;cb=f;a:{b:{c:{k=v[a+12>>2];m=v[a+8>>2];d:{if((k|0)<=1&m>>>0<=805306368|(k|0)<=0){if((k|0)>=-2&m>>>0>=3489660928|(k|0)>-2){break c}if((k|0)==-2&m>>>0>2147483647|k>>>0>4294967294){break d}break b}if((k|0)==1&m>>>0>2147483648|k>>>0>1){break b}}r=b+196648|0;break a}r=b+131112|0;break a}r=b+262184|0}x=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;g=e+(f+16|0)|0;e=a+e|0;v[g>>2]=v[e+44>>2];v[g+4>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+40>>2];o=v[a+36>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;e:while(1){if(d){b=v[f+8>>2];s=((((v[f+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+x|0;b=(b>>>16&65520)+r|0;t=u[b+14>>1];p=u[b+12>>1];w=u[b+10>>1];i=u[b+8>>1];q=u[b+6>>1];g=u[b+4>>1];e=u[b+2>>1];b=u[b>>1];l=0;while(1)if((l|0)==2){y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];j=b;l=b>>31;b=v[a+60>>2];s=b;t=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+f|0;e=v[p>>2];h=(f+16|0)+(b<<3)|0;w=v[h+4>>2];i=v[h>>2];v[h+4>>2]=i;q=e<<8;e=q;e=kka(s,t,e,e>>31);g=fb;C=h;h=e;e=Vb(i,-16777216,16776704);e=kka(j,l,e,e>>31);i=h+e|0;h=fb+g|0;h=e>>>0>i>>>0?h+1|0:h;e=Vb(w,-16777216,16776704);g=kka(z,A,e,e>>31);i=g+i|0;e=fb+h|0;e=g>>>0>i>>>0?e+1|0:e;g=i+8388608|0;e=g>>>0<8388608?e+1|0:e;e=Mc(g,e,24);v[C>>2]=e-(q&y);v[p>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;v[c>>2]=v[c>>2]+B(v[f>>2],o>>12);n=b+n|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],n>>12);Jb(f+8|0,m,k);c=c+8|0;d=d-1|0;continue e}else{j=s+(l<<1)|0;v[(l<<2)+f>>2]=(((((((B(u[j-8>>1],e)+B(u[j-12>>1],b)|0)+B(u[j-4>>1],g)|0)+B(u[j>>1],q)|0)+B(i,u[j+4>>1])|0)+B(w,u[j+8>>1])|0)+B(p,u[j+12>>1])|0)+B(t,u[j+16>>1])|0)/32768;l=l+1|0;continue}}break}c=v[f+8>>2];b=v[f+12>>2];v[a+36>>2]=o;v[a>>2]=c;v[a+4>>2]=b;v[a+40>>2]=n;v[a+20>>2]=o>>12;v[a+24>>2]=n>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}cb=f+32|0}function vN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=cb-48|0;cb=i;m=Xy(v[a+24>>2],w[a+32|0]);o=rj(m);a:{while(1){b:{u[b>>1]=g;e=g&65535;if(e>>>0>=o>>>0){break b}c:{if(!oq(m,e)){break c}e=v[a>>2];f=gd(e,v[a+4>>2]);h=x[b>>1];if(f>>>0<=h>>>0){v[c>>2]=0;a=1;break a}l=rd(e,h);kk(i+32|0,v[l>>2]);pl(i+24|0,v[l>>2],v[l+4>>2]);k=i+40|0;h=v[i+32>>2];f=v[i+36>>2];g=ol(v[i+24>>2],v[i+28>>2],h,f);d:{if(d&255){e=0;j=cb-16|0;cb=j;v[j+12>>2]=f;v[j+8>>2]=h;v[j+4>>2]=g;e:{if(f){e=32-f|0;v[j>>2]=e;n=-1<<f;f=v[Bb(j,j+4|0)>>2];e=n&-1>>>e-f&v[h>>2];if(e){$b(k,h,jka(e));break e}if((f|0)==(g|0)){sN(k,j+8|0,g);break e}e=h+4|0;g=g-f|0;f=1}else{f=0}while(1){f:{if(!f){e=h;break f}g:{if(g>>>0>=32){f=v[e>>2];if(f){v[j+8>>2]=h;$b(k,e,jka(f));break e}g=g-32|0;v[j+4>>2]=g;h=e+4|0;break g}v[j+8>>2]=h;if(!g){$b(k,e,0);break e}h=v[e>>2]&-1>>>32-g;if(!h){$b(k,e,g);break e}$b(k,e,jka(h));break e}f=0;continue}f=1;continue}}break d}e=0;j=cb-16|0;cb=j;v[j+12>>2]=f;v[j+8>>2]=h;v[j+4>>2]=g;h:{if(f){e=32-f|0;v[j>>2]=e;n=-1<<f;f=v[Bb(j,j+4|0)>>2];e=n&-1>>>e-f&(v[h>>2]^-1);if(e){$b(k,h,jka(e));break h}if((f|0)==(g|0)){sN(k,j+8|0,g);break h}e=h+4|0;g=g-f|0;f=1}else{f=0}while(1){i:{if(!f){e=h;break i}j:{if(g>>>0>=32){f=v[e>>2];if((f|0)!=-1){v[j+8>>2]=h;$b(k,e,jka(f^-1));break h}g=g-32|0;v[j+4>>2]=g;h=e+4|0;break j}v[j+8>>2]=h;if(!g){$b(k,e,0);break h}h=(v[e>>2]^-1)&-1>>>32-g;if(!h){$b(k,e,g);break h}$b(k,e,jka(h));break h}f=0;continue}f=1;continue}}}cb=j+16|0;if(d){pl(i+16|0,v[l>>2],v[l+4>>2]);if(!uN(v[i+40>>2],v[i+44>>2],v[i+16>>2],v[i+20>>2])){break c}v[c>>2]=0;a=1;break a}pl(i+16|0,v[l>>2],v[l+4>>2]);if(uN(v[i+40>>2],v[i+44>>2],v[i+16>>2],v[i+20>>2])^1){kk(i+8|0,v[l>>2]);p=c,q=AQ(v[i+8>>2],v[i+12>>2],v[i+40>>2],v[i+44>>2]),v[p>>2]=q;a=1;break a}e=v[l+4>>2];if(e>>>0>=y[Sb(v[a+24>>2]+484344|0,x[Xb(v[m>>2],x[b>>1])>>1])+12>>2]){break c}v[c>>2]=e;a=1;break a}g=x[b>>1]+1|0;continue}break}u[b>>1]=65535;v[c>>2]=-1;a=0}cb=i+48|0;return a|0}function Mha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0),h=0,i=C(0);d=cb-112|0;cb=d;c=cb-16|0;cb=c;e=b+16|0;kS(c+8|0,e);f=v[c+12>>2];Yb(c,a,v[c+8>>2],f);h=v[c+4>>2];if((f|0)==(h|0)){Ob(a,v[c+12>>2])}cb=c+16|0;if((f|0)!=(h|0)){Hb(e,0,128)}t[b+79|0]=0;t[b+143|0]=0;v[b+152>>2]=-2147483648;v[b+156>>2]=-2147483648;c=d- -64|0;Td(c,a,Ag(a));f=cc(d+88|0,c);sb(c);v[22440]=0;c=T(204,f|0)|0;e=v[22440];v[22440]=0;a:{b:{if((e|0)==1){break b}v[22440]=0;R(292,b+4|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}qe(d+56|0,v[b+4>>2],v[b+8>>2]);v[22440]=0;W(472,d- -64|0,f|0,v[d+56>>2],v[d+60>>2]);c=v[22440];v[22440]=0;if((c|0)!=1){v[22440]=0;c=T(159,a|0)|0;e=v[22440];v[22440]=0;c:{if((e|0)==1){break c}v[22440]=0;U(192,d+32|0,a|0,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break c}a=d+32|0;c=cc(d- -64|0,a);sb(a);v[22440]=0;a=T(180,c|0)|0;e=v[22440];v[22440]=0;d:{if((e|0)!=1){e:{f:{if(!a){break f}while(1){g:{v[22440]=0;a=Q(158,c|0,5)|0;e=v[22440];v[22440]=0;if((e|0)==1){break e}if(!a){break f}v[22440]=0;Q(473,c|0,d+28|0)|0;a=v[22440];v[22440]=0;h:{if((a|0)!=1){a=4;if(!Mb(d+28|0,13635,4)){break h}if(!Mb(d+28|0,14203,4)){break h}v[22440]=0;a=T(159,c|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){break h}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}v[22440]=0;U(192,d+8|0,c|0,a|0);a=v[22440];v[22440]=0;i:{j:{k:{if((a|0)!=1){e=d+8|0;a=cc(d+32|0,e);sb(e);if(Mb(d+28|0,13635,4)){break k}v[22440]=0;g=C(Ba(474,a|0));a=v[22440];v[22440]=0;if((a|0)==1){break g}z[d+8>>2]=g;v[d+4>>2]=0;v[d>>2]=1065353216;g=z[pA(d+8|0,d+4|0,d)>>2];z[b+144>>2]=g;i=C(D(g));if((i<C(1.1754943508222875e-38)^-1)&(!(i>=C(N))&g==g)){break j}v[b+144>>2]=0;break j}a=P()|0;O()|0;break d}if(Mb(d+28|0,14203,4)){break j}v[22440]=0;a=T(159,a|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break i}v[b+148>>2]=a}sb(d+32|0);continue}}break}a=P()|0;O()|0;sb(d+32|0);break d}sb(c);sb(f);cb=d+112|0;return}a=P()|0;O()|0;break d}a=P()|0;O()|0}sb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}sb(f);S(a|0);L()}function oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;f=cb-32|0;cb=f;a:{b:{c:{k=v[a+12>>2];m=v[a+8>>2];d:{if((k|0)<=1&m>>>0<=805306368|(k|0)<=0){if((k|0)>=-2&m>>>0>=3489660928|(k|0)>-2){break c}if((k|0)==-2&m>>>0>2147483647|k>>>0>4294967294){break d}break b}if((k|0)==1&m>>>0>2147483648|k>>>0>1){break b}}r=b+196648|0;break a}r=b+131112|0;break a}r=b+262184|0}y=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;g=e+(f+16|0)|0;e=a+e|0;v[g>>2]=v[e+44>>2];v[g+4>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+40>>2];o=v[a+36>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;e:while(1){if(d){b=v[f+8>>2];s=(((v[f+12>>2]&2147483647)<<1|b>>>31)&-2)+y|0;b=(b>>>16&65520)+r|0;w=u[b+14>>1];p=u[b+12>>1];x=u[b+10>>1];i=u[b+8>>1];q=u[b+6>>1];g=u[b+4>>1];e=u[b+2>>1];b=u[b>>1];l=0;while(1)if((l|0)==2){z=v[a+72>>2];b=v[a+68>>2];A=b;C=b>>31;b=v[a+64>>2];j=b;l=b>>31;b=v[a+60>>2];s=b;w=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+f|0;e=v[p>>2];h=(f+16|0)+(b<<3)|0;x=v[h+4>>2];i=v[h>>2];v[h+4>>2]=i;q=e<<8;e=q;e=kka(s,w,e,e>>31);g=fb;D=h;h=e;e=Vb(i,-16777216,16776704);e=kka(j,l,e,e>>31);i=h+e|0;h=fb+g|0;h=e>>>0>i>>>0?h+1|0:h;e=Vb(x,-16777216,16776704);g=kka(A,C,e,e>>31);i=g+i|0;e=fb+h|0;e=g>>>0>i>>>0?e+1|0:e;g=i+8388608|0;e=g>>>0<8388608?e+1|0:e;e=Mc(g,e,24);v[D>>2]=e-(q&z);v[p>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;v[c>>2]=v[c>>2]+B(v[f>>2],o>>12);n=b+n|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],n>>12);Jb(f+8|0,m,k);c=c+8|0;d=d-1|0;continue e}else{j=l+s|0;v[(l<<2)+f>>2]=(((((((B(t[j-4|0],e)+B(t[j-6|0],b)|0)+B(t[j-2|0],g)|0)+B(t[j|0],q)|0)+B(i,t[j+2|0])|0)+B(x,t[j+4|0])|0)+B(p,t[j+6|0])|0)+B(w,t[j+8|0])<<8)/32768;l=l+1|0;continue}}break}c=v[f+8>>2];b=v[f+12>>2];v[a+36>>2]=o;v[a>>2]=c;v[a+4>>2]=b;v[a+40>>2]=n;v[a+20>>2]=o>>12;v[a+24>>2]=n>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}cb=f+32|0}function mJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=cb-80|0;cb=j;a:{b:{c:{d:{e:{f:{k=ap(1,28);if(!k){a=aa(4)|0;tn(a);v[22440]=0;U(121,a|0,88360,26);a=v[22440];v[22440]=0;if((a|0)!=1){break a}break f}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:952;c=Jg(j- -64|0);g:{h:{i:{if(!i){break i}while(1){d=v[i>>2];if(!d){break i}e=v[i+4>>2];j:{if(e){v[22440]=0;d=Q(56,j+48|0,d|0)|0;f=v[22440];v[22440]=0;k:{if((f|0)!=1){v[22440]=0;f=Q(963,c|0,d|0)|0;l=v[22440];v[22440]=0;if((l|0)==1){break k}v[22440]=0;Q(277,f|0,e|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break k}break j}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;rb(d);break g}v[22440]=0;d=Q(56,j+48|0,d|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break h}es(c,d)}rb(d);i=i+8|0;continue}}d=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[22440]=0;a=T(836,80)|0;i=v[22440];v[22440]=0;l:{m:{n:{if((i|0)!=1){v[j+44>>2]=d;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;b=v[k+4>>2];d=v[k>>2];v[22440]=0;b=Q(964,d|0,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break n}v[j+48>>2]=b;b=v[bp(j+24|0,j+48|0)>>2];d=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=d;v[22440]=0;d=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=d;da(965,a|0,j+8|0,b|0,c|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break m}v[k+24>>2]=a;Ae(j+48|0);gl(c);i=k;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;Ae(j+48|0)}zb(a);break g}i=V(0)|0;O()|0}gl(c);_(i|0)|0;v[22440]=0;W(958,15236,k|0,g|0,h|0);a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)==1){break f}a=v[k+24>>2];if(a){ds(a)}zb(a);i=0;v[k+24>>2]=0;a=v[k+20>>2];if(a){zb(a);v[k+20>>2]=0}zb(k);break d}i=V(0)|0;O()|0;v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;i=0;v[22440]=0;W(958,15236,0,g|0,h|0);a=v[22440];v[22440]=0;if((a|0)==1){break c}$()}cb=j+80|0;return i|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Lb()}L()}function xe(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=cb-16|0;cb=g;a:{if(hc(v[a>>2],v[a+4>>2])){break a}e=v[b+4>>2];if(e>>>0>=y[a+12>>2]){break a}d=x[b+8>>1];k=v[v[a+48>>2]+12>>2];f=Hj(k);if(d>>>0>=f>>>0&(d|0)!=65535){break a}c=(d|0)==65535;l=c?f-1|0:d;f=c?0:d;d=Zc(a,e,f);h=w[b+12|0];j=h&4;b:{c:{if(h&2){break c}i=w[b+10|0];e=d;c=f;while(1){if((c&65535)>>>0>(l&65535)>>>0){break c}d:{if(!j){if((i|0)!=w[e+3|0]){break d}break b}if((i|0)==w[e+2|0]){break b}}e=e+6|0;c=c+1|0;continue}}i=l&65535;c=d;e=f;while(1){if(i>>>0>=(e&65535)>>>0){e:{if(!j){if(w[c+3|0]){break e}t[c+3|0]=w[b+10|0];t[c+5|0]=w[b+11|0];break b}if(w[c+2|0]){break e}t[c+2|0]=w[b+10|0];t[c+4|0]=w[b+11|0];break b}c=c+6|0;e=e+1|0;continue}break}f:{if(!(h&1)){break f}c=v[k+480180>>2]&2;i=b;g:{h:{i:{if(!j){while(1){if((f&65535)>>>0<=(l&65535)>>>0){j:{k:{switch(w[d+3|0]-9|0){case 4:if(!tT(v[v[k+8>>2]+88>>2])){break j}c=1;t[d+2|0]=1;t[d+4|0]=w[d+5|0];t[d+3|0]=w[b+10|0];t[d+5|0]=w[b+11|0];break a;case 0:break k;default:break j}}l:{if(c){e=w[d+5|0];if(e>>>0>128){break j}t[d+2|0]=2;t[d+3|0]=w[b+10|0];a=1;break l}t[d+2|0]=2;t[d+3|0]=w[b+10|0];e=w[d+5|0];a=2}t[d+4|0]=a+e>>>a;t[d+5|0]=w[b+11|0];break b}d=d+6|0;f=f+1|0;continue}break}if(!j){break i}}e=w[b+11|0];f=13;m:{switch(w[b+10|0]-1|0){case 1:f=9;e=El(B(c?2:4,e));break;case 0:break m;default:break g}}t[b+11|0]=e;t[b+10|0]=f;f=h&254;break h}t[g+15|0]=0;t[g+14|0]=0;f=!c;c=w[b+10|0];n:{if(!(f|(c|0)!=9)){e=w[b+11|0];if(e>>>0>128){break g}c=2;f=e>>>1|0;break n}e=g+8|0;uq(e,c,w[b+11|0],1);dB(g,g+15|0,g+14|0);cB(g,e);c=w[g+15|0];if(!c){h=w[b+12|0];break g}h=w[b+12|0];f=w[g+14|0]}t[b+11|0]=f;t[b+10|0]=c;f=h&254}h=f;t[i+12|0]=h}c=1;if(h&1){break f}t[b+12|0]=h^4;if(xe(a,b)){break a}}c=0;o:{p:{switch(v[b>>2]-1|0){case 0:d=v[b+4>>2]+1|0;if(d>>>0>=y[a+12>>2]){break a}v[b+4>>2]=d;break o;case 1:break p;default:break a}}d=v[b+4>>2];if(!d){break a}v[b+4>>2]=d-1}t[b+12|0]=w[b+12|0]|1;c=xe(a,b);break a}c=1}cb=g+16|0;return c}function KF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=v[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!d){break k}h=v[d>>2];if(!h){break k}if(!a){g=c;break j}v[d>>2]=0;g=c;break i}l:{if(!v[v[114924]>>2]){if(!a){break l}if(!c){break a}d=c;while(1){g=t[e|0];if(g){v[a>>2]=g&57343;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}v[a>>2]=0;v[b>>2]=0;return c-d|0}if(!a){g=c;d=0;break g}g=c;d=0;break h}return Rg(e)}d=1;break g}d=1}while(1){if(!d){if(!g){break a}while(1){m:{f=w[e|0];h=f-1|0;n:{o:{if(h>>>0>126){d=f;break o}if(e&3|g>>>0<5){break n}p:{while(1){d=v[e>>2];if((d|d-16843009)&-2139062144){break p}v[a>>2]=d&255;v[a+4>>2]=w[e+1|0];v[a+8>>2]=w[e+2|0];v[a+12>>2]=w[e+3|0];a=a+16|0;e=e+4|0;g=g-4|0;if(g>>>0>4){continue}break}d=w[e|0]}f=d&255;h=f-1|0}if(h>>>0>126){break m}}v[a>>2]=f;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;h=v[(f<<2)+79488>>2];d=1;continue}d=w[e|0];f=d>>>3|0;if((f-16|f+(h>>26))>>>0>7){break f}q:{r:{f=e+1|0;d=d-128|h<<6;s:{if((d|0)>=0){break s}i=w[f|0]-128|0;if(i>>>0>63){break r}f=e+2|0;d=i|d<<6;if((d|0)>=0){break s}f=w[f|0]-128|0;if(f>>>0>63){break r}d=f|d<<6;f=e+3|0}e=f;v[a>>2]=d;g=g-1|0;a=a+4|0;break q}v[114922]=25;e=e-1|0;break c}d=0;continue}}while(1){t:{if(!d){u:{v:{d=w[e|0];if(!(e&3|d-1>>>0>126)){d=v[e>>2];if(!((d|d-16843009)&-2139062144)){break v}}f=e;break u}while(1){g=g-4|0;d=v[e+4>>2];f=e+4|0;e=f;if(!((d-16843009|d)&-2139062144)){continue}break}}e=d&255;if(e-1>>>0<=126){e=f+1|0;g=g-1|0;break t}h=e-194|0;if(h>>>0>50){e=f;break e}e=f+1|0;h=v[(h<<2)+79488>>2];d=1;continue}d=w[e|0]>>>3|0;if((d-16|d+(h>>26))>>>0>7){break f}d=e+1|0;w:{if(!(h&33554432)){break w}if((w[d|0]&192)!=128){e=e-1|0;break d}d=e+2|0;if(!(h&524288)){break w}if((w[d|0]&192)!=128){e=e-1|0;break d}d=e+3|0}e=d;g=g-1|0}d=0;continue}}e=e-1|0;if(h){break d}d=w[e|0]}if(d&255){break d}if(a){v[a>>2]=0;v[b>>2]=0}return c-g|0}v[114922]=25;if(!a){break b}}v[b>>2]=e}return-1}v[b>>2]=e;return c}function jl(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Db(a);d=vb(c);v[22440]=0;R(47,a|0,d|0);d=v[22440];v[22440]=0;d:{if((d|0)!=1){e:{while(1){if(vb(c)>>>0>b>>>0){d=v[hk(c,b)>>2];f:{if(d>>>0<=127){v[22440]=0;R(48,a|0,d<<24>>24);d=v[22440];v[22440]=0;if((d|0)!=1){break f}break e}v[22440]=0;R(48,a|0,63);d=v[22440];v[22440]=0;if((d|0)==1){break e}}b=b+1|0;continue}break}break d}}break a}return;case 2:b=0;a=Db(a);d=vb(c);v[22440]=0;R(47,a|0,d|0);d=v[22440];v[22440]=0;g:{if((d|0)!=1){h:{while(1){if(vb(c)>>>0>b>>>0){d=v[hk(c,b)>>2];i:{if(d>>>0<=255){v[22440]=0;R(48,a|0,d<<24>>24);d=v[22440];v[22440]=0;if((d|0)!=1){break i}break h}v[22440]=0;R(48,a|0,63);d=v[22440];v[22440]=0;if((d|0)==1){break h}}b=b+1|0;continue}break}break g}}break a}return;case 3:Np(a,c,49696);return;case 5:Np(a,c,50720);return;case 4:Np(a,c,51744);return;case 6:Np(a,c,52768);return;default:a=aa(8)|0;v[22440]=0;Q(46,a|0,11075)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;ba(a|0);S(b|0);L();case 0:break c}}e=cb-16|0;cb=e;f=Db(a);j:{while(1){k:{l:{m:{n:{if(vb(c)>>>0>g>>>0){b=v[hk(c,g)>>2];if(b>>>0>=2097152){v[22440]=0;R(48,f|0,63);a=v[22440];v[22440]=0;if((a|0)!=1){break l}break k}a=0;while(1){if((a|0)==6){b=7;a=6;break m}d=b&63;t[(e+10|0)+a|0]=d;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(!a){v[22440]=0;R(48,f|0,t[e+10|0]);break n}b=a+1|0;if((b|0)!=2){break m}a=1;b=2;if((d|0)!=1){break m}v[22440]=0;R(48,f|0,t[e+10|0]|64);break n}cb=e+16|0;break j}a=v[22440];v[22440]=0;if((a|0)!=1){break l}break k}i=(-1<<b^-1)<<7-a;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){if(!a){break l}o:{if((a|0)==(b|0)){a=w[j|0];v[22440]=0;R(48,f|0,(a|i)<<24>>24);h=v[22440];v[22440]=0;a=d;break o}v[22440]=0;a=a-1|0;R(48,f|0,t[a+(e+10|0)|0]|-128);h=v[22440];v[22440]=0}if((h|0)!=1){continue}break}break k}g=g+1|0;continue}break}a=P()|0;O()|0;rb(f);S(a|0);L()}return}ia(a|0,88480,25);L()}b=P()|0;O()|0;rb(a);S(b|0);L()}function WN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;c=cb-176|0;cb=c;f=v[a+12>>2];i=1<<f;a:{if(!(f&1)){i=i>>>2|0;h=1;break a}k=i>>>1|0;f=0;while(1){if((f|0)==(k|0)){i=i>>>3|0;h=2;f=v[a+12>>2]}else{j=v[b>>2];d=f+k|0;h=sd(j,d);e=sd(j,f);l=A[h>>3];m=A[h+8>>3];ij(c+160|0,e,l,m);h=sd(v[b>>2],d);j=v[c+172>>2];v[h+8>>2]=v[c+168>>2];v[h+12>>2]=j;j=v[c+164>>2];v[h>>2]=v[c+160>>2];v[h+4>>2]=j;Rx(sd(v[b>>2],f),l,m);f=f+1|0;continue}break}}j=f&-2;b:while(1){if(j){u=B(i,3);w=i<<1;k=0;c:while(1){if((h|0)==(k|0)){j=j-2|0;i=i>>>2|0;h=h<<2;continue b}d=v[a>>2];f=sd(d,k<<1);d=sd(d,k);l=A[d>>3];m=A[d+8>>3];p=A[f>>3];q=A[f+8>>3];xi(c+160|0,l,m,p,q);f=k<<j;d=i+f|0;x=d>>>0<f>>>0?f:d;while(1)if((f|0)==(x|0)){k=k+1|0;continue c}else{g=v[b>>2];d=sd(g,f);e=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=e;e=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=e;e=c+128|0;r=f+i|0;d=sd(g,r);xi(e,p,q,A[d>>3],A[d+8>>3]);s=f+w|0;d=sd(v[b>>2],s);xi(c+112|0,l,m,A[d>>3],A[d+8>>3]);y=A[c+160>>3];z=A[c+168>>3];t=f+u|0;d=sd(v[b>>2],t);xi(c+96|0,y,z,A[d>>3],A[d+8>>3]);g=c+80|0;d=c+144|0;al(g,d,A[c+112>>3],A[c+120>>3]);n=c- -64|0;ij(n,d,A[c+112>>3],A[c+120>>3]);al(c+48|0,e,A[c+96>>3],A[c+104>>3]);d=c+16|0;lm(d,-0,-1);ij(c,e,A[c+96>>3],A[c+104>>3]);xi(c+32|0,A[c+16>>3],A[c+24>>3],A[c>>3],A[c+8>>3]);al(d,g,A[c+48>>3],A[c+56>>3]);e=sd(v[b>>2],f);o=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=o;o=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=o;ij(d,g,A[c+48>>3],A[c+56>>3]);e=sd(v[b>>2],r);g=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=g;g=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=g;al(d,n,A[c+32>>3],A[c+40>>3]);e=sd(v[b>>2],s);g=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=g;g=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=g;ij(d,n,A[c+32>>3],A[c+40>>3]);d=sd(v[b>>2],t);e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;f=f+1|0;continue}}}break}cb=c+176|0}function e4(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),k=0,m=C(0),n=0,o=0;d=cb-16|0;cb=d;a:{b:{c:{d:{switch(b-1|0){case 0:c=z[a+48>>2];a=v[a+48>>2];e:{f:{g:{if((a|0)<=8388607){e=C(C(-1)/C(c*c));if(!(a&2147483647)){break e}e=C(C(c-c)/C(0));if((a|0)<0){break e}a=(p(C(c*C(33554432))),j(2));b=-152;break g}if(a>>>0>2139095039){break f}b=-127;c=C(0);if((a|0)==1065353216){break f}}a=a+4913933|0;m=C((a>>>23|0)+b|0);c=C((l(2,(a&8388607)+1060439283|0),q())+C(-1));f=C(c*C(c*C(.5)));g=C(c/C(c+C(2)));h=C(g*g);i=C(h*h);e=c;c=(l(2,(p(C(c-f)),j(2))&-4096),q());f=C(C(g*C(f+C(C(h*C(C(i*C(.2849878668785095))+C(.6666666269302368)))+C(i*C(C(i*C(.24279078841209412))+C(.40000972151756287))))))+C(C(e-c)-f));c=C(C(m*C(.3010292053222656))+C(C(c*C(.434326171875))+C(C(f*C(.434326171875))+C(C(m*C(7.903415166765626e-7))+C(C(f+c)*C(-3168997136526741e-20))))))}e=c}c=C(e*C(2e3));if(!(C(D(c))<C(2147483648))){break c}a=~~c;break b;case 1:a=(B(v[v[a+24>>2]+24604>>2],100)|0)/128|0;break b;case 2:b=cb-16|0;cb=b;h:{i:{j:{k:{a=w[v[a+24>>2]+24648|0];if(a>>>0>=6){a=aa(8)|0;v[22440]=0;b=Q(56,b|0,5126)|0;d=v[22440];v[22440]=0;if((d|0)==1){break k}oc(a,b);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break i}d=P()|0;O()|0;rb(b);break j}cb=b+16|0;a=v[(a<<24>>24<<2)+58456>>2];break h}d=P()|0;O()|0;ba(a|0)}S(d|0)}L()}break b;case 3:v[d>>2]=0;b=cb-80|0;cb=b;k=v[a+24>>2]+24604|0;a=v[k+32>>2];v[b+40>>2]=a;v[b>>2]=v[k+36>>2];n=b+40|0;o=v[Ke(n,b)>>2];l:{if(v[Op(n)+32>>2]==(a|0)){a=-1;if(v[k+36>>2]==v[Op(b)+36>>2]){break l}}a=0;if((o|0)<=0){break l}a=(o+500>>>0)/1e3|0}v[d>>2]=a;cb=b+80|0;a=v[d>>2];break b;default:break d}}a=aa(8)|0;v[22440]=0;d=Q(56,d|0,10404)|0;b=v[22440];v[22440]=0;m:{if((b|0)!=1){oc(a,d);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}b=P()|0;O()|0;rb(d);break m}b=P()|0;O()|0;ba(a|0)}S(b|0);L()}a=-2147483648}cb=d+16|0;return a|0}L()}function zja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;d=cb-1120|0;cb=d;v[d+1116>>2]=c;i=iB(d+56|0,b);q=lq(i);e=Rb(a);v[22440]=0;a=T(204,b|0)|0;c=v[22440];v[22440]=0;a:{if((c|0)!=1){v[d+16>>2]=a;v[d+48>>2]=85899345;s=d,z=B(v[Bb(d+16|0,d+48|0)>>2],50),v[s+32>>2]=z;a=v[Bb(d+1116|0,d+32|0)>>2];v[22440]=0;R(331,e|0,a|0);a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;h=T(343,d+32|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;f=Q(344,d+16|0,8192)|0;a=v[22440];v[22440]=0;b:{if((a|0)!=1){c=v[h>>2];a=0;while(1){if((a|0)!=256){g=Ib(c,a);t[g+2|0]=a;u[g>>1]=8192;a=a+1|0;continue}break}l=9;c:{d:while(1){g=0;m=257;while(1){r=l&255;e:{while(1){j=m&65535;while(1){v[22440]=0;n=Q(166,i|0,r|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break c}k=n&65535;if((k|0)==257|j>>>0<k>>>0){break e}if(Uc(v[e>>2],v[e+4>>2])>>>0>=y[d+1116>>2]){break e}if((k|0)==256){l=9;continue d}a=j>>>0>k>>>0?n:g;c=v[h>>2];p=8192;while(1){a=a&65535;c=Ib(c,a);p=p-1|0;o=p&65535;s=Eb(v[f>>2],o),z=w[c+2|0],t[s|0]=z;c=v[h>>2];a=x[Ib(c,a)>>1];if(a>>>0<8192){continue}break}ac(d+8|0,yb(v[e+4>>2]));s=d,z=yb(v[f>>2]),v[s+48>>2]=z;a=je(d+48|0,o);c=yb(v[f+4>>2]);v[22440]=0;W(332,e|0,v[d+8>>2],a|0,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break c}f:{if((j|0)!=(k|0)){break f}a=v[f>>2];v[22440]=0;R(345,e|0,Eb(a,o)|0);a=v[22440];v[22440]=0;if((a|0)!=1){break f}break c}if(j>>>0>=8192){g=n;continue}if(Uc(v[e>>2],v[e+4>>2])>>>0>=y[d+1116>>2]){continue}break}a=w[Eb(v[f>>2],o)|0];c=Ib(v[h>>2],j);u[c>>1]=g;t[c+2|0]=a;a=m+1|0;m=8192;g=n;c=a&65535;if((c|0)==8192){continue}break}l=((c|0)==1<<r)+l|0;m=a;continue}break}break}a=lq(i);v[22440]=0;Q(157,b|0,((a-q|0)+3&-4)+q|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break c}_b(f);fc(h);sb(i);cb=d+1120|0;return}a=P()|0;O()|0;_b(f);break b}a=P()|0;O()|0}fc(h);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}_b(e);sb(i);S(a|0);L()}
function s6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=0,h=C(0),i=C(0),j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=C(0),t=0,u=0,w=0,x=0,y=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=C(0),L=C(0),M=C(0),N=C(0),O=C(0),P=C(0);n=a+44|0;if(Yh(n)){y=Ud(n,0);A=Ud(n,1);B=jd(n,0);D=jd(n,1);o=v[a+4300>>2];l=o+v[a+4292>>2]|0;f=v[a+4288>>2]+o|0;k=a+4304|0;q=v[a+4296>>2];j=q+1|0;t=j+v[a+4272>>2]&4095;m=k+(t<<4)|0;u=j+v[a+4284>>2]&4095;g=((u<<4)+k|0)+12|0;w=j+v[a+4280>>2]&4095;r=((w<<4)+k|0)+8|0;x=j+v[a+4276>>2]&4095;F=((x<<4)+k|0)+4|0;G=a+69840|0;H=a+78032|0;E=d;while(1){if(E){t=t-1&4095;j=(t<<4)+k|0;e=z[j>>2];I=f&1023;f=(I<<3)+G|0;p=z[f+4>>2];K=z[g>>2];L=z[r>>2];M=z[F>>2];N=z[m>>2];O=z[A>>2];P=z[y>>2];x=x-1&4095;m=(x<<4)+k|0;i=z[m+4>>2];s=z[a+4232>>2];h=C(C(i*C(.6180340051651001))+C(z[f>>2]*s));g=o<<3;f=g+G|0;z[f+4>>2]=i+C(h*C(-.6180340051651001));i=e;e=C(C(p*s)+C(e*C(-.6180340051651001)));z[f>>2]=i+C(e*C(.6180340051651001));z[j>>2]=h;z[m+4>>2]=e;J=l&1023;r=(J<<3)+H|0;p=z[r+4>>2];w=w-1&4095;f=(w<<4)+k|0;h=z[f+8>>2];u=u-1&4095;l=(u<<4)+k|0;i=z[l+12>>2];s=z[a+4236>>2];e=C(C(i*C(.6180340051651001))+C(z[r>>2]*s));g=g+H|0;z[g+4>>2]=i+C(e*C(-.6180340051651001));i=h;h=C(C(p*s)+C(h*C(-.6180340051651001)));z[g>>2]=i+C(h*C(.6180340051651001));z[f+8>>2]=e;z[l+12>>2]=h;h=e;e=C(P+C(1.0000000031710769e-30));z[B>>2]=h+C(C(e*z[a+4224>>2])+z[j>>2]);h=C(O+C(1.0000000031710769e-30));z[D>>2]=C(C(h*z[a+4224>>2])+z[m+4>>2])+z[l+12>>2];g=(q<<4)+k|0;i=e;e=z[a+4228>>2];p=C(i*e);z[g>>2]=p+C(C(z[j>>2]*z[a+4240>>2])+C(N*z[a+4244>>2]));e=C(h*e);z[g+4>>2]=e+C(C(z[m+4>>2]*z[a+4248>>2])+C(M*z[a+4252>>2]));z[g+8>>2]=C(C(z[f+8>>2]*z[a+4256>>2])+C(L*z[a+4260>>2]))-e;z[g+12>>2]=p+C(C(z[l+12>>2]*z[a+4264>>2])+C(K*z[a+4268>>2]));g=l+12|0;r=f+8|0;F=m+4|0;E=E-1|0;l=J-1|0;f=I-1|0;D=D+4|0;B=B+4|0;A=A+4|0;y=y+4|0;o=o-1&1023;q=q-1&4095;m=j;continue}else{v[a+4300>>2]=o;v[a+4296>>2]=q;ti(a,b,c,jd(n,0),jd(n,1),d)}break}}}function R_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=cb-16|0;cb=j;k=tw(g);o=_v(g);Zg(j,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[22440]=0;g=Q(1177,k|0,g<<24>>24)|0;i=v[22440];v[22440]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[22440]=0;g=Q(1177,k|0,48)|0;h=v[22440];v[22440]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;g=t[i+1|0];v[22440]=0;g=Q(1177,k|0,g|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];pd();if(!ZF(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];pd();if(!Yj(h)){break d}g=g+1|0;continue}}e:{if(xd(j)){h=v[f>>2];v[22440]=0;W(1171,k|0,i|0,g|0,h|0);h=v[22440];v[22440]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i<<2);break e}Nl(i,g);v[22440]=0;q=T(1169,o|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){pr((i-a<<2)+d|0,v[f>>2]);break e}f:{if(t[rc(j,l)|0]<=0){break f}if(t[rc(j,l)|0]!=(m|0)){break f}m=v[f>>2];v[f>>2]=m+4;v[m>>2]=q;l=(vb(j)-1>>>0>l>>>0)+l|0;m=0}p=t[h|0];v[22440]=0;p=Q(1177,k|0,p|0)|0;n=v[22440];v[22440]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+4;v[n>>2]=p;h=h+1|0;m=m+1|0;continue}break}break a}g:{while(1){if(c>>>0>g>>>0){i=w[g|0];if((i|0)==46){v[22440]=0;i=T(1172,o|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break a}l=v[f>>2];h=l+4|0;v[f>>2]=h;v[l>>2]=i;g=g+1|0;break g}v[22440]=0;i=Q(1177,k|0,i<<24>>24)|0;h=v[22440];v[22440]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=i;g=g+1|0;continue}break}h=v[f>>2]}v[22440]=0;W(1171,k|0,g|0,c|0,h|0);i=v[22440];v[22440]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g<<2)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;rb(j);cb=j+16|0;return}a=P()|0;O()|0;rb(j);S(a|0);L()}function Ir(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Hd(b)}if(b>>>0>=4294967232){v[114922]=48;return 0}e=b>>>0<11?16:b+11&-8;h=a-4|0;i=v[h>>2];c=i&-8;a:{b:{if(!(i&3)){if(e>>>0<256|c>>>0<(e|4)>>>0){break b}if(c-e>>>0<=v[115045]<<1>>>0){break a}break b}g=a-8|0;f=c+g|0;if(c>>>0>=e>>>0){b=c-e|0;if(b>>>0<16){break a}v[h>>2]=i&1|e|2;c=e+g|0;v[c+4>>2]=b|3;v[f+4>>2]=v[f+4>>2]|1;KG(c,b);return a}if(v[114931]==(f|0)){c=c+v[114928]|0;if(c>>>0<=e>>>0){break b}v[h>>2]=i&1|e|2;b=e+g|0;c=c-e|0;v[b+4>>2]=c|1;v[114928]=c;v[114931]=b;return a}if(v[114930]==(f|0)){c=c+v[114927]|0;if(c>>>0<e>>>0){break b}b=c-e|0;c:{if(b>>>0>=16){v[h>>2]=i&1|e|2;d=e+g|0;v[d+4>>2]=b|1;c=c+g|0;v[c>>2]=b;v[c+4>>2]=v[c+4>>2]&-2;break c}v[h>>2]=c|i&1|2;b=c+g|0;v[b+4>>2]=v[b+4>>2]|1;b=0}v[114930]=d;v[114927]=b;return a}d=v[f+4>>2];if(d&2){break b}j=c+(d&-8)|0;if(j>>>0<e>>>0){break b}l=j-e|0;d:{if(d>>>0<=255){b=v[f+8>>2];d=d>>>3|0;c=v[f+12>>2];if((c|0)==(b|0)){n=459700,o=v[114925]&oka(-2,d),v[n>>2]=o;break d}v[b+12>>2]=c;v[c+8>>2]=b;break d}k=v[f+24>>2];c=v[f+12>>2];e:{if((f|0)!=(c|0)){b=v[f+8>>2];v[b+12>>2]=c;v[c+8>>2]=b;break e}f:{b=f+20|0;d=v[b>>2];if(d){break f}b=f+16|0;d=v[b>>2];if(d){break f}c=0;break e}while(1){m=b;c=d;b=c+20|0;d=v[b>>2];if(d){continue}b=c+16|0;d=v[c+16>>2];if(d){continue}break}v[m>>2]=0}if(!k){break d}b=v[f+28>>2];d=(b<<2)+460004|0;g:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break g}n=459704,o=v[114926]&oka(-2,b),v[n>>2]=o;break d}v[(v[k+16>>2]==(f|0)?16:20)+k>>2]=c;if(!c){break d}}v[c+24>>2]=k;b=v[f+16>>2];if(b){v[c+16>>2]=b;v[b+24>>2]=c}b=v[f+20>>2];if(!b){break d}v[c+20>>2]=b;v[b+24>>2]=c}if(l>>>0<=15){v[h>>2]=i&1|j|2;b=g+j|0;v[b+4>>2]=v[b+4>>2]|1;return a}v[h>>2]=i&1|e|2;b=e+g|0;v[b+4>>2]=l|3;c=g+j|0;v[c+4>>2]=v[c+4>>2]|1;KG(b,l);return a}c=Hd(b);if(!c){return 0}d=v[h>>2];d=(d&3?-4:-8)+(d&-8)|0;ic(c,a,b>>>0>d>>>0?d:b);zb(a);a=c}return a}function rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0;f=cb-32|0;cb=f;a:{b:{c:{k=v[a+12>>2];m=v[a+8>>2];d:{if((k|0)<=1&m>>>0<=805306368|(k|0)<=0){if((k|0)>=-2&m>>>0>=3489660928|(k|0)>-2){break c}if((k|0)==-2&m>>>0>2147483647|k>>>0>4294967294){break d}break b}if((k|0)==1&m>>>0>2147483648|k>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}t=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;g=e+(f+16|0)|0;e=a+e|0;v[g>>2]=v[e+44>>2];v[g+4>>2]=v[e+48>>2];b=b+1|0;continue}break}w=v[a+24>>2];x=v[a+20>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;e:while(1){if(d){b=v[f+8>>2];q=((((v[f+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=(b>>>16&65520)+p|0;r=u[b+14>>1];n=u[b+12>>1];s=u[b+10>>1];i=u[b+8>>1];o=u[b+6>>1];g=u[b+4>>1];e=u[b+2>>1];b=u[b>>1];l=0;while(1)if((l|0)==2){y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];j=b;l=b>>31;b=v[a+60>>2];q=b;r=b>>31;b=0;while(1){if((b|0)!=2){n=(b<<2)+f|0;e=v[n>>2];h=(f+16|0)+(b<<3)|0;s=v[h+4>>2];i=v[h>>2];v[h+4>>2]=i;o=e<<8;e=o;e=kka(q,r,e,e>>31);g=fb;C=h;h=e;e=Vb(i,-16777216,16776704);e=kka(j,l,e,e>>31);i=h+e|0;h=fb+g|0;h=e>>>0>i>>>0?h+1|0:h;e=Vb(s,-16777216,16776704);g=kka(z,A,e,e>>31);i=g+i|0;e=fb+h|0;e=g>>>0>i>>>0?e+1|0:e;g=i+8388608|0;e=g>>>0<8388608?e+1|0:e;e=Mc(g,e,24);v[C>>2]=e-(o&y);v[n>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],x);v[c+4>>2]=v[c+4>>2]+B(w,v[f+4>>2]);Jb(f+8|0,m,k);c=c+8|0;d=d-1|0;continue e}else{j=q+(l<<1)|0;v[(l<<2)+f>>2]=(((((((B(u[j-8>>1],e)+B(u[j-12>>1],b)|0)+B(u[j-4>>1],g)|0)+B(u[j>>1],o)|0)+B(i,u[j+4>>1])|0)+B(s,u[j+8>>1])|0)+B(n,u[j+12>>1])|0)+B(r,u[j+16>>1])|0)/32768;l=l+1|0;continue}}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}cb=f+32|0}function ti(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0),o=C(0),p=C(0),q=0,r=C(0);m=gb[v[v[a>>2]+136>>2]](a)|0;h=v[a+20>>2];g=m?g:w[h+25|0];j=z[h+144>>2];k=C(1);if(!(gb[v[v[a>>2]+136>>2]](a)|0)){k=z[v[a+20>>2]+144>>2]}j=C(C(1)-j);a:{if((gb[v[v[a>>2]+152>>2]](a)|0)<=0){break a}if(!eK(v[a+20>>2])){break a}j=C(C(j+j)+C(-1));k=C(-j)}n=z[a+4196>>2];k=C(k*n);j=C(j*n);h=0;l=a+44|0;m=Ud(l,0);l=Ud(l,1);b:{c:{switch(g|0){case 0:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]+C(C(z[d+g>>2]*j)+C(k*z[g+m>>2]));i=c+g|0;z[i>>2]=z[i>>2]+C(C(z[e+g>>2]*j)+C(k*z[g+l>>2]));h=h+1|0;continue};case 1:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]+C(z[g+m>>2]-C(z[d+g>>2]*j));i=c+g|0;z[i>>2]=z[i>>2]+C(z[g+l>>2]-C(z[e+g>>2]*j));h=h+1|0;continue};case 2:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]+C(z[d+g>>2]-C(z[g+m>>2]*k));i=c+g|0;z[i>>2]=z[i>>2]+C(z[e+g>>2]-C(z[g+l>>2]*k));h=h+1|0;continue};case 3:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]-C(z[d+g>>2]-C(z[g+m>>2]*j));i=c+g|0;z[i>>2]=z[i>>2]-C(z[e+g>>2]-C(z[g+l>>2]*j));h=h+1|0;continue};case 4:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;k=z[i>>2];q=i;r=k;n=z[g+m>>2];i=c+g|0;o=z[i>>2];p=z[g+l>>2];k=C(C(C(C(k+n)+o)+p)*C(.5));z[q>>2]=r-C(C(k+C(k-C(z[d+g>>2]*j)))-n);z[i>>2]=o-C(C(k+C(k-C(z[e+g>>2]*j)))-p);h=h+1|0;continue};case 5:break c;default:break b}}h=eK(v[a+20>>2]);j=h?C(j*C(.5)):j;k=h?C(k*C(.5)):k;g=0;while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;n=C(z[d+h>>2]-z[h+m>>2]);o=C(z[h+l>>2]-z[e+h>>2]);z[i>>2]=z[i>>2]+C(C(j*n)+C(k*o));h=c+h|0;z[h>>2]=z[h>>2]+C(C(k*n)+C(j*o));g=g+1|0;continue}}d:{if(!((w[v[a+20>>2]+24|0]&4)>>>2|0)){break d}if(gb[v[v[a>>2]+136>>2]](a)|0){break d}h=0;while(1){if((f|0)==(h|0)){break d}a=h<<2;d=a+b|0;z[d>>2]=z[a+m>>2]+z[d>>2];d=a+c|0;z[d>>2]=z[a+l>>2]+z[d>>2];h=h+1|0;continue}}}function $_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=cb-16|0;cb=j;k=Vu(g);o=dw(g);Zg(j,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[22440]=0;g=Q(20,k|0,g<<24>>24)|0;i=v[22440];v[22440]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[22440]=0;g=Q(20,k|0,48)|0;h=v[22440];v[22440]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;g=t[i+1|0];v[22440]=0;g=Q(20,k|0,g|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];pd();if(!ZF(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];pd();if(!Yj(h)){break d}g=g+1|0;continue}}e:{if(xd(j)){h=v[f>>2];v[22440]=0;W(1157,k|0,i|0,g|0,h|0);h=v[22440];v[22440]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i|0);break e}Nl(i,g);v[22440]=0;q=T(1155,o|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){Nl((i-a|0)+d|0,v[f>>2]);break e}f:{if(t[rc(j,m)|0]<=0){break f}if(t[rc(j,m)|0]!=(l|0)){break f}l=v[f>>2];v[f>>2]=l+1;t[l|0]=q;m=(vb(j)-1>>>0>m>>>0)+m|0;l=0}p=t[h|0];v[22440]=0;p=Q(20,k|0,p|0)|0;n=v[22440];v[22440]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+1;t[n|0]=p;h=h+1|0;l=l+1|0;continue}break}break a}while(1){g:{if(c>>>0>g>>>0){i=w[g|0];if((i|0)!=46){break g}v[22440]=0;i=T(1158,o|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0}i=v[f>>2];v[22440]=0;W(1157,k|0,g|0,c|0,i|0);i=v[22440];v[22440]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g|0)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;rb(j);cb=j+16|0;return}v[22440]=0;i=Q(20,k|0,i<<24>>24)|0;h=v[22440];v[22440]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0;continue}}a=P()|0;O()|0;rb(j);S(a|0);L()}function sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;f=cb-32|0;cb=f;a:{b:{c:{k=v[a+12>>2];m=v[a+8>>2];d:{if((k|0)<=1&m>>>0<=805306368|(k|0)<=0){if((k|0)>=-2&m>>>0>=3489660928|(k|0)>-2){break c}if((k|0)==-2&m>>>0>2147483647|k>>>0>4294967294){break d}break b}if((k|0)==1&m>>>0>2147483648|k>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}w=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;g=e+(f+16|0)|0;e=a+e|0;v[g>>2]=v[e+44>>2];v[g+4>>2]=v[e+48>>2];b=b+1|0;continue}break}x=v[a+24>>2];y=v[a+20>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;e:while(1){if(d){b=v[f+8>>2];q=(((v[f+12>>2]&2147483647)<<1|b>>>31)&-2)+w|0;b=(b>>>16&65520)+p|0;r=u[b+14>>1];n=u[b+12>>1];s=u[b+10>>1];i=u[b+8>>1];o=u[b+6>>1];g=u[b+4>>1];e=u[b+2>>1];b=u[b>>1];l=0;while(1)if((l|0)==2){z=v[a+72>>2];b=v[a+68>>2];A=b;C=b>>31;b=v[a+64>>2];j=b;l=b>>31;b=v[a+60>>2];q=b;r=b>>31;b=0;while(1){if((b|0)!=2){n=(b<<2)+f|0;e=v[n>>2];h=(f+16|0)+(b<<3)|0;s=v[h+4>>2];i=v[h>>2];v[h+4>>2]=i;o=e<<8;e=o;e=kka(q,r,e,e>>31);g=fb;D=h;h=e;e=Vb(i,-16777216,16776704);e=kka(j,l,e,e>>31);i=h+e|0;h=fb+g|0;h=e>>>0>i>>>0?h+1|0:h;e=Vb(s,-16777216,16776704);g=kka(A,C,e,e>>31);i=g+i|0;e=fb+h|0;e=g>>>0>i>>>0?e+1|0:e;g=i+8388608|0;e=g>>>0<8388608?e+1|0:e;e=Mc(g,e,24);v[D>>2]=e-(o&z);v[n>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],y);v[c+4>>2]=v[c+4>>2]+B(x,v[f+4>>2]);Jb(f+8|0,m,k);c=c+8|0;d=d-1|0;continue e}else{j=l+q|0;v[(l<<2)+f>>2]=(((((((B(t[j-4|0],e)+B(t[j-6|0],b)|0)+B(t[j-2|0],g)|0)+B(t[j|0],o)|0)+B(i,t[j+2|0])|0)+B(s,t[j+4|0])|0)+B(n,t[j+6|0])|0)+B(r,t[j+8|0])<<8)/32768;l=l+1|0;continue}}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}cb=f+32|0}function A5(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=cb-48|0;cb=k;a:{b:{c:{j=ap(1,32);d:{e:{if(!j){a=aa(4)|0;tn(a);v[22440]=0;U(121,a|0,88360,26);a=v[22440];v[22440]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:952;c=Jg(k+32|0);f:{g:{h:{if(!i){break h}while(1){d=v[i>>2];if(!d){break h}e=v[i+4>>2];i:{if(e){v[22440]=0;d=Q(56,k+16|0,d|0)|0;f=v[22440];v[22440]=0;j:{if((f|0)!=1){v[22440]=0;f=Q(963,c|0,d|0)|0;l=v[22440];v[22440]=0;if((l|0)==1){break j}v[22440]=0;Q(277,f|0,e|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;rb(d);break f}v[22440]=0;d=Q(56,k+16|0,d|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break g}es(c,d)}rb(d);i=i+8|0;continue}}v[22440]=0;d=T(836,96)|0;e=v[22440];v[22440]=0;k:{l:{m:{if((e|0)!=1){e=v[j+4>>2];f=v[j>>2];v[22440]=0;e=Q(964,f|0,e|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break m}v[k+16>>2]=e;e=v[bp(k+8|0,k+16|0)>>2];v[22440]=0;ea(995,d|0,a|0,b|0,e|0,c|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break l}v[j+28>>2]=d;Ae(k+16|0);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;gl(c);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;Ae(k+16|0)}zb(d);break f}i=V(0)|0;O()|0}gl(c);_(i|0)|0;v[22440]=0;W(958,4976,j|0,g|0,h|0);a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)!=1){a=v[j+28>>2];if(a){gb[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){zb(a);v[j+20>>2]=0}zb(j);j=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)==1){break b}}_(i|0)|0;j=0;v[22440]=0;W(958,4976,0,g|0,h|0);a=v[22440];v[22440]=0;if((a|0)==1){break c}$()}cb=k+48|0;return j|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Lb()}L()}function U5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=cb-96|0;cb=e;a:{if(xd(c)){break a}f=w[OI(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+80|0;wv(f,c,0,vb(c)-1|0);tc(c,f);rb(f)}f=e+80|0;Od(f);g=v[e+80>>2];Od(e+72|0);g=NI(g,v[e+76>>2],c);Od(f);b:{c:{d:{e:{f:{if((g|0)==v[e+84>>2]){if(ue(c,21685)){a=aa(8)|0;v[22440]=0;b=Q(56,e+80|0,10501)|0;c=v[22440];v[22440]=0;if((c|0)==1){break d}oc(a,b);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}c=P()|0;O()|0;rb(b);break c}if(!d){break f}a=aa(8)|0;v[22440]=0;U(977,e+80|0,17700,c|0);b=v[22440];v[22440]=0;if((b|0)!=1){oc(a,e+80|0);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}c=P()|0;O()|0;rb(e+80|0);break c}c=P()|0;O()|0;ba(a|0);break c}f=Db(e+80|0);g:{h:{i:{j:{switch(v[g+4>>2]){case 0:se(e- -64|0,c);v[22440]=0;c=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=c;b=Y(978,b|0,e+8|0,d|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){v[22440]=0;t[e+72|0]=b;R(979,a|0,e+72|0);a=v[22440];v[22440]=0;if((a|0)!=1){break g}}break i;case 1:se(e+56|0,c);v[22440]=0;c=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=c;b=qE(b,e+16|0,d);c=fb;d=v[22440];v[22440]=0;if((d|0)!=1){v[22440]=0;v[e+72>>2]=b;v[e+76>>2]=c;R(981,a|0,e+72|0);a=v[22440];v[22440]=0;if((a|0)!=1){break g}}break i;case 2:se(e+48|0,c);v[22440]=0;c=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=c;h=+ra(982,b|0,e+24|0,d|0);b=v[22440];v[22440]=0;if((b|0)!=1){v[22440]=0;A[e+72>>3]=h;R(983,a|0,e+72|0);a=v[22440];v[22440]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}se(e+40|0,c);v[22440]=0;c=v[e+44>>2];v[e+32>>2]=v[e+40>>2];v[e+36>>2]=c;W(984,a|0,b|0,e+32|0,d|0);a=v[22440];v[22440]=0;if((a|0)!=1){break g}}c=P()|0;O()|0;rb(f);break c}zc(a,f)}rb(f);break e}Db(a)}cb=e+96|0;return}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}function h_(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=cb-1072|0;cb=j;v[j+16>>2]=f;v[j+20>>2]=g;v[j+24>>2]=h;v[j+28>>2]=i;a=j+960|0;v[j+956>>2]=a;k=hw(a,100,11138,j+16|0);v[j+48>>2]=1146;a=j+48|0;o=re(j+536|0,0,a);v[j+48>>2]=1146;m=re(j+528|0,0,a);a:{b:{c:{d:{if(k>>>0<100){f=j+960|0;a=j+544|0;break d}a=pd();v[j>>2]=f;v[j+4>>2]=g;v[j+8>>2]=h;v[j+12>>2]=i;k=Xi(j+956|0,a,11138,j);if((k|0)==-1){v[22440]=0;X(1147);a=v[22440];v[22440]=0;if((a|0)!=1){break c}break b}f=v[j+956>>2];Ue(o,f);Ue(m,Hd(k<<2));if(gk(m)){v[22440]=0;X(1147);a=v[22440];v[22440]=0;if((a|0)==1){break b}break c}a=v[m>>2]}g=j+520|0;Jc(g,d);v[22440]=0;q=T(1159,g|0)|0;g=v[22440];v[22440]=0;e:{f:{g:{h:{i:{j:{k:{if((g|0)==1){break k}v[22440]=0;W(1171,q|0,f|0,f+k|0,a|0);g=v[22440];v[22440]=0;if((g|0)==1){break k}p=(k|0)>0?w[f|0]==45:p;h=Db(j+488|0);f=Db(j+472|0);g=Db(j+456|0);v[22440]=0;na(1198,c|0,p|0,j+520|0,j+512|0,j+508|0,j+504|0,h|0,f|0,g|0,j+452|0);c=v[22440];v[22440]=0;if((c|0)==1){break j}v[j+36>>2]=1146;c=re(j+40|0,0,j+36|0);i=j+48|0;n=v[j+452>>2];l:{if((n|0)<(k|0)){l=((vb(g)+(k-n<<1)|0)+vb(f)|0)+1|0;break l}l=(vb(g)+vb(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break i}Ue(c,Hd(l<<2));i=v[c>>2];if(i){break i}v[22440]=0;X(1147);a=v[22440];v[22440]=0;if((a|0)!=1){break c}break h}k=P()|0;O()|0;break f}k=P()|0;O()|0;break g}l=v[d+4>>2];v[22440]=0;oa(1199,i|0,j+36|0,j+32|0,l|0,a|0,(k<<2)+a|0,q|0,p|0,j+512|0,v[j+508>>2],v[j+504>>2],h|0,f|0,g|0,n|0);a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;a=la(1180,b|0,i|0,v[j+36>>2],v[j+32>>2],d|0,e|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break e}}}k=P()|0;O()|0;Lc(c)}Vc(g);Vc(f);rb(h)}Pb(j+520|0);break a}Lc(c);Vc(g);Vc(f);rb(h);Pb(j+520|0);Lc(m);Lc(o);cb=j+1072|0;return a|0}L()}k=P()|0;O()|0}Lc(m);Lc(o);S(k|0);L()}function P5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=cb+-64|0;cb=e;d=v[b+4>>2];a:{if(!d){break a}f=v[b>>2];g=w[Zk(f,d)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}fl(e+40|0,f,d,d-1|0);d=v[e+44>>2];v[b>>2]=v[e+40>>2];v[b+4>>2]=d}f=e+40|0;Od(f);d=v[e+40>>2];Od(e+24|0);d=Yk(d,v[e+28>>2],b);Od(f);b:{c:{d:{e:{if((d|0)==v[e+44>>2]){d=v[b>>2];f=v[b+4>>2];a=nc(e+56|0,21685);if(Hc(d,f,v[a>>2],v[a+4>>2])){a=aa(8)|0;v[22440]=0;c=Q(56,e+40|0,10501)|0;b=v[22440];v[22440]=0;if((b|0)==1){break d}oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}b=P()|0;O()|0;rb(c);break c}d=0;f=0;if(!c){break e}c=aa(8)|0;v[22440]=0;d=Q(985,e+24|0,b|0)|0;a=v[22440];v[22440]=0;f:{g:{h:{if((a|0)!=1){v[22440]=0;U(986,e+40|0,17700,d|0);a=v[22440];v[22440]=0;if((a|0)==1){break h}oc(c,e+40|0);a=0;v[22440]=0;U(121,c|0,58712,975);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;rb(e+40|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}rb(d);if(!a){break c}}ba(c|0);break c}if(v[d+4>>2]!=1){a=aa(8)|0;v[22440]=0;c=Q(56,e+40|0,11620)|0;b=v[22440];v[22440]=0;if((b|0)!=1){oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}b=P()|0;O()|0;rb(c);break c}b=P()|0;O()|0;ba(a|0);break c}d=v[b>>2];f=v[b+4>>2];c=nc(e+16|0,21685);if(Hc(d,f,v[c>>2],v[c+4>>2])){a=aa(8)|0;v[22440]=0;c=Q(56,e+40|0,10501)|0;b=v[22440];v[22440]=0;if((b|0)!=1){oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}b=P()|0;O()|0;rb(c);break c}b=P()|0;O()|0;ba(a|0);break c}d=v[b>>2];f=v[b+4>>2];c=nc(e+8|0,10943);if(Hc(d,f,v[c>>2],v[c+4>>2])){a=v[a+8>>2];d=a;f=a>>31;break e}d=0;c=v[b>>2];g=v[b+4>>2];b=nc(e,8656);f=0;if(!Hc(c,g,v[b>>2],v[b+4>>2])){break e}d=cx(v[a+32>>2]);f=0}cb=e- -64|0;fb=f;return d|0}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function kl(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Db(a);d=vb(c);v[22440]=0;R(49,a|0,d|0);d=v[22440];v[22440]=0;d:{if((d|0)!=1){e:{while(1){if(vb(c)>>>0>b>>>0){d=t[rc(c,b)|0];f:{if((d|0)>=0){v[22440]=0;R(50,a|0,d&255);d=v[22440];v[22440]=0;if((d|0)!=1){break f}break e}v[22440]=0;R(50,a|0,65533);d=v[22440];v[22440]=0;if((d|0)==1){break e}}b=b+1|0;continue}break}break d}}break a}return;case 2:b=0;a=Db(a);d=vb(c);v[22440]=0;R(49,a|0,d|0);d=v[22440];v[22440]=0;g:{if((d|0)!=1){while(1){if(vb(c)>>>0<=b>>>0){break g}d=w[rc(c,b)|0];v[22440]=0;R(50,a|0,d|0);d=v[22440];v[22440]=0;if((d|0)!=1){b=b+1|0;continue}break}}break a}return;case 3:Jp(a,c,49696);return;case 5:Jp(a,c,50720);return;case 4:Jp(a,c,51744);return;case 6:Jp(a,c,52768);return;default:a=aa(8)|0;v[22440]=0;Q(46,a|0,11075)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=P()|0;O()|0;ba(a|0);S(b|0);L();case 0:break c}}d=cb-16|0;cb=d;e=Db(a);g=d,h=fd(c),v[g+8>>2]=h;g=d,h=gf(c),v[g>>2]=h;a=0;c=0;h:{i:{while(1){j:{if(!oj(d+8|0,d)){if(!c){break j}v[22440]=0;R(50,e|0,65533);a=v[22440];v[22440]=0;if((a|0)!=1){break j}break i}b=w[v[d+8>>2]];k:{if(!c){if(!(b&128)){c=0;v[22440]=0;R(50,e|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break k}break i}if((b&224)==192){a=b&31;c=1;break k}if((b&240)==224){a=b&15;c=2;break k}if((b&248)==240){a=b&7;c=3;break k}a=0;v[22440]=0;R(50,e|0,65533);b=v[22440];v[22440]=0;c=0;if((b|0)==1){break i}break k}if((b&192)!=128){a=0;v[22440]=0;R(50,e|0,65533);f=v[22440];v[22440]=0;c=0;if((f|0)==1){break i}}b=b&63|a<<6;c=c-1|0;if(c){a=b;break k}a=0;v[22440]=0;R(50,e|0,b|0);b=v[22440];v[22440]=0;c=0;if((b|0)==1){break i}}Fe(d+8|0);continue}break}cb=d+16|0;break h}a=P()|0;O()|0;Vc(e);S(a|0);L()}return}ia(a|0,88480,25);L()}b=P()|0;O()|0;Vc(a);S(b|0);L()}function l_(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=cb-464|0;cb=j;v[j+16>>2]=f;v[j+20>>2]=g;v[j+24>>2]=h;v[j+28>>2]=i;a=j+352|0;v[j+348>>2]=a;k=hw(a,100,11138,j+16|0);v[j+48>>2]=1146;a=j+48|0;o=re(j+232|0,0,a);v[j+48>>2]=1146;m=re(j+224|0,0,a);a:{b:{c:{d:{if(k>>>0<100){f=j+352|0;a=j+240|0;break d}a=pd();v[j>>2]=f;v[j+4>>2]=g;v[j+8>>2]=h;v[j+12>>2]=i;k=Xi(j+348|0,a,11138,j);if((k|0)==-1){v[22440]=0;X(1147);a=v[22440];v[22440]=0;if((a|0)!=1){break c}break b}f=v[j+348>>2];Ue(o,f);Ue(m,Hd(k));if(gk(m)){v[22440]=0;X(1147);a=v[22440];v[22440]=0;if((a|0)==1){break b}break c}a=v[m>>2]}g=j+216|0;Jc(g,d);v[22440]=0;q=T(19,g|0)|0;g=v[22440];v[22440]=0;e:{f:{g:{h:{i:{j:{k:{if((g|0)==1){break k}v[22440]=0;W(1157,q|0,f|0,f+k|0,a|0);g=v[22440];v[22440]=0;if((g|0)==1){break k}p=(k|0)>0?w[f|0]==45:p;h=Db(j+192|0);f=Db(j+176|0);g=Db(j+160|0);v[22440]=0;na(1196,c|0,p|0,j+216|0,j+208|0,j+207|0,j+206|0,h|0,f|0,g|0,j+156|0);c=v[22440];v[22440]=0;if((c|0)==1){break j}v[j+36>>2]=1146;c=re(j+40|0,0,j+36|0);i=j+48|0;n=v[j+156>>2];l:{if((n|0)<(k|0)){l=((vb(g)+(k-n<<1)|0)+vb(f)|0)+1|0;break l}l=(vb(g)+vb(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break i}Ue(c,Hd(l));i=v[c>>2];if(i){break i}v[22440]=0;X(1147);a=v[22440];v[22440]=0;if((a|0)!=1){break c}break h}k=P()|0;O()|0;break f}k=P()|0;O()|0;break g}l=v[d+4>>2];v[22440]=0;oa(1197,i|0,j+36|0,j+32|0,l|0,a|0,a+k|0,q|0,p|0,j+208|0,t[j+207|0],t[j+206|0],h|0,f|0,g|0,n|0);a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;a=la(15,b|0,i|0,v[j+36>>2],v[j+32>>2],d|0,e|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break e}}}k=P()|0;O()|0;Lc(c)}rb(g);rb(f);rb(h)}Pb(j+216|0);break a}Lc(c);rb(g);rb(f);rb(h);Pb(j+216|0);Lc(m);Lc(o);cb=j+464|0;return a|0}L()}k=P()|0;O()|0}Lc(m);Lc(o);S(k|0);L()}function ck(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=cb-16|0;cb=i;a:{if(!d){break a}h=v[c>>2];if(!h){break a}b:{c:{d:{f=v[a+480180>>2];if((f|0)!=512){if((f|0)!=64){break d}f=h+B(d,20)|0;break c}f=h+((B(d,36318)|0)/1024|0)|0;break c}e:{g=v[a+480208>>2]&16;if(!(!g|(f|0)==4)){f=d>>31;v[i+12>>2]=f+d^f;qc(i+12|0,1020);g=v[i+12>>2];f=c;k=f;f=v[f>>2];l=f;m=f>>31;f:{if((d|0)>0){if(g>>>0<=15){f=cb-16|0;cb=f;ub(f+8|0,a+1074312|0,7);j=tb(v[v[f+8>>2]>>2],v[f+12>>2]);cb=f+16|0;g=v[(g<<2)+(j?37120:37184)>>2];break f}f=cb-16|0;cb=f;ub(f+8|0,a+1074312|0,7);j=tb(v[v[f+8>>2]>>2],v[f+12>>2]);cb=f+16|0;g=v[(g>>>2<<2)+(j?37248:38272)>>2];break f}if(g>>>0<=15){f=cb-16|0;cb=f;ub(f+8|0,a+1074312|0,7);j=tb(v[v[f+8>>2]>>2],v[f+12>>2]);cb=f+16|0;g=v[(g<<2)+(j?37184:37120)>>2];break f}f=cb-16|0;cb=f;ub(f+8|0,a+1074312|0,7);j=tb(v[v[f+8>>2]>>2],v[f+12>>2]);cb=f+16|0;g=v[(g>>>2<<2)+(j?38272:37248)>>2]}g=kka(l,m,g,g>>31)+32768|0;f=fb;f=yc(lka(g,g>>>0<32768?f+1|0:f,65536,0),fb);v[k>>2]=f;if((f|0)!=(h|0)){break b}ub(i,a+1074312|0,7);h=v[c>>2];if(!(tb(v[v[i>>2]>>2],v[i+4>>2])^(d|0)>0)){f=2147483647;d=1;if((h|0)==2147483647){break b}break e}d=-1;if((h|0)>=2){break e}f=h;break b}g:{if(!g){ub(i,a+1074312|0,7);if(tb(v[v[i>>2]>>2],v[i+4>>2])){break g}h=v[c>>2]}f=h-d|0;break c}f=v[c>>2];if((d|0)<0){h=kka(f,0,14317456,0);g=fb;f=kka(f,0,0-d|0,0)+14317456|0;d=fb;f=sM(nka(h,g,f,f>>>0<14317456?d+1|0:d),fb);break c}d=kka(f,f>>31,d,0);h=fb;if((h|0)>=0&d>>>0>=14317456|(h|0)>0){if(e){v[c>>2]=2147483647;break a}v[c>>2]=0;v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248;break a}f=sM(nka(kka(f,0,14317456,0),fb,14317456-d|0,0-(h+(d>>>0>14317456)|0)|0),fb);break c}f=d+h|0}v[c>>2]=f}if((f|0)>0){break a}v[c>>2]=1;if(v[a+480180>>2]!=2|e){break a}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}cb=i+16|0}function lJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=cb-48|0;cb=k;a:{b:{c:{d:{e:{f:{j=ap(1,28);if(!j){a=aa(4)|0;tn(a);v[22440]=0;U(121,a|0,88360,26);a=v[22440];v[22440]=0;if((a|0)!=1){break a}break f}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:952;c=Jg(k+32|0);g:{h:{i:{if(!i){break i}while(1){d=v[i>>2];if(!d){break i}e=v[i+4>>2];j:{if(e){v[22440]=0;d=Q(56,k+16|0,d|0)|0;f=v[22440];v[22440]=0;k:{if((f|0)!=1){v[22440]=0;f=Q(963,c|0,d|0)|0;l=v[22440];v[22440]=0;if((l|0)==1){break k}v[22440]=0;Q(277,f|0,e|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break k}break j}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;rb(d);break g}v[22440]=0;d=Q(56,k+16|0,d|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break h}es(c,d)}rb(d);i=i+8|0;continue}}v[22440]=0;d=T(836,80)|0;e=v[22440];v[22440]=0;l:{m:{n:{if((e|0)!=1){e=v[j+4>>2];f=v[j>>2];v[22440]=0;e=Q(964,f|0,e|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break n}v[k+16>>2]=e;e=v[bp(k+8|0,k+16|0)>>2];v[22440]=0;ea(966,d|0,a|0,b|0,e|0,c|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break m}v[j+24>>2]=d;Ae(k+16|0);gl(c);i=j;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;Ae(k+16|0)}zb(d);break g}i=V(0)|0;O()|0}gl(c);_(i|0)|0;v[22440]=0;W(958,15175,j|0,g|0,h|0);a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)==1){break f}a=v[j+24>>2];if(a){ds(a)}zb(a);i=0;v[j+24>>2]=0;a=v[j+20>>2];if(a){zb(a);v[j+20>>2]=0}zb(j);break d}i=V(0)|0;O()|0;v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;i=0;v[22440]=0;W(958,15175,0,g|0,h|0);a=v[22440];v[22440]=0;if((a|0)==1){break c}$()}cb=k+48|0;return i|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Lb()}L()}function N5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=cb+-64|0;cb=e;f=v[c+4>>2];a:{if(!f){break a}g=v[c>>2];h=w[Zk(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}fl(e+40|0,g,f,f-1|0);f=v[e+44>>2];v[c>>2]=v[e+40>>2];v[c+4>>2]=f}f=e+40|0;Od(f);g=v[e+40>>2];Od(e+24|0);h=Yk(g,v[e+28>>2],c);Od(f);f=v[c+4>>2];g=v[c>>2];b:{c:{d:{e:{if((h|0)==v[e+44>>2]){b=nc(e+56|0,21685);if(Hc(g,f,v[b>>2],v[b+4>>2])){a=aa(8)|0;v[22440]=0;b=Q(56,e+40|0,10501)|0;c=v[22440];v[22440]=0;if((c|0)==1){break d}oc(a,b);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}c=P()|0;O()|0;rb(b);break c}if(d){a=aa(8)|0;v[22440]=0;b=Q(985,e+24|0,c|0)|0;c=v[22440];v[22440]=0;f:{g:{h:{if((c|0)!=1){v[22440]=0;U(986,e+40|0,17700,b|0);c=v[22440];v[22440]=0;if((c|0)==1){break h}oc(a,e+40|0);d=0;v[22440]=0;U(121,a|0,58712,975);c=v[22440];v[22440]=0;if((c|0)!=1){break b}c=P()|0;O()|0;rb(e+40|0);break g}c=P()|0;O()|0;break f}c=P()|0;d=1;O()|0}rb(b);if(!d){break c}}ba(a|0);break c}Db(a);break e}d=nc(e+16|0,21685);if(Hc(g,f,v[d>>2],v[d+4>>2])){a=aa(8)|0;v[22440]=0;b=Q(56,e+40|0,10501)|0;c=v[22440];v[22440]=0;if((c|0)!=1){oc(a,b);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}c=P()|0;O()|0;rb(b);break c}c=P()|0;O()|0;ba(a|0);break c}f=v[c>>2];g=v[c+4>>2];d=nc(e+8|0,12389);if(Hc(f,g,v[d>>2],v[d+4>>2])){i:{switch(v[b+52>>2]){case 0:Bc(a,5604);break e;case 1:Bc(a,11321);break e;case 2:Bc(a,9235);break e;default:break i}}Db(a);break e}d=v[c>>2];f=v[c+4>>2];c=nc(e,11558);if(Hc(d,f,v[c>>2],v[c+4>>2])){j:{switch(v[b+56>>2]){case 0:Bc(a,15627);break e;case 1:Bc(a,15632);break e;case 2:Bc(a,12663);break e;case 3:Bc(a,9299);break e;default:break j}}Db(a);break e}Db(a)}cb=e- -64|0;return}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}function zn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=cb-16|0;cb=e;v[b+88>>2]=v[b+88>>2]|524288;a:{b:{if(!(v[a+480208>>2]&8)){ub(e+8|0,a+1074312|0,15);if(tb(v[v[e+8>>2]>>2],v[e+12>>2])){break b}}if(v[a+480180>>2]!=268435456){break a}}c=c?c:w[b+811|0];t[b+812|0]=c;t[b+811|0]=c}if(c){u[b+768>>1]=c}d=v[b+656>>2];c:{if(uj(d)){c=x[b+768>>1];if(!c){break c}f=v[b+856>>2];g=v[a+1074392>>2];i=0-c|0;j=c;c=v[b+708>>2];h=(+(g>>>0)+1)*+(((c|0)<0?i:j)|0)/+y[a+1074416>>2];d:{if(D(h)<2147483648){a=~~h;break d}a=-2147483648}v[b+856>>2]=a;if(w[b+90|0]&16){a=B(v[v[d+44>>2]+36>>2]+1|0,a);v[b+856>>2]=a}a=a-(g?f:0)|0;d=a>>31;f=c>>31;if((f+c^f)>>>0<=(d^a+d)>>>0){if(!c){break c}v[b+708>>2]=0;v[b+852>>2]=c+v[b+852>>2];t[b+851|0]=w[b+851|0]|64;break c}v[b+708>>2]=c-a;v[b+852>>2]=a+v[b+852>>2];t[b+851|0]=w[b+851|0]|64;break c}c=1;e:{if(!(t[b+851|0]&1)){break e}d=v[a+480180>>2];if(d&524352){break e}if(v[a+1074416>>2]==1){ub(e+8|0,a+1074312|0,6);if(tb(v[v[e+8>>2]>>2],v[e+12>>2])){break e}d=v[a+480180>>2]}c=0;if((d|0)!=8){break e}c=(w[a+480208|0]&2)>>>1|0}f:{if(!v[b+700>>2]|!v[b+708>>2]){break f}f=v[a+480180>>2];d=x[b+768>>1];g=(f|0)==268435456&d>>>0>239;if(!(g?t[b+851|0]&1:c)){break f}c=b+700|0;d=B((f|0)==64?2:4,g?d-240|0:d);d=lj(a)?d:0-d|0;f=v[b+700>>2];g=v[b+708>>2];if(!(w[b+851|0]&16?0:(f|0)>=(g|0))){ck(a,b,c,d,1);d=v[b+708>>2];if((d|0)>=v[b+700>>2]){break f}v[c>>2]=d;break f}if((f|0)<=(g|0)){break f}ck(a,b,c,0-d|0,1);f=v[b+700>>2];d=v[b+708>>2];g:{if((f|0)<(d|0)){v[c>>2]=d;break g}if((d|0)!=(f|0)){break f}}ub(e+8|0,a+1074312|0,112);if(!tb(v[v[e+8>>2]>>2],v[e+12>>2])){break f}t[b+851|0]=w[b+851|0]|16}if(v[b+700>>2]!=v[b+708>>2]){break c}ub(e+8|0,a+1074312|0,25);if(!tb(v[v[e+8>>2]>>2],v[e+12>>2])&v[a+480180>>2]!=1){break c}v[b+708>>2]=0}cb=e+16|0}function Zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0;h=cb-32|0;cb=h;x=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;i=e+(h+16|0)|0;e=a+e|0;v[i>>2]=v[e+44>>2];v[i+4>>2]=v[e+48>>2];f=f+1|0;continue}break}i=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=e;y=v[a+8>>2];z=v[a+12>>2];a:while(1){if(d){f=v[h+8>>2];g=((((v[h+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+x|0;e=(((f>>>16|0)+4&131064)<<1)+b|0;n=u[e+38>>1];o=u[e+36>>1];p=u[e+34>>1];q=u[e+32>>1];r=u[e+30>>1];s=u[e+28>>1];t=u[e+26>>1];l=u[e+24>>1];f=0;while(1)if((f|0)==2){n=v[a+72>>2];e=v[a+68>>2];o=e;p=e>>31;e=v[a+64>>2];q=e;r=e>>31;e=v[a+60>>2];s=e;t=e>>31;f=0;while(1){if((f|0)!=2){l=(f<<2)+h|0;g=v[l>>2];e=(h+16|0)+(f<<3)|0;m=v[e+4>>2];j=v[e>>2];v[e+4>>2]=j;w=g<<8;g=w;g=kka(s,t,g,g>>31);A=fb;C=e;e=Vb(j,-16777216,16776704);j=kka(q,r,e,e>>31);g=j+g|0;e=fb+A|0;e=g>>>0<j>>>0?e+1|0:e;j=g;g=Vb(m,-16777216,16776704);m=kka(o,p,g,g>>31);g=j+m|0;e=fb+e|0;e=g>>>0<m>>>0?e+1|0:e;g=g+8388608|0;e=g>>>0<8388608?e+1|0:e;e=Mc(g,e,24);v[C>>2]=e-(n&w);v[l>>2]=(e|0)/256;f=f+1|0;continue}break}e=v[a+32>>2];k=v[a+28>>2]+k|0;v[c>>2]=v[c>>2]+B(v[h>>2],k>>12);i=e+i|0;v[c+4>>2]=v[c+4>>2]+B(v[h+4>>2],i>>12);Jb(h+8|0,y,z);c=c+8|0;d=d-1|0;continue a}else{e=g+(f<<1)|0;v[(f<<2)+h>>2]=(((((B(p,u[e+8>>1])+B(q,u[e+4>>1])|0)+B(o,u[e+12>>1])|0)+B(n,u[e+16>>1])|0)/2|0)+((((B(u[e-8>>1],t)+B(u[e-12>>1],l)|0)+B(u[e-4>>1],s)|0)+B(u[e>>1],r)|0)/2|0)|0)/16384;f=f+1|0;continue}}break}b=v[h+8>>2];c=v[h+12>>2];v[a+36>>2]=k;v[a>>2]=b;v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=k>>12;v[a+24>>2]=i>>12;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(h+16|0)|0;v[c+44>>2]=v[b>>2];v[c+48>>2]=v[b+4>>2];f=f+1|0;continue}break}cb=h+32|0}function hg(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=v[a+8>>2]+(B(x[a+14>>1],(w[a+80|0]?c:0)+b|0)>>>1|0)|0;v[a+8>>2]=j;i=w[a+79|0]?x[v[a>>2]+3836>>1]:i;b=x[a+20>>1];l=x[a+22>>1];m=x[a+70>>1];a:{b:{c:{d:{switch(v[a+16>>2]){case 1:c=x[v[a>>2]+3832>>1];f=x[a+26>>1]?x[a+48>>1]>>>x[v[a+52>>2]+((c>>>x[a+44>>1]&7)<<1)>>1]|0:0;g=c;c=x[a+46>>1];f=b+(c?g&c?0:f:f)|0;u[a+20>>1]=f;c=2;h=x[a+28>>1];if((h|0)<=f<<16>>16){break c}break b;case 2:if(w[a+78|0]){break b}case 3:c=0;f=x[v[a>>2]+3832>>1];h=x[a+30>>1]?x[a+60>>1]>>>x[v[a+64>>2]+((f>>>x[a+56>>1]&7)<<1)>>1]|0:0;g=f;f=x[a+58>>1];f=b+(f?g&f?0:h:h)|0;u[a+20>>1]=f;if(f<<16>>16<511){break b}v[a+16>>2]=-1;u[a+20>>1]=511;v[a+72>>2]=0;break a;default:c=0;v[a+72>>2]=0;break a;case 0:break d}}c=1;f=x[v[a>>2]+3832>>1];k=x[a+24>>1]?B((b^-1)<<16>>16,x[a+36>>1]>>>x[v[a+40>>2]+((f>>>x[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;g=f;f=x[a+34>>1];f=b+(f?g&f?0:k:k)|0;u[a+20>>1]=f;if(f<<16>>16>0){break b}}v[a+16>>2]=c;u[a+20>>1]=h}i=((b+l|0)+m|0)+i<<3;if(e){d=(u[a+74>>1]+u[a+72>>1]>>e)+d|0}d=(j>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(x[a+12>>1]){case 0:d=(b&512)>>>9|0;b=x[((b&256?c^255:c)<<1)+28512>>1];break e;case 1:d=0;b=x[((b&512?0:b&256?c^255:c)<<1)+28512>>1];break e;case 2:d=0;b=x[((b&256?c^255:c)<<1)+28512>>1];break e;case 3:d=0;b=x[((b&256?0:c)<<1)+28512>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=x[(e<<1)+28512>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=x[(b<<1)+28512>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}u[a+74>>1]=x[a+72>>1];e=a;a=b+i|0;a=(a&65535)>>>0<8191?a:8191;c=0-d^x[((a&255)<<1)+28e3>>1]+1024>>>((a&65280)>>>8)<<1;u[e+72>>1]=c}return c<<16>>16}function _ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;h=cb-32|0;cb=h;y=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;i=e+(h+16|0)|0;e=a+e|0;v[i>>2]=v[e+44>>2];v[i+4>>2]=v[e+48>>2];f=f+1|0;continue}break}i=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=e;z=v[a+8>>2];A=v[a+12>>2];a:while(1){if(d){f=v[h+8>>2];g=(((v[h+12>>2]&2147483647)<<1|f>>>31)&-2)+y|0;e=(((f>>>16|0)+4&131064)<<1)+b|0;n=u[e+38>>1];o=u[e+36>>1];p=u[e+34>>1];q=u[e+32>>1];r=u[e+30>>1];s=u[e+28>>1];w=u[e+26>>1];l=u[e+24>>1];f=0;while(1)if((f|0)==2){n=v[a+72>>2];e=v[a+68>>2];o=e;p=e>>31;e=v[a+64>>2];q=e;r=e>>31;e=v[a+60>>2];s=e;w=e>>31;f=0;while(1){if((f|0)!=2){l=(f<<2)+h|0;g=v[l>>2];e=(h+16|0)+(f<<3)|0;m=v[e+4>>2];j=v[e>>2];v[e+4>>2]=j;x=g<<8;g=x;g=kka(s,w,g,g>>31);C=fb;D=e;e=Vb(j,-16777216,16776704);j=kka(q,r,e,e>>31);g=j+g|0;e=fb+C|0;e=g>>>0<j>>>0?e+1|0:e;j=g;g=Vb(m,-16777216,16776704);m=kka(o,p,g,g>>31);g=j+m|0;e=fb+e|0;e=g>>>0<m>>>0?e+1|0:e;g=g+8388608|0;e=g>>>0<8388608?e+1|0:e;e=Mc(g,e,24);v[D>>2]=e-(n&x);v[l>>2]=(e|0)/256;f=f+1|0;continue}break}e=v[a+32>>2];k=v[a+28>>2]+k|0;v[c>>2]=v[c>>2]+B(v[h>>2],k>>12);i=e+i|0;v[c+4>>2]=v[c+4>>2]+B(v[h+4>>2],i>>12);Jb(h+8|0,z,A);c=c+8|0;d=d-1|0;continue a}else{e=f+g|0;v[(f<<2)+h>>2]=(((((B(p,t[e+4|0])+B(q,t[e+2|0])|0)+B(o,t[e+6|0])|0)+B(n,t[e+8|0])<<8)/2|0)+((((B(t[e-4|0],w)+B(t[e-6|0],l)|0)+B(t[e-2|0],s)|0)+B(t[e|0],r)<<8)/2|0)|0)/16384;f=f+1|0;continue}}break}b=v[h+8>>2];c=v[h+12>>2];v[a+36>>2]=k;v[a>>2]=b;v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=k>>12;v[a+24>>2]=i>>12;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(h+16|0)|0;v[c+44>>2]=v[b>>2];v[c+48>>2]=v[b+4>>2];f=f+1|0;continue}break}cb=h+32|0}function _Q(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=cb-16|0;cb=f;t[a|0]=0;c=w[b|0];if(c){t[a|0]=c>>>0>96?-1:c+12|0}t[a+1|0]=w[b+1|0];c=w[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){t[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch((c+96&240)>>>4|0){case 0:t[a+2|0]=4;c=c&15;break b;case 1:t[a+2|0]=3;c=c&15;break b;case 2:t[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}t[a+2|0]=5;c=c&15}t[a+4|0]=c}e=w[b+4|0];d=w[b+5|0];c=w[b+6|0];d:{if(!(c?1:e|d)){break d}e:{f:{g:{h:{i:{j:{switch(e|0){default:k:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break k}}if((e|0)==128){break e}if((e|0)!=157){break d}t[a+2|0]=15;t[a+3|0]=20;t[a+4|0]=c>>>3;t[f+15|0]=15;h=a,i=w[Tb(b+5|0,f+15|0)|0]|208,t[h+5|0]=i;break d;case 0:Ef(a,c,d);g=w[b+6|0]==15;break d;case 1:t[a+3|0]=2;h=a,i=rg(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 2:t[a+3|0]=3;h=a,i=rg(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 3:t[a+3|0]=4;h=a,i=rg(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 4:t[a+3|0]=5;t[a+5|0]=c&240|(d&240)>>>4;break d;case 8:if(d){t[a+5|0]=d;t[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}t[a+5|0]=145;t[a+3|0]=20;break d;case 12:t[a+3|0]=13;t[a+5|0]=c>>>1;break d;case 15:if(c){t[a+5|0]=c;t[a+3|0]=17;break d}t[a+3|0]=16;t[a+5|0]=d&15;break d;case 16:break j;case 5:case 6:case 7:case 9:case 10:case 11:case 13:case 14:break d}}EA(a,c,d,1);g=(w[a+3|0]&254)==16;break d}t[a+5|0]=d;t[a+3|0]=18;break d}t[a+3|0]=31;t[a+5|0]=c>>>1;break d}t[a+3|0]=31;t[a+5|0]=c>>>1&120;break d}t[a+5|0]=159;t[a+3|0]=20;break d}t[a+3|0]=21;t[a+5|0]=c>>>2}b=w[b+3|0];l:{if(!b){break l}if(!w[a+3|0]){t[a+5|0]=b;t[a+3|0]=9;break l}if(w[a+2|0]){break l}t[a+2|0]=2;t[a+4|0]=b>>>2}cb=f+16|0;return g}function Cp(a,b,c,d){var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=cb-16|0;cb=e;v[e+12>>2]=u[b+780>>1]+w[b+837|0];v[e+8>>2]=u[b+782>>1]+(w[b+838|0]&127);oe(e+12|0,0,127);oe(e+8|0,0,127);k=a+1074312|0;ub(e,k,1);j=v[e+12>>2];a:{if(tb(v[v[e>>2]>>2],v[e+4>>2])){i=v[e+8>>2];break a}u[b+780>>1]=0;t[b+837|0]=j;i=v[e+8>>2];u[b+782>>1]=0;t[b+838|0]=i}ub(e,k,36);l=B(j,d+256|0);m=(l|0)/256|0;b:{if(!(!tb(v[v[e>>2]>>2],v[e+4>>2])|i|(l|0)<65024)){m=-1;if(!Rc(w[b+788|0])){break b}if(Rs(b+788|0)|x[b+786>>1]|!(w[b+851|0]&2)){break b}v[b+88>>2]=v[b+88>>2]&-32769;break b}v[b+88>>2]=v[b+88>>2]|32768;f=te(C(10),C(C(0-i|0)*C(.00937500037252903)));i=cb-16|0;cb=i;g=C(B(j,d+256|0)>>>0);c:{if(v[a+480180>>2]!=33554432){h=C(110);g=C(C(g/(w[a+480209|0]&128?C(10240):C(12288)))+C(.25));break c}h=C(125);g=C(C(g*C(6))/C(65024))}n=i,o=Nh(C(te(C(2),g)*h)),v[n+12>>2]=o;oe(i+12|0,120,2e4);d=v[i+12>>2];j=v[a+24620>>2];cb=i+16|0;ub(e,k,36);g=C(C(((j|0)<d<<1?j>>>1|0:d)>>>0)*C(6.2831854820251465));d:{if(!(!tb(v[v[e>>2]>>2],v[e+4>>2])|v[a+480208>>2]&32768)){h=C(C(y[a+24620>>2])/g);g=C(C(C(f*h)+f)+C(-1));z[e>>2]=g;f=C(h*h);break d}h=C(f+f);f=C(g/C(y[a+24620>>2]));z[e>>2]=C(C(1)-h)*f;bN(e,C(2));g=C(C(h-z[e>>2])/f);z[e>>2]=g;f=C(C(1)/C(f*f))}h=C(f+C(g+C(1)));g=C(C(f+C(f+g))/h);f=C(C(-f)/h);h=C(C(1)/h);e:{if(w[b+845|0]==1){n=b,o=Nh(C(C(C(1)-h)*C(16777216))),v[n+60>>2]=o;n=b,o=Nh(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Nh(C(f*C(16777216))),v[n+68>>2]=o;a=-1;break e}d=Nh(C(h*C(16777216)));v[b+60>>2]=d;n=b,o=Nh(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Nh(C(f*C(16777216))),v[n+68>>2]=o;a=0;if(d){break e}v[b+60>>2]=1}v[b+72>>2]=a;if(!c){break b}v[b+44>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;v[b+56>>2]=0}cb=e+16|0;return m}function zQ(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=cb-16|0;cb=l;a:{if((c|0)==(g|0)){f=$b(l+8|0,f,c);g=cb-16|0;cb=g;d=ol(d,e,b,c);v[g+12>>2]=d;b:{if((d|0)<=0){d=v[f>>2];break b}c:{if(!c){c=v[f>>2];break c}k=32-c|0;v[g+8>>2]=k;e=d;d=v[ld(g+8|0,g+12|0)>>2];v[g+12>>2]=e-d;e=v[f>>2];c=-1<<c&-1>>>k-d;v[e>>2]=v[e>>2]&(c^-1)|c&v[b>>2];c=d+v[f+4>>2]|0;v[f+4>>2]=c&31;c=e+(c>>>3&536870908)|0;v[f>>2]=c;b=b+4|0;d=v[g+12>>2]}k=c;e=(d|0)/32|0;c=e<<2;gj(k,b,c);e=d-(e<<5)|0;v[g+12>>2]=e;d=c+v[f>>2]|0;v[f>>2]=d;if((e|0)<=0){break b}e=-1>>>32-e|0;v[d>>2]=v[d>>2]&(e^-1)|e&v[b+c>>2];v[f+4>>2]=v[g+12>>2]}$b(a,d,v[f+4>>2]);cb=g+16|0;break a}k=a;g=$b(l,f,g);f=cb-16|0;cb=f;d=ol(d,e,b,c);v[f+12>>2]=d;d:{if((d|0)<=0){a=v[g+4>>2];break d}e:{if(!c){a=v[g+4>>2];break e}i=32-c|0;v[f+8>>2]=i;a=d;e=f+8|0;d=v[ld(e,f+12|0)>>2];v[f+12>>2]=a-d;a=v[g+4>>2];j=v[b>>2];v[f+8>>2]=d;m=32-a|0;v[f+4>>2]=m;h=v[g>>2];n=v[h>>2];e=v[Bb(e,f+4|0)>>2];i=j&(-1<<c&-1>>>i-d);v[h>>2]=(-1<<a&-1>>>m-e^-1)&n|(a>>>0>c>>>0?i<<a-c:i>>>c-a|0);j=a+e|0;a=j&31;v[g+4>>2]=a;h=h+(j>>>3&536870908)|0;v[g>>2]=h;d=d-e|0;if((d|0)>0){v[h>>2]=v[h>>2]&(-1>>>32-d^-1)|i>>>c+e;v[g+4>>2]=d;a=d}b=b+4|0;d=v[f+12>>2]}e=32-a|0;h=-1<<a;i=h^-1;while(1){if((d|0)>=32){c=v[g>>2];d=v[b>>2];v[c>>2]=i&v[c>>2]|d<<a;v[g>>2]=c+4;v[c+4>>2]=h&v[c+4>>2]|d>>>e;d=v[f+12>>2]-32|0;v[f+12>>2]=d;b=b+4|0;continue}break}if((d|0)<=0){break d}i=v[b>>2];v[f+8>>2]=e;c=v[g>>2];b=v[c>>2];j=b;b=v[ld(f+12|0,f+8|0)>>2];j=j&(h&-1>>>e-b^-1);e=i&-1>>>32-d;v[c>>2]=j|e<<a;d=a+b|0;a=d&31;v[g+4>>2]=a;c=c+(d>>>3&536870908)|0;v[g>>2]=c;d=v[f+12>>2]-b|0;v[f+12>>2]=d;if((d|0)<=0){break d}v[c>>2]=v[c>>2]&(-1>>>32-d^-1)|e>>>b;a=v[f+12>>2];v[g+4>>2]=a}$b(k,v[g>>2],a);cb=f+16|0}cb=l+16|0}function nL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=cb-16|0;cb=g;e=B(b,872)+a|0;k=e+1074992|0;a:{b:{if(w[e+1075082|0]&2){h=a+480180|0;e=v[h>>2];j=1;c:{d:{e:{f=v[a+480208>>2];if(f&4096){if(!(e&16777248)){break e}j=!(f&4)}if((e|0)!=64){break d}break b}if((e|0)==64){break b}h=a+480180|0;j=0;break c}if(!j){break c}ub(g+8|0,a+1074312|0,21);if(!tb(v[v[g+8>>2]>>2],v[g+12>>2])){break c}e=B(b,872)+a|0;f=e+1075811|0;t[f|0]=w[f|0]+(w[e+1075815|0]<<2)}f=B(b,872)+a|0;i=f+1075814|0;l=f+1075811|0;e=dy(a,w[i|0],w[l|0]);m=f+1075648|0;f:{if(uj(v[m>>2])){z[d>>2]=z[d>>2]+C(C(C(B(w[f+1075816|0],e)|0)*C(.05000000074505806))/C(7680));c=f+1075843|0;d=w[c|0];t[c|0]=d&159|64;if(v[a+1074416>>2]!=(v[a+1074392>>2]+1|0)){break f}t[c|0]=d|96;break f}d=v[a+480208>>2];if((d&2101248)==2101248){break a}f=v[h>>2];if(d&4096?f&67633152:0){break a}e=f&5?(w[i|0]&3)==1?0-e|0:e:e;i=a+1074312|0;ub(g+8|0,i,21);f=v[a+480208>>2];g:{if(tb(v[v[g+8>>2]>>2],v[g+12>>2])){d=f&4;e=d?e:0-e|0;d=d?5:6;break g}d=5;h:{if(f&131072){break h}h=v[h>>2];d=8;if((h|0)==1024){break h}d=7;if(h&524304){break h}d=h&16777248?f&4?6:7:6}ub(g+8|0,i,80);if(!tb(v[v[g+8>>2]>>2],v[g+12>>2])){break g}d=w[(B(b,872)+a|0)+1075783|0]==26?d+2|0:d}d=(0-B(w[(B(b,872)+a|0)+1075816|0],e)|0)/(1<<d)|0;ck(a,k,c,d,0);c=Is(a,k);if(!c){break f}e=v[m>>2];if(e){e=t[e+33|0]}else{e=2}gb[v[v[c>>2]+88>>2]](c,d,e<<24>>24,b)}if(!j){break a}ub(g+8|0,a+1074312|0,21);if(tb(v[v[g+8>>2]>>2],v[g+12>>2])){break a}t[l|0]=w[l|0]+w[(B(b,872)+a|0)+1075815|0];break a}if(!(w[e+1075662|0]&2)){break a}a=Is(a,k);if(!a){break a}gb[v[v[a>>2]+88>>2]](a,0,0,b);break a}a=B(b,872)+a|0;b=a+1075811|0;d=w[b|0];if(d&1){v[c>>2]=v[c>>2]+B(w[a+1075816|0],167)}t[b|0]=d+1}cb=g+16|0}function NY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;r=cb-16|0;cb=r;j=c;while(1){a:{if((d|0)==(j|0)){j=d;break a}if(!w[j|0]){break a}j=j+1|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}i=v[b+4>>2];v[r+8>>2]=v[b>>2];v[r+12>>2]=i;s=cb-16|0;cb=s;u=gi(s+8|0,v[a+8>>2]);m=j-c|0;k=0;o=0;n=cb-1040|0;cb=n;i=v[e>>2];v[n+12>>2]=i;p=f?f:n+16|0;l=f?g-f>>2:256;e:{f:{if(!(!i|!l)){while(1){g:{q=m>>>2|0;if(q>>>0<l>>>0&m>>>0<=131){break f}q=KF(p,n+12|0,l>>>0<=q>>>0?l:q,b);if((q|0)==-1){k=-1;l=0;i=v[n+12>>2];break g}t=(n+16|0)==(p|0)?0:q;l=l-t|0;p=(t<<2)+p|0;m=i+m|0;i=v[n+12>>2];m=i?m-i|0:0;k=k+q|0;if(!i){break g}if(l){continue}}break}}if(!i){break e}}if(!(!l|!m)){o=i;i=k;while(1){h:{k=sr(p,o,m,b);i:{if(k+2>>>0<=2){j:{switch(k+1|0){case 1:o=0;break i;case 0:break e;default:break j}}v[b>>2]=0;break i}i=i+1|0;o=k+o|0;l=l-1|0;if(l){break h}}k=i;break e}p=p+4|0;m=m-k|0;k=i;if(m){continue}break}break e}o=i}if(f){v[e>>2]=o}cb=n+1040|0;fi(u);cb=s+16|0;k:{l:{m:{n:{if((k|0)==-1){while(1){o:{v[h>>2]=f;if(v[e>>2]==(c|0)){break o}g=1;p:{q:{r:{b=JE(f,c,j-c|0,r+8|0,v[a+8>>2]);switch(b+2|0){case 0:break l;case 2:break p;case 1:break r;default:break q}}v[e>>2]=c;break n}g=b}c=c+g|0;f=v[h>>2]+4|0;continue}break}v[e>>2]=c;break d}f=v[h>>2]+(k<<2)|0;v[h>>2]=f;if((f|0)==(g|0)){break k}c=v[e>>2];if((d|0)==(j|0)){j=d;continue}if(!JE(f,c,1,b,v[a+8>>2])){break m}}a=2;break c}v[h>>2]=v[h>>2]+4;c=v[e>>2]+1|0;v[e>>2]=c;j=c;while(1){if((d|0)==(j|0)){j=d;break b}if(!w[j|0]){break b}j=j+1|0;continue}}v[e>>2]=c;a=1;break c}c=v[e>>2]}a=(c|0)!=(d|0)}cb=r+16|0;return a|0}f=v[h>>2];continue}}function qr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=cb-128|0;cb=i;v[i+120>>2]=b;k=GF(c,d);v[i+4>>2]=1146;m=FF(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Hd(k);if(!j){v[22440]=0;X(1147);a=v[22440];v[22440]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}Ue(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[22440]=0;h=Q(1148,a|0,i+120|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[22440]=0;b=Q(1149,a|0,i+120|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}b=v[a>>2];v[22440]=0;n=T(1150,b|0)|0;b=v[22440];v[22440]=0;g:{if((b|0)!=1){if(g){break g}v[22440]=0;n=Q(1151,e|0,n|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}q=o+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=q;if(!r){continue e}v[22440]=0;T(1152,a|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((vb(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=t[rc(b,o)|0];j:{if(g){break j}v[22440]=0;p=Q(1151,e|0,p<<24>>24)|0;s=v[22440];v[22440]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n&255)==(p&255)){r=1;if((vb(b)|0)!=(q|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Lc(m);cb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!xd(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Lc(m);S(b|0)}L()}function xi(a,b,c,d,e){var f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;q=c*d;r=b*e;m=q+r;s=b*d;t=c*e;p=s-t;a:{if(!Qh(p)){break a}if(!Qh(m)){break a}h=kf(b);f=kf(c);k=h|f;if((k|0)==1){o(+(f?1:0));f=j(1)|0;i=j(0)|0;o(+c);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);c=+n();o(0);f=j(1)|0;i=j(0)|0;o(+d);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);d=(u=+n(),v=d,w=Qh(d),w?u:v);o(0);f=j(1)|0;i=j(0)|0;o(+e);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);e=(u=+n(),v=e,w=Qh(e),w?u:v);o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=+n()}h=kf(d);f=kf(e);b:{if(f?1:h){o(+(f?1:0));f=j(1)|0;g=j(0)|0;o(+e);k=j(1)|0;j(0)|0;l(0,g|0);l(1,f&2147483647|k&-2147483648);e=+n();o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=+n();o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=Qh(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=Qh(c),w?u:v);break b}if(k){break b}c:{if(kf(s)){break c}if(kf(t)){break c}if(kf(r)){break c}if(!kf(q)){break a}}o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=Qh(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=Qh(c),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=(u=+n(),v=d,w=Qh(d),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+e);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);e=(u=+n(),v=e,w=Qh(e),w?u:v)}m=(b*e+d*c)*N;p=(b*d-e*c)*N}lm(a,p,m)}function D9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=cb-160|0;cb=c;e=Tl(c+48|0,a);v[22440]=0;d=Q(462,c+32|0,43918)|0;a=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){v[22440]=0;v[c+8>>2]=19988487;v[c+12>>2]=0;U(463,e|0,d|0,c+8|0);a=v[22440];v[22440]=0;if((a|0)==1){break n}Ab(d);if(Gk(w[c+48|0])){break e}v[22440]=0;d=Q(462,c+32|0,13375)|0;a=v[22440];v[22440]=0;if((a|0)==1){break m}v[22440]=0;da(494,e|0,b|0,d|0,896)|0;a=v[22440];v[22440]=0;if((a|0)==1){break l}Ab(d);v[c+28>>2]=0;v[c+24>>2]=0;v[22440]=0;d=Q(462,c+32|0,16781)|0;a=v[22440];v[22440]=0;if((a|0)==1){break k}v[22440]=0;U(897,e|0,c+28|0,d|0);a=v[22440];v[22440]=0;if((a|0)==1){break j}Ab(d);v[22440]=0;d=Q(462,c+32|0,16753)|0;a=v[22440];v[22440]=0;if((a|0)==1){break i}v[22440]=0;U(897,e|0,c+24|0,d|0);a=v[22440];v[22440]=0;if((a|0)==1){break h}Ab(d);a=v[c+28>>2];d=v[c+24>>2];o:{if(!a|d>>>0<a>>>0){break o}f=v[v[v[v[b+48>>2]+12>>2]+8>>2]+40>>2];if(f>>>0<a>>>0|d>>>0>f>>>0){break o}v[b+20>>2]=d;v[b+16>>2]=a}d=bf(c+32|0);v[22440]=0;f=Q(462,c+8|0,14208)|0;a=v[22440];v[22440]=0;if((a|0)==1){break d}v[22440]=0;U(898,e|0,d|0,f|0);a=v[22440];v[22440]=0;if((a|0)==1){break g}Ab(f);if(hc(v[d>>2],v[d+4>>2])){break f}a=v[b+16>>2];v[22440]=0;R(850,d|0,a|0);a=v[22440];v[22440]=0;if((a|0)!=1){break f}break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(d);break a}a=P()|0;O()|0;Ab(f);break b}v[22440]=0;R(899,b|0,d|0);a=v[22440];v[22440]=0;if((a|0)==1){break c}fc(d)}jh(e);cb=c+160|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}fc(d)}jh(e);S(a|0);L()}function or(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=cb-128|0;cb=i;v[i+120>>2]=b;k=GF(c,d);v[i+4>>2]=1146;m=FF(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Hd(k);if(!j){v[22440]=0;X(1147);a=v[22440];v[22440]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}Ue(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[22440]=0;h=Q(1164,a|0,i+120|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[22440]=0;b=Q(1165,a|0,i+120|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}b=v[a>>2];v[22440]=0;n=T(1166,b|0)|0;b=v[22440];v[22440]=0;g:{if((b|0)!=1){if(g){break g}v[22440]=0;n=Q(1167,e|0,n|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}q=o+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=q;if(!r){continue e}v[22440]=0;T(1168,a|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((vb(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=v[hk(b,o)>>2];j:{if(g){break j}v[22440]=0;p=Q(1167,e|0,p|0)|0;s=v[22440];v[22440]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n|0)==(p|0)){r=1;if((vb(b)|0)!=(q|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Lc(m);cb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!xd(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Lc(m);S(b|0)}L()}function mba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;f=cb-48|0;cb=f;e=YN(f+32|0,1<<v[b+12>>2]);while(1){c=v[a>>2];if(Vg(c,v[a+4>>2])>>>0>d>>>0){c=Xe(c,d);XN(sd(v[e>>2],d),A[c>>3]);d=d+1|0;continue}break}WN(b,e);x=f,y=yb(v[e>>2]),v[x+8>>2]=y;u=yb(v[e+4>>2]);while(1){i=v[f+8>>2];if(Qb(i,u)){k=A[i+8>>3];h=cb-32|0;cb=h;o(+A[i>>3]);d=j(1)|0;r=j(0)|0;o(+k);c=j(1)|0;s=j(0)|0;q=d&2147483647;p=c&2147483647;c=(q|0)==(p|0)&r>>>0<s>>>0|q>>>0<p>>>0;d=c?r:s;c=c?q:p;w=c;l(0,d|0);l(1,c|0);m=+n();t=c>>>20|0;g=m;a:{if((t|0)==2047){break a}c=(q|0)==(p|0)&r>>>0>s>>>0|q>>>0>p>>>0;l(0,(c?r:s)|0);c=c?q:p;l(1,c|0);k=+n();b:{if(!(d|w)){break b}c=c>>>20|0;if((c|0)==2047){break b}g=k+m;if((c-t|0)>=65){break a}c:{if(c>>>0>=1534){m=m*1.90109156629516e-211;k=k*1.90109156629516e-211;g=5.260135901548374e210;break c}g=1;if(t>>>0>572){break c}m=m*5.260135901548374e210;k=k*5.260135901548374e210;g=1.90109156629516e-211}XG(h+24|0,h+16|0,k);XG(h+8|0,h,m);g=g*K(A[h>>3]+A[h+16>>3]+A[h+8>>3]+A[h+24>>3]);break a}g=k}m=g;cb=h+32|0;XN(i,jp(m));Sp(f+8|0);continue}break}VN(b,e);UN(e);d=1;while(1){c=v[e>>2];if(vj(c,v[e+4>>2])>>>1>>>0>d>>>0){Yy(sd(c,d),2);c=v[e>>2];Yy(sd(c,(vj(c,v[e+4>>2])>>>1|0)+d|0),0);d=d+1|0;continue}break}WN(b,e);x=f,y=yb(v[e>>2]),v[x+24>>2]=y;i=yb(v[e+4>>2]);while(1){d=v[f+24>>2];if(Qb(d,i)){TN(f+8|0,d);c=v[f+20>>2];v[d+8>>2]=v[f+16>>2];v[d+12>>2]=c;c=v[f+12>>2];v[d>>2]=v[f+8>>2];v[d+4>>2]=c;Sp(f+24|0);continue}break}VN(b,e);UN(e);i=v[a>>2];c=Vg(i,v[a+4>>2]);b=v[e>>2];d=0;while(1){if((d|0)==(c|0)){ml(e);cb=f+48|0}else{a=sd(b,d);x=Xe(i,d),z=A[a>>3],A[x>>3]=z;d=d+1|0;continue}break}}function bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0;h=cb-32|0;cb=h;t=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;g=e+(h+16|0)|0;e=a+e|0;v[g>>2]=v[e+44>>2];v[g+4>>2]=v[e+48>>2];f=f+1|0;continue}break}w=v[a+24>>2];x=v[a+20>>2];e=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=e;y=v[a+8>>2];z=v[a+12>>2];a:while(1){if(d){f=v[h+8>>2];g=((((v[h+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+t|0;e=(((f>>>16|0)+4&131064)<<1)+b|0;l=u[e+38>>1];m=u[e+36>>1];n=u[e+34>>1];o=u[e+32>>1];p=u[e+30>>1];q=u[e+28>>1];r=u[e+26>>1];j=u[e+24>>1];f=0;while(1)if((f|0)==2){l=v[a+72>>2];e=v[a+68>>2];m=e;n=e>>31;e=v[a+64>>2];o=e;p=e>>31;e=v[a+60>>2];q=e;r=e>>31;f=0;while(1){if((f|0)!=2){j=(f<<2)+h|0;g=v[j>>2];e=(h+16|0)+(f<<3)|0;k=v[e+4>>2];i=v[e>>2];v[e+4>>2]=i;s=g<<8;g=s;g=kka(q,r,g,g>>31);A=fb;C=e;e=Vb(i,-16777216,16776704);i=kka(o,p,e,e>>31);g=i+g|0;e=fb+A|0;e=g>>>0<i>>>0?e+1|0:e;i=g;g=Vb(k,-16777216,16776704);k=kka(m,n,g,g>>31);g=i+k|0;e=fb+e|0;e=g>>>0<k>>>0?e+1|0:e;g=g+8388608|0;e=g>>>0<8388608?e+1|0:e;e=Mc(g,e,24);v[C>>2]=e-(l&s);v[j>>2]=(e|0)/256;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[h>>2],x);v[c+4>>2]=v[c+4>>2]+B(w,v[h+4>>2]);Jb(h+8|0,y,z);c=c+8|0;d=d-1|0;continue a}else{e=g+(f<<1)|0;v[(f<<2)+h>>2]=(((((B(n,u[e+8>>1])+B(o,u[e+4>>1])|0)+B(m,u[e+12>>1])|0)+B(l,u[e+16>>1])|0)/2|0)+((((B(u[e-8>>1],r)+B(u[e-12>>1],j)|0)+B(u[e-4>>1],q)|0)+B(u[e>>1],p)|0)/2|0)|0)/16384;f=f+1|0;continue}}break}b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(h+16|0)|0;v[c+44>>2]=v[b>>2];v[c+48>>2]=v[b+4>>2];f=f+1|0;continue}break}cb=h+32|0}function CK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{b:{d=b;e=v[b>>2];if(e){if(!v[b+4>>2]){break b}c=v[b+4>>2];c:{if(c){d=XS(c);break c}while(1){c=wh(d);d=v[d+8>>2];if(!c){continue}break}}e=v[d>>2];if(e){break b}}e=v[d+4>>2];if(e){break b}e=0;g=1;break a}v[e+8>>2]=v[d+8>>2];g=0}d:{e:{if(wh(d)){v[v[d+8>>2]>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=v[d+8>>2]+4|0;break e}v[v[d+8>>2]+4>>2]=e;c=v[d+8>>2]}c=v[c>>2]}h=!w[d+12|0];if((b|0)!=(d|0)){f=v[b+8>>2];v[d+8>>2]=f;if(!wh(b)){f=v[d+8>>2]+4|0}v[f>>2]=d;f=v[b>>2];v[d>>2]=f;bm(f,d);f=v[b+4>>2];v[d+4>>2]=f;if(f){bm(f,d)}t[d+12|0]=w[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=w[c+12|0];f:{g:{if(!wh(c)){if(!b){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;aq(v[c+8>>2]);b=v[c>>2];a=(b|0)==(a|0)?c:a;c=v[b+4>>2]}b=v[c>>2];h:{if(!(w[b+12|0]?0:b)){d=v[c+4>>2];if(w[d+12|0]?0:d){break h}t[c+12|0]=0;i:{b=v[c+8>>2];if((b|0)!=(a|0)){if(w[b+12|0]){break i}a=b}t[a+12|0]=1;return}if(!wh(b)){break g}b=v[b+8>>2]+4|0;break f}d=v[c+4>>2];if(w[d+12|0]?0:d){break h}t[b+12|0]=1;t[c+12|0]=0;$p(c);c=v[c+8>>2];d=v[c+4>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[d+12|0]=1;aq(v[c+8>>2]);return}if(!b){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;$p(v[c+8>>2]);b=v[c+4>>2];a=(b|0)==(a|0)?c:a;c=v[b>>2]}d=v[c>>2];j:{if(w[d+12|0]?0:d){break j}b=v[c+4>>2];if(!(w[b+12|0]?0:b)){t[c+12|0]=0;b=v[c+8>>2];if(!((a|0)!=(b|0)?w[b+12|0]:0)){t[b+12|0]=1;return}if(wh(b)){b=v[b+8>>2]+4|0;break f}b=v[b+8>>2];break f}if(w[d+12|0]?0:d){break j}t[b+12|0]=1;t[c+12|0]=0;aq(c);c=v[c+8>>2];d=v[c>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[d+12|0]=1;$p(v[c+8>>2]);return}b=v[b+8>>2]}c=v[b>>2];continue}}t[e+12|0]=1}}function fh(a,b,c,d){var e=0,f=0,g=0,h=0;f=v[a+4>>2];if(!f){b=v[a>>2];f=cb-16|0;cb=f;a:{if((c|0)==189){t[b+3843|0]=d>>>7;t[b+3844|0]=d>>>6&1;break a}e=c&224;if(!e){if((c|0)!=8){if((c|0)!=260){break a}a=0;c=1;while(1){if((a|0)==6){break a}g=b+B(a>>>0<3?a:a+6|0,44)|0;e=g+148|0;g=g+16|0;h=c&d;b:{if(h){Jn(g,e);break b}Jn(g,0)}t[e+40|0]=!h;a=a+1|0;c=c<<1&510;continue}}t[b+3842|0]=d>>>6&1;a=0;while(1){if((a|0)==18){break a}dz((b+B(a,44)|0)+16|0);a=a+1|0;continue}}if(e-160>>>0<=32){a=c&15;if(a>>>0>8){break a}a=b+B(c&256?a+9|0:a,44)|0;v[f+8>>2]=a+16;b=v[a+52>>2];v[f+12>>2]=b;e=b?2:1;c:{b=c&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}g=d&3;h=d>>>2&7;a=0;c=(d&32)!=0;while(1){if((a|0)==(e|0)){break a}b=v[(f+8|0)+(a<<2)>>2];gO(v[b>>2],c);gO(v[b+4>>2],c);u[b+22>>1]=h;cz(b);dz(b);t[b+21|0]=g;cz(b);dz(b);a=a+1|0;continue}}a=0;while(1){if((a|0)==(e|0)){break a}b=v[(f+8|0)+(a<<2)>>2];u[b+20>>1]=x[b+20>>1]&768|d&255;cz(b);a=a+1|0;continue}}t[a+58|0]=(d&32)>>>5;t[a+57|0]=(d&16)>>>4;b=d>>>1&7;u[a+46>>1]=b?9-b|0:0;u[a+48>>1]=d&1;break a}if((e|0)!=224&e>>>0>=129|-4144960>>>c&1){break a}a=t[(c&31)+29104|0];a=(b+B(c&256?a+18|0:a,84)|0)+808|0;d:{switch(e-32>>>5|0){case 0:t[a+79|0]=d>>>7;t[a+80|0]=(d&64)>>>6;t[a+78|0]=(d&32)>>>5;t[a+77|0]=(d&16)>>>4;Kn(a);u[a+14>>1]=x[((d&15)<<1)+29136>>1];break a;case 1:u[a+68>>1]=w[(d>>>6|0)+21670|0];hO(a);u[a+22>>1]=(d&63)<<2;break a;case 2:u[a+24>>1]=d>>>4;Kn(a);u[a+26>>1]=d&15;Kn(a);break a;case 3:b=d>>>4|0;u[a+28>>1]=b>>>0<15?b<<4:496;u[a+30>>1]=d&15;Kn(a);break a;case 6:break d;default:break a}}u[a+12>>1]=d&7}cb=f+16|0;return}gb[v[v[f>>2]>>2]](f,b,c,d)}function hW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=cb+-64|0;cb=f;sc(b);Fo(a);a:{if(!$h(b,f+56|0)){break a}if(!lD(f+56|0)){break a}if(!c){l=1;break a}if(!Kb(b,4)){break a}tv(a);p=f,q=sv(),v[p+32>>2]=q;c=f+32|0;rv(Sj(v[a+4>>2])+32|0,c);Wq(c);k=v[Sj(v[a+4>>2])+32>>2];c=Ck(b);if(c&1){break a}d=c-4|0;Tc(b,d);h=cb-16|0;cb=h;c=h+8|0;hv(c,b);e=w[Eb(c,0)|0];i=w[Eb(c,1)|0];c=w[Eb(c,2)|0];cb=h+16|0;h=c|(i<<8|e<<16);if(!h){break a}v[22440]=0;R(177,k|0,h|0);c=v[22440];v[22440]=0;l=1;if((c|0)==1){a=V(88360)|0;if((O()|0)==(fa(88360)|0)){_(a|0)|0;$();l=0;break a}S(a|0);L()}Tc(b,4);m=f+32|0;kD(m,b);i=v[k>>2];e=cb-32|0;cb=e;b=v[f+32>>2];t[e+24|0]=w[b|0];t[e+25|0]=w[b+1|0];t[e+26|0]=w[b+2|0];t[e+27|0]=w[b+3|0];c=jD(e+8|0);d=b+d|0;v[c+12>>2]=d-4;v[c+8>>2]=b;Qj(c,w[d-1|0]);b=h;b:while(1){c:{d:{e:{if(!b){break e}if(Qj(c,1)){break d}d=1;while(1){g=Qj(c,2);d=g+d|0;if((g|0)==3){continue}break}v[e+4>>2]=d;qc(e+4|0,b);d=0;g=v[e+4>>2];while(1)if((d|0)==(g|0)){if(!b){break e}break d}else{b=b-1|0;p=i+b|0,q=Qj(c,8),t[p|0]=q;d=d+1|0;continue}}cb=e+32|0;break c}g=Qj(c,2);d=g+2|0;v[e+4>>2]=d;f:{if((g|0)==3){if(Qj(c,1)){g=w[Eb(e+24|0,3)|0]}else{g=7}g=Qj(c,g);while(1){j=Qj(c,3);d=j+d|0;if((j|0)==7){continue}break}v[e+4>>2]=d;break f}g=Qj(c,w[Eb(e+24|0,g)|0])}qc(e+4|0,b);d=0;o=v[e+4>>2];while(1){if((d|0)==(o|0)){continue b}j=0;n=b+g|0;if(h>>>0>n>>>0){j=w[i+n|0]}b=b-1|0;t[i+b|0]=j;d=d+1|0;continue}}break}qe(f+16|0,v[k>>2],v[k+4>>2]);_g(f+24|0,v[f+16>>2],v[f+20>>2]);b=ee(f+8|0);b=Uq(m,v[f+24>>2],v[f+28>>2],v[b>>2],v[b+4>>2]);Sc(Sj(v[a+4>>2])+12|0,b);sb(b)}cb=f- -64|0;return l|0}function cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;h=cb-32|0;cb=h;w=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;g=e+(h+16|0)|0;e=a+e|0;v[g>>2]=v[e+44>>2];v[g+4>>2]=v[e+48>>2];f=f+1|0;continue}break}x=v[a+24>>2];y=v[a+20>>2];e=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=e;z=v[a+8>>2];A=v[a+12>>2];a:while(1){if(d){f=v[h+8>>2];g=(((v[h+12>>2]&2147483647)<<1|f>>>31)&-2)+w|0;e=(((f>>>16|0)+4&131064)<<1)+b|0;l=u[e+38>>1];m=u[e+36>>1];n=u[e+34>>1];o=u[e+32>>1];p=u[e+30>>1];q=u[e+28>>1];r=u[e+26>>1];j=u[e+24>>1];f=0;while(1)if((f|0)==2){l=v[a+72>>2];e=v[a+68>>2];m=e;n=e>>31;e=v[a+64>>2];o=e;p=e>>31;e=v[a+60>>2];q=e;r=e>>31;f=0;while(1){if((f|0)!=2){j=(f<<2)+h|0;g=v[j>>2];e=(h+16|0)+(f<<3)|0;k=v[e+4>>2];i=v[e>>2];v[e+4>>2]=i;s=g<<8;g=s;g=kka(q,r,g,g>>31);C=fb;D=e;e=Vb(i,-16777216,16776704);i=kka(o,p,e,e>>31);g=i+g|0;e=fb+C|0;e=g>>>0<i>>>0?e+1|0:e;i=g;g=Vb(k,-16777216,16776704);k=kka(m,n,g,g>>31);g=i+k|0;e=fb+e|0;e=g>>>0<k>>>0?e+1|0:e;g=g+8388608|0;e=g>>>0<8388608?e+1|0:e;e=Mc(g,e,24);v[D>>2]=e-(l&s);v[j>>2]=(e|0)/256;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[h>>2],y);v[c+4>>2]=v[c+4>>2]+B(x,v[h+4>>2]);Jb(h+8|0,z,A);c=c+8|0;d=d-1|0;continue a}else{e=f+g|0;v[(f<<2)+h>>2]=(((((B(n,t[e+4|0])+B(o,t[e+2|0])|0)+B(m,t[e+6|0])|0)+B(l,t[e+8|0])<<8)/2|0)+((((B(t[e-4|0],r)+B(t[e-6|0],j)|0)+B(t[e-2|0],q)|0)+B(t[e|0],p)<<8)/2|0)|0)/16384;f=f+1|0;continue}}break}b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(h+16|0)|0;v[c+44>>2]=v[b>>2];v[c+48>>2]=v[b+4>>2];f=f+1|0;continue}break}cb=h+32|0}function Dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=cb-32|0;cb=g;s=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+16|0)|0;e=a+e|0;v[h>>2]=v[e+44>>2];v[h+4>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;t=v[a+8>>2];w=v[a+12>>2];a:while(1){if(d){e=v[g+8>>2];f=((((v[g+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+s|0;b=e>>>21&2040;l=u[b+39830>>1];m=u[b+39828>>1];n=u[b+39826>>1];o=u[b+39824>>1];b=0;while(1)if((b|0)==2){l=v[a+72>>2];b=v[a+68>>2];m=b;n=b>>31;b=v[a+64>>2];o=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){q=(b<<2)+g|0;f=v[q>>2];e=(g+16|0)+(b<<3)|0;k=v[e+4>>2];j=v[e>>2];v[e+4>>2]=j;r=f<<8;f=r;f=kka(y,z,f,f>>31);p=fb;A=e;e=Vb(j,-16777216,16776704);j=kka(o,x,e,e>>31);f=j+f|0;e=fb+p|0;e=f>>>0<j>>>0?e+1|0:e;p=f;f=Vb(k,-16777216,16776704);k=kka(m,n,f,f>>31);f=p+k|0;e=fb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Mc(f,e,24);v[A>>2]=e-(l&r);v[q>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(v[g>>2],i>>12);h=b+h|0;v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],h>>12);Jb(g+8|0,t,w);c=c+8|0;d=d-1|0;continue a}else{e=f+(b<<1)|0;v[(b<<2)+g>>2]=(((B(n,u[e>>1])+B(o,u[e-4>>1])|0)+B(m,u[e+4>>1])|0)+B(l,u[e+8>>1])|0)/16384;b=b+1|0;continue}}break}b=v[g+8>>2];c=v[g+12>>2];v[a+36>>2]=i;v[a>>2]=b;v[a+4>>2]=c;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}cb=g+32|0}function Oda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=cb-48|0;cb=f;k=c+484344|0;wg(k,w[b+70|0]|w[b+71|0]<<8);a:{b:{while(1){if((w[b+70|0]|w[b+71|0]<<8)>>>0<=j>>>0){break b}h=v[a+8>>2];e=Ag(a);Ob(a,1);c:{if((w[b+58|0]|w[b+59|0]<<8)==258){c=He(a)+1|0;break c}c=Sg(a)}d=Sg(a);Tc(a,e+h|0);Td(f,a,d);h=cc(f+24|0,f);sb(f);v[22440]=0;c=Y(229,k|0,j&65535,(c?c>>>0<1024?c:1024:64)|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){d:{if(!(c&(d|0)!=0)){break d}c=Sb(k,j);m=f,n=Pg(c),v[m>>2]=n;l=Og(c);while(1){d=v[f>>2];if(!Qb(d,l)){break d}v[22440]=0;c=T(208,h|0)|0;e=v[22440];v[22440]=0;e:{f:{g:{if((e|0)!=1){if(!(c&128)){break g}if(c&1){v[22440]=0;e=T(208,h|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break a}t[d|0]=e}if(c&2){break f}break e}break a}t[d|0]=c;c=255}v[22440]=0;e=T(208,h|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break a}t[d+1|0]=e}i=0;e=0;if(c&4){v[22440]=0;e=T(208,h|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break a}}if(c&8){v[22440]=0;i=T(208,h|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break a}}if(c&16){v[22440]=0;c=T(208,h|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break a}t[d+5|0]=c}h:{i:{c=w[d|0];if(!c){break i}g=255;if((c|0)==97){break h}if(c>>>0>96){break i}g=c+12|0;break h}g=0}t[d|0]=g;c=w[d+5|0];j:{if((c|i)&255){Ef(d,i,c);break j}t[d+3|0]=0}if(w[d+1|0]==255){t[d+1|0]=0}c=e-16|0;k:{if((c&255)>>>0<=64){t[d+4|0]=c;t[d+2|0]=1;break k}if(e>>>0<96){break k}c=e&15;t[d+4|0]=c;e=e-96>>4;t[d+2|0]=w[e+27246|0];if((e|0)!=6){break k}t[d+4|0]=c<<2}Ki(f);continue}}j=j+1|0;sb(f+24|0);continue}break}break a}cb=f+48|0;return}a=P()|0;O()|0;sb(f+24|0);S(a|0);L()}function s_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=cb-624|0;cb=a;v[a+608>>2]=c;v[a+616>>2]=b;v[a+16>>2]=1181;h=re(a+200|0,a+208|0,a+16|0);b=a+192|0;Jc(b,e);v[22440]=0;i=T(1159,b|0)|0;b=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){t[a+191|0]=0;b=v[e+4>>2];v[22440]=0;b=pa(1189,a+616|0,c|0,d|0,a+192|0,b|0,f|0,a+191|0,i|0,h|0,a+196|0,a+608|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break d}if(!b){break e}b=w[14741]|w[14742]<<8|(w[14743]<<16|w[14744]<<24);t[a+183|0]=b;t[a+184|0]=b>>>8;t[a+185|0]=b>>>16;t[a+186|0]=b>>>24;b=w[14738]|w[14739]<<8|(w[14740]<<16|w[14741]<<24);v[a+176>>2]=w[14734]|w[14735]<<8|(w[14736]<<16|w[14737]<<24);v[a+180>>2]=b;v[22440]=0;W(1171,i|0,a+176|0,a+186|0,a+128|0);b=v[22440];v[22440]=0;if((b|0)==1){break g}v[a+4>>2]=1146;d=re(a+8|0,0,a+4|0);c=a+16|0;b=v[a+196>>2];e=b-v[h>>2]|0;if((e|0)<393){break f}Ue(d,Hd((e>>2)+2|0));c=v[d>>2];if(c){break f}v[22440]=0;X(1147);b=v[22440];v[22440]=0;if((b|0)==1){break c}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}if(w[a+191|0]){t[c|0]=45;c=c+1|0}e=v[h>>2];while(1){if(b>>>0<=e>>>0){t[c|0]=0;v[a>>2]=g;if((RF(a+16|0,a)|0)!=1){v[22440]=0;Z(1183,8029);b=v[22440];v[22440]=0;if((b|0)!=1){break a}break c}Lc(d)}else{b=a+128|0;j=c,k=w[(a+176|0)+(Zv(b,b+40|0,v[e>>2])-b>>2)|0],t[j|0]=k;c=c+1|0;e=e+4|0;b=v[a+196>>2];continue}break}}v[22440]=0;b=Q(1165,a+616|0,a+608|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break d}if(b){v[f>>2]=v[f>>2]|2}b=v[a+616>>2];Pb(a+192|0);Lc(h);cb=a+624|0;return b|0}e=P()|0;O()|0;break b}e=P()|0;O()|0;Lc(d)}Pb(a+192|0);Lc(h);S(e|0);L()}L()}function dW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=cb-48|0;cb=f;h=wi(b)^-1;a:{if(pc(v[d>>2],v[d+4>>2])>>>0<=h>>>0){xs(a);break a}wi(b);g=c+4|0;if((w[g|0]|w[g+1|0]<<8)>>>0>=60){Ob(b,4)}j=f,k=wi(b),v[j+44>>2]=k;Ob(b,4);c=wi(b);i=wi(b);if(!((c|0)>0&(i|0)>36)){xs(a);break a}if(gq(rd(v[e>>2],v[Ib(v[d>>2],h)>>2]),13133)){xs(a);break a}pv(f,b,i,c);c=cc(f+24|0,f);sb(f);v[22440]=0;b=T(180,c|0)|0;d=v[22440];v[22440]=0;b:{if((d|0)==1){break b}c:{d:{if(!b){v[22440]=0;T(189,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break d}break b}b=w[g|0]|w[g+1|0]<<8;if(b>>>0<=39){v[22440]=0;Q(190,c|0,8)|0;b=v[22440];v[22440]=0;if((b|0)==1){break b}b=w[g|0]|w[g+1|0]<<8}if((b&65535)>>>0<=59){v[22440]=0;Q(190,c|0,16)|0;b=v[22440];v[22440]=0;if((b|0)==1){break b}}v[22440]=0;T(191,c|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break b}b=w[g|0]|w[g+1|0]<<8;e:{if(b>>>0>=120){v[22440]=0;T(191,c|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break b}v[22440]=0;Q(190,c|0,8)|0;break e}if(b>>>0>=100){v[22440]=0;Q(190,c|0,4)|0;b=v[22440];v[22440]=0;if((b|0)==1){break b}v[22440]=0;T(191,c|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break b}v[22440]=0;Q(190,c|0,4)|0;break e}if(b>>>0>=62){v[22440]=0;T(191,c|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break b}v[22440]=0;Q(190,c|0,4)|0;break e}v[22440]=0;T(191,c|0)|0}b=v[22440];v[22440]=0;if((b|0)==1){break b}v[22440]=0;b=T(191,c|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}v[22440]=0;U(192,f|0,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break c}cc(a,f);v[a+20>>2]=v[f+44>>2];sb(f)}sb(c);break a}}a=P()|0;O()|0;sb(c);S(a|0);L()}cb=f+48|0}function Eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0;g=cb-32|0;cb=g;s=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+16|0)|0;e=a+e|0;v[h>>2]=v[e+44>>2];v[h+4>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];a:while(1){if(d){e=v[g+8>>2];f=(((v[g+12>>2]&2147483647)<<1|e>>>31)&-2)+s|0;b=e>>>21&2040;l=u[b+39830>>1];m=u[b+39828>>1];n=u[b+39826>>1];o=u[b+39824>>1];b=0;while(1)if((b|0)==2){l=v[a+72>>2];b=v[a+68>>2];m=b;n=b>>31;b=v[a+64>>2];o=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;b=0;while(1){if((b|0)!=2){q=(b<<2)+g|0;f=v[q>>2];e=(g+16|0)+(b<<3)|0;k=v[e+4>>2];j=v[e>>2];v[e+4>>2]=j;r=f<<8;f=r;f=kka(z,A,f,f>>31);p=fb;C=e;e=Vb(j,-16777216,16776704);j=kka(o,y,e,e>>31);f=j+f|0;e=fb+p|0;e=f>>>0<j>>>0?e+1|0:e;p=f;f=Vb(k,-16777216,16776704);k=kka(m,n,f,f>>31);f=p+k|0;e=fb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Mc(f,e,24);v[C>>2]=e-(l&r);v[q>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(v[g>>2],i>>12);h=b+h|0;v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],h>>12);Jb(g+8|0,w,x);c=c+8|0;d=d-1|0;continue a}else{e=b+f|0;v[(b<<2)+g>>2]=(((B(n,t[e|0])+B(o,t[e-2|0])|0)+B(m,t[e+2|0])|0)+B(l,t[e+4|0])<<8)/16384;b=b+1|0;continue}}break}b=v[g+8>>2];c=v[g+12>>2];v[a+36>>2]=i;v[a>>2]=b;v[a+4>>2]=c;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}cb=g+32|0}function qea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=cb-16|0;cb=h;l=h,m=yj(b),v[l>>2]=m;f=cb-16|0;cb=f;d=b;i=a;a=Kd(a);a:{b:{if(a){b=bc(i);while(1){c:{c=a+14|0;if(kt(d,c)){c=v[a>>2];if(!c){break b}break c}if(kt(c,d)){b=a+4|0;c=v[a+4>>2];if(c){a=b;break c}v[f+12>>2]=a;a=b;break a}v[f+12>>2]=a;a=b;break a}b=a;a=c;continue}}a=bc(i)}v[f+12>>2]=a}b=v[a>>2];if(!b){j=cb-16|0;cb=j;b=bc(i);k=kh(f,lc(48),lh(j+8|0,b));b=v[k>>2]+14|0;g=cb-16|0;cb=g;v[g+8>>2]=v[h>>2];c=v[g+8>>2];d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+24|0]=e;t[b+25|0]=e>>>8;t[b+26|0]=e>>>16;t[b+27|0]=e>>>24;t[b+28|0]=d;t[b+29|0]=d>>>8;t[b+30|0]=d>>>16;t[b+31|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b+16|0]=e;t[b+17|0]=e>>>8;t[b+18|0]=e>>>16;t[b+19|0]=e>>>24;t[b+20|0]=d;t[b+21|0]=d>>>8;t[b+22|0]=d>>>16;t[b+23|0]=d>>>24;d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);c=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[b+8|0]=c;t[b+9|0]=c>>>8;t[b+10|0]=c>>>16;t[b+11|0]=c>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;u[b+32>>1]=0;cb=g+16|0;l=bc(k),m=1,t[l+4|0]=m;cb=j+16|0;Ig(i,v[f+12>>2],a,v[f>>2]);b=Vd(f);pk(f);g=1}a=h+8|0;Hg(a,ac(f,b),g);cb=f+16|0;a=Xn(a);cb=h+16|0;return a+32|0}function Aha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=cb-16|0;cb=f;i=rf(a,c);ke(f,v[a+36>>2]);j=a;a:{if(!i){Cc(f,a+32|0,5);c=0;if(tb(v[v[f>>2]>>2],v[f+4>>2])){break a}}e=cb-160|0;cb=e;g=Tl(e+48|0,v[a+36>>2]);v[22440]=0;a=Q(462,e|0,27919)|0;c=v[22440];v[22440]=0;b:{c:{d:{e:{if((c|0)!=1){v[22440]=0;v[e+40>>2]=19988487;v[e+44>>2]=0;U(463,g|0,a|0,e+40|0);c=v[22440];v[22440]=0;if((c|0)==1){break e}Ab(a);if(!Gk(w[e+48|0])){break d}break b}c=P()|0;O()|0;break c}c=P()|0;O()|0;Ab(a);break c}t[e+40|0]=0;t[e+39|0]=0;v[22440]=0;a=Q(462,e|0,10113)|0;c=v[22440];v[22440]=0;f:{g:{h:{i:{if((c|0)!=1){v[22440]=0;U(502,g|0,e+40|0,a|0);c=v[22440];v[22440]=0;if((c|0)==1){break i}Ab(a);if(!w[e+40|0]){break b}yf(e+40|0,50);v[22440]=0;a=Q(462,e|0,13256)|0;c=v[22440];v[22440]=0;if((c|0)==1){break f}v[22440]=0;U(502,g|0,e+39|0,a|0);c=v[22440];v[22440]=0;if((c|0)==1){break g}Ab(a);c=qj(b);h=w[e+40|0];if(c>>>0<h>>>0){a=jz(e,v[b+12>>2]);v[22440]=0;U(503,b|0,h|0,a|0);c=v[22440];v[22440]=0;if((c|0)==1){break h}il(a)}k=x[xj(b,0)+28>>1];c=0;j:{while(1){a=c&255;if(a>>>0>=h>>>0){c=w[e+39|0];m=b,n=qj(b)>>>0>c>>>0?c:0,t[m+16|0]=n;break b}Qe(xj(b,a),k);a=xj(b,a);v[22440]=0;R(504,e|0,c|0);l=v[22440];v[22440]=0;if((l|0)!=1){v[22440]=0;W(505,g|0,a|0,e|0,d|0);a=v[22440];v[22440]=0;if((a|0)==1){break j}c=c+1|0;Ab(e);continue}break}c=P()|0;O()|0;break c}c=P()|0;O()|0;Ab(e);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;Ab(a);break c}c=P()|0;O()|0;il(a);break c}c=P()|0;O()|0;Ab(a);break c}c=P()|0;O()|0}jh(g);S(c|0);L()}jh(g);cb=e+160|0;c=i}Se(j,c);cb=f+16|0}function f_(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=cb-16|0;cb=x;v[c>>2]=a;z=d&512;A=h<<2;while(1){if((y|0)==4){if(vb(n)>>>0>1){C=x,D=fd(n),v[C+8>>2]=D;e=cb-16|0;cb=e;v[e+8>>2]=v[x+8>>2];f=v[Ge(e+8|0)>>2];cb=e+16|0;C=c,D=Qi(f,Mk(n),v[c>>2]),v[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}cb=x+16|0}else{a:{b:{switch(t[i+y|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];h=wr(g,32);p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 3:if(xd(n)){break a}h=v[hk(n,0)>>2];p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 2:if(xd(m)|!z){break a}C=c,D=Qi(fd(m),Mk(m),v[c>>2]),v[C>>2]=D;break a;case 4:break b;default:break a}}B=v[c>>2];e=e+A|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!Rk(g,2048,v[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=v[c>>2];q=o;while(1){if(!(!q|e>>>0>=h>>>0)){h=h-4|0;s=v[h>>2];r=p+4|0;v[c>>2]=r;v[p>>2]=s;q=q-1|0;p=r;continue}break}d:{if(!q){s=0;break d}s=wr(g,48);p=v[c>>2]}while(1){r=p+4|0;if((q|0)>0){v[p>>2]=s;q=q-1|0;p=r;continue}break}v[c>>2]=r;v[p>>2]=j}e:{if((e|0)==(h|0)){p=wr(g,48);q=v[c>>2];h=q+4|0;v[c>>2]=h;v[q>>2]=p;break e}if(xd(l)){s=-1}else{s=t[rc(l,0)|0]}q=0;u=0;while(1){if((e|0)!=(h|0)){r=v[c>>2];f:{if((q|0)!=(s|0)){p=r;r=q;break f}p=r+4|0;v[c>>2]=p;v[r>>2]=k;r=0;u=u+1|0;if(vb(l)>>>0<=u>>>0){s=q;break f}s=-1;if(w[rc(l,u)|0]==127){break f}s=t[rc(l,u)|0]}h=h-4|0;q=v[h>>2];v[c>>2]=p+4;v[p>>2]=q;q=r+1|0;continue}break}h=v[c>>2]}pr(B,h)}y=y+1|0;continue}break}}function z_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=cb-288|0;cb=a;v[a+272>>2]=c;v[a+280>>2]=b;v[a+16>>2]=1181;h=re(a+152|0,a+160|0,a+16|0);b=a+144|0;Jc(b,e);v[22440]=0;i=T(19,b|0)|0;b=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){t[a+143|0]=0;b=v[e+4>>2];v[22440]=0;b=pa(1182,a+280|0,c|0,d|0,a+144|0,b|0,f|0,a+143|0,i|0,h|0,a+148|0,a+260|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break d}if(!b){break e}b=w[14741]|w[14742]<<8|(w[14743]<<16|w[14744]<<24);t[a+135|0]=b;t[a+136|0]=b>>>8;t[a+137|0]=b>>>16;t[a+138|0]=b>>>24;b=w[14738]|w[14739]<<8|(w[14740]<<16|w[14741]<<24);v[a+128>>2]=w[14734]|w[14735]<<8|(w[14736]<<16|w[14737]<<24);v[a+132>>2]=b;v[22440]=0;W(1157,i|0,a+128|0,a+138|0,a+118|0);b=v[22440];v[22440]=0;if((b|0)==1){break g}v[a+4>>2]=1146;d=re(a+8|0,0,a+4|0);c=a+16|0;b=v[a+148>>2];e=b-v[h>>2]|0;if((e|0)<99){break f}Ue(d,Hd(e+2|0));c=v[d>>2];if(c){break f}v[22440]=0;X(1147);b=v[22440];v[22440]=0;if((b|0)==1){break c}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}if(w[a+143|0]){t[c|0]=45;c=c+1|0}e=v[h>>2];while(1){if(b>>>0<=e>>>0){t[c|0]=0;v[a>>2]=g;if((RF(a+16|0,a)|0)!=1){v[22440]=0;Z(1183,8029);b=v[22440];v[22440]=0;if((b|0)!=1){break a}break c}Lc(d)}else{b=a+118|0;j=c,k=w[((yi(b,gT(b),e)-a|0)+a|0)+10|0],t[j|0]=k;c=c+1|0;e=e+1|0;b=v[a+148>>2];continue}break}}v[22440]=0;b=Q(1149,a+280|0,a+272|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break d}if(b){v[f>>2]=v[f>>2]|2}b=v[a+280>>2];Pb(a+144|0);Lc(h);cb=a+288|0;return b|0}e=P()|0;O()|0;break b}e=P()|0;O()|0;Lc(d)}Pb(a+144|0);Lc(h);S(e|0);L()}L()}function Tea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=cb-48|0;cb=e;ed(b,2);sk(e+16|0,2,a+1|0);f=e+32|0;xc(f,v[e+16>>2],v[e+20>>2],w[e+24|0]);pe(b+43|0,f);rb(f);a:{b:{c:{d:{e:{f=a;switch(w[a|0]){case 2:break b;case 1:break d;case 0:break e;default:break a}}d=v[b+4>>2];a=v[b+8>>2];break c}a=f+16|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=d;a=f+20|0;v[e+32>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[e+16>>2]=d-1;g=e+32|0;d=v[Bb(g,e+16|0)>>2];v[b+4>>2]=d;a=f+24|0;v[e+32>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=v[Bb(g,b)>>2];v[b+8>>2]=a;u[b+34>>1]=x[b+34>>1]&65533|w[f+31|0]<<1&2}if(a>>>0>d>>>0&a>>>0>=2){break a}u[b+34>>1]=0;v[b+4>>2]=0;v[b+8>>2]=0;break a}g=e+16|0;Eh(g,f+16|0);a=e+32|0;d=v[e+16>>2];d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;Eh(g,f+20|0);d=v[e+16>>2];d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[a+4|0]=d;t[a+5|0]=d>>>8;t[a+6|0]=d>>>16;t[a+7|0]=d>>>24;Eh(g,f+24|0);d=v[e+16>>2];d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[a+8|0]=d;t[a+9|0]=d>>>8;t[a+10|0]=d>>>16;t[a+11|0]=d>>>24;v[e+8>>2]=v[e+40>>2];a=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=a;zl(b,1,e)}t[e+32|0]=w[f+28|0];t[e+16|0]=64;h=b,i=w[Tb(e+32|0,e+16|0)|0]<<2,u[h+30>>1]=i;a=f+32|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b+24>>2]=a;b=b+24|0;f:{if(!c){break f}if(w[f|0]==2){a=a&65535;v[b>>2]=a;break f}if(y[b>>2]>=65536){v[b>>2]=65535}a=v[b>>2]}g:{h:{if(!a){c=8363;break h}c=1024;if(a>>>0>1023){break g}}v[b>>2]=c}cb=e+48|0}function cy(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=cb-16|0;cb=e;i=mL(b,c);a:{if(!v[b+656>>2]|!(t[i+6|0]&1)){break a}f=v[i>>2];j=a+1074312|0;ub(e+8|0,j,31);g=tb(v[v[e+8>>2]>>2],v[e+12>>2]);d=Qu(v[b+656>>2],c);if(hc(v[d>>2],v[d+4>>2])){break a}g=f+(g^1)|0;ub(e+8|0,j,31);f=w[d+12|0];b:{c:{if(!tb(v[v[e+8>>2]>>2],v[e+12>>2])){d:{if(!(f&2)){break d}h=w[d+14|0];k=!(v[a+480180>>2]&1048580)+x[Ib(v[d>>2],h)>>1]|0;if(!(w[b+89|0]&8)|(!(f&4)|(h|0)!=w[d+16|0])){f=l}else{ub(e+8|0,j,70);f=tb(v[v[e+8>>2]>>2],v[e+12>>2])}if(f|(g|0)!=(k|0)){break d}g=x[Ib(v[d>>2],w[d+13|0])>>1]}if(!(!(w[d+12|0]&4)|w[b+89|0]&8)){a=v[d>>2];if((x[Ib(a,w[d+16|0])>>1]+1|0)!=(g|0)){break b}g=x[Ib(a,w[d+15|0])>>1];ub(e+8|0,j,93);if(!tb(v[v[e+8>>2]>>2],v[e+12>>2])|(c|0)!=1|v[b+88>>2]&2048){break b}t[i+6|0]=w[i+6|0]&254;break b}k=1;f=x[zj(v[d+4>>2])>>1];if(g>>>0>f>>>0){break c}break b}e:{f:{if(!(!(f&4)|w[b+669|0]&8)){if(x[i+4>>1]==65535){break f}ub(e+8|0,j,97);if(tb(v[v[e+8>>2]>>2],v[e+12>>2])){break f}f=w[d+12|0]}if(f&2){h=v[d>>2];f=x[Ib(h,w[d+13|0])>>1];h=x[Ib(h,w[d+14|0])>>1]+1|0;break e}f=x[zj(v[d+4>>2])>>1];k=g>>>0>f>>>0;h=f;break e}h=v[d>>2];f=x[Ib(h,w[d+15|0])>>1];h=x[Ib(h,w[d+16|0])>>1]+1|0}f=g>>>0<h>>>0?g:f}g:{if(!k|c){break g}g=v[a+480180>>2];c=v[b+88>>2];if(!(!(g&16777248)&(!(c&2048)|(g|0)==16384))){c=c|4096;v[b+88>>2]=c}if(w[zj(v[d+4>>2])+2|0]|!(v[a+480180>>2]&16777248?1:x[b+786>>1])){break g}v[b+696>>2]=0;v[b+720>>2]=0;v[b+680>>2]=0;v[b+88>>2]=c|4096}g=f}ub(e+8|0,j,31);m=i,n=tb(v[v[e+8>>2]>>2],v[e+12>>2])+g|0,v[m>>2]=n}cb=e+16|0}function zs(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=cb-144|0;cb=g;a:{b:{c:{d:{e:{f:{g:{h:{if(!d){break h}e=v[d+4>>2];if(!e&c>>>0<=y[d>>2]|e){break h}a=aa(8)|0;v[22440]=0;Q(215,a|0,21685)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break g}b=P()|0;O()|0;ba(a|0);break a}if(!b){a=aa(8)|0;v[22440]=0;T(839,a|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break f}b=P()|0;O()|0;ba(a|0);break a}e=cb-16|0;cb=e;_g(e+8|0,b,c);h=g+120|0;b=h;MD(b,v[e+8>>2],v[e+12>>2]);v[b+12>>2]=0;cb=e+16|0;i:{j:{if(a&2){b=Pm(g+96|0,h);v[22440]=0;b=T(840,b|0)|0;f=v[22440];v[22440]=0;e=1;if((f|0)==1){break i}if((b|0)==1){break j}e=Pm(g+72|0,h);v[22440]=0;f=T(841,e|0)|0;i=v[22440];v[22440]=0;e=1;if((i|0)==1){break e}k=(f|0)==1;if(k){break j}e=Pm(g+48|0,h);v[22440]=0;i=Q(842,e|0,d|0)|0;j=v[22440];v[22440]=0;e=1;if((j|0)==1){break d}l=(i|0)==1;if(l){break j}e=Pm(g+24|0,h);v[22440]=0;j=Q(843,e|0,d|0)|0;m=v[22440];v[22440]=0;e=1;if((m|0)==1){break c}if((j|0)==1){break j}b=(b|0)==-1?-1:0;b=k?b:(f|0)==-1?-1:b;f=(j|0)==-1?-1:l?b:(i|0)==-1?-1:b}k:{if(!(a&1)){break k}b=31664;while(1){if((b|0)==32204){break k}a=v[b>>2];if(a){e=Pm(g,h);v[22440]=0;a=Q(a|0,e|0,d|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break b}e=1;if((a|0)==1){break j}f=(a|0)==-1?-1:f}b=b+12|0;continue}}if(d){e=0;if((f|0)!=-1){break j}e=wc(v[d>>2],v[d+4>>2])>>>0>c>>>0?-1:0;break j}e=0;if((f|0)!=-1){break j}e=c>>>0>2047?1:-1}cb=g+144|0;return e}b=P()|0;O()|0;break a}ia(a|0,88640,25);L()}ia(a|0,88536,25);L()}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}S(b|0);L()}function ZI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=C(0);d=cb-48|0;cb=d;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;a=a+24|0;if((b|0)==v[v[a>>2]+24604>>2]){break d}c=d+8|0;a=v[a>>2];ic(c,a+24604|0,40);v[d+8>>2]=b;gy(a,c);break d;case 2:b=a+24|0;a=v[b>>2];e=a+24664|0;f=v[e+4>>2];v[d+24>>2]=v[e>>2];v[d+28>>2]=f;e=a+24656|0;f=v[e+4>>2];v[d+16>>2]=v[e>>2];v[d+20>>2]=f;e=v[a+24652>>2];v[d+8>>2]=v[a+24648>>2];v[d+12>>2]=e;e=cb-16|0;cb=e;a=3;f:{g:{h:{if(!c|(c|0)>7){break h}a=2;if((c|0)>2){break h}a=1;if((c|0)==2){break h}a=0;if((c|0)>0){break h}b=aa(8)|0;v[22440]=0;c=Q(56,e|0,10799)|0;a=v[22440];v[22440]=0;i:{if((a|0)!=1){oc(b,c);v[22440]=0;U(121,b|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break g}a=P()|0;O()|0;rb(c);break i}a=P()|0;O()|0;ba(b|0)}S(a|0);L()}cb=e+16|0;break f}L()}t[d+8|0]=a;a=v[b>>2];if(!dx(d+8|0,a+24648|0)){break d}fy(a,d+8|0);break d;case 3:b=d+8|0;a=a+24|0;ic(b,v[a>>2]+24604|0,40);e=cb-48|0;cb=e;j:{if((c|0)==-1){Zr(b,v[Op(e+8|0)+32>>2]);Jn(b,v[Op(e+8|0)+36>>2]);break j}if((c|0)<=0){Zr(b,0);Jn(b,0);break j}c=B(c,1e3);Zr(b,c);Jn(b,c)}cb=e+48|0;if(v[v[a>>2]+24636>>2]==v[d+40>>2]&v[v[a>>2]+24640>>2]==v[d+44>>2]){break d}gy(v[a>>2],d+8|0);break d;default:a=aa(8)|0;v[22440]=0;b=Q(56,d+8|0,10404)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}oc(a,b);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}c=P()|0;O()|0;rb(b);break b;case 0:break e}}g=a,h=te(C(10),C(C(C(c|0)*C(.0010000000474974513))*C(.5))),z[g+48>>2]=h}cb=d+48|0;return}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}function j_(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=cb-16|0;cb=x;v[c>>2]=a;A=d&512;while(1){if((y|0)==4){if(vb(n)>>>0>1){C=x,D=fd(n),v[C+8>>2]=D;e=cb-16|0;cb=e;v[e+8>>2]=v[x+8>>2];f=v[Fe(e+8|0)>>2];cb=e+16|0;C=c,D=YE(f,gf(n),v[c>>2]),v[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}cb=x+16|0;return}a:{b:{switch(t[i+y|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];q=Cl(g,32);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 3:if(xd(n)){break a}q=w[rc(n,0)|0];p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 2:if(xd(m)|!A){break a}C=c,D=YE(fd(m),gf(m),v[c>>2]),v[C>>2]=D;break a;case 4:break b;default:break a}}B=v[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!qh(g,2048,t[r|0])){break c}r=r+1|0;continue}break}q=o;if((q|0)>0){while(1){if(!(!q|e>>>0>=r>>>0)){r=r-1|0;p=w[r|0];s=v[c>>2];v[c>>2]=s+1;t[s|0]=p;q=q-1|0;continue}break}if(q){p=Cl(g,48)}else{p=0}while(1){s=v[c>>2];v[c>>2]=s+1;if((q|0)>0){t[s|0]=p;q=q-1|0;continue}break}t[s|0]=j}d:{if((e|0)==(r|0)){q=Cl(g,48);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break d}if(xd(l)){p=-1}else{p=t[rc(l,0)|0]}q=0;u=0;while(1){if((e|0)==(r|0)){break d}e:{if((q|0)!=(p|0)){s=q;break e}p=v[c>>2];v[c>>2]=p+1;t[p|0]=k;s=0;u=u+1|0;if(vb(l)>>>0<=u>>>0){p=q;break e}p=-1;if(w[rc(l,u)|0]==127){break e}p=t[rc(l,u)|0]}r=r-1|0;q=w[r|0];z=v[c>>2];v[c>>2]=z+1;t[z|0]=q;q=s+1|0;continue}}Nl(B,v[c>>2])}y=y+1|0;continue}}function Lba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;h=cb-48|0;cb=h;q=v[a+16>>2];f=ee(h+16|0);v[f+8>>2]=a+112;j=v[a+128>>2];v[f+16>>2]=j;w=f,x=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[w+12>>2]=x;n=v[a+8>>2];o=v[a+12>>2];if(j){w=f,x=kg(n,o,j),v[w>>2]=x;v[f+4>>2]=fb}g=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;a:while(1){b:{j=b;if(!d){break b}v[h+40>>2]=i;v[h+44>>2]=0;e=(e<<1)+q|0;b=v[f+16>>2];while(1)if((b|0)<=0){b=v[f+8>>2];i=v[b+8>>2];Jb(b,i,v[b+12>>2]);b=v[f+8>>2];i=v[b+4>>2];if(i){Jd(b,u[e+(v[h+44>>2]<<1)>>1]/4<<16>>16);Id(v[f+8>>2],i);b=v[f+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}d=d-1|0;i=v[a+72>>2];r=v[a+32>>2];m=v[a+28>>2]+m|0;e=v[a+60>>2];p=ig(b,v[f+12>>2])<<8;b=p;b=kka(e,e>>31,b,b>>31);s=fb;e=b;b=v[a+64>>2];k=b;t=b>>31;b=Vb(j,-16777216,16776704);k=kka(k,t,b,b>>31);e=e+k|0;b=fb+s|0;b=e>>>0<k>>>0?b+1|0:b;k=e;e=v[a+68>>2];g=Vb(g,-16777216,16776704);e=kka(e,e>>31,g,g>>31);g=k+e|0;b=fb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=Mc(g,b,24);g=(b|0)/256|0;v[c>>2]=B(m>>12,g)+v[c>>2];l=l+r|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,g);Jb(h+8|0,n,o);b=b-(i&p)|0;c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];g=j;continue a}else{Jd(v[f+8>>2],u[e+(v[h+44>>2]<<1)>>1]/4<<16>>16);Id(v[f+8>>2],4);Jb(h+40|0,v[f>>2],v[f+4>>2]);b=b-1|0;continue}}break}v[a+36>>2]=m;v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=l;v[a+48>>2]=g;v[a+44>>2]=j;v[a+20>>2]=m>>12;v[a+24>>2]=l>>12;cb=h+48|0}function Uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=cb-32|0;cb=g;q=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+16|0)|0;e=a+e|0;v[h>>2]=v[e+44>>2];v[h+4>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;r=v[a+8>>2];s=v[a+12>>2];a:while(1){if(d){b=v[g+8>>2];f=b>>>18|0;m=((((v[g+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+q|0;b=0;while(1)if((b|0)==2){m=v[a+72>>2];b=v[a+68>>2];k=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){o=(b<<2)+g|0;f=v[o>>2];e=(g+16|0)+(b<<3)|0;l=v[e+4>>2];j=v[e>>2];v[e+4>>2]=j;p=f<<8;f=p;f=kka(y,z,f,f>>31);n=fb;A=e;e=Vb(j,-16777216,16776704);j=kka(w,x,e,e>>31);f=j+f|0;e=fb+n|0;e=f>>>0<j>>>0?e+1|0:e;n=f;f=Vb(l,-16777216,16776704);l=kka(k,t,f,f>>31);f=n+l|0;e=fb+e|0;e=f>>>0<l>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Mc(f,e,24);v[A>>2]=e-(m&p);v[o>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(v[g>>2],i>>12);h=b+h|0;v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],h>>12);Jb(g+8|0,r,s);c=c+8|0;d=d-1|0;continue a}else{k=m+(b<<1)|0;e=u[k>>1];v[(b<<2)+g>>2]=e+((B(f,u[k+4>>1]-e|0)|0)/16384|0);b=b+1|0;continue}}break}b=v[g+8>>2];c=v[g+12>>2];v[a+36>>2]=i;v[a>>2]=b;v[a+4>>2]=c;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}cb=g+32|0}function OJ(a){var b=C(0),c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,k=C(0),l=0,m=C(0);d=cb-16|0;cb=d;b=px(z[a+4216>>2]);e=v[a+16>>2];z[d+12>>2]=b/C(y[e+24620>>2]);v[d+8>>2]=1056964608;b=cp(C(z[$l(d+12|0,d+8|0)>>2]*C(6.2831854820251465)));b=C(K(C(C(C(b+b)+C(3))/C(5))));z[a+4236>>2]=b;z[a+4240>>2]=K(C(C(1)-C(b*b)));b=C(C(z[a+4212>>2]*C(29))+C(2));a:{if(b<C(4294967296)&b>=C(0)){f=~~b>>>0;break a}f=0}t[a+4272|0]=f;c=2;b:{if(f>>>0<4){break b}c=3;if(f>>>0<8){break b}c=f>>>0<16?4:5}t[a+4273|0]=c;k=te(C(10),C(RJ(z[a+4208>>2])/C(20)));c=e+24620|0;l=d,m=C(px(z[a+4220>>2])/C(y[c>>2])),z[l+12>>2]=m;v[d+8>>2]=1056964608;g=z[$l(d+12|0,d+8|0)>>2];l=d,m=C(px(z[a+4224>>2])/C(y[c>>2])),z[l+12>>2]=m;v[d+8>>2]=1056964608;b=C(C(z[$l(d+12|0,d+8|0)>>2]*C(6.2831854820251465))*C(.5));i=cb-16|0;cb=i;e=(p(b),j(2));c=e&2147483647;c:{if(c>>>0<=1061752794){if(c>>>0<964689920){break c}b=mn(+b,0);break c}if(c>>>0<=1081824209){h=+b;if(c>>>0<=1075235811){b=mn(((e|0)>=0?-1.5707963267948966:1.5707963267948966)+h,1);break c}b=mn(((e|0)>=0?-3.141592653589793:3.141592653589793)+h,0);break c}if(c>>>0<=1088565717){h=+b;if(c>>>0<=1085271519){b=mn(((e|0)>=0?-4.71238898038469:4.71238898038469)+h,1);break c}b=mn(((e|0)>=0?-6.283185307179586:6.283185307179586)+h,0);break c}if(c>>>0>=2139095040){b=C(b-b);break c}c=Dw(b,i+8|0);b=mn(A[i+8>>3],c&1)}cb=i+16|0;b=C(C(C(1)-b)/C(b+C(1)));z[a+4268>>2]=b;g=cp(C(g*C(6.2831854820251465)));z[a+4264>>2]=-g;z[a+4260>>2]=C(C(k*C(K(C(C(1)-C(g*g)))))*C(K(C(C(1)-C(b*b)))))*z[(f<<2)+45680>>2];cb=d+16|0}function _3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=cb-48|0;cb=c;f=Rb(a);a:{b:{c:{d:{if(fj(b)){If(c+40|0);break d}v[22440]=0;R(1046,c+24|0,b|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}v[22440]=0;a=T(1030,c+24|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}v[c+40>>2]=a;Rf(c+24|0)}if(fj(b)){a=b+36|0}else{a=v[c+40>>2]}e=v[a+4>>2];g=v[a>>2];v[22440]=0;R(183,f|0,Ri(g,e)|0);e=v[22440];v[22440]=0;e:{if((e|0)!=1){i=c,j=yb(v[a>>2]),v[i+16>>2]=j;b=b+24|0;g=yb(v[a+4>>2]);f:{g:{h:{i:{j:{k:{while(1){a=v[c+16>>2];if(!Qb(a,g)){Xk(c+40|0);cb=c+48|0;return}e=xj(v[b>>2]+484360|0,w[a+16|0]);v[22440]=0;R(1047,c|0,e|0);d=v[22440];v[22440]=0;if((d|0)!=1){v[22440]=0;R(1033,c+24|0,c|0);d=v[22440];v[22440]=0;if((d|0)==1){break k}v[22440]=0;R(185,f|0,c+24|0);d=v[22440];v[22440]=0;if((d|0)==1){break j}rb(c+24|0);rb(c);l:{if(!xd(Vw(v[f+4>>2]))){break l}d=w[a+12|0];v[22440]=0;d=Q(318,e|0,d|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break f}if(!d){break l}d=v[v[b>>2]+1298404>>2];a=Sb(v[b>>2]+484344|0,x[Xb(v[e>>2],v[a+12>>2])>>1]);v[22440]=0;R(1040,c|0,a|0);a=v[22440];v[22440]=0;if((a|0)==1){break h}v[22440]=0;W(241,c+24|0,0,d|0,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break g}a=c+24|0;tc(Vw(v[f+4>>2]),a);rb(a);rb(c)}Fx(c+16|0);continue}break}b=P()|0;O()|0;break e}b=P()|0;O()|0;break i}b=P()|0;O()|0;rb(c+24|0)}rb(c);break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;rb(c);break e}b=P()|0;O()|0;break e}b=P()|0;O()|0}Xk(c+40|0);break a}b=P()|0;O()|0;Rf(c+24|0);break a}b=P()|0;O()|0}ad(f);S(b|0);L()}function Vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=cb-32|0;cb=g;q=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+16|0)|0;e=a+e|0;v[h>>2]=v[e+44>>2];v[h+4>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;r=v[a+8>>2];s=v[a+12>>2];a:while(1){if(d){b=v[g+8>>2];f=b>>>10&4194048;m=(((v[g+12>>2]&2147483647)<<1|b>>>31)&-2)+q|0;b=0;while(1)if((b|0)==2){m=v[a+72>>2];b=v[a+68>>2];k=b;u=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){o=(b<<2)+g|0;f=v[o>>2];e=(g+16|0)+(b<<3)|0;l=v[e+4>>2];j=v[e>>2];v[e+4>>2]=j;p=f<<8;f=p;f=kka(y,z,f,f>>31);n=fb;A=e;e=Vb(j,-16777216,16776704);j=kka(w,x,e,e>>31);f=j+f|0;e=fb+n|0;e=f>>>0<j>>>0?e+1|0:e;n=f;f=Vb(l,-16777216,16776704);l=kka(k,u,f,f>>31);f=n+l|0;e=fb+e|0;e=f>>>0<l>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Mc(f,e,24);v[A>>2]=e-(m&p);v[o>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(v[g>>2],i>>12);h=b+h|0;v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],h>>12);Jb(g+8|0,r,s);c=c+8|0;d=d-1|0;continue a}else{k=b+m|0;e=t[k|0];v[(b<<2)+g>>2]=((B(f,t[k+2|0]-e|0)|0)/16384|0)+(e<<8);b=b+1|0;continue}}break}b=v[g+8>>2];c=v[g+12>>2];v[a+36>>2]=i;v[a>>2]=b;v[a+4>>2]=c;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}cb=g+32|0}function pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=cb-16|0;cb=g;a:{b:{c:{h=v[a+12>>2];j=v[a+8>>2];d:{if((h|0)<=1&j>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&j>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&j>>>0>2147483647|h>>>0>4294967294){break d}break b}if((h|0)==1&j>>>0>2147483648|h>>>0>1){break b}}q=b+196648|0;break a}q=b+131112|0;break a}q=b+262184|0}t=v[a+16>>2];e=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];m=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=m;while(1){m=b;if(d){w=v[a+72>>2];x=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;b=v[a+64>>2];n=b;r=b>>31;b=Vb(m,-16777216,16776704);b=kka(n,r,b,b>>31);o=fb;r=i;i=b;b=v[a+60>>2];n=b;s=b>>31;f=(v[g+12>>2]<<1)+t|0;b=(v[g+8>>2]>>>16&65520)+q|0;f=(((((((B(u[f-4>>1],u[b+2>>1])+B(u[f-6>>1],u[b>>1])|0)+B(u[f-2>>1],u[b+4>>1])|0)+B(u[f>>1],u[b+6>>1])|0)+B(u[f+2>>1],u[b+8>>1])|0)+B(u[f+4>>1],u[b+10>>1])|0)+B(u[f+6>>1],u[b+12>>1])|0)+B(u[f+8>>1],u[b+14>>1])|0)/32768<<8;b=f;b=kka(n,s,b,b>>31);i=i+b|0;p=fb+o|0;p=b>>>0>i>>>0?p+1|0:p;b=v[a+68>>2];n=b;s=b>>31;b=Vb(e,-16777216,16776704);e=kka(n,s,b,b>>31);o=e+i|0;b=fb+p|0;b=e>>>0>o>>>0?b+1|0:b;e=o+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Mc(e,b,24);b=(e|0)/256|0;v[c>>2]=B(r,b)+v[c>>2];k=k+x|0;v[c+4>>2]=v[c+4>>2]+B(b,k>>12);Jb(g+8|0,j,h);b=e-(f&w)|0;c=c+8|0;d=d-1|0;e=m;continue}break}c=v[g+12>>2];b=v[g+8>>2];v[a+36>>2]=l;v[a>>2]=b;v[a+4>>2]=c;v[a+40>>2]=k;v[a+48>>2]=e;v[a+44>>2]=m;v[a+20>>2]=l>>12;v[a+24>>2]=k>>12;cb=g+16|0}function ida(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=cb-32|0;cb=g;p=v[a+16>>2];m=Zf(1,2);b=fb;q=b;Jb(a,m,b);b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+16|0)|0;e=a+e|0;v[h>>2]=v[e+44>>2];v[h+4>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;r=v[a+8>>2];s=v[a+12>>2];a:while(1){if(d){e=((((v[g+12>>2]&2147483647)<<1|v[g+8>>2]>>>31)&2147483646)<<1)+p|0;b=0;while(1)if((b|0)==2){t=v[a+72>>2];b=v[a+68>>2];w=b;x=b>>31;b=v[a+64>>2];y=b;z=b>>31;b=v[a+60>>2];A=b;C=b>>31;b=0;while(1){if((b|0)!=2){n=(b<<2)+g|0;f=v[n>>2];e=(g+16|0)+(b<<3)|0;k=v[e+4>>2];j=v[e>>2];v[e+4>>2]=j;o=f<<8;f=o;f=kka(A,C,f,f>>31);l=fb;D=e;e=Vb(j,-16777216,16776704);j=kka(y,z,e,e>>31);f=j+f|0;e=fb+l|0;e=f>>>0<j>>>0?e+1|0:e;l=f;f=Vb(k,-16777216,16776704);k=kka(w,x,f,f>>31);f=l+k|0;e=fb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Mc(f,e,24);v[D>>2]=e-(t&o);v[n>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(v[g>>2],i>>12);h=b+h|0;v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],h>>12);Jb(g+8|0,r,s);c=c+8|0;d=d-1|0;continue a}else{v[(b<<2)+g>>2]=u[e+(b<<1)>>1];b=b+1|0;continue}}break}b=v[g+8>>2];c=v[g+12>>2];v[a+36>>2]=i;v[a>>2]=b;v[a+4>>2]=c;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}lg(a,m,q);cb=g+32|0}function aka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=Db(a);k=vb(b);v[22440]=0;R(304,g|0,k|0);a=v[22440];v[22440]=0;a:{b:{if((a|0)!=1){a=0;c:{while(1){d:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break d}return}e=t[rc(b,a)|0];h=e&255;e:{f:{switch(f+1|0){case 1:f=1;g:{switch(h-123|0){case 2:f=3;break e;case 0:break e;default:break g}}f=0;v[22440]=0;Q(305,g|0,e|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){break e}break c;case 2:h:{switch(h-123|0){case 0:f=0;v[22440]=0;Q(305,g|0,123)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}break e;case 2:m=1;e=i+1|0;f=0;if(d>>>0<=i>>>0){i=e;break e}v[22440]=0;Q(306,g|0,rd(c,i)|0)|0;h=v[22440];v[22440]=0;i=e;if((h|0)!=1){break e}a=P()|0;O()|0;break b;default:break h}}f=-1;e=e-48|0;if((e&255)>>>0>9){break e}l=1;f=2;j=e;break e;case 3:f=-1;i:{switch(h-123|0){case 2:f=0;if(d>>>0<=j>>>0){break e}v[22440]=0;Q(306,g|0,rd(c,j)|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){break e}a=P()|0;O()|0;break b;case 0:break e;default:break i}}if((e-48&255)>>>0>9){break e}j=(e+B(j,10)|0)-48|0;l=1;f=2;break e;case 4:f=-1;if((e|0)!=125){break e}f=0;v[22440]=0;Q(305,g|0,125)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}break e;case 0:break f;default:break e}}f=-1}a=a+1|0;continue}break}b=aa(8)|0;v[22440]=0;T(120,b|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;U(121,b|0,41924,25);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;ba(b|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0}rb(g);S(a|0)}L()}function Ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=cb-32|0;cb=g;q=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+16|0)|0;e=a+e|0;v[f>>2]=v[e+44>>2];v[f+4>>2]=v[e+48>>2];b=b+1|0;continue}break}r=v[a+24>>2];s=v[a+20>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;t=v[a+8>>2];w=v[a+12>>2];a:while(1){if(d){e=v[g+8>>2];f=((((v[g+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+q|0;b=e>>>21&2040;j=u[b+39830>>1];k=u[b+39828>>1];l=u[b+39826>>1];m=u[b+39824>>1];b=0;while(1)if((b|0)==2){j=v[a+72>>2];b=v[a+68>>2];k=b;l=b>>31;b=v[a+64>>2];m=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){o=(b<<2)+g|0;f=v[o>>2];e=(g+16|0)+(b<<3)|0;i=v[e+4>>2];h=v[e>>2];v[e+4>>2]=h;p=f<<8;f=p;f=kka(y,z,f,f>>31);n=fb;A=e;e=Vb(h,-16777216,16776704);h=kka(m,x,e,e>>31);f=h+f|0;e=fb+n|0;e=f>>>0<h>>>0?e+1|0:e;n=f;f=Vb(i,-16777216,16776704);i=kka(k,l,f,f>>31);f=n+i|0;e=fb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Mc(f,e,24);v[A>>2]=e-(j&p);v[o>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g>>2],s);v[c+4>>2]=v[c+4>>2]+B(r,v[g+4>>2]);Jb(g+8|0,t,w);c=c+8|0;d=d-1|0;continue a}else{e=f+(b<<1)|0;v[(b<<2)+g>>2]=(((B(l,u[e>>1])+B(m,u[e-4>>1])|0)+B(k,u[e+4>>1])|0)+B(j,u[e+8>>1])|0)/16384;b=b+1|0;continue}}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}cb=g+32|0}function hM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=cb-16|0;cb=c;d=a+1074376|0;e=B(b,872);a:{if(v[(d+e|0)+704>>2]&134218752){break a}h=v[(a+e|0)+1075648>>2];if(!dk(h)|w[h+15|0]&2){break a}d=Il(a,d,b,2,1);if((d-1&255)>>>0>249){break a}g=v[(B(d,160)+a|0)+906140>>2];if(!g){break a}f=B(b,872)+a|0;d=w[f+1075780|0];b:{if(w[f+1075782|0]==1){t[c+8|0]=64;e=w[Tb(f+1075784|0,c+8|0)|0];break b}e=255;if(w[f+1075783|0]!=13){break b}t[c+8|0]=64;e=w[Tb((B(b,872)+a|0)+1075785|0,c+8|0)|0]}i=a+1074312|0;ub(c+8|0,i,2);if(tb(v[v[c+8>>2]>>2],v[c+12>>2])){if(d){if(Rc(d)){d=w[Eb(h+108|0,d-1|0)|0]}gm(a,b,d,x[(B(b,872)+a|0)+1075680>>1]);break a}if((e|0)==255){break a}gb[v[v[g>>2]+76>>2]](g,39,e,b);break a}j=v[h+4>>2];if(d){f=w[h+35|0]?j<<2:v[(B(b,872)+a|0)+1075680>>2];k=u[(B(b,872)+a|0)+1075768>>1];ub(c+8|0,i,28);l=c,m=f+(tb(v[v[c+8>>2]>>2],v[c+12>>2])?k<<2:k)|0,v[l+4>>2]=m;oe(c+4|0,0,256);f=a;if(Rc(d)){a=w[Eb(h+108|0,d-1|0)|0]}else{a=d}gm(f,b,a&255,x[c+4>>1])}f=w[h+35|0];ub(c+8|0,i,101);i=(e|0)!=255;if(tb(v[v[c+8>>2]>>2],v[c+12>>2])){a=(d|0)!=0}else{a=Rc(d)}if(!(a?0:i)&(!a|(f|0)!=1)){break a}c:{switch(w[h+36|0]){case 1:if((e|0)!=255){hL(v[g+20>>2],e<<1);break a}hL(v[g+20>>2],j<<1);break a;case 0:break c;default:break a}}if((e|0)!=255){t[c+8|0]=127;t[c+4|0]=e<<1;m=g,n=7,o=w[Tb(c+8|0,c+4|0)|0],p=b,l=v[v[g>>2]+76>>2],gb[l](m|0,n|0,o|0,p|0);break a}v[c+8>>2]=127;v[c+4>>2]=j<<1;p=g,o=7,n=w[Bb(c+8|0,c+4|0)|0],m=b,l=v[v[g>>2]+76>>2],gb[l](p|0,o|0,n|0,m|0)}cb=c+16|0}function $9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-112|0;cb=c;d=c+88|0;Aj(d,b,1413829443);v[22440]=0;b=T(180,d|0)|0;d=v[22440];v[22440]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){v[22440]=0;U(795,c- -64|0,a+140|0,1413894985);a=v[22440];v[22440]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){v[22440]=0;a=Q(873,c- -64|0,13692)|0;b=v[22440];v[22440]=0;if((b|0)==1){break e}b=28591;if(a){b=Db(c+48|0);v[22440]=0;a=T(204,c- -64|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break m}v[22440]=0;U(275,c- -64|0,b|0,a|0);a=v[22440];v[22440]=0;if((a|0)==1){break m}v[22440]=0;d=Q(55,c+16|0,b|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break l}v[22440]=0;Z(874,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break k}v[22440]=0;U(875,c+32|0,d|0,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break j}a=c+32|0;e=tc(b,a);rb(a);rb(c);rb(d);v[22440]=0;U(11,a|0,2,e|0);a=v[22440];v[22440]=0;if((a|0)==1){break h}v[22440]=0;a=T(764,c+32|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break g}rb(c+32|0);rb(e);b=a-1>>>0<19398657?1252:28591}sb(c- -64|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;rb(c)}rb(d);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;rb(c+32|0)}rb(b);break d}a=P()|0;O()|0}sb(c- -64|0);break b}v[22440]=0;a=Q(158,c+88|0,2)|0;b=v[22440];v[22440]=0;if((b|0)==1){break c}b=28591;if(!a){break a}v[22440]=0;b=T(196,c+88|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0}sb(c+88|0);S(a|0);L()}sb(c+88|0);cb=c+112|0;return b|0}function pX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=Db(a);j=vb(b);v[22440]=0;R(117,g|0,j|0);a=v[22440];v[22440]=0;a:{b:{if((a|0)!=1){a=0;c:{while(1){d:{if((a|0)==(j|0)){a=!f;if(!(k?a&(l^-1):a)){break d}return}e=w[rc(b,a)|0];e:{f:{switch(f+1|0){case 1:f=1;g:{switch(e-123|0){case 2:f=3;break e;case 0:break e;default:break g}}f=0;v[22440]=0;Q(118,g|0,e|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){break e}break c;case 2:h:{switch(e-123|0){case 0:f=0;v[22440]=0;Q(118,g|0,123)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}break e;case 2:l=1;e=h+1|0;f=0;if(d>>>0<=h>>>0){h=e;break e}v[22440]=0;Q(119,g|0,rd(c,h)|0)|0;m=v[22440];v[22440]=0;h=e;if((m|0)!=1){break e}a=P()|0;O()|0;break b;default:break h}}f=-1;e=e-48|0;if((e&255)>>>0>9){break e}k=1;f=2;i=e;break e;case 3:f=-1;i:{switch(e-123|0){case 2:f=0;if(d>>>0<=i>>>0){break e}v[22440]=0;Q(119,g|0,rd(c,i)|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){break e}a=P()|0;O()|0;break b;case 0:break e;default:break i}}if((e-48&255)>>>0>9){break e}i=(e+B(i,10)|0)-48|0;k=1;f=2;break e;case 4:f=-1;if((e|0)!=125){break e}f=0;v[22440]=0;Q(118,g|0,125)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}break e;case 0:break f;default:break e}}f=-1}a=a+1|0;continue}break}b=aa(8)|0;v[22440]=0;T(120,b|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;U(121,b|0,41924,25);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;ba(b|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0}rb(g);S(a|0)}L()}function cba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,A=0;f=cb+-64|0;cb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}k=e<<2;if(k>>>0>d>>>0){break g}s=k-4|0;n=B(b,e);x=n-8|0;h:while(1){v[22440]=0;b=Q(158,c|0,k|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break b}if(!(b&m>>>0<n>>>0)){break g}v[22440]=0;U(192,f+16|0,c|0,d|0);b=v[22440];v[22440]=0;if((b|0)==1){break c}h=f+40|0;b=f+16|0;o=cc(h,b);sb(b);v[22440]=0;R(573,b|0,h|0);b=v[22440];v[22440]=0;if((b|0)==1){break e}y=ce(f+16|0);p=v[f+16>>2];z=p-4|0;h=0;while(1){if((e|0)==(h|0)){m=(p-k<<1)+m|0;vc(f+16|0);sb(f+40|0);continue h}v[22440]=0;g=T(566,o|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){v[22440]=0;b=T(208,o|0)|0;j=v[22440];v[22440]=0;if((j|0)==1){break f}v[f+8>>2]=b;oe(f+8|0,0,89);v[22440]=0;Q(190,f+40|0,1)|0;b=v[22440];v[22440]=0;if((b|0)==1){break f}j=h+m|0;b=e+h<<2;i:while(1){j:{if(j>>>0>x>>>0){break j}l=0;if(b>>>0>z>>>0){break j}while(1)if((l|0)==8){b=b+s|0;continue i}else{q=v[f+8>>2];i=w[b+y|0];r=l&1;i=r?i>>>4|0:i&15;v[f+8>>2]=q+t[(i&7)+30376|0];A=g;g=u[(q<<1)+30384>>1];g=(((0-(i&1)&g>>2)+(g>>3)|0)+(i<<30>>31&g>>1)|0)+(g&i<<29>>31)|0;v[f+12>>2]=A+(i&8?0-g|0:g);oe(f+8|0,0,88);oe(f+12|0,-32768,32767);g=v[f+12>>2];u[(j<<1)+a>>1]=g;l=l+1|0;j=e+j|0;b=b+r|0;continue}}break}h=h+1|0;continue}break}break}break f}sb(c);cb=f- -64|0;return}b=P()|0;O()|0;vc(f+16|0);break d}b=P()|0;O()|0}sb(f+40|0);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}sb(c);S(b|0);L()}function Mba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0;h=cb-48|0;cb=h;q=v[a+16>>2];f=ee(h+16|0);v[f+8>>2]=a+112;j=v[a+128>>2];v[f+16>>2]=j;w=f,x=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[w+12>>2]=x;n=v[a+8>>2];o=v[a+12>>2];if(j){w=f,x=kg(n,o,j),v[w>>2]=x;v[f+4>>2]=fb}g=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;a:while(1){b:{j=b;if(!d){break b}v[h+40>>2]=i;v[h+44>>2]=0;e=e+q|0;b=v[f+16>>2];while(1)if((b|0)<=0){b=v[f+8>>2];i=v[b+8>>2];Jb(b,i,v[b+12>>2]);b=v[f+8>>2];i=v[b+4>>2];if(i){Jd(b,t[e+v[h+44>>2]|0]<<6);Id(v[f+8>>2],i);b=v[f+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}d=d-1|0;i=v[a+72>>2];r=v[a+32>>2];m=v[a+28>>2]+m|0;e=v[a+60>>2];p=ig(b,v[f+12>>2])<<8;b=p;b=kka(e,e>>31,b,b>>31);s=fb;e=b;b=v[a+64>>2];k=b;u=b>>31;b=Vb(j,-16777216,16776704);k=kka(k,u,b,b>>31);e=e+k|0;b=fb+s|0;b=e>>>0<k>>>0?b+1|0:b;k=e;e=v[a+68>>2];g=Vb(g,-16777216,16776704);e=kka(e,e>>31,g,g>>31);g=k+e|0;b=fb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=Mc(g,b,24);g=(b|0)/256|0;v[c>>2]=B(m>>12,g)+v[c>>2];l=l+r|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,g);Jb(h+8|0,n,o);b=b-(i&p)|0;c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];g=j;continue a}else{Jd(v[f+8>>2],t[e+v[h+44>>2]|0]<<6);Id(v[f+8>>2],4);Jb(h+40|0,v[f>>2],v[f+4>>2]);b=b-1|0;continue}}break}v[a+36>>2]=m;v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=l;v[a+48>>2]=g;v[a+44>>2]=j;v[a+20>>2]=m>>12;v[a+24>>2]=l>>12;cb=h+48|0}function jda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=cb-32|0;cb=g;p=v[a+16>>2];m=Zf(1,2);b=fb;q=b;Jb(a,m,b);b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+16|0)|0;e=a+e|0;v[h>>2]=v[e+44>>2];v[h+4>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;r=v[a+8>>2];s=v[a+12>>2];a:while(1){if(d){e=(((v[g+12>>2]&2147483647)<<1|v[g+8>>2]>>>31)&-2)+p|0;b=0;while(1)if((b|0)==2){u=v[a+72>>2];b=v[a+68>>2];w=b;x=b>>31;b=v[a+64>>2];y=b;z=b>>31;b=v[a+60>>2];A=b;C=b>>31;b=0;while(1){if((b|0)!=2){n=(b<<2)+g|0;f=v[n>>2];e=(g+16|0)+(b<<3)|0;k=v[e+4>>2];j=v[e>>2];v[e+4>>2]=j;o=f<<8;f=o;f=kka(A,C,f,f>>31);l=fb;D=e;e=Vb(j,-16777216,16776704);j=kka(y,z,e,e>>31);f=j+f|0;e=fb+l|0;e=f>>>0<j>>>0?e+1|0:e;l=f;f=Vb(k,-16777216,16776704);k=kka(w,x,f,f>>31);f=l+k|0;e=fb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Mc(f,e,24);v[D>>2]=e-(u&o);v[n>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(v[g>>2],i>>12);h=b+h|0;v[c+4>>2]=v[c+4>>2]+B(v[g+4>>2],h>>12);Jb(g+8|0,r,s);c=c+8|0;d=d-1|0;continue a}else{v[(b<<2)+g>>2]=t[b+e|0]<<8;b=b+1|0;continue}}break}b=v[g+8>>2];c=v[g+12>>2];v[a+36>>2]=i;v[a>>2]=b;v[a+4>>2]=c;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}lg(a,m,q);cb=g+32|0}function Jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0;g=cb-32|0;cb=g;q=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+16|0)|0;e=a+e|0;v[f>>2]=v[e+44>>2];v[f+4>>2]=v[e+48>>2];b=b+1|0;continue}break}r=v[a+24>>2];s=v[a+20>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];a:while(1){if(d){e=v[g+8>>2];f=(((v[g+12>>2]&2147483647)<<1|e>>>31)&-2)+q|0;b=e>>>21&2040;j=u[b+39830>>1];k=u[b+39828>>1];l=u[b+39826>>1];m=u[b+39824>>1];b=0;while(1)if((b|0)==2){j=v[a+72>>2];b=v[a+68>>2];k=b;l=b>>31;b=v[a+64>>2];m=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;b=0;while(1){if((b|0)!=2){o=(b<<2)+g|0;f=v[o>>2];e=(g+16|0)+(b<<3)|0;i=v[e+4>>2];h=v[e>>2];v[e+4>>2]=h;p=f<<8;f=p;f=kka(z,A,f,f>>31);n=fb;C=e;e=Vb(h,-16777216,16776704);h=kka(m,y,e,e>>31);f=h+f|0;e=fb+n|0;e=f>>>0<h>>>0?e+1|0:e;n=f;f=Vb(i,-16777216,16776704);i=kka(k,l,f,f>>31);f=n+i|0;e=fb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Mc(f,e,24);v[C>>2]=e-(j&p);v[o>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g>>2],s);v[c+4>>2]=v[c+4>>2]+B(r,v[g+4>>2]);Jb(g+8|0,w,x);c=c+8|0;d=d-1|0;continue a}else{e=b+f|0;v[(b<<2)+g>>2]=(((B(l,t[e|0])+B(m,t[e-2|0])|0)+B(k,t[e+2|0])|0)+B(j,t[e+4|0])<<8)/16384;b=b+1|0;continue}}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}cb=g+32|0}function qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=cb-16|0;cb=g;a:{b:{c:{h=v[a+12>>2];i=v[a+8>>2];d:{if((h|0)<=1&i>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|h>>>0>4294967294){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}o=b+196648|0;break a}o=b+131112|0;break a}o=b+262184|0}p=v[a+16>>2];b=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];l=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=l;while(1){l=e;if(d){q=v[a+72>>2];r=v[a+32>>2];k=v[a+28>>2]+k|0;e=v[a+64>>2];m=e;f=e>>31;e=Vb(l,-16777216,16776704);e=kka(m,f,e,e>>31);f=fb;m=e;e=v[a+68>>2];b=Vb(b,-16777216,16776704);e=kka(e,e>>31,b,b>>31);n=m+e|0;b=fb+f|0;b=e>>>0>n>>>0?b+1|0:b;e=v[a+60>>2];m=e;s=e>>31;f=v[g+12>>2]+p|0;e=(v[g+8>>2]>>>16&65520)+o|0;f=(((((((B(t[f-2|0],u[e+2>>1])+B(t[f-3|0],u[e>>1])|0)+B(t[f-1|0],u[e+4>>1])|0)+B(t[f|0],u[e+6>>1])|0)+B(t[f+1|0],u[e+8>>1])|0)+B(t[f+2|0],u[e+10>>1])|0)+B(t[f+3|0],u[e+12>>1])|0)+B(t[f+4|0],u[e+14>>1])<<8)/32768<<8;e=f;e=kka(m,s,e,e>>31);n=e+n|0;b=fb+b|0;b=e>>>0>n>>>0?b+1|0:b;e=n+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Mc(e,b,24);b=(e|0)/256|0;v[c>>2]=B(k>>12,b)+v[c>>2];j=j+r|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,b);Jb(g+8|0,i,h);e=e-(f&q)|0;c=c+8|0;d=d-1|0;b=l;continue}break}d=v[g+12>>2];c=v[g+8>>2];v[a+36>>2]=k;v[a>>2]=c;v[a+4>>2]=d;v[a+40>>2]=j;v[a+48>>2]=b;v[a+44>>2]=l;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;cb=g+16|0}function i9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;k=cb-16|0;cb=k;i=cb-32|0;cb=i;h=Me(i+16|0,1,0);a:{b:{c:{while(1){f=Fb(h);g=f+vb(h)|0;c=v[b>>2];d=v[b+4>>2];if(!((d|0)>0|(d|0)>=0|(f|0)==(g|0))){t[f|0]=45;e=c;c=0-c|0;f=f+1|0;d=0-(d+((e|0)!=0)|0)|0}m=i;d:{e:{e=g-f|0;if((e|0)<=19){j=E(d);j=B(64-((j|0)==32?E(c|1)+32|0:j)|0,1233)>>>12|0;l=(j<<3)+25904|0;n=e;e=v[l+4>>2];if((n|0)<((j-((d|0)==(e|0)&c>>>0<y[l>>2]|d>>>0<e>>>0)|0)+1|0)){break e}}f:{if(!d&c>>>0<=99999999){e=Aw(f,c);break f}if((d|0)==2328306&c>>>0<=1874919423|d>>>0<2328306){d=nka(c,d,1e8,0);g=fb;e=Aw(f,d);d=kka(d,g,-1e8,-1)+c|0;c=d;d=(c>>>0)/1e4|0;e=aj(aj(e,d),c+B(d,-1e4)|0);break f}g=nka(c,d,1874919424,2328306);j=fb;l=zw(f,g);g=kka(g,j,-1874919424,-2328307)+c|0;f=d+fb|0;d=g;c=nka(d,c>>>0>d>>>0?f+1|0:f,1e8,0);f=fb;g=(c>>>0)/1e4|0;e=aj(aj(l,g),c+B(g,-1e4)|0);c=kka(c,f,-1e8,-1)+d|0;d=(c>>>0)/1e4|0;e=aj(aj(e,d),c+B(d,-1e4)|0)}v[i+8>>2]=e;e=0;break d}v[i+8>>2]=g;e=61}v[m+12>>2]=e;if(!v[i+12>>2]){break c}c=Yf(vb(h));v[22440]=0;R(60,h|0,c|0);c=v[22440];v[22440]=0;if((c|0)!=1){continue}break}break b}b=v[i+8>>2];c=Fb(h);v[22440]=0;R(61,h|0,b-c|0);b=v[22440];v[22440]=0;g:{if((b|0)!=1){v[22440]=0;R(62,k|0,h|0);b=v[22440];v[22440]=0;if((b|0)!=1){break g}break b}break b}rb(h);cb=i+32|0;break a}a=P()|0;O()|0;rb(h);S(a|0);L()}v[22440]=0;R(59,a|0,k|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(k);cb=k+16|0;return}a=P()|0;O()|0;rb(k);S(a|0);L()}function Eda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=cb-48|0;cb=e;u[e+46>>1]=b;d=rj(a);f=e+32|0;g=yd(f);a:{b:{if(d){v[22440]=0;R(634,f|0,d|0);h=v[22440];v[22440]=0;if((h|0)==1){break b}fC(f,d)}break a}a=P()|0;O()|0;_c(g);S(a|0);L()}c:{d:{while(1){e:{if((c|0)==(d|0)){if(!(i&65535)){break c}b=yb(v[a>>2]);d=yb(v[a+4>>2]);c=cb-16|0;cb=c;b=Oz(b,d,e+46|0);v[c+8>>2]=b;if(Qb(b,d)){v[c>>2]=b;while(1){f:{Ne(c);b=v[c>>2];if(!Qb(b,d)){break f}b=x[b>>1];if((b|0)==x[e+46>>1]){continue}u[v[c+8>>2]>>1]=b;Ne(c+8|0);continue}break}b=v[c+8>>2]}cb=c+16|0;b=ac(e+24|0,b);c=v[ac(e+16|0,yb(v[a+4>>2]))>>2];d=v[b>>2];b=v[a>>2];b=(go(d,yb(b))<<1)+b|0;if(Qb(d,c)){Nd(a,Qi(b+(go(c,d)<<1)|0,v[a+4>>2],b))}yb(b);j=e,k=yb(v[a>>2]),v[j+8>>2]=k;c=yb(v[a+4>>2]);break e}j=Xb(v[f>>2],c),k=c-i|0,u[j>>1]=k;g=v[a+4>>2];h=v[a>>2];v[22440]=0;g=Y(770,h|0,g|0,c|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}c=c+1|0;i=(x[g>>1]==(b|0))+i|0;continue}break}while(1){b=v[e+8>>2];if(!Qb(b,c)){b=v[f>>2];d=Fc(b,v[f+4>>2]);c=x[a+28>>1];if(d>>>0<=c>>>0){break c}j=a,k=x[Xb(b,c)>>1],u[j+28>>1]=k;break c}g:{d=v[a+24>>2]+484344|0;b=x[b>>1];if(!ve(d,b)){break g}b=Sb(d,b);j=e,k=Pg(b),v[j>>2]=k;d=Og(b);while(1){b=v[e>>2];if(!Qb(b,d)){break g}h:{if(w[b+3|0]!=12){break h}i=v[f>>2];h=Fc(i,v[f+4>>2]);g=w[b+5|0];if(h>>>0<=g>>>0){break h}j=b,k=w[Xb(i,g)|0],t[j+5|0]=k}Ki(e);continue}}Ne(e+8|0);continue}}a=P()|0;O()|0;_c(f);S(a|0);L()}_c(f);cb=e+48|0}function n4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=cb-32|0;cb=d;f=Rb(a);g=b+24|0;h=rj(Nb(v[g>>2]+484360|0));v[22440]=0;R(183,f|0,h|0);a=v[22440];v[22440]=0;a:{if((a|0)!=1){a=0;while(1){b:{if((a|0)!=(h|0)){c=x[Xb(v[Nb(v[g>>2]+484360|0)>>2],a)>>1];if(Dm(v[g>>2]+484344|0,c)){c=v[g>>2];c=Sb(c+484344|0,x[Xb(v[Nb(c+484360|0)>>2],a)>>1]);v[22440]=0;R(1040,d|0,c|0);c=v[22440];v[22440]=0;c:{d:{e:{if((c|0)!=1){v[22440]=0;U(1027,d+16|0,b|0,d|0);c=v[22440];v[22440]=0;if((c|0)==1){break e}v[22440]=0;R(185,f|0,d+16|0);c=v[22440];v[22440]=0;if((c|0)==1){break d}rb(d+16|0);rb(d);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;rb(d+16|0)}rb(d);break a}f:{switch(c-65534|0){case 0:v[22440]=0;c=Q(56,d+16|0,9269)|0;e=v[22440];v[22440]=0;g:{if((e|0)!=1){v[22440]=0;R(185,f|0,c|0);e=v[22440];v[22440]=0;if((e|0)==1){break g}rb(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;rb(c);break a;case 1:v[22440]=0;c=Q(56,d+16|0,9231)|0;e=v[22440];v[22440]=0;h:{if((e|0)!=1){v[22440]=0;R(185,f|0,c|0);e=v[22440];v[22440]=0;if((e|0)==1){break h}rb(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;rb(c);break a;default:break f}}v[22440]=0;c=Q(56,d+16|0,14703)|0;e=v[22440];v[22440]=0;i:{if((e|0)!=1){v[22440]=0;R(185,f|0,c|0);e=v[22440];v[22440]=0;if((e|0)==1){break i}rb(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;rb(c);break a}cb=d+32|0;return}a=a+1|0;continue}}a=P()|0;O()|0}ad(f);S(a|0);L()}function i$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=cb-384|0;cb=a;v[a+368>>2]=c;v[a+376>>2]=b;Yv(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Db(a+200|0);b=Dc(d);v[22440]=0;R(61,d|0,b|0);b=v[22440];v[22440]=0;a:{b:{c:{if((b|0)!=1){c=rc(d,0);v[a+196>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;h=v[a+232>>2];i=v[a+236>>2];while(1){d:{v[22440]=0;b=Q(1164,a+376|0,a+368|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+196>>2];b=vb(d);if((g|0)==(b+c|0)){v[22440]=0;R(61,d|0,b<<1);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=rc(d,0);v[a+196>>2]=b+c}v[22440]=0;b=T(1166,v[a+376>>2])|0;g=v[22440];v[22440]=0;if((g|0)==1){break d}if(Xv(b,a+23|0,a+22|0,c,a+196|0,i,h,a+216|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[22440]=0;T(1168,a+376|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!vb(a+216|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}tF(a,c,v[a+196>>2],e);b=v[a>>2];c=v[a+4>>2];h=v[a+12>>2];v[f+8>>2]=v[a+8>>2];v[f+12>>2]=h;v[f>>2]=b;v[f+4>>2]=c;Mf(a+216|0,a+32|0,v[a+28>>2],e);v[22440]=0;b=Q(1165,a+376|0,a+368|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+376>>2];rb(d);rb(a+216|0);cb=a+384|0;break a}}b=P()|0;O()|0;rb(d);rb(a+216|0);S(b|0);L()}return b|0}function Pba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;h=cb-48|0;cb=h;o=v[a+16>>2];f=ee(h+16|0);v[f+8>>2]=a+112;j=v[a+128>>2];v[f+16>>2]=j;t=f,w=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+12>>2]=w;l=v[a+8>>2];m=v[a+12>>2];if(j){t=f,w=kg(l,m,j),v[t>>2]=w;v[f+4>>2]=fb}g=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];b=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;a:while(1){b:{j=b;if(!d){break b}v[h+40>>2]=i;v[h+44>>2]=0;e=(e<<1)+o|0;b=v[f+16>>2];while(1)if((b|0)<=0){b=v[f+8>>2];i=v[b+8>>2];Jb(b,i,v[b+12>>2]);b=v[f+8>>2];i=v[b+4>>2];if(i){Jd(b,u[e+(v[h+44>>2]<<1)>>1]/4<<16>>16);Id(v[f+8>>2],i);b=v[f+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}d=d-1|0;i=v[a+72>>2];e=v[a+60>>2];n=ig(b,v[f+12>>2])<<8;b=n;b=kka(e,e>>31,b,b>>31);r=fb;e=b;b=v[a+64>>2];k=b;s=b>>31;b=Vb(j,-16777216,16776704);k=kka(k,s,b,b>>31);e=e+k|0;b=fb+r|0;b=e>>>0<k>>>0?b+1|0:b;k=e;e=v[a+68>>2];g=Vb(g,-16777216,16776704);e=kka(e,e>>31,g,g>>31);g=k+e|0;b=fb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=Mc(g,b,24);g=(b|0)/256|0;v[c>>2]=B(g,q)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(g,p);Jb(h+8|0,l,m);b=b-(i&n)|0;c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];g=j;continue a}else{Jd(v[f+8>>2],u[e+(v[h+44>>2]<<1)>>1]/4<<16>>16);Id(v[f+8>>2],4);Jb(h+40|0,v[f>>2],v[f+4>>2]);b=b-1|0;continue}}break}v[a+48>>2]=g;v[a+44>>2]=j;v[a>>2]=i;v[a+4>>2]=e;cb=h+48|0}function r$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=cb-288|0;cb=a;v[a+272>>2]=c;v[a+280>>2]=b;aw(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Db(a+208|0);b=Dc(d);v[22440]=0;R(61,d|0,b|0);b=v[22440];v[22440]=0;a:{b:{c:{if((b|0)!=1){c=rc(d,0);v[a+204>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;h=t[a+238|0];i=t[a+239|0];while(1){d:{v[22440]=0;b=Q(1148,a+280|0,a+272|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+204>>2];b=vb(d);if((g|0)==(b+c|0)){v[22440]=0;R(61,d|0,b<<1);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=rc(d,0);v[a+204>>2]=b+c}v[22440]=0;b=T(1150,v[a+280>>2])|0;g=v[22440];v[22440]=0;if((g|0)==1){break d}if($v(b,a+23|0,a+22|0,c,a+204|0,i,h,a+224|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[22440]=0;T(1152,a+280|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!vb(a+224|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}tF(a,c,v[a+204>>2],e);b=v[a>>2];c=v[a+4>>2];h=v[a+12>>2];v[f+8>>2]=v[a+8>>2];v[f+12>>2]=h;v[f>>2]=b;v[f+4>>2]=c;Mf(a+224|0,a+32|0,v[a+28>>2],e);v[22440]=0;b=Q(1149,a+280|0,a+272|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+280>>2];rb(d);rb(a+224|0);cb=a+288|0;break a}}b=P()|0;O()|0;rb(d);rb(a+224|0);S(b|0);L()}return b|0}function Q_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=cb-432|0;cb=i;v[i+424>>2]=37;v[i+428>>2]=0;m=mr(i+424|1,13962,v[c+4>>2]);v[i+380>>2]=i+384;a=pd();a:{if(m){j=v[c+8>>2];k=i- -64|0;v[k>>2]=g;v[k+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=j;j=Lf(i+384|0,30,a,i+424|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;j=Lf(i+384|0,30,a,i+424|0,i+80|0)}v[i+128>>2]=1146;l=re(i+368|0,0,i+128|0);k=i+384|0;a=k;b:{c:{d:{if((j|0)>=30){a=pd();e:{if(m){j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i+8>>2]=e;v[i+12>>2]=f;v[i>>2]=j;j=Xi(i+380|0,a,i+424|0,i);break e}v[i+32>>2]=e;v[i+36>>2]=f;v[i+40>>2]=g;v[i+44>>2]=h;j=Xi(i+380|0,a,i+424|0,i+32|0)}if((j|0)==-1){v[22440]=0;X(1147);a=v[22440];v[22440]=0;if((a|0)==1){break c}break d}a=v[i+380>>2];Ue(l,a)}f=a+j|0;g=Yg(a,f,c);v[i+116>>2]=1146;e=re(i+120|0,0,i+116|0);f:{g:{if((i+384|0)==(a|0)){j=i+128|0;break g}j=Hd(j<<3);if(!j){v[22440]=0;X(1147);a=v[22440];v[22440]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ue(e,j);k=a}a=i+104|0;Jc(a,c);v[22440]=0;ja(1179,k|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=v[22440];v[22440]=0;h:{if((a|0)!=1){Pb(i+104|0);v[22440]=0;a=la(1180,b|0,j|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break h}Lc(e);Lc(l);cb=i+432|0;return a|0}c=P()|0;O()|0;Pb(i+104|0);break f}c=P()|0;O()|0}Lc(e);break b}L()}c=P()|0;O()|0}Lc(l);S(c|0);L()}function __(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=cb-256|0;cb=i;v[i+248>>2]=37;v[i+252>>2]=0;m=mr(i+248|1,13962,v[c+4>>2]);v[i+204>>2]=i+208;a=pd();a:{if(m){j=v[c+8>>2];k=i- -64|0;v[k>>2]=g;v[k+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=j;j=Lf(i+208|0,30,a,i+248|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;j=Lf(i+208|0,30,a,i+248|0,i+80|0)}v[i+128>>2]=1146;l=re(i+192|0,0,i+128|0);k=i+208|0;a=k;b:{c:{d:{if((j|0)>=30){a=pd();e:{if(m){j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i+8>>2]=e;v[i+12>>2]=f;v[i>>2]=j;j=Xi(i+204|0,a,i+248|0,i);break e}v[i+32>>2]=e;v[i+36>>2]=f;v[i+40>>2]=g;v[i+44>>2]=h;j=Xi(i+204|0,a,i+248|0,i+32|0)}if((j|0)==-1){v[22440]=0;X(1147);a=v[22440];v[22440]=0;if((a|0)==1){break c}break d}a=v[i+204>>2];Ue(l,a)}f=a+j|0;g=Yg(a,f,c);v[i+116>>2]=1146;e=re(i+120|0,0,i+116|0);f:{g:{if((i+208|0)==(a|0)){j=i+128|0;break g}j=Hd(j<<1);if(!j){v[22440]=0;X(1147);a=v[22440];v[22440]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ue(e,j);k=a}a=i+104|0;Jc(a,c);v[22440]=0;ja(1174,k|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=v[22440];v[22440]=0;h:{if((a|0)!=1){Pb(i+104|0);v[22440]=0;a=la(15,b|0,j|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break h}Lc(e);Lc(l);cb=i+256|0;return a|0}c=P()|0;O()|0;Pb(i+104|0);break f}c=P()|0;O()|0}Lc(e);break b}L()}c=P()|0;O()|0}Lc(l);S(c|0);L()}function Yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=cb-32|0;cb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+16|0)|0;e=a+e|0;v[f>>2]=v[e+44>>2];v[f+4>>2]=v[e+48>>2];b=b+1|0;continue}break}p=v[a+24>>2];q=v[a+20>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;r=v[a+8>>2];s=v[a+12>>2];a:while(1){if(d){b=v[g+8>>2];f=b>>>18|0;k=((((v[g+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+o|0;b=0;while(1)if((b|0)==2){k=v[a+72>>2];b=v[a+68>>2];i=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){m=(b<<2)+g|0;f=v[m>>2];e=(g+16|0)+(b<<3)|0;j=v[e+4>>2];h=v[e>>2];v[e+4>>2]=h;n=f<<8;f=n;f=kka(y,z,f,f>>31);l=fb;A=e;e=Vb(h,-16777216,16776704);h=kka(w,x,e,e>>31);f=h+f|0;e=fb+l|0;e=f>>>0<h>>>0?e+1|0:e;l=f;f=Vb(j,-16777216,16776704);j=kka(i,t,f,f>>31);f=l+j|0;e=fb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Mc(f,e,24);v[A>>2]=e-(k&n);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g>>2],q);v[c+4>>2]=v[c+4>>2]+B(p,v[g+4>>2]);Jb(g+8|0,r,s);c=c+8|0;d=d-1|0;continue a}else{i=k+(b<<1)|0;e=u[i>>1];v[(b<<2)+g>>2]=e+((B(f,u[i+4>>1]-e|0)|0)/16384|0);b=b+1|0;continue}}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}cb=g+32|0}function uq(a,b,c,d){var e=0,f=0;e=cb-16|0;cb=e;t[e+15|0]=c;a:{b:{c:{switch(b-2|0){case 11:t[e+14|0]=64;ae(a,1,Tb(e+15|0,e+14|0));break a;case 0:if(!(c&3|c>>>0>223?d:1)){break b}t[e+14|0]=c>>>2;ae(a,12,e+14|0);break a;case 1:if(!(c&3|c>>>0>223?d:1)){break b}t[e+14|0]=c>>>2;ae(a,13,e+14|0);break a;case 2:if(c>>>0>=240){t[e+14|0]=9;ae(a,11,e+14|0);break a}b=0;while(1){if((b|0)==10){break b}f=w[b+43856|0];d:{e:{if(d){if(c>>>0<=f>>>0){break e}break d}if((c|0)!=(f|0)){break d}}t[e+14|0]=b;ae(a,11,e+14|0);break a}b=b+1|0;continue};case 17:f:{switch((c>>>4|0)-8|0){case 0:t[e+14|0]=c<<2&60|2;ae(a,2,e+14|0);break a;case 2:t[e+14|0]=c&15;ae(a,5,e+14|0);break a;case 3:break f;default:break b}}t[e+14|0]=c&15;ae(a,6,e+14|0);break a;case 18:if((c&240)!=128){break b}t[e+14|0]=c<<2&60|2;ae(a,2,e+14|0);break a;case 9:if(!c){break b}b=c&15;if(!b){t[e+14|0]=c>>>4;ae(a,3,e+14|0);break a}d=c&240;if(!d){ae(a,4,e+15|0);break a}if((b|0)==15){t[e+14|0]=c>>>4;ae(a,5,e+14|0);break a}if((d|0)!=240){break b}t[e+14|0]=c&15;ae(a,6,e+14|0);break a;case 7:t[e+15|0]=(c|0)==255?64:c>>>2|0;ae(a,2,e+15|0);break a;case 24:g:{if(d){t[e+15|0]=0;break g}if(c){break b}}ae(a,8,e+15|0);break a;case 3:break c;default:break b}}h:{if(d){t[e+14|0]=c&15;t[e+13|0]=9;c=w[Tb(e+14|0,e+13|0)|0];t[e+15|0]=c;break h}if(c&240|(c&14)>>>0>9){break b}}t[e+14|0]=c&15;ae(a,8,e+14|0);break a}t[e+14|0]=0;ae(a,0,e+14|0)}cb=e+16|0}function h$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=cb-352|0;cb=a;v[a+336>>2]=c;v[a+344>>2]=b;h=Db(a+208|0);b=a+16|0;Jc(b,d);v[22440]=0;b=T(1159,b|0)|0;c=v[22440];v[22440]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[22440]=0;W(1171,b|0,79696,79722,a+224|0);b=v[22440];v[22440]=0;if((b|0)==1){break d}Pb(a+16|0);c=Db(a+192|0);b=Dc(c);v[22440]=0;R(61,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break b}b=rc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[22440]=0;d=Q(1164,a+344|0,a+336|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break e}if(!d){break c}g=v[a+188>>2];d=vb(c);if((g|0)==(d+b|0)){v[22440]=0;R(61,c|0,d<<1);b=v[22440];v[22440]=0;if((b|0)==1){break b}b=Dc(c);v[22440]=0;R(61,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break b}b=rc(c,0);v[a+188>>2]=d+b}v[22440]=0;d=T(1166,v[a+344>>2])|0;g=v[22440];v[22440]=0;if((g|0)==1){break e}if($m(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[22440]=0;T(1168,a+344|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;Pb(a+16|0);break a}v[22440]=0;R(61,c|0,v[a+188>>2]-b|0);b=v[22440];v[22440]=0;f:{if((b|0)==1){break f}b=Fb(c);d=pd();v[a>>2]=f;if((sF(b,d,a)|0)!=1){v[e>>2]=4}v[22440]=0;b=Q(1165,a+344|0,a+336|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];rb(c);rb(h);cb=a+352|0;return b|0}}b=P()|0;O()|0;rb(c)}rb(h);S(b|0);L()}function Zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=cb-32|0;cb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+16|0)|0;e=a+e|0;v[f>>2]=v[e+44>>2];v[f+4>>2]=v[e+48>>2];b=b+1|0;continue}break}p=v[a+24>>2];q=v[a+20>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;r=v[a+8>>2];s=v[a+12>>2];a:while(1){if(d){b=v[g+8>>2];f=b>>>10&4194048;k=(((v[g+12>>2]&2147483647)<<1|b>>>31)&-2)+o|0;b=0;while(1)if((b|0)==2){k=v[a+72>>2];b=v[a+68>>2];i=b;u=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;b=0;while(1){if((b|0)!=2){m=(b<<2)+g|0;f=v[m>>2];e=(g+16|0)+(b<<3)|0;j=v[e+4>>2];h=v[e>>2];v[e+4>>2]=h;n=f<<8;f=n;f=kka(y,z,f,f>>31);l=fb;A=e;e=Vb(h,-16777216,16776704);h=kka(w,x,e,e>>31);f=h+f|0;e=fb+l|0;e=f>>>0<h>>>0?e+1|0:e;l=f;f=Vb(j,-16777216,16776704);j=kka(i,u,f,f>>31);f=l+j|0;e=fb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Mc(f,e,24);v[A>>2]=e-(k&n);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g>>2],q);v[c+4>>2]=v[c+4>>2]+B(p,v[g+4>>2]);Jb(g+8|0,r,s);c=c+8|0;d=d-1|0;continue a}else{i=b+k|0;e=t[i|0];v[(b<<2)+g>>2]=((B(f,t[i+2|0]-e|0)|0)/16384|0)+(e<<8);b=b+1|0;continue}}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}cb=g+32|0}function q$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=cb-272|0;cb=a;v[a+256>>2]=c;v[a+264>>2]=b;h=Db(a+208|0);b=a+16|0;Jc(b,d);v[22440]=0;b=T(19,b|0)|0;c=v[22440];v[22440]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[22440]=0;W(1157,b|0,79696,79722,a+224|0);b=v[22440];v[22440]=0;if((b|0)==1){break d}Pb(a+16|0);c=Db(a+192|0);b=Dc(c);v[22440]=0;R(61,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break b}b=rc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[22440]=0;d=Q(1148,a+264|0,a+256|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break e}if(!d){break c}g=v[a+188>>2];d=vb(c);if((g|0)==(d+b|0)){v[22440]=0;R(61,c|0,d<<1);b=v[22440];v[22440]=0;if((b|0)==1){break b}b=Dc(c);v[22440]=0;R(61,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break b}b=rc(c,0);v[a+188>>2]=d+b}v[22440]=0;d=T(1150,v[a+264>>2])|0;g=v[22440];v[22440]=0;if((g|0)==1){break e}if(an(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[22440]=0;T(1152,a+264|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;Pb(a+16|0);break a}v[22440]=0;R(61,c|0,v[a+188>>2]-b|0);b=v[22440];v[22440]=0;f:{if((b|0)==1){break f}b=Fb(c);d=pd();v[a>>2]=f;if((sF(b,d,a)|0)!=1){v[e>>2]=4}v[22440]=0;b=Q(1149,a+264|0,a+256|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];rb(c);rb(h);cb=a+272|0;return b|0}}b=P()|0;O()|0;rb(c)}rb(h);S(b|0);L()}function gE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-96|0;cb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!b){jc(a,9769);break j}if(!(b&65535)){d=cb-16|0;cb=d;e=jc(d,4402);zc(c+80|0,e);rb(e);cb=d+16|0;v[22440]=0;v[c+24>>2]=b>>>24;R(111,c- -64|0,c+24|0);d=v[22440];v[22440]=0;k:{l:{m:{n:{if((d|0)!=1){v[22440]=0;v[c+8>>2]=b>>>16&255;R(112,c+48|0,c+8|0);b=v[22440];v[22440]=0;if((b|0)==1){break n}v[22440]=0;W(113,a|0,c+80|0,c- -64|0,c+48|0);a=v[22440];v[22440]=0;if((a|0)==1){break m}rb(c+48|0);rb(c- -64|0);Ab(c+80|0);break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;rb(c+48|0)}rb(c- -64|0)}break a}d=cb-16|0;cb=d;e=jc(d,4126);zc(c+80|0,e);rb(e);cb=d+16|0;v[22440]=0;v[c+44>>2]=b>>>24;R(111,c- -64|0,c+44|0);d=v[22440];v[22440]=0;if((d|0)==1){break i}v[22440]=0;v[c+40>>2]=b>>>16&255;R(112,c+48|0,c+40|0);d=v[22440];v[22440]=0;if((d|0)==1){break h}v[22440]=0;v[c+20>>2]=b>>>8&255;R(112,c+24|0,c+20|0);d=v[22440];v[22440]=0;if((d|0)==1){break g}v[22440]=0;v[c+4>>2]=b&255;R(112,c+8|0,c+4|0);b=v[22440];v[22440]=0;if((b|0)==1){break f}v[22440]=0;ka(114,a|0,c+80|0,c- -64|0,c+48|0,c+24|0,c+8|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}rb(c+8|0);rb(c+24|0);rb(c+48|0);rb(c- -64|0);Ab(c+80|0)}cb=c+96|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;rb(c+8|0)}rb(c+24|0)}rb(c+48|0)}rb(c- -64|0)}Ab(c+80|0);S(b|0);L()}function nda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=cb-32|0;cb=g;n=v[a+16>>2];k=Zf(1,2);b=fb;o=b;Jb(a,k,b);b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+16|0)|0;e=a+e|0;v[f>>2]=v[e+44>>2];v[f+4>>2]=v[e+48>>2];b=b+1|0;continue}break}p=v[a+24>>2];q=v[a+20>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;r=v[a+8>>2];s=v[a+12>>2];a:while(1){if(d){e=((((v[g+12>>2]&2147483647)<<1|v[g+8>>2]>>>31)&2147483646)<<1)+n|0;b=0;while(1)if((b|0)==2){t=v[a+72>>2];b=v[a+68>>2];w=b;x=b>>31;b=v[a+64>>2];y=b;z=b>>31;b=v[a+60>>2];A=b;C=b>>31;b=0;while(1){if((b|0)!=2){l=(b<<2)+g|0;f=v[l>>2];e=(g+16|0)+(b<<3)|0;i=v[e+4>>2];h=v[e>>2];v[e+4>>2]=h;m=f<<8;f=m;f=kka(A,C,f,f>>31);j=fb;D=e;e=Vb(h,-16777216,16776704);h=kka(y,z,e,e>>31);f=h+f|0;e=fb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Vb(i,-16777216,16776704);i=kka(w,x,f,f>>31);f=j+i|0;e=fb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Mc(f,e,24);v[D>>2]=e-(t&m);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g>>2],q);v[c+4>>2]=v[c+4>>2]+B(p,v[g+4>>2]);Jb(g+8|0,r,s);c=c+8|0;d=d-1|0;continue a}else{v[(b<<2)+g>>2]=u[e+(b<<1)>>1];b=b+1|0;continue}}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}lg(a,k,o);cb=g+32|0}function Ai(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!Sd(a)){break a}yk(a);b:{switch(Nm(x[a+34>>1])-1|0){case 1:e=cb+-64|0;cb=e;h=v[a+20>>2];c=v[a>>2];d=zd(x[a+34>>1]);f=h+(B(c,d)<<1)|0;while(1){c:{d:{if((g|0)!=16){i=B(d,g);j=B(d,g^-1);c=0;break d}g=f+(d<<5)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];ub(e+32|0,b+1074312|0,33);BO(e+40|0,g,h+(B(d,f)<<1)|0,i-f|0,d,(c&4)>>>2|0,tb(v[v[e+32>>2]>>2],v[e+36>>2]));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];ub(e+32|0,b+1074312|0,33);BO(e+8|0,g+(d<<7)|0,h+(B(a,d)<<1)|0,f-a|0,d,(c&16)>>>4|0,tb(v[v[e+32>>2]>>2],v[e+36>>2]))}cb=e- -64|0;break c}while(1){if((c|0)!=(d|0)){u[f+(c+i<<1)>>1]=x[f+(c-d<<1)>>1];u[h+(c+j<<1)>>1]=x[h+(c<<1)>>1];c=c+1|0;continue}break}g=g+1|0;continue}break};return;case 0:break b;default:break a}}e=cb+-64|0;cb=e;h=v[a+20>>2];c=v[a>>2];d=zd(x[a+34>>1]);f=h+B(c,d)|0;while(1){e:{f:{if((g|0)!=16){i=B(d,g);j=B(d,g^-1);c=0;break f}g=f+(d<<4)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];ub(e+32|0,b+1074312|0,33);AO(e+40|0,g,h+B(d,f)|0,i-f|0,d,(c&4)>>>2|0,tb(v[v[e+32>>2]>>2],v[e+36>>2]));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];ub(e+32|0,b+1074312|0,33);AO(e+8|0,g+(d<<6)|0,h+B(a,d)|0,f-a|0,d,(c&16)>>>4|0,tb(v[v[e+32>>2]>>2],v[e+36>>2]))}cb=e- -64|0;break e}while(1){if((c|0)!=(d|0)){t[f+(c+i|0)|0]=w[f+(c-d|0)|0];t[h+(c+j|0)|0]=w[c+h|0];c=c+1|0;continue}break}g=g+1|0;continue}break}}}function Aga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=cb-16|0;cb=e;a:{if((c|0)!=4){h=b+236|0;g=b+108|0;while(1){if((d|0)==120){break a}f=(d<<2)+a|0;i=Eb(g,d),j=w[f+4|0]+1|0,t[i|0]=j;f=f+6|0;i=Xb(h,d),j=(w[f|0]|w[f+1|0]<<8)+1|0,u[i>>1]=j;d=d+1|0;continue}}h=b+236|0;while(1){if((d|0)==96){break a}g=((d<<2)+a|0)+6|0;i=Xb(h,d+12|0),j=(w[g|0]|w[g+1|0]<<8)+1|0,u[i>>1]=j;d=d+1|0;continue}}Zz(a+484|0,b+48|0,0);Zz(a+590|0,b+68|0,0);Zz(a+696|0,b+88|0,5);d=a+806|0;v[b>>2]=w[d|0]|w[d+1|0]<<8;d=t[a+808|0];b:{if((d|0)<0){t[b+34|0]=d-127;break b}if(d>>>0>16){break b}if(t[a|0]&1){t[b+31|0]=d+1;break b}if((d-1&255)>>>0>15){break b}t[b+31|0]=d+1}if(w[b+31|0]){c:{d:{if((c|0)==4){d=a+810|0;break d}d=t[a+809|0];if((d|0)>=0){u[b+28>>1]=(d&255)+1}d=a+810|0;if(t[d|0]<0){break c}}t[b+30|0]=w[d|0]+1}t[b+33|0]=w[a+811|0]}if((c|0)==32){t[e+15|0]=w[a+812|0];t[e+14|0]=128;i=b,j=w[Tb(e+15|0,e+14|0)|0]>>>1|0,v[i+4>>2]=j}c=a+813|0;c=w[c|0]|w[c+1|0]<<8;if(c>>>0<=256){v[b+8>>2]=c;t[b+15|0]=w[b+15|0]|1}t[b+16|0]=w[a+815|0];t[b+26|0]=w[a+816|0];t[b+27|0]=w[a+817|0];t[b+17|0]=w[a+818|0];t[b+18|0]=w[a+819|0];c=a+820|0;u[e+12>>1]=w[c|0]|w[c+1|0]<<8;u[e+10>>1]=100;i=b,j=w[Kc(e+12|0,e+10|0)|0],t[i+20|0]=j;c=a+822|0;u[e+8>>1]=w[c|0]|w[c+1|0]<<8;u[e+6>>1]=256;i=b,j=x[Kc(e+8|0,e+6|0)>>1]>>>2|0,t[i+19|0]=j;c=w[a+824|0];Jj(b,c&127,c>>>7|0);a=w[a+825|0];Ij(b,a&127,a>>>7|0);cb=e+16|0}function Ky(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=cb-16|0;cb=h;f=v[c+656>>2];a:{if(!uj(f)){i=v[c+704>>2];f=cb-16|0;cb=f;v[f+12>>2]=d;g=0;b:{if(!d){break b}j=v[b+480180>>2];if(j&20){e=b+1074312|0;ub(f,e,73);d=tb(v[v[f>>2]>>2],v[f+4>>2])?d&65535:d;if(w[b+480208|0]&16){ub(f,e,73);e=tb(v[v[f>>2]>>2],v[f+4>>2])?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;g=v[((d>>>0)%768<<2)+34048>>2]<<6>>>e|0;break b}if(!d){v[f+12>>2]=1;d=1}g=229079296/(d>>>0)|0;break b}g=227001280/(d>>>0)|0;if(vm(j)){break b}g=(d+i<<4)-133808|0;if((j|0)==64){break b}qc(f+12|0,16777215);if(j&17408){g=wc(nka(kka(i?i:8363,0,3506176,0),fb,(v[f+12>>2]<<8)+e|0,0),fb);break b}if(lj(b)){d=v[f+12>>2];i=d>>>24|0;j=d<<8;d=j+e|0;e=i+(e>>31)|0;g=((d>>>0<j>>>0?e+1|0:e)&15)<<28|d>>>4;break b}if(w[b+480208|0]&16){g=wc(nka(kka(i?i:8363,0,7012352,0),fb,(v[f+12>>2]<<8)+e|0,0),fb);break b}g=wc(nka(-1485242368,13,(v[f+12>>2]<<8)+e|0,0),fb)}d=g;cb=f+16|0;f=v[c+656>>2];break a}d=v[c+700>>2]}v[h+12>>2]=d;c=u[c+774>>1];c:{if(!c){break c}c=f?B(t[f+33|0],c):c;if(!c){break c}d=Le(ni(+(c|0)/393216)*+(d>>>0));v[h+12>>2]=d}d:{if(!f){break d}c=v[f+40>>2];if(!c){break d}e=(c|0)/2|0;f=v[b+1074420>>2];d=kka(f,f>>31,d,d>>31);f=e+d|0;e=fb+(e>>31)|0;k=h,l=yc(lka(f,d>>>0>f>>>0?e+1|0:e,c,c>>31),fb),v[k+12>>2]=l}qc(h+12|0,2147483647);c=v[h+12>>2];b=Zf(c,v[b+24620>>2]<<4);v[a+8>>2]=c;v[a>>2]=b;v[a+4>>2]=fb;cb=h+16|0}function tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=cb-16|0;cb=g;a:{b:{c:{h=v[a+12>>2];i=v[a+8>>2];d:{if((h|0)<=1&i>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|h>>>0>4294967294){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];e=v[a+48>>2];r=v[a+24>>2];s=v[a+20>>2];b=v[a+44>>2];j=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=j;while(1){j=b;if(d){t=v[a+72>>2];b=v[a+64>>2];k=b;l=b>>31;b=Vb(j,-16777216,16776704);b=kka(k,l,b,b>>31);m=fb;l=b;b=v[a+60>>2];k=b;n=b>>31;f=(v[g+12>>2]<<1)+q|0;b=(v[g+8>>2]>>>16&65520)+p|0;f=(((((((B(u[f-4>>1],u[b+2>>1])+B(u[f-6>>1],u[b>>1])|0)+B(u[f-2>>1],u[b+4>>1])|0)+B(u[f>>1],u[b+6>>1])|0)+B(u[f+2>>1],u[b+8>>1])|0)+B(u[f+4>>1],u[b+10>>1])|0)+B(u[f+6>>1],u[b+12>>1])|0)+B(u[f+8>>1],u[b+14>>1])|0)/32768<<8;b=f;b=kka(k,n,b,b>>31);n=l+b|0;o=fb+m|0;o=b>>>0>n>>>0?o+1|0:o;b=v[a+68>>2];k=b;l=b>>31;b=Vb(e,-16777216,16776704);e=kka(k,l,b,b>>31);m=e+n|0;b=fb+o|0;b=e>>>0>m>>>0?b+1|0:b;e=m+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Mc(e,b,24);b=(e|0)/256|0;v[c>>2]=B(b,s)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(b,r);Jb(g+8|0,i,h);b=e-(f&t)|0;c=c+8|0;d=d-1|0;e=j;continue}break}c=v[g+12>>2];b=v[g+8>>2];v[a+48>>2]=e;v[a+44>>2]=j;v[a>>2]=b;v[a+4>>2]=c;cb=g+16|0}function Qba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;h=cb-48|0;cb=h;o=v[a+16>>2];f=ee(h+16|0);v[f+8>>2]=a+112;j=v[a+128>>2];v[f+16>>2]=j;u=f,w=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+12>>2]=w;l=v[a+8>>2];m=v[a+12>>2];if(j){u=f,w=kg(l,m,j),v[u>>2]=w;v[f+4>>2]=fb}g=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];b=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;a:while(1){b:{j=b;if(!d){break b}v[h+40>>2]=i;v[h+44>>2]=0;e=e+o|0;b=v[f+16>>2];while(1)if((b|0)<=0){b=v[f+8>>2];i=v[b+8>>2];Jb(b,i,v[b+12>>2]);b=v[f+8>>2];i=v[b+4>>2];if(i){Jd(b,t[e+v[h+44>>2]|0]<<6);Id(v[f+8>>2],i);b=v[f+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}d=d-1|0;i=v[a+72>>2];e=v[a+60>>2];n=ig(b,v[f+12>>2])<<8;b=n;b=kka(e,e>>31,b,b>>31);r=fb;e=b;b=v[a+64>>2];k=b;s=b>>31;b=Vb(j,-16777216,16776704);k=kka(k,s,b,b>>31);e=e+k|0;b=fb+r|0;b=e>>>0<k>>>0?b+1|0:b;k=e;e=v[a+68>>2];g=Vb(g,-16777216,16776704);e=kka(e,e>>31,g,g>>31);g=k+e|0;b=fb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=Mc(g,b,24);g=(b|0)/256|0;v[c>>2]=B(g,q)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(g,p);Jb(h+8|0,l,m);b=b-(i&n)|0;c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];g=j;continue a}else{Jd(v[f+8>>2],t[e+v[h+44>>2]|0]<<6);Id(v[f+8>>2],4);Jb(h+40|0,v[f>>2],v[f+4>>2]);b=b-1|0;continue}}break}v[a+48>>2]=g;v[a+44>>2]=j;v[a>>2]=i;v[a+4>>2]=e;cb=h+48|0}function kR(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=cb-16|0;cb=j;a:{if((b|0)==(c|0)){break a}v[j+12>>2]=-1953789045;Pz(b,c,j+12|0);c=c-b|0;e=c>>2;v[j+8>>2]=e;f=v[a>>2];i=pc(f,v[a+4>>2]);d=11;b:{if(c>>>0>2488){break b}d=7;if(c>>>0>268){break b}d=5;if(c>>>0>152){break b}d=3;if(c>>>0>24){break b}d=e-1>>>1|0}a=i+1|0;v[j+4>>2]=a;c=v[Pc(j+4|0,j+8|0)>>2];m=e-d>>>1|0;k=(m<<2)+b|0;h=v[k>>2];g=B(Bt(v[((e<<2)+b|0)-4>>2]^(h^v[b>>2])),1664525);v[k>>2]=g+h;k=d+m|0;d=(k<<2)+b|0;h=d;l=v[d>>2];d=g+i|0;v[h>>2]=l+d;v[b>>2]=d;d=1;while(1)if(d>>>0>i>>>0){while(1)if(a>>>0>=c>>>0){a=c;while(1){if(c+e>>>0<=a>>>0){break a}f=((a+m>>>0)%(e>>>0)<<2)+b|0;h=v[f>>2];i=(a>>>0)%(e>>>0)|0;g=(i<<2)+b|0;d=B(Bt(v[((a-1>>>0)%(e>>>0)<<2)+b>>2]+(h+v[g>>2]|0)|0),1566083941);v[f>>2]=d^h;f=((a+k>>>0)%(e>>>0)<<2)+b|0;d=d-i|0;v[f>>2]=d^v[f>>2];v[g>>2]=d;a=a+1|0;continue}}else{f=((a+m>>>0)%(e>>>0)<<2)+b|0;h=v[f>>2];i=(a>>>0)%(e>>>0)|0;g=(i<<2)+b|0;d=B(Bt(v[((a-1>>>0)%(e>>>0)<<2)+b>>2]^(h^v[g>>2])),1664525);v[f>>2]=d+h;f=((a+k>>>0)%(e>>>0)<<2)+b|0;d=d+i|0;v[f>>2]=d+v[f>>2];v[g>>2]=d;a=a+1|0;continue}}else{h=d-1|0;l=((d+m>>>0)%(e>>>0)<<2)+b|0;n=v[l>>2];o=(d>>>0)%(e>>>0)|0;p=(o<<2)+b|0;g=B(Bt(v[((h>>>0)%(e>>>0)<<2)+b>>2]^(n^v[p>>2])),1664525);v[l>>2]=g+n;l=((d+k>>>0)%(e>>>0)<<2)+b|0;n=v[l>>2];g=v[Ib(f,h)>>2]+(g+o|0)|0;v[l>>2]=g+n;v[p>>2]=g;d=d+1|0;continue}}cb=j+16|0}function oda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=cb-32|0;cb=g;n=v[a+16>>2];k=Zf(1,2);b=fb;o=b;Jb(a,k,b);b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+16|0)|0;e=a+e|0;v[f>>2]=v[e+44>>2];v[f+4>>2]=v[e+48>>2];b=b+1|0;continue}break}p=v[a+24>>2];q=v[a+20>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;r=v[a+8>>2];s=v[a+12>>2];a:while(1){if(d){e=(((v[g+12>>2]&2147483647)<<1|v[g+8>>2]>>>31)&-2)+n|0;b=0;while(1)if((b|0)==2){u=v[a+72>>2];b=v[a+68>>2];w=b;x=b>>31;b=v[a+64>>2];y=b;z=b>>31;b=v[a+60>>2];A=b;C=b>>31;b=0;while(1){if((b|0)!=2){l=(b<<2)+g|0;f=v[l>>2];e=(g+16|0)+(b<<3)|0;i=v[e+4>>2];h=v[e>>2];v[e+4>>2]=h;m=f<<8;f=m;f=kka(A,C,f,f>>31);j=fb;D=e;e=Vb(h,-16777216,16776704);h=kka(y,z,e,e>>31);f=h+f|0;e=fb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Vb(i,-16777216,16776704);i=kka(w,x,f,f>>31);f=j+i|0;e=fb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Mc(f,e,24);v[D>>2]=e-(u&m);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g>>2],q);v[c+4>>2]=v[c+4>>2]+B(p,v[g+4>>2]);Jb(g+8|0,r,s);c=c+8|0;d=d-1|0;continue a}else{v[(b<<2)+g>>2]=t[b+e|0]<<8;b=b+1|0;continue}}break}b=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+16|0)|0;v[d+44>>2]=v[c>>2];v[d+48>>2]=v[c+4>>2];b=b+1|0;continue}break}lg(a,k,o);cb=g+32|0}function OY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=cb-16|0;cb=n;b=c;while(1){a:{if((b|0)==(d|0)){b=d;break a}if(!v[b>>2]){break a}b=b+4|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){q=1;r=cb-16|0;cb=r;s=gi(r+8|0,v[a+8>>2]);i=f;j=g-f|0;m=0;o=cb-16|0;cb=o;k=v[e>>2];p=b-c>>2;d:{if(!k|!p){break d}j=i?j:0;while(1){l=Cw(j>>>0<4?o+12|0:i,v[k>>2]);if((l|0)==-1){m=-1;break d}if(i){if(j>>>0<=3){if(j>>>0<l>>>0){break d}ic(i,o+12|0,l)}j=j-l|0;i=i+l|0}else{i=0}if(!v[k>>2]){k=0;break d}m=m+l|0;k=k+4|0;p=p-1|0;if(p){continue}break}}if(i){v[e>>2]=k}cb=o+16|0;fi(s);cb=r+16|0;e:{f:{g:{h:{switch(m+1|0){case 0:v[h>>2]=f;while(1){i:{if(v[e>>2]==(c|0)){break i}b=Nv(f,v[c>>2],v[a+8>>2]);if((b|0)==-1){break i}f=b+v[h>>2]|0;v[h>>2]=f;c=c+4|0;continue}break};v[e>>2]=c;break g;case 1:break c;default:break h}}f=m+v[h>>2]|0;v[h>>2]=f;if((f|0)==(g|0)){break e}if((b|0)==(d|0)){c=v[e>>2];b=d;continue}b=Nv(n+12|0,0,v[a+8>>2]);if((b|0)!=-1){break f}}q=2;break c}c=n+12|0;if(g-v[h>>2]>>>0<b>>>0){break c}while(1){if(b){f=w[c|0];i=v[h>>2];v[h>>2]=i+1;t[i|0]=f;b=b-1|0;c=c+1|0;continue}break}c=v[e>>2]+4|0;v[e>>2]=c;b=c;while(1){if((b|0)==(d|0)){b=d;break b}if(!v[b>>2]){break b}b=b+4|0;continue}}c=v[e>>2]}q=(c|0)!=(d|0)}cb=n+16|0;return q|0}f=v[h>>2];continue}}function ky(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=88;j=92;k=91;l=85;m=84;n=83;o=5;p=113;q=111;r=107;s=106;t=96;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;c=qy(a);a:{b:{c:{d:{switch(b-1|0){default:a=(b|0)==16777216;if(!a&(b|0)!=32){break c}Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(c,0,1),7,1),8,1),9,1),10,1),11,1),12,1),13,1),14,1),15,1),16,1),17,1),18,1),19,1),20,1),21,1),22,1),23,1),24,1),25,1),26,1),27,1),28,1),29,1),30,1),31,1),32,1),33,1),34,1),35,1),36,1),37,1),38,1),39,1),40,1),41,1),42,1),43,1),44,1),45,1),46,1),47,1),48,1),103,1),50,1),87,1),88,1),100,1),102,1),104,1),115,1);if(!a){break a}d=111;e=105;f=99;break b;case 3:Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(c,0,1),4,1),8,1),9,1),10,1),17,1),40,1),51,1),52,1),53,1),54,1),55,1),56,1),57,1),58,1),59,1),60,1),61,1),62,1),63,1),64,1),65,1),66,1),67,1);p=112;q=98;r=93;s=90;t=89;u=86;v=76;w=75;x=74;y=73;z=72;A=71;d=70;e=69;g=68;case 1:Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(c,g,1),e,1),d,1),A,1),z,1),y,1),x,1),w,1);m=88;o=v;n=u;l=t;k=s;j=r;i=q;h=p;break;case 2:break c;case 0:break d}}Gb(Gb(Gb(Gb(c,o,1),n,1),m,1),l,1);g=k;f=j;e=i;d=h}Gb(c,g,1)}Gb(Gb(Gb(c,f,1),e,1),d,1)}}function PM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=cb-32|0;cb=e;f=v[b+64>>2];a:{b:{h=v[b+60>>2];g=x[b+68>>1];if(!((h|0)==-1&(g|0)==65535)){c:{if((f|0)==-1){break c}f=a+1074312|0;ub(e+24|0,f,68);if(tb(v[v[e+24>>2]>>2],v[e+28>>2])){break c}ub(e+16|0,f,103);if(i=tb(v[v[e+16>>2]>>2],v[e+20>>2]),j=0,k=(g|0)!=65535,k?i:j){break c}ub(e+8|0,f,49);if(i=tb(v[v[e+8>>2]>>2],v[e+12>>2]),j=0,k=(g|0)!=65535,k?i:j){break c}f=v[b+64>>2];break b}if((g|0)==65535){u[b+68>>1]=x[b+72>>1]+1}if((h|0)==-1){v[b+60>>2]=0}g=Fc(v[c>>2],v[c+4>>2]);f=x[b+68>>1];if(g>>>0<=f>>>0){f=x[c+28>>1];u[b+68>>1]=f}d:{if(x[b+72>>1]==(f&65535)){break d}c=a+1074312|0;ub(e+24|0,c,26);if(tb(v[v[e+24>>2]>>2],v[e+28>>2])){break d}ub(e+16|0,c,68);if(tb(v[v[e+16>>2]>>2],v[e+20>>2])|v[a+480180>>2]==1){break d}c=x[a+480188>>1];f=0;while(1){if((c|0)==(f|0)){break d}t[(B(f,872)+b|0)+1457|0]=0;f=f+1|0;continue}}v[b+52>>2]=v[b+60>>2];if(d){c=1;if(w[a+480208|0]&32){break a}}u[b+74>>1]=x[b+68>>1];c=1;break a}if((f|0)!=-1){break b}c=0;break a}v[b+52>>2]=f;u[b+74>>1]=x[b+72>>1];e:{if(!v[b+20>>2]){break e}c=v[a+480180>>2];if((c|0)==32){ub(e+24|0,a+1074312|0,103);if(tb(v[v[e+24>>2]>>2],v[e+28>>2])){break e}c=v[a+480180>>2]}if((c|0)==2){break e}v[b+52>>2]=v[b+52>>2]+1}c=0;if(y[b+64>>2]<y[Sb(a+484344|0,x[b+70>>1])+12>>2]){break a}v[b+52>>2]=0;u[b+74>>1]=x[b+74>>1]+1;c=0}cb=e+32|0;return c}function BH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=cb-16|0;cb=h;f=a+8|0;g=cs(f);if(!g){g=bs(f)}a:{b:{c:{if(b>>>0>=g>>>0){b=aa(8)|0;v[22440]=0;c=Q(56,h|0,6003)|0;a=v[22440];v[22440]=0;if((a|0)==1){break c}oc(b,c);v[22440]=0;U(121,b|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;rb(c);break b}if(c>>>0>=120){b=aa(8)|0;v[22440]=0;c=Q(56,h|0,11354)|0;a=v[22440];v[22440]=0;if((a|0)!=1){oc(b,c);v[22440]=0;U(121,b|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;rb(c);break b}a=P()|0;O()|0;ba(b|0);break b}g=a+32|0;a=v[g>>2];f=wy(a,65535);i=(f|0)==65535?255:f;u[h>>1]=i;a=a+B(i,872)|0;f=a+1074992|0;Ln(f,v[g>>2],65535,1024);c=c+1|0;t[a+1075794|0]=c;t[a+1075791|0]=c;u[a+1075778>>1]=0;hm(f);Ap(v[g>>2],f,b+1|0,0,1,1);v[a+1075688>>2]=65536;Qs(v[g>>2],f,c,0,1,1,65535);l=a+1075684|0,m=tl(Wt(e*128,-128,128)+128),v[l>>2]=m;l=a+1075680|0,m=tl(Wt(d*256,0,256)),v[l>>2]=m;b=v[g>>2];a=b+1074478|0;k=a;b=(x[b+480212>>1]<<1)+a|0;f=x[h>>1];c=f;while(1){d:{e:{if((a|0)!=(b|0)){if((c|0)!=x[a>>1]){break e}}else{a=b}break d}a=a+2|0;continue}break}f:{if((a|0)==(b|0)){break f}c=a;while(1){c=c+2|0;if((c|0)==(b|0)){b=a;break f}j=x[c>>1];if((j|0)==(f|0)){continue}u[a>>1]=j;a=a+2|0;f=x[h>>1];continue}}a=jt(k,b);u[v[g>>2]+480212>>1]=a;cb=h+16|0;return i|0}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function qia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=cb-80|0;cb=d;b=b&4095;u[d+78>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=cb-16|0;cb=e;f=jc(e,4454);zc(d- -64|0,f);rb(f);cb=e+16|0;v[22440]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=kka(e,e>>31,1e4,0)+14780|0;b=fb;b=lka(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(B(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;v[d+44>>2]=g+f;R(99,d+48|0,d+44|0);g=v[22440];v[22440]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){v[22440]=0;v[d+28>>2]=(e+B(f,-12)|0)+1;R(101,d+32|0,d+28|0);e=v[22440];v[22440]=0;if((e|0)==1){break j}v[22440]=0;v[d+12>>2]=(((B(b,306)+5|0)/-10|0)+c|0)+1;R(101,d+16|0,d+12|0);b=v[22440];v[22440]=0;if((b|0)==1){break i}v[22440]=0;ga(415,a|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[22440];v[22440]=0;if((a|0)==1){break h}rb(d+16|0);rb(d+32|0);break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;rb(d+16|0)}rb(d+32|0)}rb(d+48|0)}break a}Xf(d- -64|0,4434);v[22440]=0;R(416,d+48|0,d+78|0);b=v[22440];v[22440]=0;if((b|0)==1){break c}v[22440]=0;U(147,a|0,d- -64|0,d+48|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}}rb(d+48|0);Ab(d- -64|0);cb=d+80|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;rb(d+48|0)}Ab(d- -64|0);S(b|0);L()}function zV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=cb-32|0;cb=g;sc(c);while(1){a:{if(!Kb(c,3)){break a}f=g+24|0;Bq(f,c);i=Ec(f);e=Oe(f);f=w[f|0];if(f>>>0>=y[a+12>>2]){break a}h=Zc(a,f,b);f=w[i|0];if(f>>>0<=126){if(!(f|w[e|0])){t[h|0]=254;continue}t[h|0]=f+1;if(w[e|0]==255){continue}t[h+2|0]=1;t[h+4|0]=w[e|0];continue}b:{switch(f-127|0){case 1:t[h+1|0]=w[e|0]+1;continue;case 0:continue;default:break b}}d=t[e|0];t[g+23|0]=d;f=0;j=w[i|0];e=j&127;if(e>>>0<=23){f=w[e+26304|0]}c:{d:{e:{f:{g:{switch(e-2|0){case 0:case 8:case 9:if((d|0)>=0){break f}e=0-d&15;break e;case 1:t[g+16|0]=64;d=w[Tb(g+23|0,g+16|0)|0];if(w[h+2|0]>1){break d}t[h+4|0]=d;t[h+2|0]=1;continue;case 2:e=3;if((d|0)>=0){break c}e=0-d&127;break e;case 15:if(!d){continue}e=0-d|-16;if((d|0)<0){break e}e=d<<4|15;break e;case 16:case 20:if(!d){continue}f=(d|0)>=0;if(!f){d=0-d&15;t[g+23|0]=d;j=w[i|0]}e=f?3:2;d=((j|0)==22?-32:-16)|d;t[g+23|0]=d;break c;case 17:e=d&15|-48;break e;case 18:e=d&15|-64;break e;case 21:break g;default:break d}}e=164;if((d|0)==100){break e}v[g+16>>2]=d- -64;v[g+12>>2]=0;v[g+8>>2]=128;d=v[Gj(g+16|0,g+12|0,g+8|0)>>2];if(!w[h+3|0]){break d}h:{switch(w[h+2|0]){case 0:case 2:break h;default:continue}}t[h+2|0]=2;t[h+4|0]=(d&254)>>>1;continue}e=d<<4}d=e;t[g+23|0]=d}e=f;if(!f){continue}}t[h+5|0]=d;t[h+3|0]=e;continue}break}cb=g+32|0}function uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=cb-16|0;cb=g;a:{b:{c:{h=v[a+12>>2];i=v[a+8>>2];d:{if((h|0)<=1&i>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|h>>>0>4294967294){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}n=v[a+16>>2];b=v[a+48>>2];o=v[a+24>>2];p=v[a+20>>2];e=v[a+44>>2];j=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=j;while(1){j=e;if(d){q=v[a+72>>2];e=v[a+64>>2];k=e;f=e>>31;e=Vb(j,-16777216,16776704);e=kka(k,f,e,e>>31);f=fb;k=e;e=v[a+68>>2];b=Vb(b,-16777216,16776704);e=kka(e,e>>31,b,b>>31);l=k+e|0;b=fb+f|0;b=e>>>0>l>>>0?b+1|0:b;e=v[a+60>>2];k=e;r=e>>31;f=v[g+12>>2]+n|0;e=(v[g+8>>2]>>>16&65520)+m|0;f=(((((((B(t[f-2|0],u[e+2>>1])+B(t[f-3|0],u[e>>1])|0)+B(t[f-1|0],u[e+4>>1])|0)+B(t[f|0],u[e+6>>1])|0)+B(t[f+1|0],u[e+8>>1])|0)+B(t[f+2|0],u[e+10>>1])|0)+B(t[f+3|0],u[e+12>>1])|0)+B(t[f+4|0],u[e+14>>1])<<8)/32768<<8;e=f;e=kka(k,r,e,e>>31);l=e+l|0;b=fb+b|0;b=e>>>0>l>>>0?b+1|0:b;e=l+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Mc(e,b,24);b=(e|0)/256|0;v[c>>2]=B(b,p)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(b,o);Jb(g+8|0,i,h);e=e-(f&q)|0;c=c+8|0;d=d-1|0;b=j;continue}break}d=v[g+12>>2];c=v[g+8>>2];v[a+48>>2]=b;v[a+44>>2]=j;v[a>>2]=c;v[a+4>>2]=d;cb=g+16|0}function fO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=cb-16|0;cb=g;a:{if(gk(a)){h=cb-16|0;cb=h;e=lc(3848);f=e+808|0;c=e+16|0;while(1){v[c+16>>2]=0;v[c+20>>2]=0;v[c+36>>2]=0;t[c+42|0]=1;u[c+40>>1]=257;v[c+24>>2]=0;v[c+28>>2]=0;u[c+32>>1]=0;c=c+44|0;if((f|0)!=(c|0)){continue}break}f=e+3832|0;c=e+808|0;while(1){v[c>>2]=0;v[c+4>>2]=0;v[c+68>>2]=0;v[c+72>>2]=0;v[c+24>>2]=0;v[c+28>>2]=0;u[c+20>>1]=511;v[c+16>>2]=-1;u[c+14>>1]=1;u[c+6>>1]=0;u[c+8>>1]=0;u[c+10>>1]=0;u[c+12>>1]=0;t[c+73|0]=0;t[c+74|0]=0;t[c+75|0]=0;t[c+76|0]=0;t[c+77|0]=0;t[c+78|0]=0;t[c+79|0]=0;t[c+80|0]=0;c=c+84|0;if((f|0)!=(c|0)){continue}break}c=0;f=0;v[e+3832>>2]=0;v[e+3836>>2]=0;d=e+3837|0;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;while(1){if((f|0)==36){while(1){if((c|0)==18){b:{c=0;f=0;while(1)if((c|0)==18){while(1){if((f|0)==36){break b}Kn((B(f,84)+e|0)+808|0);f=f+1|0;continue}}else{d=(B(c,44)+e|0)+16|0;j=v[(c<<2)+29024>>2];c:{if(!(!(1<<c&3591)|c>>>0>11)){i=d;d=B(j,84)+e|0;jO(i,d+808|0,d+1060|0,d+1312|0,d+1564|0);break c}i=d;d=B(j,84)+e|0;jO(i,d+808|0,d+1060|0,0,0)}c=c+1|0;continue}}}else{v[(B(c,44)+e|0)+32>>2]=e;c=c+1|0;continue}break}iO(e,b)}else{qd((B(f,84)+e|0)+808|0,e);f=f+1|0;continue}break}b=v[Sf(h+8|0,e)>>2];cb=h+16|0;v[g+8>>2]=b;b=g+8|0;mA(a,b);sl(b);break a}iO(v[a>>2],b)}eO(a);cb=g+16|0}function Sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=cb-48|0;cb=f;o=v[a+16>>2];g=ee(f+16|0);v[g+8>>2]=a+112;e=v[a+128>>2];v[g+16>>2]=e;q=g,r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;l=v[a+8>>2];m=v[a+12>>2];if(e){q=g,r=kg(l,m,e),v[q>>2]=r;v[g+4>>2]=fb}i=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;while(1){if(d){v[f+40>>2]=e;v[f+44>>2]=0;n=(((b&2147483647)<<1|e>>>31)&-2)+o|0;e=v[g+16>>2];a:{b:while(1){c:{if((e|0)<=0){b=v[g+8>>2];e=v[b+8>>2];Jb(b,e,v[b+12>>2]);e=v[g+8>>2];k=v[e+4>>2];if(!k){break a}p=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;h=0;b=0;break c}k=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;b=0;h=0;while(1)if((b|0)==2){Jd(v[g+8>>2],(h|0)/8<<16>>16);Id(v[g+8>>2],4);Jb(f+40|0,v[g>>2],v[g+4>>2]);e=e-1|0;continue b}else{h=(t[(b+k|0)+n|0]<<8)+h|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){h=(t[(b+p|0)+n|0]<<8)+h|0;b=b+1|0;continue}break}Jd(e,(h|0)/8<<16>>16);Id(v[g+8>>2],k);e=v[g+8>>2];b=e;h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}d=d-1|0;b=v[a+32>>2];j=v[a+28>>2]+j|0;e=ig(e,v[g+12>>2]);v[c>>2]=B(j>>12,e)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(e,i>>12);Jb(f+8|0,l,m);c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}v[a+36>>2]=j;v[a>>2]=e;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+24>>2]=i>>12;cb=f+48|0}function RY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;a=cb-16|0;cb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c:{while(1){c=v[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){i=t[c|0];j=i&255;d:{if((i|0)>=0){u[f>>1]=j;b=c+1|0;break d}b=2;if(i>>>0<4294967234){break b}if(i>>>0<=4294967263){if((d-c|0)<2){break c}i=w[c+1|0];if((i&192)!=128){break a}u[f>>1]=i&63|j<<6&1984;b=c+2|0;break d}if(i>>>0<=4294967279){if((d-c|0)<3){break c}k=w[c+2|0];i=w[c+1|0];e:{f:{if((j|0)!=237){if((j|0)!=224){break f}if((i&224)==160){break e}break a}if((i&224)==128){break e}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}u[f>>1]=k&63|((i&63)<<6|j<<12);b=c+3|0;break d}if(i>>>0>4294967284){break b}b=1;if((d-c|0)<4){break a}k=w[c+3|0];i=w[c+2|0];c=w[c+1|0];g:{h:{switch(j-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;j=j&7;if((c<<12&196608|j<<18)>>>0>1114111){break a}b=c<<2;u[f>>1]=(i>>>4&3|(b&192|j<<8|b&60))+16320|55296;v[a+8>>2]=f+2;u[f+2>>1]=i<<6&960|k&63|56320;b=v[a+12>>2]+4|0}v[a+12>>2]=b;f=v[a+8>>2]+2|0;v[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];cb=a+16|0;return b|0}function IA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=cb-32|0;cb=h;a:{if(b&4){break a}e=w[a+14|0];b:{if(e>>>0>=w[a+15|0]){break b}d=w[a+12|0];if(!(d&2)){break b}t[a+12|0]=d&251}if(!(w[a+12|0]&2)|e>>>0<=w[a+13|0]){break a}if(Dd(a)>>>0<=e>>>0){break a}e=x[Gc(v[a>>2],v[a+4>>2],e)>>1];d=Gc(v[a>>2],v[a+4>>2],w[a+14|0]-1|0);c=w[a+14|0];if(x[d>>1]<(e-1|0)){c=x[Gc(v[a>>2],v[a+4>>2],c)>>1]-1&65535;e=Lp(a,c,64,64);n=h,o=yb(v[a>>2]),v[n+16>>2]=o;d=ac(h+24|0,nl(h+16|0,w[a+14|0]));k=ul(h+8|0,c,e&255);m=cb-32|0;cb=m;c=v[d>>2];d=v[a>>2];c=(It(c,yb(d))<<2)+d|0;i=v[a+4>>2];c:{d:{if(i>>>0<y[xb(a)>>2]){if((c|0)!=(i|0)){break d}_R(a,k);break c}d=xb(a);f=$f(m+8|0,Gg(a,pc(v[a>>2],i)+1|0),c-v[a>>2]>>2,d);v[22440]=0;R(772,f|0,k|0);d=v[22440];v[22440]=0;if((d|0)!=1){d=v[f+4>>2];j=f+4|0;Pn(v[a>>2],c,j);e=v[a+4>>2];g=f+8|0;while(1){if((c|0)!=(e|0)){sm(v[g>>2],c);v[g>>2]=v[g>>2]+4;c=c+4|0;continue}break}ec(a,j);ec(a+4|0,g);ec(xb(a),mc(f));v[f>>2]=v[f+4>>2];c=d;_f(f);break c}a=P()|0;O()|0;_f(f);S(a|0);L()}f=cb-16|0;cb=f;j=v[a+4>>2];d=(j-(c+4|0)|0)+c|0;g=uh(f,a,i-d>>2);l=v[g+4>>2];e=d;while(1){if(e>>>0>=i>>>0){dc(g);iq(c,d,j);cb=f+16|0}else{sm(l,e);l=l+4|0;v[g+4>>2]=l;e=e+4|0;continue}break}t[c+2|0]=w[k+2|0];u[c>>1]=x[k>>1]}yb(c);cb=m+32|0;break a}t[a+14|0]=c-1}if((b|0)!=16777216){t[a+17|0]=255}cb=h+32|0}function k$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=C(0);a=cb-368|0;cb=a;v[a+352>>2]=c;v[a+360>>2]=b;Yv(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Db(a+184|0);b=Dc(d);v[22440]=0;R(61,d|0,b|0);b=v[22440];v[22440]=0;a:{b:{c:{if((b|0)!=1){c=rc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[22440]=0;b=Q(1164,a+360|0,a+352|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+180>>2];b=vb(d);if((g|0)==(b+c|0)){v[22440]=0;R(61,d|0,b<<1);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=rc(d,0);v[a+180>>2]=b+c}v[22440]=0;b=T(1166,v[a+360>>2])|0;g=v[22440];v[22440]=0;if((g|0)==1){break d}if(Xv(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22440]=0;T(1168,a+360|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!vb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=wF(c,v[a+180>>2],e),z[j>>2]=k;Mf(a+200|0,a+16|0,v[a+12>>2],e);v[22440]=0;b=Q(1165,a+360|0,a+352|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];rb(d);rb(a+200|0);cb=a+368|0;break a}}b=P()|0;O()|0;rb(d);rb(a+200|0);S(b|0);L()}return b|0}function $ga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=v[a>>2];b=Lt(c,v[a+4>>2]);if(b>>>0<=63){g=cb-32|0;cb=g;f=64-b|0;c=v[xb(a)>>2];d=v[a+4>>2];a:{if(f>>>0<=(c-d|0)/33>>>0){b=cb-16|0;cb=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+B(f,33);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){dc(b);cb=b+16|0}else{YR(a);a=a+33|0;v[b+4>>2]=a;continue}break}break a}i=xb(a);c=g+8|0;h=Lt(v[a>>2],d)+f|0;d=cb-16|0;cb=d;v[d+12>>2]=h;e=cb-16|0;cb=e;v[e+12>>2]=130150524;v[e+8>>2]=2147483647;b=v[Bb(e+12|0,e+8|0)>>2];cb=e+16|0;b:{if(b>>>0>=h>>>0){e=ZR(a);if(e>>>0<b>>>1>>>0){v[d+8>>2]=e<<1;b=v[Pc(d+8|0,d+12|0)>>2]}cb=d+16|0;break b}nd();L()}e=Lt(v[a>>2],v[a+4>>2]);lf(c+12|0,i);if(b){if(b>>>0>=130150525){af(11191);L()}d=lc(B(b,33))}else{d=0}v[c>>2]=d;e=d+B(e,33)|0;v[c+8>>2]=e;v[c+4>>2]=e;j=mc(c),k=d+B(b,33)|0,v[j>>2]=k;b=cb-16|0;cb=b;v[b>>2]=v[c+8>>2];d=v[c+8>>2];v[b+8>>2]=c+8;v[b+4>>2]=d+B(f,33);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){YR(d);d=v[b>>2]+33|0;v[b>>2]=d;continue}break}Gd(b);cb=b+16|0;b=c+4|0;f=v[a>>2];d=v[a+4>>2]-f|0;e=v[b>>2]+B((d|0)/-33|0,33)|0;v[b>>2]=e;if((d|0)>0){ic(e,f,d)}ec(a,b);ec(a+4|0,c+8|0);ec(xb(a),mc(c));v[c>>2]=v[c+4>>2];b=v[c+4>>2];a=v[c+8>>2];while(1){if((a|0)!=(b|0)){a=a-33|0;v[c+8>>2]=a;continue}break}a=v[c>>2];if(a){mc(c);zb(a)}}cb=g+32|0;return}if((b|0)!=64){Nd(a,c+2112|0)}}function t$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=C(0);a=cb-272|0;cb=a;v[a+256>>2]=c;v[a+264>>2]=b;aw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Db(a+192|0);b=Dc(d);v[22440]=0;R(61,d|0,b|0);b=v[22440];v[22440]=0;a:{b:{c:{if((b|0)!=1){c=rc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=t[a+222|0];i=t[a+223|0];while(1){d:{v[22440]=0;b=Q(1148,a+264|0,a+256|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+188>>2];b=vb(d);if((g|0)==(b+c|0)){v[22440]=0;R(61,d|0,b<<1);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=rc(d,0);v[a+188>>2]=b+c}v[22440]=0;b=T(1150,v[a+264>>2])|0;g=v[22440];v[22440]=0;if((g|0)==1){break d}if($v(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22440]=0;T(1152,a+264|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!vb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=wF(c,v[a+188>>2],e),z[j>>2]=k;Mf(a+208|0,a+16|0,v[a+12>>2],e);v[22440]=0;b=Q(1149,a+264|0,a+256|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];rb(d);rb(a+208|0);cb=a+272|0;break a}}b=P()|0;O()|0;rb(d);rb(a+208|0);S(b|0);L()}return b|0}function j$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=cb-368|0;cb=a;v[a+352>>2]=c;v[a+360>>2]=b;Yv(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Db(a+184|0);b=Dc(d);v[22440]=0;R(61,d|0,b|0);b=v[22440];v[22440]=0;a:{b:{c:{if((b|0)!=1){c=rc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[22440]=0;b=Q(1164,a+360|0,a+352|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+180>>2];b=vb(d);if((g|0)==(b+c|0)){v[22440]=0;R(61,d|0,b<<1);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=rc(d,0);v[a+180>>2]=b+c}v[22440]=0;b=T(1166,v[a+360>>2])|0;g=v[22440];v[22440]=0;if((g|0)==1){break d}if(Xv(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22440]=0;T(1168,a+360|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!vb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=uF(c,v[a+180>>2],e),A[j>>3]=k;Mf(a+200|0,a+16|0,v[a+12>>2],e);v[22440]=0;b=Q(1165,a+360|0,a+352|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];rb(d);rb(a+200|0);cb=a+368|0;break a}}b=P()|0;O()|0;rb(d);rb(a+200|0);S(b|0);L()}return b|0}
function s$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=cb-272|0;cb=a;v[a+256>>2]=c;v[a+264>>2]=b;aw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Db(a+192|0);b=Dc(d);v[22440]=0;R(61,d|0,b|0);b=v[22440];v[22440]=0;a:{b:{c:{if((b|0)!=1){c=rc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=t[a+222|0];i=t[a+223|0];while(1){d:{v[22440]=0;b=Q(1148,a+264|0,a+256|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+188>>2];b=vb(d);if((g|0)==(b+c|0)){v[22440]=0;R(61,d|0,b<<1);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=rc(d,0);v[a+188>>2]=b+c}v[22440]=0;b=T(1150,v[a+264>>2])|0;g=v[22440];v[22440]=0;if((g|0)==1){break d}if($v(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22440]=0;T(1152,a+264|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!vb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=uF(c,v[a+188>>2],e),A[j>>3]=k;Mf(a+208|0,a+16|0,v[a+12>>2],e);v[22440]=0;b=Q(1149,a+264|0,a+256|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];rb(d);rb(a+208|0);cb=a+272|0;break a}}b=P()|0;O()|0;rb(d);rb(a+208|0);S(b|0);L()}return b|0}function kH(a){var b=0,c=0,d=0;ze(v[a+80>>2],v[a+20>>2]);while(1){if((b|0)<v[a+24>>2]){ze(v[a+80>>2],v[v[a+28>>2]+(b<<2)>>2]);b=b+1|0;continue}break}ze(v[a+80>>2],v[a+28>>2]);a:{if(!v[a+396>>2]){break a}while(1){if(v[a+264>>2]<=(c|0)){break a}d=v[a+396>>2]+B(c,24)|0;if(v[d+16>>2]){b=0;while(1){if((b|0)<v[(v[a+124>>2]+B(w[d+13|0],2096)|0)+4>>2]){ze(v[a+80>>2],v[v[d+16>>2]+(b<<2)>>2]);b=b+1|0;continue}break}ze(v[a+80>>2],v[d+16>>2])}ze(v[a+80>>2],v[d+20>>2]);c=c+1|0;continue}}if(v[a+124>>2]){c=0;while(1){if((c|0)<v[a+120>>2]){b=v[a+124>>2]+B(c,2096)|0;ze(v[a+80>>2],v[b+8>>2]);ze(v[a+80>>2],v[b+28>>2]);ze(v[a+80>>2],v[b+32>>2]);ze(v[a+80>>2],v[b+2084>>2]);b=v[b+2088>>2];ze(v[a+80>>2],b?b-4|0:0);c=c+1|0;continue}break}ze(v[a+80>>2],v[a+124>>2])}ze(v[a+80>>2],v[a+260>>2]);ze(v[a+80>>2],v[a+396>>2]);if(v[a+404>>2]){b=0;while(1){if((b|0)<v[a+400>>2]){ze(v[a+80>>2],v[(v[a+404>>2]+B(b,40)|0)+4>>2]);b=b+1|0;continue}break}ze(v[a+80>>2],v[a+404>>2])}c=0;b=0;while(1){if(!(v[a+4>>2]<=(b|0)|b>>>0>15)){d=(b<<2)+a|0;ze(v[a+80>>2],v[d+800>>2]);ze(v[a+80>>2],v[d+928>>2]);ze(v[a+80>>2],v[d+996>>2]);b=b+1|0;continue}break}while(1){if((c|0)!=2){b=(c<<2)+a|0;ze(v[a+80>>2],v[b+1068>>2]);ze(v[a+80>>2],v[b+1076>>2]);ze(v[a+80>>2],v[b+1084>>2]);ze(v[a+80>>2],v[b+1092>>2]);ze(v[a+80>>2],v[b+1100>>2]);c=c+1|0;continue}break}}function Gn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=cb-16|0;cb=d;g=a+1074312|0;ub(d+8|0,g,96);i=b,j=(k=0,l=v[b+660>>2],m=tb(v[v[d+8>>2]>>2],v[d+12>>2]),m?k:l)+c|0,v[i+660>>2]=j;f=v[a+480180>>2];e=v[b+84>>2];if(!(!(f&18)|e>>>0>c>>>0|(!(w[b+88|0]&2)|!e))){h=c;c=v[b+80>>2];c=((h-c>>>0)%(e-c>>>0)|0)+c|0}c=c>>>(v[b+88>>2]&1&(f|0)==16384)|0;a:{b:{if(!Rc(w[b+788|0])){ub(d+8|0,g,114);if(!tb(v[v[d+8>>2]>>2],v[d+12>>2])){break b}}e=v[b+656>>2];c:{if(!e){break c}f=w[b+788|0];if(!Rc(f)){break c}e=x[Xb(e+236|0,f-1|0)>>1];if(!e|e>>>0>x[a+480190>>1]){break a}}if(w[a+480210|0]&32){e=c;c=v[b+660>>2];v[b+660>>2]=e+c}v[b>>2]=0;v[b+4>>2]=c;if((!(w[b+88|0]&2)|y[b+84>>2]>c>>>0)&y[b+76>>2]>c>>>0){break a}ub(d+8|0,g,57);d:{if(!tb(v[v[d+8>>2]>>2],v[d+12>>2])){c=v[a+480180>>2];if((c|0)!=16){break d}}v[b+700>>2]=0;v[b+88>>2]=v[b+88>>2]|2097152;break a}if(!(c&1048581)){ub(d+8|0,g,27);if(tb(v[v[d+8>>2]>>2],v[d+12>>2])){if(w[a+480208|0]&4){c=v[b+76>>2];v[b>>2]=0;v[b+4>>2]=c;break a}v[b>>2]=0;v[b+4>>2]=0;break a}c=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=c;if(!(w[a+480208|0]&4)){break a}a=v[b+76>>2];if(a>>>0<5){break a}v[b>>2]=0;v[b+4>>2]=a-2;break a}if(!(w[b+88|0]&2)|(c|0)!=1){break a}a=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=a;break a}if(!(v[a+480180>>2]&268582928)|y[b+76>>2]<=c>>>0){break a}v[b>>2]=0;v[b+4>>2]=c}cb=d+16|0}function bt(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=cb-32|0;cb=e;if(b&5){if((b|0)==1){d=kka(v[a+24>>2],0,8363,0)+4136|0;c=fb;h=a,i=wc(nka(d,d>>>0<4136?c+1|0:c,8272,0),fb),v[h+24>>2]=i}d=cb-16|0;cb=d;g=d+8|0;c=cb-16|0;cb=c;f=v[a+24>>2];a:{if(!f){no(g);break a}lB(c+8|0,Vb(tl(jp(+(f>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);f=v[c+8>>2];t[c+7|0]=v[c+12>>2];ae(g,f,c+7|0)}cb=c+16|0;dB(d,a+36|0,a+37|0);cB(d,g);cb=d+16|0}if(b&3){u[a+38>>1]=0;u[a+40>>1]=0;t[a+36|0]=0;u[a+34>>1]=x[a+34>>1]&65499}if(b&7){u[a+32>>1]=64;c=x[a+34>>1];if(c&8){d=v[a+16>>2];v[a+4>>2]=v[a+12>>2];v[a+8>>2]=d;c=c&16?c|6:c&65529|2}v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=c&65511}b:{if(!(b&4)){break b}c=x[a+34>>1];if(!(c&32)){u[a+28>>1]=128;u[a+34>>1]=c|32}yf(a+40|0,15);yf(a+41|0,63);if(!w[a+41|0]){break b}d=w[a+40|0];if(!d){break b}c=w[a+39|0];if(c){c=El(wc(((d<<8|c>>>1)>>>0)/(c>>>0)|0,0))}else{c=255}t[a+39|0]=c}c:{d:{if((b|0)!=4){if((b|0)==16777216){break c}if((b|0)!=32|w[a+38|0]!=2){break d}t[a+38|0]=3;break d}if(w[a+38|0]!=4){break d}t[a+38|0]=0}u[a+34>>1]=x[a+34>>1]&49151}e:{if(!(!(w[a+35|0]&2)|b&16777218)){v[e+24>>2]=0;v[e+8>>2]=0;v[e+16>>2]=0;v[e+20>>2]=0;v[e>>2]=0;v[e+4>>2]=0;zl(a,0,e);break e}if(!(w[a+35|0]&2)|(b|0)!=2){break e}a=a+68|0;b=Eb(a,8);t[b|0]=w[b|0]&3;a=Eb(a,9);t[a|0]=w[a|0]&3}cb=e+32|0}function x4(a){a=a|0;var b=0,c=0,d=0,e=0;d=cb-160|0;cb=d;e=Bc(d,11636);v[22440]=0;b=d+12|0;Q(56,b|0,10974)|0;c=v[22440];v[22440]=0;a:{b:{if((c|0)==1){break a}v[22440]=0;b=d+24|0;Q(56,b|0,11466)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}v[22440]=0;b=d+36|0;Q(56,b|0,10966)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}v[22440]=0;b=d+48|0;Q(56,b|0,8272)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}v[22440]=0;b=d+60|0;Q(56,b|0,10951)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}v[22440]=0;b=d+72|0;Q(56,b|0,8338)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}v[22440]=0;b=d+84|0;Q(56,b|0,5623)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}v[22440]=0;b=d+96|0;Q(56,b|0,12040)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}v[22440]=0;b=d+108|0;Q(56,b|0,11409)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}v[22440]=0;b=d+120|0;Q(56,b|0,12241)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}v[22440]=0;b=d+132|0;Q(56,b|0,5475)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}v[22440]=0;b=d+144|0;Q(56,b|0,7295)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}v[22440]=0;Y(1037,a|0,e|0,13)|0;a=v[22440];v[22440]=0;if((a|0)==1){break b}b=d+156|0;while(1){b=rb(b-12|0);if((e|0)!=(b|0)){continue}break}cb=d+160|0;return}b=d+156|0}a=P()|0;O()|0;while(1){b=rb(b-12|0);if((e|0)!=(b|0)){continue}break}S(a|0);L()}function n$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=cb-352|0;cb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=_i(d);i=Po(d,a+224|0);Oo(a+208|0,d,a+332|0);d=Db(a+192|0);c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;a:{b:{c:{if((c|0)!=1){c=rc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22440]=0;g=Q(1164,a+344|0,a+336|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=vb(d);if((h|0)==(g+c|0)){v[22440]=0;R(61,d|0,g<<1);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=rc(d,0);v[a+188>>2]=g+c}v[22440]=0;g=T(1166,v[a+344>>2])|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if($m(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[22440]=0;T(1168,a+344|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!vb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=BF(c,v[a+188>>2],e,b),v[k>>2]=l;v[f+4>>2]=fb;Mf(a+208|0,a+16|0,v[a+12>>2],e);v[22440]=0;b=Q(1165,a+344|0,a+336|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];rb(d);rb(a+208|0);cb=a+352|0;break a}}b=P()|0;O()|0;rb(d);rb(a+208|0);S(b|0);L()}return b|0}function l$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=cb-352|0;cb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=_i(d);i=Po(d,a+224|0);Oo(a+208|0,d,a+332|0);d=Db(a+192|0);c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;a:{b:{c:{if((c|0)!=1){c=rc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22440]=0;g=Q(1164,a+344|0,a+336|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=vb(d);if((h|0)==(g+c|0)){v[22440]=0;R(61,d|0,g<<1);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=rc(d,0);v[a+188>>2]=g+c}v[22440]=0;g=T(1166,v[a+344>>2])|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if($m(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[22440]=0;T(1168,a+344|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!vb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=xF(c,v[a+188>>2],e,b),v[k>>2]=l;v[f+4>>2]=fb;Mf(a+208|0,a+16|0,v[a+12>>2],e);v[22440]=0;b=Q(1165,a+344|0,a+336|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];rb(d);rb(a+208|0);cb=a+352|0;break a}}b=P()|0;O()|0;rb(d);rb(a+208|0);S(b|0);L()}return b|0}function jfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[xb(a)>>2]){c=cb-16|0;cb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+56;a=v[c+4>>2];v[22440]=0;R(674,a|0,b|0);a=v[22440];v[22440]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+56;dc(c);cb=c+16|0;break a}a=P()|0;O()|0;dc(c);S(a|0);L()}return}h=cb-32|0;cb=h;i=xb(a);f=h+8|0;g=Up(v[a>>2],v[a+4>>2])+1|0;d=cb-16|0;cb=d;v[d+12>>2]=g;e=cb-16|0;cb=e;v[e+12>>2]=76695844;v[e+8>>2]=2147483647;c=v[Bb(e+12|0,e+8|0)>>2];cb=e+16|0;b:{if(c>>>0>=g>>>0){e=DQ(a);if(e>>>0<c>>>1>>>0){v[d+8>>2]=e<<1;c=v[Pc(d+8|0,d+12|0)>>2]}cb=d+16|0;break b}nd();L()}e=Up(v[a>>2],v[a+4>>2]);lf(f+12|0,i);if(c){if(c>>>0>=76695845){af(11191);L()}d=lc(B(c,56))}else{d=0}v[f>>2]=d;e=d+B(e,56)|0;v[f+8>>2]=e;v[f+4>>2]=e;j=mc(f),k=d+B(c,56)|0,v[j>>2]=k;c=v[f+8>>2];v[22440]=0;R(674,c|0,b|0);b=v[22440];v[22440]=0;c:{if((b|0)!=1){v[f+8>>2]=v[f+8>>2]+56;e=v[a>>2];b=v[a+4>>2];d=f+4|0;while(1){if((b|0)!=(e|0)){c=v[d>>2]-56|0;b=b-56|0;lk(c,b);lk(c+12|0,b+12|0);Hz(c+24|0,b+24|0);u[c+52>>1]=x[b+52>>1];g=v[b+48>>2];v[c+44>>2]=v[b+44>>2];v[c+48>>2]=g;g=v[b+40>>2];v[c+36>>2]=v[b+36>>2];v[c+40>>2]=g;v[d>>2]=v[d>>2]-56;continue}break}ec(a,d);ec(a+4|0,f+8|0);ec(xb(a),mc(f));v[f>>2]=v[f+4>>2];CQ(f);cb=h+32|0;break c}a=P()|0;O()|0;CQ(f);S(a|0);L()}}function Bha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=cb-16|0;cb=g;c=rf(a,c);ke(g,v[a+36>>2]);a:{if(!c){b:{Cc(g,a+32|0,5);if(!tb(v[v[g>>2]>>2],v[g+4>>2])){break b}break a}}e=cb-144|0;cb=e;h=Tl(e+32|0,v[a+36>>2]);v[22440]=0;f=Q(462,e+16|0,43923)|0;d=v[22440];v[22440]=0;c:{d:{e:{f:{if((d|0)!=1){v[22440]=0;v[e+8>>2]=19988487;v[e+12>>2]=0;U(463,h|0,f|0,e+8|0);d=v[22440];v[22440]=0;if((d|0)==1){break f}Ab(f);if(!Gk(w[e+32|0])){break e}break c}d=P()|0;O()|0;break d}d=P()|0;O()|0;Ab(f);break d}k=e,l=Cf(b),u[k+8>>1]=l;u[e+6>>1]=65535;v[22440]=0;f=Q(462,e+16|0,10124)|0;d=v[22440];v[22440]=0;g:{if((d|0)!=1){v[22440]=0;d=Y(492,h|0,e+6|0,f|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break g}Ab(f);if(d){u[e+8>>1]=x[e+6>>1]}Kf(e+8|0,4e3);f=x[e+8>>1];h:{if(Cf(b)>>>0>=f>>>0){break h}v[22440]=0;R(228,b|0,f|0);d=v[22440];v[22440]=0;if((d|0)!=1){break h}d=P()|0;O()|0;break d}d=0;i:{while(1){if((d|0)==(f|0)){break c}i=Sb(b,d);v[22440]=0;R(493,e+16|0,d|0);j=v[22440];v[22440]=0;if((j|0)!=1){v[22440]=0;da(494,h|0,i|0,e+16|0,495)|0;i=v[22440];v[22440]=0;if((i|0)==1){break i}d=d+1|0;Ab(e+16|0);continue}break}d=P()|0;O()|0;break d}d=P()|0;O()|0;Ab(e+16|0);break d}d=P()|0;O()|0;break d}d=P()|0;O()|0;Ab(f)}jh(h);S(d|0);L()}jh(h);cb=e+144|0;e=c}Se(a,e);cb=g+16|0}function pF(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=cb-352|0;cb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=_i(d);i=Po(d,a+224|0);Oo(a+208|0,d,a+332|0);d=Db(a+192|0);c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;a:{b:{c:{if((c|0)!=1){c=rc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22440]=0;g=Q(1164,a+344|0,a+336|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=vb(d);if((h|0)==(g+c|0)){v[22440]=0;R(61,d|0,g<<1);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=rc(d,0);v[a+188>>2]=g+c}v[22440]=0;g=T(1166,v[a+344>>2])|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if($m(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[22440]=0;T(1168,a+344|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!vb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=yF(c,v[a+188>>2],e,b),v[k>>2]=l;Mf(a+208|0,a+16|0,v[a+12>>2],e);v[22440]=0;b=Q(1165,a+344|0,a+336|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];rb(d);rb(a+208|0);cb=a+352|0;break a}}b=P()|0;O()|0;rb(d);rb(a+208|0);S(b|0);L()}return b|0}function o$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=cb-352|0;cb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=_i(d);i=Po(d,a+224|0);Oo(a+208|0,d,a+332|0);d=Db(a+192|0);c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;a:{b:{c:{if((c|0)!=1){c=rc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22440]=0;g=Q(1164,a+344|0,a+336|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=vb(d);if((h|0)==(g+c|0)){v[22440]=0;R(61,d|0,g<<1);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=rc(d,0);v[a+188>>2]=g+c}v[22440]=0;g=T(1166,v[a+344>>2])|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if($m(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[22440]=0;T(1168,a+344|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!vb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=CF(c,v[a+188>>2],e,b),v[k>>2]=l;Mf(a+208|0,a+16|0,v[a+12>>2],e);v[22440]=0;b=Q(1165,a+344|0,a+336|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];rb(d);rb(a+208|0);cb=a+352|0;break a}}b=P()|0;O()|0;rb(d);rb(a+208|0);S(b|0);L()}return b|0}function m$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=cb-352|0;cb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=_i(d);i=Po(d,a+224|0);Oo(a+208|0,d,a+332|0);d=Db(a+192|0);c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;a:{b:{c:{if((c|0)!=1){c=rc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22440]=0;g=Q(1164,a+344|0,a+336|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=vb(d);if((h|0)==(g+c|0)){v[22440]=0;R(61,d|0,g<<1);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=rc(d,0);v[a+188>>2]=g+c}v[22440]=0;g=T(1166,v[a+344>>2])|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if($m(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[22440]=0;T(1168,a+344|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!vb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=AF(c,v[a+188>>2],e,b),u[k>>1]=l;Mf(a+208|0,a+16|0,v[a+12>>2],e);v[22440]=0;b=Q(1165,a+344|0,a+336|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];rb(d);rb(a+208|0);cb=a+352|0;break a}}b=P()|0;O()|0;rb(d);rb(a+208|0);S(b|0);L()}return b|0}function SY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=cb-16|0;cb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;c=v[a+12>>2];a:{while(1){if(c>>>0>=d>>>0){f=0;break a}b:{b=x[c>>1];c:{if(b>>>0<=127){f=1;c=v[a+8>>2];if((g-c|0)<=0){break a}v[a+8>>2]=c+1;t[c|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if(b>>>0<=55295){c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=x[c+2>>1];if((i&64512)!=56320){break e}if((g-v[a+8>>2]|0)<4){break a}v[a+12>>2]=c+2;c=v[a+8>>2];v[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;t[f|0]=c>>>2|240;f=v[a+8>>2];v[a+8>>2]=f+1;t[f|0]=c<<4&48|b>>>2&15|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=i>>>6&15|b<<4&48|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}c=v[a+12>>2]+2|0;v[a+12>>2]=c;continue}break}f=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];cb=a+16|0;return f|0}function w$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=cb-240|0;cb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=_i(d);Ro(a+208|0,d,a+223|0);d=Db(a+192|0);c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;a:{b:{c:{if((c|0)!=1){c=rc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[22440]=0;g=Q(1148,a+232|0,a+224|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=vb(d);if((h|0)==(g+c|0)){v[22440]=0;R(61,d|0,g<<1);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=rc(d,0);v[a+188>>2]=g+c}v[22440]=0;g=T(1150,v[a+232>>2])|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if(an(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,79696)){break c}v[22440]=0;T(1152,a+232|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!vb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=BF(c,v[a+188>>2],e,b),v[j>>2]=k;v[f+4>>2]=fb;Mf(a+208|0,a+16|0,v[a+12>>2],e);v[22440]=0;b=Q(1149,a+232|0,a+224|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];rb(d);rb(a+208|0);cb=a+240|0;break a}}b=P()|0;O()|0;rb(d);rb(a+208|0);S(b|0);L()}return b|0}function u$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=cb-240|0;cb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=_i(d);Ro(a+208|0,d,a+223|0);d=Db(a+192|0);c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;a:{b:{c:{if((c|0)!=1){c=rc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[22440]=0;g=Q(1148,a+232|0,a+224|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=vb(d);if((h|0)==(g+c|0)){v[22440]=0;R(61,d|0,g<<1);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=rc(d,0);v[a+188>>2]=g+c}v[22440]=0;g=T(1150,v[a+232>>2])|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if(an(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,79696)){break c}v[22440]=0;T(1152,a+232|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!vb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=xF(c,v[a+188>>2],e,b),v[j>>2]=k;v[f+4>>2]=fb;Mf(a+208|0,a+16|0,v[a+12>>2],e);v[22440]=0;b=Q(1149,a+232|0,a+224|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];rb(d);rb(a+208|0);cb=a+240|0;break a}}b=P()|0;O()|0;rb(d);rb(a+208|0);S(b|0);L()}return b|0}function te(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0),k=0;f=(p(b),j(2));d=uE(f);a:{b:{c:{d:{c=(p(a),j(2));e:{if(c-2139095040>>>0>=2164260864){if(d){break e}break c}if(!d){break d}}i=C(1);if((c|0)==1065353216){break b}e=f<<1;if(!e){break b}d=e>>>0<4278190081;e=c<<1;a=C(a+b);if(!(d&e>>>0<=4278190080)){break a}if((e|0)==2130706432){break b}a=((f^-1)>>>31|0)==(e>>>0<2130706432|0)?C(0):C(b*b);break a}if(uE(c)){i=C(a*a);if((c|0)<0){i=(tE(f)|0)==1?C(-i):i}if((f|0)>=0){break b}a=SG(C(C(1)/i));break a}if((c|0)<0){e=tE(f);if(!e){a=oJ(a);break a}c=c&2147483647;e=((e|0)==1)<<16}if(c>>>0>8388607){break c}c=((p(C(a*C(8388608))),j(2))&2147483647)-192937984|0}f=c-1060306944|0;d=f>>>15&240;g=+(l(2,c-(f&-8388608)|0),q())*A[d+88976>>3]+-1;h=g*g;h=((g*.288457581109214+-.36092606229713164)*(h*h)+((g*.480898481472577+-.7213474675006291)*h+(g*1.4426950408774342+(A[d+88984>>3]+ +(f>>23)))))*+b;o(+h);d=j(1)|0;j(0)|0;f:{d=d&2147450880;if((d|0)==1079967744|d>>>0<1079967744){break f}if(h>127.99999995700433){a=TD(e);break a}if(!(h<=-150)){break f}a=tD(e);break a}k=h;g=A[160];h=g+h;g=k-(h-g);k=(A[161]*g+A[162])*(g*g)+(A[163]*g+1);o(+h);j(1)|0;c=j(0)|0;f=e+c|0;f=f<<15;d=((c&31)<<3)+1024|0;e=v[d>>2];c=e;d=v[d+4>>2]+f|0;l(0,c|0);l(1,(c>>>0<c>>>0?d+1|0:d)|0);i=C(k*+n())}a=i}return a}function $y(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{e=a;b:{c:{h=a+62|0;f=Eb(h,b);a=t[f|0];if((a|0)==-1){break c}if((a|0)>=0){break b}a=a&127;d=Xb(e+26|0,a);g=x[d>>1];if((g|0)!=65535&(b|0)!=(g|0)){break c}u[d>>1]=b;t[f|0]=a;break b}l=e+8|0;i=e+26|0;d=255;a=0;g=255;while(1){if((a|0)!=18){j=Xb(i,a);k=x[j>>1];if((k|0)==65535){u[j>>1]=b;t[f|0]=a;break b}else{if(!(w[Eb(l,a)|0]&32)){g=t[Eb(h,k)|0]>=0?g:a;d=a}a=a+1|0;continue}}break}if((d&255)!=255){a=(g&255)==255?d:g;d=Xb(i,a&255);m=Eb(h,x[d>>1]),n=255,t[m|0]=n;u[d>>1]=b;t[f|0]=a}a=hl(e,b)}g=a&255;if((g|0)==255){break a}if(gk(e)){break a}d=rd(e+318|0,g);a=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[d+8|0]=a;t[d+9|0]=a>>>8;t[d+10|0]=a>>>16;t[d+11|0]=a>>>24;a=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d|0]=f;t[d+1|0]=f>>>8;t[d+2|0]=f>>>16;t[d+3|0]=f>>>24;t[d+4|0]=a;t[d+5|0]=a>>>8;t[d+6|0]=a>>>16;t[d+7|0]=a>>>24;f=dO(g);h=f+3|0;a=0;while(1){if((a|0)==2){fh(e,b,$s(g)|192,w[Eb(c,10)|0])}else{d=a?h:f;fh(e,b,(d|32)&65535,w[Eb(c,a)|0]);fh(e,b,(d|64)&65535,w[Eb(c,a+2|0)|0]);fh(e,b,(d|96)&65535,w[Eb(c,a+4|0)|0]);fh(e,b,(d|128)&65535,w[Eb(c,a+6|0)|0]);fh(e,b,(d|224)&65535,w[Eb(c,a+8|0)|0]);a=a+1|0;continue}break}}}function zF(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=cb-240|0;cb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=_i(d);Ro(a+208|0,d,a+223|0);d=Db(a+192|0);c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;a:{b:{c:{if((c|0)!=1){c=rc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[22440]=0;g=Q(1148,a+232|0,a+224|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=vb(d);if((h|0)==(g+c|0)){v[22440]=0;R(61,d|0,g<<1);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=rc(d,0);v[a+188>>2]=g+c}v[22440]=0;g=T(1150,v[a+232>>2])|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if(an(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,79696)){break c}v[22440]=0;T(1152,a+232|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!vb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=yF(c,v[a+188>>2],e,b),v[j>>2]=k;Mf(a+208|0,a+16|0,v[a+12>>2],e);v[22440]=0;b=Q(1149,a+232|0,a+224|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];rb(d);rb(a+208|0);cb=a+240|0;break a}}b=P()|0;O()|0;rb(d);rb(a+208|0);S(b|0);L()}return b|0}function x$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=cb-240|0;cb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=_i(d);Ro(a+208|0,d,a+223|0);d=Db(a+192|0);c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;a:{b:{c:{if((c|0)!=1){c=rc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[22440]=0;g=Q(1148,a+232|0,a+224|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=vb(d);if((h|0)==(g+c|0)){v[22440]=0;R(61,d|0,g<<1);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=rc(d,0);v[a+188>>2]=g+c}v[22440]=0;g=T(1150,v[a+232>>2])|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if(an(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,79696)){break c}v[22440]=0;T(1152,a+232|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!vb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=CF(c,v[a+188>>2],e,b),v[j>>2]=k;Mf(a+208|0,a+16|0,v[a+12>>2],e);v[22440]=0;b=Q(1149,a+232|0,a+224|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];rb(d);rb(a+208|0);cb=a+240|0;break a}}b=P()|0;O()|0;rb(d);rb(a+208|0);S(b|0);L()}return b|0}function v$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=cb-240|0;cb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=_i(d);Ro(a+208|0,d,a+223|0);d=Db(a+192|0);c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;a:{b:{c:{if((c|0)!=1){c=rc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[22440]=0;g=Q(1148,a+232|0,a+224|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=vb(d);if((h|0)==(g+c|0)){v[22440]=0;R(61,d|0,g<<1);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=Dc(d);v[22440]=0;R(61,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}c=rc(d,0);v[a+188>>2]=g+c}v[22440]=0;g=T(1150,v[a+232>>2])|0;h=v[22440];v[22440]=0;if((h|0)==1){break d}if(an(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,79696)){break c}v[22440]=0;T(1152,a+232|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!vb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=AF(c,v[a+188>>2],e,b),u[j>>1]=k;Mf(a+208|0,a+16|0,v[a+12>>2],e);v[22440]=0;b=Q(1149,a+232|0,a+224|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];rb(d);rb(a+208|0);cb=a+240|0;break a}}b=P()|0;O()|0;rb(d);rb(a+208|0);S(b|0);L()}return b|0}function W_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=cb-16|0;cb=k;l=tw(g);g=_v(g);Zg(k,g);a:{b:{if(xd(k)){v[22440]=0;W(1171,l|0,a|0,c|0,d|0);g=v[22440];v[22440]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[22440]=0;j=Q(1177,l|0,h<<24>>24)|0;h=v[22440];v[22440]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[22440]=0;h=Q(1177,l|0,48)|0;i=v[22440];v[22440]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;h=t[j+1|0];v[22440]=0;h=Q(1177,l|0,h|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;j=j+2|0}Nl(j,c);i=0;v[22440]=0;o=T(1169,g|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){pr((j-a<<2)+d|0,v[f>>2]);g=v[f>>2];break a}e:{if(!w[rc(k,h)|0]){break e}if(t[rc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=o;h=(vb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[22440]=0;n=Q(1177,l|0,n|0)|0;m=v[22440];v[22440]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+4;v[m>>2]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;O()|0;rb(k);S(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;rb(k);cb=k+16|0}function $G(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=C(0);d=(b<<2)+a|0;h=d+1068|0;k=c<<1&-4;p=h,q=ge(a,k),v[p>>2]=q;g=d+1076|0;p=g,q=ge(a,k),v[p>>2]=q;i=ge(a,c&-4);v[d+1084>>2]=i;a:{h=v[h>>2];if(!h){break a}g=v[g>>2];if(!g|!i){break a}d=c>>2;o=(d|0)>0?d:0;j=C(c|0);d=0;while(1){if((e|0)==(o|0)){d=0;e=c>>3;h=(e|0)>0?e:0;e=0;while(1){if((d|0)!=(h|0)){g=e|1;f=+C(C(C(g<<1)*C(3.1415927410125732))/j);p=i+(e<<2)|0,r=C(We(f)),z[p>>2]=r;p=i+(g<<2)|0,r=C(-C(Bi(f))),z[p>>2]=r;e=e+2|0;d=d+1|0;continue}break}}else{l=d<<2;f=+C(C(C(e<<2)*C(3.1415927410125732))/j);p=h+l|0,r=C(We(f)),z[p>>2]=r;m=d|1;n=m<<2;p=h+n|0,r=C(-C(Bi(f))),z[p>>2]=r;f=+C(C(C(C(m|0)*C(3.1415927410125732))/j)*C(.5));p=g+l|0,r=C(C(We(f))*C(.5)),z[p>>2]=r;p=g+n|0,r=C(C(Bi(f))*C(.5)),z[p>>2]=r;d=d+2|0;e=e+1|0;continue}break}i=(b<<2)+a|0;d=ge(a,k);v[i+1092>>2]=d;if(!d){break a}b=0;e=c>>1;k=(e|0)>0?e:0;f=+(e|0);while(1){if((b|0)!=(k|0)){j=C(Bi((+(b|0)+.5)/f*.5*3.1415927410125732));p=d+(b<<2)|0,r=C(Bi(+C(j*j)*1.5707963705062866)),z[p>>2]=r;b=b+1|0;continue}break}b=ge(a,c>>2&-2);v[i+1100>>2]=b;if(!b){break a}a=0;d=c>>3;d=(d|0)>0?d:0;c=36-Yl(c)|0;while(1){if((a|0)!=(d|0)){p=b+(a<<1)|0,q=Wl(a)>>>c<<2,u[p>>1]=q;a=a+1|0;continue}break}return 1}Zb(a,3);return 0}function ch(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=cb-16|0;cb=f;v[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;g=v[a+480180>>2];if(!vm(g)){if(g&17408){a=((e&255)>>>0)/12|0;e=x[((B(a,-12)+e&255)<<1)+33360>>1]<<4>>>a|0;break a}if(!d){v[f+12>>2]=8363;d=8363}if(lj(a)){a=((e&255)>>>0)/12|0;b=kka(v[(B(a,-12)+e<<6&960)+37248>>2]<<a,0,d,0);a=fb;c=a>>>21|0;h=f,i=wc((a&2097151)<<11|b>>>21,c),v[h>>2]=i;qc(f,2147483647);e=v[f>>2];break a}if(w[a+480208|0]&16){a=e&255;e=x[((a>>>0)%12<<1)+33360>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;qc(f+12|0,-1>>>a|0);e=wc(nka(kka(x[((B(a,-12)+e&255)<<1)+33360>>1],0,267616,0),fb,v[f+12>>2]<<a,0),fb);break a}if(g&20){d=e>>>0>12;if((g|0)==16){b=c<<4}else{ub(f,a+1074312|0,76);b=tb(v[v[f>>2]>>2],v[f+4>>2])?c&-8:c}c=d?e:12;if(w[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;e=(a|0)>1?a:1;break a}a=c-12|0;c=((a&255)>>>0)/12|0;d=((b|0)/16|0)+(B(c,-12)+a<<3&248)|0;v[f>>2]=d+8;oe(f,0,103);a=b>>31;b=(a+b^a)&15;a=d+(a|1)|0;a=(a|0)>-8?a:-8;e=B(b,x[(((a|0)<95?a:95)<<1)+33856>>1])+B(x[(v[f>>2]<<1)+33840>>1],16-b|0)<<1>>>c|0;break a}if(!((c&255)>>>0<16&b-25>>>0<=83)){a=((e&255)>>>0)/12|0;e=x[(B((c&240)>>>4|0,12)+(B(a,-12)+e&255)<<1)+32960>>1]<<5>>>a|0;break a}e=x[(b<<1)+32734>>1]<<2}cb=f+16|0;return e}function qaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=cb-16|0;cb=h;f=b+1298304|0;if(!Bd(f)){d=cb-16|0;cb=d;c=lc(12);v[22440]=0;e=T(932,c|0)|0;g=v[22440];v[22440]=0;a:{if((g|0)!=1){c=v[Sf(d+8|0,e)>>2];cb=d+16|0;break a}a=P()|0;O()|0;zb(c);S(a|0);L()}v[h+8>>2]=c;c=h+8|0;RL(f,Vd(c));Fs(c)}c=v[f>>2];f=cb-48|0;cb=f;d=f+16|0;FL(d,a);v[22440]=0;U(8,f+32|0,0,d|0);d=v[22440];v[22440]=0;b:{c:{if((d|0)!=1){rb(f+16|0);m=f,n=yb(v[c>>2]),v[m+8>>2]=n;l=yb(v[c+4>>2]);c=0;d=0;d:{while(1){e:{g=v[f+8>>2];if(!Qb(g,l)){if(!d){break e}c=v[d+4>>2];if(!c){break e}v[22440]=0;Y(c|0,d|0,b|0,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break e}break d}i=0;e=v[g>>2];if(v[e+32>>2]==(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))){i=v[e+36>>2]==(w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))}v[22440]=0;R(933,f+16|0,e+8|0);e=v[22440];v[22440]=0;if((e|0)==1){break d}e=cb-16|0;cb=e;j=f+16|0;se(e+8|0,j);se(e,f+32|0);k=cN(v[e+8>>2],v[e+12>>2],v[e>>2],v[e+4>>2]);cb=e+16|0;rb(j);f:{if(!(!i|(k|0)!=0)){d=v[g>>2];c=3;break f}if((c|0)<2&i){d=v[g>>2];c=2;break f}e=!k&(c|0)<=0;d=e?v[g>>2]:d;c=e?1:c}Ge(f+8|0);continue}break}rb(f+32|0);cb=f+48|0;break b}d=P()|0;O()|0;rb(f+32|0);break c}d=P()|0;O()|0;rb(f+16|0)}S(d|0);L()}cb=h+16|0}function uR(a,b){var c=0;a:{b:{c:{d:{if(me(a,16758)){break d}if(me(a,17527)){break d}if(me(a,13615)){break d}if(me(a,13777)){break d}if(!me(a,14346)){break c}}u[b+10>>1]=4;v[b>>2]=12072;break b}e:{f:{if(me(a,17522)){break f}if(me(a,13625)){break f}if(!me(a,16743)){break e}}t[b+12|0]=1;v[b>>2]=8420;u[b+10>>1]=4;return 1}g:{if(!me(a,14392)){if(!me(a,14397)){break g}}u[b+10>>1]=8;v[b>>2]=8198;break b}h:{if(!me(a,15413)){if(!me(a,15418)){break h}}v[b>>2]=17130;u[b+10>>1]=t[a+2|0]-48;break b}i:{if(!me(a,26986)){if(!me(a,26991)){break i}}v[b+4>>2]=1;v[b>>2]=16936;u[b+10>>1]=w[a|0]==56?8:4;return 1}if(!(Mb(a,15519,3)|(w[a+3|0]-52&255)>>>0>4)){v[b>>2]=8538;a=t[a+3|0];u[b+8>>1]=1088;u[b+10>>1]=a-48;break b}j:{if(Mb(a,13705,3)){if(Mb(a,13839,3)){break j}}if((w[a+3|0]-52&255)>>>0>5){break j}t[b+15|0]=1;t[b+13|0]=1;v[b>>2]=8297;u[b+10>>1]=t[a+3|0]-48;return 1}k:{if((w[a|0]-49&255)>>>0>8){break k}if(!Mb(a+1|0,13863,3)){t[b+14|0]=1;v[b>>2]=8602;u[b+10>>1]=t[a|0]-48;return 1}if((w[a+1|0]-48&255)>>>0>9){break k}c=a+2|0;if(Mb(c,14195,2)){if(Mb(c,13867,2)){break k}}t[b+14|0]=1;v[b>>2]=8602;u[b+10>>1]=(t[a+1|0]+B(t[a|0],10)|0)-528;return 1}c=0;if(Mb(a,13481,3)|(w[a+3|0]-49&255)>>>0>8){break a}v[b>>2]=8447;u[b+10>>1]=t[a+3|0]-48}c=1}return c}function e_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=cb-496|0;cb=a;g=a+488|0;Jc(g,d);v[22440]=0;m=T(1159,g|0)|0;g=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(vb(f)){g=v[hk(f,0)>>2];v[22440]=0;h=Q(1177,m|0,45)|0;k=v[22440];v[22440]=0;if((k|0)==1){break g}n=(g|0)==(h|0)}k=Db(a+456|0);g=Db(a+440|0);h=Db(a+424|0);v[22440]=0;na(1198,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,k|0,g|0,h|0,a+420|0);c=v[22440];v[22440]=0;if((c|0)==1){break f}v[a+4>>2]=1146;c=re(a+8|0,0,a+4|0);j=vb(f);l=v[a+420>>2];h:{if((j|0)>(l|0)){i=((vb(h)+(j-l<<1)|0)+vb(g)|0)+1|0;break h}i=(vb(h)+vb(g)|0)+2|0}j=a+16|0;i=i+l|0;if(i>>>0<101){break e}Ue(c,Hd(i<<2));j=v[c>>2];if(j){break e}v[22440]=0;X(1147);b=v[22440];v[22440]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}o=v[d+4>>2];i=Fb(f);f=vb(f);v[22440]=0;oa(1199,j|0,a+4|0,a|0,o|0,i|0,i+(f<<2)|0,m|0,n|0,a+480|0,v[a+476>>2],v[a+472>>2],k|0,g|0,h|0,l|0);f=v[22440];v[22440]=0;if((f|0)!=1){v[22440]=0;b=la(1180,b|0,j|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Lc(c)}Vc(h);Vc(g);rb(k)}Pb(a+488|0);S(f|0);L()}Lc(c);Vc(h);Vc(g);rb(k);Pb(a+488|0);cb=a+496|0;return b|0}function YV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=cb-1088|0;cb=e;ai(a);Hb(a+20|0,0,1040);v[a+1064>>2]=0;v[a+1068>>2]=0;v[a+1060>>2]=c;g=a+1072|0;v[g>>2]=0;v[g+4>>2]=0;v[a+1080>>2]=0;t[a+1084|0]=d;g=a+1064|0;d=c;a:{b:{c:while(1){if(zd(x[d+34>>1])>>>0<=h>>>0){break a}v[a+1064>>2]=0;v[a+1068>>2]=0;d=0;while(1){d:{e:{f:{g:{h:{i:{j:{if(y[c>>2]<=d>>>0){break j}v[22440]=0;d=Q(158,b|0,2)|0;f=v[22440];v[22440]=0;if((f|0)==1){break i}if(!d){break j}v[22440]=0;d=T(196,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break h}if(!d){break e}v[22440]=0;U(192,e|0,b|0,d|0);d=v[22440];v[22440]=0;if((d|0)==1){break g}d=e+24|0;f=Vq(d,e);Sc(a,f);ic(a+20|0,f+20|0,1040);sb(d);sb(e);v[a+1076>>2]=0;v[a+1080>>2]=0;d=v[a+1060>>2];if(Nm(x[d+34>>1])>>>0>=2){d=v[d+20>>2];v[22440]=0;R(197,a|0,d+(h<<1)|0);d=v[22440];v[22440]=0;if((d|0)!=1){break e}break f}d=v[d+20>>2];v[22440]=0;R(198,a|0,d+h|0);d=v[22440];v[22440]=0;if((d|0)==1){break f}break e}h=h+1|0;d=v[a+1060>>2];continue c}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=V(30592)|0;if((O()|0)!=(fa(30592)|0)){break b}_(d|0)|0;v[22440]=0;X(18);d=v[22440];v[22440]=0;if((d|0)==1){break d}}d=v[g>>2];continue}break}break}d=P()|0;O()|0}sb(a);S(d|0);L()}cb=e+1088|0;return a|0}function e$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=cb-16|0;cb=k;l=Vu(g);g=dw(g);Zg(k,g);a:{b:{if(xd(k)){v[22440]=0;W(1157,l|0,a|0,c|0,d|0);g=v[22440];v[22440]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[22440]=0;j=Q(20,l|0,h<<24>>24)|0;h=v[22440];v[22440]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+1;t[h|0]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[22440]=0;h=Q(20,l|0,48)|0;i=v[22440];v[22440]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;h=t[j+1|0];v[22440]=0;h=Q(20,l|0,h|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;j=j+2|0}Nl(j,c);i=0;v[22440]=0;o=T(1155,g|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){Nl((j-a|0)+d|0,v[f>>2]);g=v[f>>2];break a}e:{if(!w[rc(k,h)|0]){break e}if(t[rc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+1;t[i|0]=o;h=(vb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[22440]=0;n=Q(20,l|0,n|0)|0;m=v[22440];v[22440]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+1;t[m|0]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;O()|0;rb(k);S(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;rb(k);cb=k+16|0}function Rba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=cb-48|0;cb=e;m=v[a+16>>2];f=ee(e+16|0);v[f+8>>2]=a+112;h=v[a+128>>2];v[f+16>>2]=h;o=f,p=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;k=v[a+8>>2];l=v[a+12>>2];if(h){o=f,p=kg(k,l,h),v[o>>2]=p;v[f+4>>2]=fb}h=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=b;a:while(1){if(d){v[e+40>>2]=g;v[e+44>>2]=0;g=((((b&2147483647)<<1|g>>>31)&2147483646)<<1)+m|0;b=v[f+16>>2];while(1)if((b|0)<=0){b=v[f+8>>2];i=v[b+8>>2];Jb(b,i,v[b+12>>2]);b=v[f+8>>2];i=v[b+4>>2];if(i){n=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Jd(n,(u[(b<<1|2)+g>>1]+u[g+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[f+8>>2],i);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;g=v[a+32>>2];j=v[a+28>>2]+j|0;b=ig(b,v[f+12>>2]);v[c>>2]=B(j>>12,b)+v[c>>2];h=g+h|0;v[c+4>>2]=v[c+4>>2]+B(b,h>>12);Jb(e+8|0,k,l);c=c+8|0;g=v[e+8>>2];b=v[e+12>>2];continue a}else{i=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Jd(v[f+8>>2],(u[(i<<1|2)+g>>1]+u[g+((i&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[f+8>>2],4);Jb(e+40|0,v[f>>2],v[f+4>>2]);b=b-1|0;continue}}break}v[a+36>>2]=j;v[a>>2]=g;v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=j>>12;v[a+24>>2]=h>>12;cb=e+48|0}function VF(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{f:{g:{c=v[a+4>>2];h:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break h}c=id(a)}switch(c-43|0){case 0:case 2:break g;default:break f}}f=(c|0)==45;g=!b;c=v[a+4>>2];i:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break i}c=id(a)}b=c-58|0;if(g|b>>>0>4294967285){break e}b=v[a+116>>2];if((b|0)>0|(b|0)>=0){break d}break a}b=c-58|0}if(b>>>0<4294967286){break c}b=c-48|0;if(b>>>0<10){while(1){e=(B(e,10)+c|0)-48|0;d=(e|0)<214748364;c=v[a+4>>2];j:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break j}c=id(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}k:{if(b>>>0>=10){break k}while(1){b=kka(e,d,10,0);c=b+c|0;d=fb;d=b>>>0>c>>>0?d+1|0:d;b=c;e=b-48|0;d=d-(b>>>0<48)|0;b=v[a+4>>2];l:{if((b|0)!=v[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break l}c=id(a)}b=c-48|0;if(b>>>0>9){break k}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=v[a+4>>2];m:{if((b|0)!=v[a+104>>2]){v[a+4>>2]=b+1;b=w[b|0];break m}b=id(a)}if(b-48>>>0<10){continue}break}}b=v[a+116>>2];if((b|0)>0|(b|0)>=0){v[a+4>>2]=v[a+4>>2]-1}fb=f?0-(((e|0)!=0)+d|0)|0:d;return f?0-e|0:e}v[a+4>>2]=v[a+4>>2]-1;break b}if(v[a+116>>2]<0){break a}}v[a+4>>2]=v[a+4>>2]-1}fb=-2147483648;return 0}function Wba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=cb-48|0;cb=f;m=v[a+16>>2];g=ee(f+16|0);v[g+8>>2]=a+112;e=v[a+128>>2];v[g+16>>2]=e;q=g,r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;j=v[a+8>>2];k=v[a+12>>2];if(e){q=g,r=kg(j,k,e),v[q>>2]=r;v[g+4>>2]=fb}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;while(1){if(d){v[f+40>>2]=e;v[f+44>>2]=0;l=(((b&2147483647)<<1|e>>>31)&-2)+m|0;e=v[g+16>>2];a:{b:while(1){c:{if((e|0)<=0){b=v[g+8>>2];e=v[b+8>>2];Jb(b,e,v[b+12>>2]);e=v[g+8>>2];i=v[e+4>>2];if(!i){break a}p=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;h=0;b=0;break c}i=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;b=0;h=0;while(1)if((b|0)==2){Jd(v[g+8>>2],(h|0)/8<<16>>16);Id(v[g+8>>2],4);Jb(f+40|0,v[g>>2],v[g+4>>2]);e=e-1|0;continue b}else{h=(t[(b+i|0)+l|0]<<8)+h|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){h=(t[(b+p|0)+l|0]<<8)+h|0;b=b+1|0;continue}break}Jd(e,(h|0)/8<<16>>16);Id(v[g+8>>2],i);e=v[g+8>>2];b=e;h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}d=d-1|0;h=v[c>>2];b=ig(e,v[g+12>>2]);v[c>>2]=h+B(b,o);v[c+4>>2]=v[c+4>>2]+B(b,n);Jb(f+8|0,j,k);c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}v[a>>2]=e;v[a+4>>2]=b;cb=f+48|0}function $ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=cb-16|0;cb=h;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];l=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=l;o=v[a+8>>2];p=v[a+12>>2];while(1){l=e;if(d){q=v[a+72>>2];r=v[a+32>>2];k=v[a+28>>2]+k|0;e=v[a+64>>2];g=e;m=e>>31;e=Vb(l,-16777216,16776704);e=kka(g,m,e,e>>31);g=fb;m=e;e=v[a+68>>2];f=Vb(f,-16777216,16776704);i=kka(e,e>>31,f,f>>31);e=m+i|0;f=fb+g|0;f=e>>>0<i>>>0?f+1|0:f;m=e;e=v[a+60>>2];i=e;s=e>>31;e=(v[h+12>>2]<<1)+n|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+b|0;g=(((((B(u[e+4>>1],u[g+34>>1])+B(u[e+2>>1],u[g+32>>1])|0)+B(u[e+6>>1],u[g+36>>1])|0)+B(u[e+8>>1],u[g+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[g+26>>1])+B(u[e-6>>1],u[g+24>>1])|0)+B(u[e-2>>1],u[g+28>>1])|0)+B(u[e>>1],u[g+30>>1])|0)/2|0)|0)/16384<<8;e=g;i=kka(i,s,e,e>>31);e=m+i|0;f=fb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Mc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(k>>12,e)+v[c>>2];j=j+r|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Jb(h+8|0,o,p);e=f-(g&q)|0;c=c+8|0;d=d-1|0;f=l;continue}break}b=v[h+12>>2];c=v[h+8>>2];v[a+36>>2]=k;v[a>>2]=c;v[a+4>>2]=b;v[a+40>>2]=j;v[a+48>>2]=f;v[a+44>>2]=l;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;cb=h+16|0}function i_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=cb-192|0;cb=a;g=a+184|0;Jc(g,d);v[22440]=0;m=T(19,g|0)|0;g=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(vb(f)){g=w[rc(f,0)|0];v[22440]=0;h=Q(20,m|0,45)|0;k=v[22440];v[22440]=0;if((k|0)==1){break g}n=(g|0)==(h&255)}k=Db(a+160|0);g=Db(a+144|0);h=Db(a+128|0);v[22440]=0;na(1196,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,k|0,g|0,h|0,a+124|0);c=v[22440];v[22440]=0;if((c|0)==1){break f}v[a+4>>2]=1146;c=re(a+8|0,0,a+4|0);j=vb(f);l=v[a+124>>2];h:{if((j|0)>(l|0)){i=((vb(h)+(j-l<<1)|0)+vb(g)|0)+1|0;break h}i=(vb(h)+vb(g)|0)+2|0}j=a+16|0;i=i+l|0;if(i>>>0<101){break e}Ue(c,Hd(i));j=v[c>>2];if(j){break e}v[22440]=0;X(1147);b=v[22440];v[22440]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}o=v[d+4>>2];i=Fb(f);f=vb(f);v[22440]=0;oa(1197,j|0,a+4|0,a|0,o|0,i|0,f+i|0,m|0,n|0,a+176|0,t[a+175|0],t[a+174|0],k|0,g|0,h|0,l|0);f=v[22440];v[22440]=0;if((f|0)!=1){v[22440]=0;b=la(15,b|0,j|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Lc(c)}rb(h);rb(g);rb(k)}Pb(a+184|0);S(f|0);L()}Lc(c);rb(h);rb(g);rb(k);Pb(a+184|0);cb=a+192|0;return b|0}function Dda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=cb-48|0;cb=d;l=a+480190|0;c=x[l>>1];t[d+32|0]=0;MN(b,c+1|0,d+32|0);a:{j=a+480192|0;if(!x[j>>1]){break a}g=Rb(d+32|0);c=a+484344|0;p=d,q=Pg(c),v[p+24>>2]=q;o=Og(c);m=a+480188|0;while(1){i=v[d+24>>2];if(!Qb(i,o)){c=x[a+480190>>1];while(1)if(c){ub(d+8|0,v[b>>2],c);if(!tb(v[v[d+8>>2]>>2],v[d+12>>2])){f=Sd((B(c,104)+a|0)+484380|0)+f|0}c=c-1|0;continue}else{_b(g);break a}}b:{if(!Vh(i)){break b}c=x[m>>1];v[22440]=0;t[d+8|0]=0;U(771,g|0,c|0,d+8|0);c=v[22440];v[22440]=0;if((c|0)!=1){p=d,q=yb(v[i>>2]),v[p+16>>2]=q;k=0;c:while(1){f=0;if(y[i+12>>2]<=k>>>0){break b}while(1){if(x[m>>1]<=f>>>0){k=k+1|0;continue c}d:{c=v[d+16>>2];if(!Rc(w[c|0])){break d}e:{f:{c=w[c+1|0];if(c){h=x[j>>1];break f}h=x[j>>1];c=w[Eb(v[g>>2],f)|0];if(c){break f}c=1;break e}p=Eb(v[g>>2],f),q=c,t[p|0]=q;e=(h&65535)>>>0<c>>>0;h=e?h:c;c=e?1:c}while(1){e=c&65535;if(e>>>0>(h&65535)>>>0){break d}e=v[((e<<2)+a|0)+900380>>2];g:{if(!e){break g}e=x[Xb(e+236|0,w[v[d+16>>2]]-1|0)>>1];if(e>>>0>x[l>>1]){break g}n=d+8|0;ub(n,v[b>>2],e);Te(n,1)}c=c+1|0;continue}}f=f+1|0;Ki(d+16|0);continue}}}a=P()|0;O()|0;_b(g);S(a|0);L()}JL(d+24|0);continue}}cb=d+48|0;return f&65535}function aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=cb-16|0;cb=h;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];l=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=l;o=v[a+8>>2];p=v[a+12>>2];while(1){l=e;if(d){q=v[a+72>>2];r=v[a+32>>2];k=v[a+28>>2]+k|0;e=v[a+64>>2];g=e;m=e>>31;e=Vb(l,-16777216,16776704);e=kka(g,m,e,e>>31);g=fb;m=e;e=v[a+68>>2];f=Vb(f,-16777216,16776704);i=kka(e,e>>31,f,f>>31);e=m+i|0;f=fb+g|0;f=e>>>0<i>>>0?f+1|0:f;m=e;e=v[a+60>>2];i=e;s=e>>31;e=v[h+12>>2]+n|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+b|0;g=(((((B(t[e+2|0],u[g+34>>1])+B(t[e+1|0],u[g+32>>1])|0)+B(t[e+3|0],u[g+36>>1])|0)+B(t[e+4|0],u[g+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[g+26>>1])+B(t[e-3|0],u[g+24>>1])|0)+B(t[e-1|0],u[g+28>>1])|0)+B(t[e|0],u[g+30>>1])<<8)/2|0)|0)/16384<<8;e=g;i=kka(i,s,e,e>>31);e=m+i|0;f=fb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Mc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(k>>12,e)+v[c>>2];j=j+r|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Jb(h+8|0,o,p);e=f-(g&q)|0;c=c+8|0;d=d-1|0;f=l;continue}break}b=v[h+12>>2];c=v[h+8>>2];v[a+36>>2]=k;v[a>>2]=c;v[a+4>>2]=b;v[a+40>>2]=j;v[a+48>>2]=f;v[a+44>>2]=l;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;cb=h+16|0}function ika(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{e=b;if(e){if(!c){break j}f=d;if(!f){break i}e=E(f)-E(e)|0;if(e>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;db=a-B(b,c)|0;eb=0;fb=0;return b}f=d;if(!a){break g}if(!f){break f}g=f-1|0;if(g&f){break f}db=a;eb=e&g;a=e>>>jka(f)|0;fb=0;return a}f=c-1|0;if(!(f&c)){break e}h=(E(c)+33|0)-E(e)|0;g=0-h|0;break c}h=e+1|0;g=63-e|0;break c}db=0;a=(e>>>0)/(f>>>0)|0;eb=e-B(a,f)|0;fb=0;return a}e=E(f)-E(e)|0;if(e>>>0<31){break d}break b}db=a&f;eb=0;if((c|0)==1){break a}d=a;c=jka(c);a=c&31;if((c&63)>>>0>=32){e=0;a=b>>>a|0}else{e=b>>>a|0;a=((1<<a)-1&b)<<32-a|d>>>a}fb=e;return a}h=e+1|0;g=63-e|0}i=a;e=h&63;f=e&31;if((e&63)>>>0>=32){e=0;k=b>>>f|0}else{e=b>>>f|0;k=((1<<f)-1&b)<<32-f|i>>>f}f=e;e=g&63;a=e&31;if((e&63)>>>0>=32){e=i<<a;a=0}else{e=(1<<a)-1&i>>>32-a|b<<a;a=i<<a}b=e;if(h){e=d-1|0;g=c-1|0;e=(g|0)!=-1?e+1|0:e;i=e;while(1){j=k;e=f<<1|j>>>31;f=j<<1;j=e;f=b>>>31|f;e=i-((f>>>0>g>>>0)+e|0)>>31;l=e;m=c&e;k=f-m|0;f=j-((d&e)+(f>>>0<m>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;j=0;l=l&1;n=l;h=h-1|0;if(h){continue}break}}db=k;eb=f;e=b<<1|a>>>31;a=l|a<<1;fb=e|j;return a}db=a;eb=b;a=0;b=0}fb=b;return a}function TV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=cb-32|0;cb=d;if(!Mb(a,13735,4)){ed(b,32);Wh(d,1,a+4|0);c=d+16|0;xc(c,v[d>>2],v[d+4>>2],w[d+8|0]);pe(b+43|0,c);rb(c);u[b+30>>1]=w[a+19|0]<<2;Kf(b+30|0,256);u[b+32>>1]=w[a+17|0];Kf(b+32|0,64);c=a+47|0;u[b+28>>1]=(w[c|0]&127)<<2;Kf(b+28|0,256);if(t[c|0]<0){u[b+34>>1]=x[b+34>>1]|32}e=a+18|0;c=w[e|0];if(c&16){u[b+34>>1]=x[b+34>>1]|2;c=w[e|0]}if(c&32){u[b+34>>1]=x[b+34>>1]|8;c=w[e|0]}if(c&64){u[b+34>>1]=x[b+34>>1]|4;c=w[e|0]}if(c<<24>>24<0){u[b+34>>1]=x[b+34>>1]|16}c=a+60|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c?c:8363;v[b+24>>2]=c>>>0>256?c:256;c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a- -64|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+68|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);yk(b);t[b+38|0]=w[(w[a+79|0]&7)+39808|0];t[b+41|0]=w[a+76|0];t[b+40|0]=w[a+77|0]&127;t[b+39|0]=w[a+78|0];c=w[a+46|0];a:{if((c|0)==64){c=512}else{if((c|0)!=128){break a}c=16384}u[b+34>>1]=c|x[b+34>>1]}a=a+72|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}cb=d+32|0;return c|0}function vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;f=cb-16|0;cb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){h=v[f+8>>2];m=((((v[f+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+l|0;e=(h>>>16&65520)+b|0;n=u[e+14>>1];o=u[e+12>>1];p=u[e+10>>1];q=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];t=u[e+2>>1];w=u[e>>1];h=0;while(1){if((h|0)!=2){e=(h<<1)+m|0;v[(h<<2)+f>>2]=(((((((B(u[e-8>>1],t)+B(u[e-12>>1],w)|0)+B(u[e-4>>1],s)|0)+B(u[e>>1],r)|0)+B(u[e+4>>1],q)|0)+B(u[e+8>>1],p)|0)+B(u[e+12>>1],o)|0)+B(u[e+16>>1],n)|0)/32768;h=h+1|0;continue}break}e=v[a+32>>2];k=v[a+28>>2]+k|0;v[c>>2]=v[c>>2]+B(v[f>>2],k>>12);j=e+j|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],j>>12);Jb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];c=v[f+8>>2];v[a+36>>2]=k;v[a>>2]=c;v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;cb=f+16|0}function UJ(a){var b=0,c=C(0),d=0,e=0,f=C(0),g=0,h=0,i=C(0),k=0,m=0,n=C(0);d=cb-16|0;cb=d;b=v[v[a+16>>2]+24620>>2];m=a,n=te(C(10),C(C(C(z[a+4208>>2]*C(120))+C(-60))/C(20))),z[m+4232>>2]=n;i=C(C(b>>>0)/C(1e3));m=a,n=te(C(10),C(C(-1)/C(i*C(C(z[a+4212>>2]*C(499.989990234375))+C(.009999999776482582))))),z[m+4236>>2]=n;m=a,n=te(C(10),C(C(-1)/C(i*C(C(z[a+4216>>2]*C(2950))+C(50))))),z[m+4240>>2]=n;v[d+12>>2]=1325400064;c=C(te(C(10),C(RJ(z[a+4220>>2])/C(20)))*C(2147483648));b=(p(c),j(2));f=C(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){e=b<<1;if(!e){b=cb-16|0;z[b+12>>2]=-1;f=C(z[b+12>>2]/C(0));break a}if((b|0)==2139095040){break b}if(!(e>>>0<4278190080&(b|0)>=0)){f=oJ(c);break a}b=(p(C(c*C(8388608))),j(2))-192937984|0}e=b-1060306944|0;g=e>>>15&240;h=+(l(2,b-(e&-8388608)|0),q())*A[g+3568>>3]+-1;k=h*h;c=C((A[479]*k+(A[480]*h+A[481]))*k+(+(e>>23)*A[478]+A[g+3576>>3]+h))}f=c}z[d+8>>2]=C(C(f*C(67108864))/C(.6931471824645996))+C(67108864);m=a,n=C(z[$l(d+12|0,d+8|0)>>2]*C(4.656612873077393e-10)),z[m+4244>>2]=n;z[a+4248>>2]=C(C(-1)/C(C(z[a+4224>>2]*C(99))+C(1)))+C(1);c=C(C(C(z[a+4228>>2]*C(4))*i)+C(2));c:{if(C(D(c))<C(2147483648)){g=~~c;break c}g=-2147483648}v[a+4252>>2]=g;cb=d+16|0}function AL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=cb-16|0;cb=e;c=a+484360|0;while(1){a:{d=Nb(c);f=Fc(v[d>>2],v[d+4>>2]);d=b&65535;if(f>>>0<=d>>>0){break a}if(oq(Nb(c),d)){break a}b=b+1|0;continue}break}c=Nb(c);if(Fc(v[c>>2],v[c+4>>2])>>>0>d>>>0){d=a+1074312|0;f=a+1298224|0;c=a+1074992|0;b:{while(1){c:{if((c|0)==(f|0)){zL(a);if(b&65535){break c}b=0;while(1){if((b|0)==256){In(a+1298264|0,1);v[a+1074456>>2]=v[a+480200>>2];v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];v[a+480208>>2]=v[a+480208>>2]&-769;Hy(a+1074376|0);u[a+1074450>>1]=0;v[a+1074392>>2]=-2;b=a+1074428|0;v[b>>2]=0;v[b+4>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074376>>2]=0;v[a+1074380>>2]=0}else{Ln((B(b,872)+a|0)+1074992|0,a,b&65535,134217728);b=b+1|0;continue}break}break b}t[c+797|0]=0;v[c+700>>2]=0;t[c+841|0]=0;t[c+805|0]=0;v[c+708>>2]=0;t[c+821|0]=0;v[c+764>>2]=0;t[c+819|0]=0;t[c+820|0]=0;ub(e+8|0,d,23);if(tb(v[v[e+8>>2]>>2],v[e+12>>2])){t[c+807|0]=1;t[c+808|0]=0}t[c+839|0]=0;c=c+872|0;continue}break}u[a+1074450>>1]=b;u[a+1074446>>1]=0;b=a+1074424|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074392>>2]=-2;v[a+1074432>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074380>>2]=0}v[a+480208>>2]=v[a+480208>>2]&-769}cb=e+16|0}function kja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=cb-288|0;cb=e;dg(b);a:{if(!Kb(a,1)){break a}while(1){d=e+32|0;hn(e+8|0,d,d+256|0);d=cb-32|0;cb=d;k=v[a>>2];g=v[a+8>>2];_g(d+16|0,v[e+8>>2],v[e+12>>2]);l=v[v[k>>2]+28>>2];h=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=h;gb[l|0](d+24|0,k,g,d+8|0);_g(e+16|0,v[d+24>>2],v[d+28>>2]);cb=d+32|0;v[e+28>>2]=v[e+20>>2];p=e,q=c-vb(b)|0,v[p+4>>2]=q;d=v[Bb(e+28|0,e+4|0)>>2];if(!d){break a}t[e+16|0]=0;k=e+32|0;m=k+d|0;d=e+16|0;l=yi(k,m,d);p=e,q=gf(b),v[p+16>>2]=q;kj(e,d);g=cb-32|0;cb=g;i=v[e>>2];v[g+24>>2]=i;p=g,q=fd(b),v[p+8>>2]=q;h=xn(g+24|0,g+8|0);b:{c:{d=k;f=Oh(d,l);if(!f){break c}if(!Js(b,d)){i=vb(b);j=Dc(b);d:{if(f>>>0<=j-i>>>0){j=Fb(b);n=i-h|0;if(!n){break d}o=h+j|0;Rh(f+o|0,o,n);break d}fm(b,j,(f+i|0)-j|0,i,h,0,f);j=v[b>>2]}f=f+i|0;Bf(b,f);t[g+8|0]=0;$d(f+j|0,g+8|0);f=h+j|0;while(1){if((d|0)==(l|0)){break c}$d(f,d);d=d+1|0;f=f+1|0;continue}}d=Ph(g+8|0,d,l);h=Fb(d);f=vb(d);v[22440]=0;da(367,b|0,i|0,h|0,f+h|0)|0;h=v[22440];v[22440]=0;if((h|0)!=1){rb(d);break b}a=P()|0;O()|0;rb(d);S(a|0);L()}p=g,q=fd(b),v[p+8>>2]=q;je(g+8|0,h)}cb=g+32|0;Ob(a,l-k|0);if(l>>>0>=m>>>0){continue}break}Ob(a,1)}cb=e+288|0}function S_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=cb-384|0;cb=f;v[f+376>>2]=37;v[f+380>>2]=0;h=mr(f+376|1,21685,v[c+4>>2]);v[f+332>>2]=f+336;a=pd();a:{if(h){g=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=g;g=Lf(f+336|0,30,a,f+376|0,f+32|0);break a}A[f+48>>3]=e;g=Lf(f+336|0,30,a,f+376|0,f+48|0)}v[f+80>>2]=1146;i=re(f+320|0,0,f+80|0);j=f+336|0;a=j;b:{c:{d:{if((g|0)>=30){a=pd();e:{if(h){g=v[c+8>>2];A[f+8>>3]=e;v[f>>2]=g;g=Xi(f+332|0,a,f+376|0,f);break e}A[f+16>>3]=e;g=Xi(f+332|0,a,f+376|0,f+16|0)}if((g|0)==-1){v[22440]=0;X(1147);a=v[22440];v[22440]=0;if((a|0)==1){break c}break d}a=v[f+332>>2];Ue(i,a)}k=a+g|0;l=Yg(a,k,c);v[f+68>>2]=1146;h=re(f+72|0,0,f+68|0);f:{g:{if((f+336|0)==(a|0)){g=f+80|0;break g}g=Hd(g<<3);if(!g){v[22440]=0;X(1147);a=v[22440];v[22440]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ue(h,g);j=a}a=f+56|0;Jc(a,c);v[22440]=0;ja(1179,j|0,l|0,k|0,g|0,f+68|0,f- -64|0,a|0);a=v[22440];v[22440]=0;h:{if((a|0)!=1){Pb(f+56|0);v[22440]=0;a=la(1180,b|0,g|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break h}Lc(h);Lc(i);cb=f+384|0;return a|0}c=P()|0;O()|0;Pb(f+56|0);break f}c=P()|0;O()|0}Lc(h);break b}L()}c=P()|0;O()|0}Lc(i);S(c|0);L()}function a$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=cb-208|0;cb=f;v[f+200>>2]=37;v[f+204>>2]=0;h=mr(f+200|1,21685,v[c+4>>2]);v[f+156>>2]=f+160;a=pd();a:{if(h){g=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=g;g=Lf(f+160|0,30,a,f+200|0,f+32|0);break a}A[f+48>>3]=e;g=Lf(f+160|0,30,a,f+200|0,f+48|0)}v[f+80>>2]=1146;i=re(f+144|0,0,f+80|0);j=f+160|0;a=j;b:{c:{d:{if((g|0)>=30){a=pd();e:{if(h){g=v[c+8>>2];A[f+8>>3]=e;v[f>>2]=g;g=Xi(f+156|0,a,f+200|0,f);break e}A[f+16>>3]=e;g=Xi(f+156|0,a,f+200|0,f+16|0)}if((g|0)==-1){v[22440]=0;X(1147);a=v[22440];v[22440]=0;if((a|0)==1){break c}break d}a=v[f+156>>2];Ue(i,a)}k=a+g|0;l=Yg(a,k,c);v[f+68>>2]=1146;h=re(f+72|0,0,f+68|0);f:{g:{if((f+160|0)==(a|0)){g=f+80|0;break g}g=Hd(g<<1);if(!g){v[22440]=0;X(1147);a=v[22440];v[22440]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ue(h,g);j=a}a=f+56|0;Jc(a,c);v[22440]=0;ja(1174,j|0,l|0,k|0,g|0,f+68|0,f- -64|0,a|0);a=v[22440];v[22440]=0;h:{if((a|0)!=1){Pb(f+56|0);v[22440]=0;a=la(15,b|0,g|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break h}Lc(h);Lc(i);cb=f+208|0;return a|0}c=P()|0;O()|0;Pb(f+56|0);break f}c=P()|0;O()|0}Lc(h);break b}L()}c=P()|0;O()|0}Lc(i);S(c|0);L()}function X$(){var a=0,b=0,c=0;b=cb-16|0;cb=b;js(462960);v[115752]=-1;v[115750]=463016;v[115748]=89448;v[115740]=74388;t[463012]=0;a=b+8|0;yr(a,462960);c=v[v[115740]+8>>2];v[22440]=0;R(c|0,462960,a|0);a=v[22440];v[22440]=0;a:{if((a|0)!=1){Pb(b+8|0);cb=b+16|0;break a}a=P()|0;O()|0;Pb(b+8|0);am(462960);S(a|0);L()}qs(462288);v[115572]=74520;v[115570]=74500;v[115571]=0;un(462288,462960);b=cb-16|0;cb=b;AG(463024);v[115768]=-1;v[115766]=463080;v[115764]=89448;v[115756]=74612;t[463076]=0;a=b+8|0;yr(a,463024);c=v[v[115756]+8>>2];v[22440]=0;R(c|0,463024,a|0);a=v[22440];v[22440]=0;b:{if((a|0)!=1){Pb(b+8|0);cb=b+16|0;break b}a=P()|0;O()|0;Pb(b+8|0);Uo(463024);S(a|0);L()}dG(462376);v[115594]=74744;v[115592]=74724;v[115593]=0;un(462376,463024);hG(463088,89592,463136);kw(462456,463088);gG(463144,89592,463192);jw(462540,463144);hG(463200,89288,463248);kw(462624,463200);kw(462792,v[(v[v[115656]-12>>2]+462624|0)+24>>2]);gG(463256,89288,463304);jw(462708,463256);jw(462876,v[(v[v[115677]-12>>2]+462708|0)+24>>2]);fG(v[v[115570]-12>>2]+462280|0);eG(v[v[115592]-12>>2]+462368|0);AI(v[v[115656]-12>>2]+462624|0);AI(v[v[115677]-12>>2]+462708|0);fG(v[v[115656]-12>>2]+462624|0);eG(v[v[115677]-12>>2]+462708|0)}function u3(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=cb-80|0;cb=e;a:{b:{c:{d:{e:{if(fj(a)){If(e+72|0);break e}c=e+32|0;sn(c,a);v[22440]=0;c=T(1030,c|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break d}v[e+72>>2]=c;Rf(e+32|0)}if(fj(a)){c=a+36|0}else{c=v[e+72>>2]}f=v[a+8>>2];if((f|0)==-1){d=v[c+4>>2];f=d-24|0;g=v[c>>2];h=Ri(g,d);j=A[f>>3];d=0;while(1){if((d|0)==(h|0)){c=f;break c}c=jf(g,d);if(i+A[c>>3]>b){break c}d=d+1|0;i=i+j;continue}}c=jf(v[c>>2],f);break b}d=P()|0;O()|0;Rf(e+32|0);break a}b=b-i}f=a+24|0;d=v[f>>2];g=x[c+12>>1];v[22440]=0;R(1063,d|0,g|0);d=v[22440];v[22440]=0;if((d|0)!=1){f:{d=v[f>>2];g=w[a+64|0];c=rL(mR(e+32|0,b),w[c+16|0],x[c+12>>1],v[c+8>>2]);v[22440]=0;h=v[c+12>>2];v[e+16>>2]=v[c+8>>2];v[e+20>>2]=h;h=v[c+20>>2];v[e+24>>2]=v[c+16>>2];v[e+28>>2]=h;h=v[c+4>>2];v[e+8>>2]=v[c>>2];v[e+12>>2]=h;W(1064,e+56|0,d|0,(g?7:1)|0,e+8|0);c=v[22440];v[22440]=0;if((c|0)==1){break f}c=sL(v[e+60>>2]);d=t[c+26|0]&1;g=v[(d?c+8|0:c+12|0)>>2];d=x[(d?c+20|0:c+22|0)>>1];b=A[c>>3];Di(e+56|0);u[v[f>>2]+1074448>>1]=d;u[v[f>>2]+1074450>>1]=d;v[v[f>>2]+1074428>>2]=g;v[v[f>>2]+1074392>>2]=-2;b=i+b;A[a+16>>3]=b;Xk(e+72|0);cb=e+80|0;return+b}}d=P()|0;O()|0;Xk(e+72|0)}S(d|0);L()}function yga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=cb-16|0;cb=f;ed(b,0);e=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(c&34){if(d){v[b+24>>2]=e;break a}g=b,h=Le(ni(+(e+1408|0)/1536)*8363),v[g+24>>2]=h;break a}t[b+37|0]=(c|0)==16?e:e^128;t[b+36|0]=w[a+4|0]}t[f+15|0]=w[a+5|0];t[f+14|0]=64;g=b,h=w[Tb(f+15|0,f+14|0)|0]<<2,u[g+30>>1]=h;d=a+6|0;d=w[d|0]|w[d+1|0]<<8;if(d>>>0<=256){u[b+28>>1]=d;u[b+34>>1]=x[b+34>>1]|32}d=a+8|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+12|0;v[b+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+16|0;v[b+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);e=a+20|0;d=w[e|0]|w[e+1|0]<<8;if(d&16){u[b+34>>1]=x[b+34>>1]|2;d=w[e|0]|w[e+1|0]<<8}if(d&32){u[b+34>>1]=x[b+34>>1]|4;d=w[e|0]|w[e+1|0]<<8}if(d&256){u[b+34>>1]=x[b+34>>1]|8;d=w[e|0]|w[e+1|0]<<8}if(d&512){u[b+34>>1]=x[b+34>>1]|16}t[b+38|0]=w[(w[a+22|0]&7)+39808|0];t[b+39|0]=w[a+23|0];t[b+40|0]=w[a+24|0];t[b+41|0]=w[a+25|0];if((c|0)==32){t[f+13|0]=w[a+26|0];t[f+12|0]=64;g=b,h=w[Tb(f+13|0,f+12|0)|0],u[g+32>>1]=h}c=a+27|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);a=a+31|0;v[b+16>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);cb=f+16|0}function rf(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=cb-96|0;cb=c;d=v[a+36>>2];Ml(v[v[d>>2]-12>>2]+d|0,0);d=a+32|0;Cc(c+56|0,d,4);if(!tb(v[v[c+56>>2]>>2],v[c+60>>2])){Pv(a)}a:{if(!v[a+8>>2]){break a}Cc(c+56|0,d,6);if(tb(v[v[c+56>>2]>>2],v[c+60>>2])){break a}Cc(c+88|0,d,7);if(tb(v[v[c+88>>2]>>2],v[c+92>>2])){break a}h=v[a+36>>2];e=v[a+92>>2];g=B(v[a+28>>2],v[a+8>>2]);f=g+v[a+88>>2]|0;e=Xg(c+72|0,f,f>>>0<g>>>0?e+1|0:e);f=v[e+12>>2];v[c+32>>2]=v[e+8>>2];v[c+36>>2]=f;f=v[e+4>>2];v[c+24>>2]=v[e>>2];v[c+28>>2]=f;Uj(h,c+24|0)}Cc(c+56|0,d,5);e=0;b:{if(!tb(v[v[c+56>>2]>>2],v[c+60>>2])){break b}f=Ri(v[a+52>>2],v[a+56>>2]);d=0;while(1){if((d|0)==(f|0)){break b}h=(v[a+108>>2]+d>>>0)%(f>>>0)|0;i=jf(v[a+52>>2],h);g=v[i>>2];c:{j=v[a+40>>2];if(Uc(j,v[a+44>>2])>>>0<=g>>>0){break c}g=Lk(c+56|0,Eb(j,g),x[i+20>>1]);i=Wv(b,g);Ab(g);if(!i){break c}v[a+108>>2]=(h+1>>>0)%(f>>>0);e=jf(v[a+52>>2],h);d=e;b=v[d+12>>2];d=v[d+8>>2];if(!(b|d)){break b}e=v[a+36>>2];b=v[a+20>>2]+b|0;f=v[a+16>>2];d=f+d|0;b=Xg(c+40|0,d,d>>>0<f>>>0?b+1|0:b);d=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;Uj(e,c+8|0);e=jf(v[a+52>>2],h);break b}d=d+1|0;continue}}cb=c+96|0;return e}function wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;f=cb-16|0;cb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){h=v[f+8>>2];m=(((v[f+12>>2]&2147483647)<<1|h>>>31)&-2)+l|0;e=(h>>>16&65520)+b|0;n=u[e+14>>1];o=u[e+12>>1];p=u[e+10>>1];q=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];w=u[e+2>>1];x=u[e>>1];h=0;while(1){if((h|0)!=2){e=h+m|0;v[(h<<2)+f>>2]=(((((((B(t[e-4|0],w)+B(t[e-6|0],x)|0)+B(t[e-2|0],s)|0)+B(t[e|0],r)|0)+B(t[e+2|0],q)|0)+B(t[e+4|0],p)|0)+B(t[e+6|0],o)|0)+B(t[e+8|0],n)<<8)/32768;h=h+1|0;continue}break}e=v[a+32>>2];k=v[a+28>>2]+k|0;v[c>>2]=v[c>>2]+B(v[f>>2],k>>12);j=e+j|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],j>>12);Jb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];c=v[f+8>>2];v[a+36>>2]=k;v[a>>2]=c;v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;cb=f+16|0}function UY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=cb-16|0;cb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{while(1){j=v[a+12>>2];if(!(j>>>0>=d>>>0|f>>>0>=g>>>0)){i=t[j|0];c=i&255;c:{if((i|0)>=0){i=1;break c}b=2;if(i>>>0<4294967234){break a}if(i>>>0<=4294967263){if((d-j|0)<2){break b}i=w[j+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;i=2;break c}if(i>>>0<=4294967279){if((d-j|0)<3){break b}k=w[j+2|0];i=w[j+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}c=k&63|(c<<12&61440|(i&63)<<6);i=3;break c}if(i>>>0>4294967284){break a}if((d-j|0)<4){break b}l=w[j+3|0];m=w[j+2|0];k=w[j+1|0];f:{g:{switch(c-240|0){case 0:if((k+112&255)>>>0<48){break f}break a;case 4:if((k&240)==128){break f}break a;default:break g}}if((k&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;c=l&63|(m<<6&4032|(c<<18&1835008|(k&63)<<12));if(c>>>0>1114111){break a}}v[f>>2]=c;v[a+12>>2]=i+j;f=v[a+8>>2]+4|0;v[a+8>>2]=f;continue}break}b=d>>>0>j>>>0;break a}b=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];cb=a+16|0;return b|0}function JP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=v[a>>2];e=th(c,v[a+4>>2]);if(e>>>0<b>>>0){g=cb-32|0;cb=g;f=b-e|0;b=v[xb(a)>>2];c=v[a+4>>2];a:{if(f>>>0<=b-c>>8>>>0){b=cb-16|0;cb=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(f<<8);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){dc(b);cb=b+16|0}else{tP(a);a=a+256|0;v[b+4>>2]=a;continue}break}break a}i=xb(a);b=g+8|0;e=a;h=th(v[a>>2],c)+f|0;c=cb-16|0;cb=c;v[c+12>>2]=h;d=cb-16|0;cb=d;v[d+12>>2]=16777215;v[d+8>>2]=2147483647;a=v[Bb(d+12|0,d+8|0)>>2];cb=d+16|0;b:{if(a>>>0>=h>>>0){d=tz(e);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Pc(c+8|0,c+12|0)>>2]}cb=c+16|0;break b}nd();L()}d=th(v[e>>2],v[e+4>>2]);lf(b+12|0,i);if(a){if(a>>>0>=16777216){af(11191);L()}c=lc(a<<8)}else{c=0}v[b>>2]=c;d=c+(d<<8)|0;v[b+8>>2]=d;v[b+4>>2]=d;j=mc(b),k=c+(a<<8)|0,v[j>>2]=k;a=cb-16|0;cb=a;v[a>>2]=v[b+8>>2];c=v[b+8>>2];v[a+8>>2]=b+8;v[a+4>>2]=c+(f<<8);c=v[a>>2];while(1){if(v[a+4>>2]!=(c|0)){tP(c);c=v[a>>2]+256|0;v[a>>2]=c;continue}break}Gd(a);cb=a+16|0;Ad(e,b);e=v[b+4>>2];a=v[b+8>>2];while(1){if((a|0)!=(e|0)){a=a-256|0;v[b+8>>2]=a;continue}break}a=v[b>>2];if(a){mc(b);zb(a)}}cb=g+32|0;return}if(b>>>0<e>>>0){Nd(a,c+(b<<8)|0)}}function hba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=cb-16|0;cb=j;k=cb-32|0;cb=k;g=k+28|0;f=k+24|0;e=cb-32|0;cb=e;v[e+24>>2]=b;a:{b:{if(!hc(b,v[ac(e+16|0,cg(a))>>2])){h=x[c>>1];i=v[c+4>>2];if(!Ws(h,i,od(e+24|0))){break b}}v[e+16>>2]=b;f=ac(e+8|0,bq(a));c:{if(!hc(v[e+16>>2],v[f>>2])){i=od(Wy(e+16|0));f=x[c>>1];h=v[c+4>>2];if(!Vs(i,f,h)){break c}}if(!v[b>>2]){v[g>>2]=b;break a}b=v[e+16>>2];v[g>>2]=b;b=b+4|0;break a}b=Vy(a,g,f,h);break a}if(Vs(od(e+24|0),h,i)){f=Uy(b);v[e+16>>2]=f;d:{if(!hc(f,v[ac(e+8|0,cg(a))>>2])){h=x[c>>1];i=v[c+4>>2];if(!Ws(h,i,od(e+16|0))){break d}}if(!v[v[e+24>>2]+4>>2]){v[g>>2]=b;b=b+4|0;break a}v[g>>2]=f;b=f;break a}b=Vy(a,g,h,i);break a}v[g>>2]=b;v[f>>2]=b;b=f}cb=e+32|0;e=v[b>>2];if(!e){e=cb-16|0;cb=e;g=bc(a);f=k+8|0;h=kh(f,lc(36),lh(e+8|0,g));g=v[h>>2]+16|0;i=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=i;lk(g+8|0,d);m=bc(h),n=1,t[m+4|0]=n;cb=e+16|0;Ig(a,v[k+28>>2],b,v[f>>2]);e=Vd(f);EN(f);l=1}Hg(j,ac(k+8|0,e),l);cb=k+32|0;if(!w[bc(j)|0]){a=od(j)+8|0;DN(a);v[a>>2]=v[d>>2];v[a+4>>2]=v[d+4>>2];b=xb(d);m=xb(a),n=v[b>>2],v[m>>2]=n;v[b>>2]=0;v[d>>2]=0;v[d+4>>2]=0}a=v[ac(j+8|0,v[j>>2])>>2];cb=j+16|0;return a|0}function U6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=C(0),r=0,s=C(0),t=0;i=cb-16|0;cb=i;a:{m=a+44|0;if(!Yh(m)){break a}j=Ud(m,0);k=Ud(m,1);f=jd(m,0);g=jd(m,1);s=z[a+4212>>2];v[i+12>>2]=d;n=d;while(1){if(!n){ti(a,b,c,jd(m,0),jd(m,1),d);break a}h=v[a+4224>>2];r=v[a+4220>>2];b:{if(h>>>0<r>>>0){v[i+8>>2]=r-h;l=v[Bb(i+12|0,i+8|0)>>2];e=0;c:{if(s<C(1)){e=h+l|0;o=e>>>0<h>>>0?h:e;p=C(C(1)/C(r>>>0));while(1){if((h|0)==(o|0)){break c}q=C(h>>>0);z[f>>2]=p*C(z[j>>2]*q);z[g>>2]=p*C(z[k>>2]*q);h=h+1|0;g=g+4|0;k=k+4|0;f=f+4|0;j=j+4|0;continue}}while(1){if((e|0)!=(l|0)){z[f>>2]=z[j>>2];z[g>>2]=z[k>>2];e=e+1|0;g=g+4|0;k=k+4|0;f=f+4|0;j=j+4|0;continue}break}e=h+l|0}n=n-l|0;v[i+12>>2]=n;break b}t=v[a+4216>>2];e=t-h|0;v[i+4>>2]=e;l=v[Bb(i+12|0,i+4|0)>>2];o=0;d:{if(s<C(1)){o=e-l|0;p=C(C(1)/C(r>>>0));while(1){if(e>>>0<=o>>>0){break d}q=C(e>>>0);z[f>>2]=p*C(z[j>>2]*q);z[g>>2]=p*C(z[k>>2]*q);e=e-1|0;g=g+4|0;k=k+4|0;f=f+4|0;j=j+4|0;continue}}while(1){if((l|0)!=(o|0)){v[f>>2]=0;v[g>>2]=0;o=o+1|0;g=g+4|0;f=f+4|0;continue}break}e=l<<2;k=e+k|0;j=e+j|0}n=n-l|0;v[i+12>>2]=n;e=h+l|0;e=e>>>0<t>>>0?e:0}v[a+4224>>2]=e;continue}}cb=i+16|0}function Aaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=cb-32|0;cb=f;v[f+16>>2]=c;v[f+24>>2]=b;o=Af(a);while(1){if(ih(f+24|0,f+16|0)){ac(f+8|0,o);b=v[f+8>>2];m=f+24|0;h=od(m);l=cb-16|0;cb=l;n=0;k=cb-16|0;cb=k;i=cb-32|0;cb=i;e=i+28|0;c=i+24|0;d=cb-32|0;cb=d;v[d+24>>2]=b;a:{b:{if(!hc(b,v[ac(d+16|0,cg(a))>>2])){g=w[h|0];j=v[h+4>>2];if(!yy(g,j,od(d+24|0))){break b}}v[d+16>>2]=b;c=ac(d+8|0,bq(a));c:{if(!hc(v[d+16>>2],v[c>>2])){j=od(Wy(d+16|0));c=w[h|0];g=v[h+4>>2];if(!xy(j,c,g)){break c}}if(!v[b>>2]){v[e>>2]=b;break a}b=v[d+16>>2];v[e>>2]=b;b=b+4|0;break a}b=zy(a,e,c,g);break a}if(xy(od(d+24|0),g,j)){c=Uy(b);v[d+16>>2]=c;d:{if(!hc(c,v[ac(d+8|0,cg(a))>>2])){g=w[h|0];j=v[h+4>>2];if(!yy(g,j,od(d+16|0))){break d}}if(!v[v[d+24>>2]+4>>2]){v[e>>2]=b;b=b+4|0;break a}v[e>>2]=c;b=c;break a}b=zy(a,e,g,j);break a}v[e>>2]=b;v[c>>2]=b;b=c}cb=d+32|0;d=v[b>>2];if(!d){d=cb-16|0;cb=d;e=bc(a);c=i+8|0;e=kh(c,lc(28),lh(d+8|0,e));Dz(v[e>>2]+16|0,h);p=bc(e),q=1,t[p+4|0]=q;cb=d+16|0;Ig(a,v[i+28>>2],b,v[c>>2]);d=Vd(c);pk(c);n=1}Hg(k+8|0,ac(i+8|0,d),n);cb=i+32|0;cb=k+16|0;ac(l+8|0,v[k+8>>2]);cb=l+16|0;mk(m);continue}else{cb=f+32|0}break}}function JF(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=cb-16|0;cb=l;f=w[a|0];a:{if(!f){g=a;break a}g=a;b:{while(1){if(!Pk(f<<24>>24)){break b}f=w[g+1|0];g=g+1|0;if(f){continue}break}break a}c:{f=f&255;switch(f-43|0){case 0:case 2:break c;default:break a}}m=(f|0)==45?-1:0;g=g+1|0}d:{if(!(c&-17|w[g|0]!=48)){o=1;if((w[g+1|0]&223)==88){g=g+2|0;j=16;break d}g=g+1|0;j=c?c:8;break d}j=c?c:10}p=j>>31;c=0;while(1){e:{f=-48;i=t[g|0];f:{if((i-48&255)>>>0<10){break f}f=-87;if((i-97&255)>>>0<26){break f}f=-55;if((i-65&255)>>>0>25){break e}}i=f+i|0;if((i|0)>=(j|0)){break e}xf(l,j,p,0,0,k,h,0,0);f=1;g:{if(v[l+8>>2]|v[l+12>>2]){break g}q=kka(k,h,j,p);n=fb;r=i>>31;s=r^-1;if((n|0)==(s|0)&(i^-1)>>>0<q>>>0|n>>>0>s>>>0){break g}h=n+r|0;f=i+q|0;h=f>>>0<i>>>0?h+1|0:h;k=f;o=1;f=c}g=g+1|0;c=f;continue}break}if(b){v[b>>2]=o?g:a}h:{i:{j:{if(c){v[114922]=68;a=d&1;m=a?0:m;k=d;h=e;break j}if((e|0)==(h|0)&d>>>0>k>>>0|e>>>0>h>>>0){break i}a=d&1}if(!(a|m)){v[114922]=68;a=d;d=a-1|0;e=e-!a|0;break h}if((e|0)==(h|0)&d>>>0>=k>>>0|e>>>0>h>>>0){break i}v[114922]=68;break h}a=m;b=a^k;d=b-a|0;c=a>>31;e=(c^h)-((a>>>0>b>>>0)+c|0)|0}cb=l+16|0;fb=e;return d}function Iia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;ed(b,32);_n(b);c=a+50|0;i=b,j=Rd((w[c|0]|w[c+1|0]<<8)<<16>>16)>>>2|0,u[i+32>>1]=j;c=a+32|0;if((Rd((w[c|0]|w[c+1|0]<<8)<<16>>16)|0)>0){u[b+34>>1]=x[b+34>>1]|32;c=Rd((w[c|0]|w[c+1|0]<<8)<<16>>16);e=c>>>24|0;d=(c<<8&-256)+2047|0;c=e&255;i=b,j=wc(nka(d,d>>>0<2047?c+1|0:c,4095,0),fb),u[i+28>>1]=j}c=a+38|0;e=Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));v[b>>2]=e;d=a+42|0;g=Wb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));v[b+4>>2]=g;c=a+46|0;h=Wb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))|0;v[b+8>>2]=h;f=a+34|0;if((wb(w[f|0]|w[f+1|0]<<8)|0)==16){v[b+8>>2]=h>>>1;v[b+4>>2]=g>>>1;v[b>>2]=e>>>1}a:{b:{if(Wb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))){d=x[b+34>>1];break b}d=x[b+34>>1];if(Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>=3){break b}c=d&-3;break a}c=d|2}u[b+34>>1]=c;f=c&65531;c=a+30|0;i=b,j=f|wb(w[c|0]|w[c+1|0]<<8)<<1&4,u[i+34>>1]=j;c=a+36|0;i=b,j=wb(w[c|0]|w[c+1|0]<<8)<<1,v[i+24>>2]=j;c=a+52|0;a=Rd((w[c|0]|w[c+1|0]<<8)<<16>>16);if(a){vl(b,+(a|0)/96);a=Rd((w[c|0]|w[c+1|0]<<8)<<16>>16)}t[b+37|0]=a<<4}function tea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,z=0,A=0;i=cb-16|0;cb=i;ed(d,32);e=i+8|0;DP(e,a+20|0,v[b>>2]);h=bc(e);DP(i,a+36|0,v[c>>2]);a=0;h=v[h>>2];if(h-838861>>>0>=4294128436){a=v[bc(i)>>2];v[d>>2]=B(h,320);u[d+34>>1]=1;a:{l=Lg(d);if(!l){break a}k=h<<2;f=+(k>>>0);p=+(a>>>0)/f;q=+(h>>>0)/f;r=1/+y[d>>2];s=+y[i>>2];t=+y[e>>2];h=0;b:while(1){if((h|0)==(k|0)){break a}m=+(h>>>0);n=0;o=0;if(Sd(b)){f=m*q+t;c:{if(f<4294967296&f>=0){g=~~f>>>0;break c}g=0}a=g;f=f-+(a>>>0);e=x[b+34>>1];a=zd(e);g=B(g,a);d:{if(e&1){j=v[b+20>>2];e=x[j+(g<<1)>>1];a=u[j+(a+g<<1)>>1];break d}e=v[b+20>>2];a=w[e+(a+g|0)|0]<<8;e=w[e+g|0]<<8}o=+(e<<16>>16)*(1-f)+f*+(a<<16>>16)}if(Sd(c)){f=m*p+s;e:{if(f<4294967296&f>=0){g=~~f>>>0;break e}g=0}a=g;f=f-+(a>>>0);e=x[c+34>>1];a=zd(e);g=B(g,a);f:{if(e&1){j=v[c+20>>2];e=x[j+(g<<1)>>1];a=u[j+(a+g<<1)>>1];break f}e=v[c+20>>2];a=w[e+(a+g|0)|0]<<8;e=w[e+g|0]<<8}n=+(e<<16>>16)*(1-f)+f*+(a<<16>>16)}e=0;a=h;while(1)if((e|0)==80){h=h+1|0;continue b}else{f=r*+(a>>>0);z=v[d+20>>2]+(a<<1)|0,A=zz(o*(1-f)+n*f),u[z>>1]=A;a=a+k|0;e=e+1|0;continue}}}a=(l|0)!=0}cb=i+16|0;return a|0}function ud(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=cb+-64|0;cb=d;v[a+480180>>2]=b;b=fq(a);eq(d,b);e=v[d+12>>2];c=a+1074320|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=e;c=v[d+4>>2];v[a+1074312>>2]=v[d>>2];v[a+1074316>>2]=c;As(a+8|0,b);b=1;while(1){c=b&65535;if(c>>>0>x[a+480192>>1]){v[a+480184>>2]=0;v[a+480188>>2]=0;v[a+480236>>2]=65536;v[a+480228>>2]=48;v[a+480232>>2]=48;t[a+480268|0]=5;v[a+480260>>2]=16;v[a+480264>>2]=32767;v[a+480204>>2]=125e4;v[a+480208>>2]=0;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+1074304>>2]=0;v[a+1074308>>2]=0;u[a+480192>>1]=0;ly(a,4);e=cb+-64|0;cb=e;b=a+484344|0;Ds(b);f=vk(v[b>>2],v[b+4>>2]);c=Mx(e+8|0,b);v[22440]=0;U(838,b|0,f|0,c|0);b=v[22440];v[22440]=0;a:{if((b|0)!=1){bl(c);cb=e- -64|0;break a}a=P()|0;O()|0;bl(c);S(a|0);L()}rO(a+484360|0);dg(a+1298308|0);Dt(a+1298320|0);dg(a+1298332|0);c=a+1298344|0;d=Hb(d,0,64);b=WL(d);Cb(c,b);Cb(c+12|0,b+12|0);Cb(c+24|0,b+24|0);Cb(c+36|0,b+36|0);Cb(c+48|0,b+48|0);v[c+60>>2]=v[b+60>>2];Gs(b);Ac(a+1298408|0);Ac(a+480248|0);if(v[a+480180>>2]&738230281){v[a+480208>>2]=v[a+480208>>2]|8388608}cb=d- -64|0;return}e=((c<<2)+a|0)+900380|0;c=v[e>>2];if(c){Jt(c)}zb(c);v[e>>2]=0;b=b+1|0;continue}}function nea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=cb-32|0;cb=e;u[e+28>>1]=c;u[e+30>>1]=b;u[e+26>>1]=d;i=x[v[v[a+24>>2]+8>>2]+12>>1];a:{if(i>>>0<=b>>>0){break a}if(!c|rj(a)>>>0>=i>>>0){break a}Kf(e+28|0,i-b&65535);p=e,q=yl(a),u[p+8>>1]=q;f=x[e+28>>1];MR(a,f+x[ie(e+30|0,e+8|0)>>1]|0);c=v[a>>2];if(Fc(c,v[a+4>>2])>>>0<b>>>0){Ff(a,b);c=v[a>>2]}p=e,q=yb(c),v[p+8>>2]=q;c=cb-16|0;cb=c;v[c+8>>2]=v[e+8>>2];b=v[vO(c+8|0,b)>>2];cb=c+16|0;b=v[ac(e+16|0,b)>>2];g=e+26|0;l=cb-32|0;cb=l;c=a;a=v[c>>2];d=(go(b,yb(a))<<1)+a|0;a=f;b:{if(!a){break b}b=v[xb(c)>>2];f=v[c+4>>2];if(a>>>0<=b-f>>1>>>0){b=a;j=f-d|0;h=j>>1;if(h>>>0<a>>>0){oo(c,a-h|0,g);b=h;if(!j){break b}}m=cb-16|0;cb=m;j=f;o=v[c+4>>2];h=(o-((a<<1)+d|0)|0)+d|0;n=Xh(m,c,f-h>>1);k=v[n+4>>2];f=h;while(1){if(f>>>0>=j>>>0){dc(n);iq(d,h,o);cb=m+16|0}else{Mi(k,x[f>>1]);k=k+2|0;v[n+4>>2]=k;f=f+2|0;continue}break}if(d>>>0<=g>>>0){g=((y[c+4>>2]>g>>>0?a:0)<<1)+g|0}Ft(d,b,g);break b}b=xb(c);b=Mj(l+8|0,Nj(c,Fc(v[c>>2],f)+a|0),d-v[c>>2]>>1,b);zC(b,a,g);d=sO(c,b,d);Pi(b)}yb(d);cb=l+32|0;if(Fc(v[c>>2],v[c+4>>2])>>>0<=i>>>0){break a}Ff(c,i)}cb=e+32|0}function OU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;f=cb-144|0;cb=f;v[22440]=0;n=T(278,a|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){e=f+8|0;o=e|4;p=e|6;q=e|5;j=e|2;k=e|3;r=c+480192|0;while(1){a:{if((l&65535)>>>0>=n>>>0){sb(a);cb=f+144|0;return}v[22440]=0;R(297,a|0,f+8|0);e=v[22440];v[22440]=0;if((e|0)!=1){b:{e=f+8|0;e=wb(w[e|0]|w[e+1|0]<<8);if(!e|e>>>0>x[r>>1]){break b}e=v[((e<<2)+c|0)+900380>>2];if(!e){break b}g=Bh(e,b);c:{if(!w[k|0]){break c}e=w[j|0];if(e&1){t[g+12|0]=w[g+12|0]|1;e=w[j|0]}if(e&2){t[g+12|0]=w[g+12|0]|4;e=w[j|0]}if(!(e&4)){break c}t[g+12|0]=w[g+12|0]|2}t[f+4|0]=w[k|0];t[f+7|0]=31;e=w[Tb(f+4|0,f+7|0)|0];v[22440]=0;m=e+1&255;R(298,g|0,m|0);e=v[22440];v[22440]=0;if((e|0)==1){break a}t[g+13|0]=w[q|0];t[g+14|0]=w[p|0];e=w[o|0];t[g+15|0]=e;t[g+16|0]=e;e=0;while(1){if((e|0)==(m|0)){break b}h=(f+8|0)+(e<<2)|0;i=h+8|0;i=wb(w[i|0]|w[i+1|0]<<8);s=Ib(v[g>>2],e),y=i,u[s>>1]=y;h=h+10|0;h=wb(w[h|0]|w[h+1|0]<<8);u[f+4>>1]=d?h+128>>>2|0:h;Kf(f+4|0,64);s=Ib(v[g>>2],e),y=w[f+4|0],t[s+2|0]=y;e=e+1|0;continue}}l=l+1|0;continue}}break}}b=P()|0;O()|0;sb(a);S(b|0);L()}function Vba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=cb-48|0;cb=f;l=v[a+16>>2];g=ee(f+16|0);v[g+8>>2]=a+112;e=v[a+128>>2];v[g+16>>2]=e;o=g,p=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;j=v[a+8>>2];k=v[a+12>>2];if(e){o=g,p=kg(j,k,e),v[o>>2]=p;v[g+4>>2]=fb}m=v[a+24>>2];n=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;a:while(1){if(d){v[f+40>>2]=e;v[f+44>>2]=0;e=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+l|0;b=v[g+16>>2];while(1)if((b|0)<=0){b=v[g+8>>2];h=v[b+8>>2];Jb(b,h,v[b+12>>2]);b=v[g+8>>2];h=v[b+4>>2];if(h){i=b;b=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Jd(i,(u[(b<<1|2)+e>>1]+u[e+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[g+8>>2],h);b=v[g+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}d=d-1|0;i=v[c>>2];b=ig(b,v[g+12>>2]);v[c>>2]=i+B(b,n);v[c+4>>2]=v[c+4>>2]+B(b,m);Jb(f+8|0,j,k);c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue a}else{h=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Jd(v[g+8>>2],(u[(h<<1|2)+e>>1]+u[e+((h&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[g+8>>2],4);Jb(f+40|0,v[g>>2],v[g+4>>2]);b=b-1|0;continue}}break}v[a>>2]=e;v[a+4>>2]=b;cb=f+48|0}function bS(a,b,c){var d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;t[d+15|0]=c;a:{if(b>>>0>=22){t[d+14|0]=0;ae(a,0,d+14|0);break a}e=w[b+26784|0];b:{c:{switch(b-8|0){case 0:t[d+15|0]=c<<1;break b;case 4:t[d+15|0]=c+1>>>1;break b;case 5:t[d+15|0]=B(c>>>4|0,10)+(c&15);break b;case 6:d:{switch((c>>>4|0)-1|0){default:e=0;break b;case 0:t[d+13|0]=c&15;t[d+12|0]=14;f=d,g=w[Tb(d+13|0,d+12|0)|0]<<4|15,t[f+15|0]=g;e=29;break b;case 1:t[d+11|0]=c&15;t[d+10|0]=14;f=d,g=w[Tb(d+11|0,d+10|0)|0]|240,t[f+15|0]=g;e=29;break b;case 3:t[d+15|0]=c&15|48;break b;case 4:t[d+15|0]=c<<4^128;e=35;break b;case 5:t[d+15|0]=c&15|176;break b;case 6:t[d+15|0]=c&15|64;break b;case 8:e=15;t[d+15|0]=c&15;break b;case 9:t[d+15|0]=(c<<3&120)+8&240;e=24;break b;case 10:t[d+15|0]=(c&15)+1>>>1;e=24;break b;case 14:break d;case 11:case 12:case 13:break b}}e=10;break b;case 8:if(c>>>0<=223){b=c>>>2|0;t[d+15|0]=(b>>>0<15?b:15)<<4;break b}if(c>>>0<=239){t[d+15|0]=c<<2&48|15;break b}t[d+15|0]=c<<4|15;break b;case 9:break c;default:break b}}if(c>>>0<=223){b=c>>>2|0;t[d+15|0]=b>>>0<15?b:15;break b}if(c>>>0>239){break b}t[d+15|0]=c>>>2&3|240}ae(a,e,d+15|0)}cb=d+16|0}function u8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=cb-16|0;cb=h;if(!w[a+4242|0]){yx(a);a:{if(!w[a+4240|0]){break a}e=BL(v[a+16>>2]);if(e==A[a+4288>>3]){break a}A[a+4288>>3]=e;rs(a)}f=a+4256|0;b:{if(w[a+4244|0]){if(A[f>>3]>1){v[f>>2]=0;v[f+4>>2]=1072693248}break b}i=(v[a+4232>>2]&-2)!=4;e=A[f>>3];c:{if(D(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<=0)){wx(a);e=A[a+4256>>3]}A[f>>3]=e-+(g|0)}e=0;d:{e:{switch(v[a+4232>>2]){case 0:e=Bi(A[f>>3]*6.283185307179586);break d;case 1:e=D(A[f>>3]+-.5)*-4+1;break d;case 2:e=A[f>>3];e=e+e+-1;break d;case 3:e=A[f>>3]<.5?-1:1;break d;case 4:e=A[a+4272>>3];break d;case 5:break e;default:break d}}e=A[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=A[a+4280>>3]*e+A[a+4272>>3]*(1-e)}A[h+8>>3]=(w[a+4241|0]?-e:e)*+z[a+4220>>2]+ +z[a+4224>>2];dN(h+8|0,1);g=$j(a);f:{if(!g){break f}f=v[a+4236>>2];if(w[a+4243|0]){k=g,l=(f>>>8&15|176)&191|(f&127)<<8|rk(A[h+8>>3]*127)<<16,j=v[v[g>>2]+68>>2],gb[j](k|0,l|0)|0;break f}gb[v[v[g>>2]+44>>2]](g,f,C(A[h+8>>3]))}A[a+4256>>3]=A[a+4264>>3]*+(d>>>0)+A[a+4256>>3]}g=a;a=a+44|0;ti(g,b,c,Ud(a,0),Ud(a,1),d);cb=h+16|0}function Vda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;l=cb-48|0;cb=l;if(Cf(b)>>>0>c>>>0){while(1){f=m&65535;if(f>>>0<=c>>>0){e=fg(v[b>>2],f);if(Vh(e)){n=l+24|0;e=Pg(e);o=Og(fg(v[b>>2],f));g=gP(l,d);j=cb-16|0;cb=j;v[j+8>>2]=e;while(1){if(Qb(e,o)){i=cb-16|0;cb=i;if(!(w[e+5|0]|w[e+3|0]!=4)){f=i+8|0;ub(f,v[g>>2],x[g+14>>1]);Te(f,0);t[e+3|0]=0}h=w[e+2|0];if(!(w[e+4|0]|(h|0)!=11)){f=i+8|0;ub(f,v[g>>2],x[g+14>>1]);Te(f,0);t[e+2|0]=0;h=0}a:{b:{if(!w[e|0]){ub(i+8|0,v[g>>2],x[g+14>>1]);if(tb(v[v[i+8>>2]>>2],v[i+12>>2])){break b}h=w[e+2|0]}k=w[e+3|0];f=i+8|0;ub(f,v[g>>2],x[g+14>>1]);Te(f,(k|0)==4|(h|0)==11);h=w[e+3|0];break a}h=w[e+3|0];f=w[e+2|0];if(!(h|(f|0)==11)){t[e+5|0]=0;h=4;t[e+3|0]=4;break a}if(f|(h|0)==4){break a}t[e+4|0]=0;t[e+2|0]=11}c:{d:{e:{if(!(!w[g+16|0]|h)){t[e+3|0]=17;k=0;h=125;break e}k=0;f:{switch(h-16|0){case 1:break d;case 0:break f;default:break c}}if(w[e+5|0]){break c}k=1;h=6}t[e+5|0]=h}t[g+16|0]=k}u[g+14>>1]=(x[g+14>>1]+1>>>0)%x[g+12>>1];cb=i+16|0;Ki(j+8|0);e=v[j+8>>2];continue}break}dP(n,g);cb=j+16|0;Re(n);Re(g)}m=m+1|0;continue}break}}dP(a,d);cb=l+48|0}function dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=cb-16|0;cb=h;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];j=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=j;o=v[a+8>>2];p=v[a+12>>2];while(1){j=e;if(d){q=v[a+72>>2];e=v[a+64>>2];g=e;k=e>>31;e=Vb(j,-16777216,16776704);e=kka(g,k,e,e>>31);g=fb;k=e;e=v[a+68>>2];f=Vb(f,-16777216,16776704);i=kka(e,e>>31,f,f>>31);e=k+i|0;f=fb+g|0;f=e>>>0<i>>>0?f+1|0:f;k=e;e=v[a+60>>2];i=e;r=e>>31;e=(v[h+12>>2]<<1)+n|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+b|0;g=(((((B(u[e+4>>1],u[g+34>>1])+B(u[e+2>>1],u[g+32>>1])|0)+B(u[e+6>>1],u[g+36>>1])|0)+B(u[e+8>>1],u[g+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[g+26>>1])+B(u[e-6>>1],u[g+24>>1])|0)+B(u[e-2>>1],u[g+28>>1])|0)+B(u[e>>1],u[g+30>>1])|0)/2|0)|0)/16384<<8;e=g;i=kka(i,r,e,e>>31);e=k+i|0;f=fb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Mc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Jb(h+8|0,o,p);e=f-(g&q)|0;c=c+8|0;d=d-1|0;f=j;continue}break}b=v[h+12>>2];c=v[h+8>>2];v[a+48>>2]=f;v[a+44>>2]=j;v[a>>2]=c;v[a+4>>2]=b;cb=h+16|0}function SX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(Wg(a,v[b+8>>2],e)){Gv(b,c,d);return}a:{if(Wg(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;if(v[b+44>>2]!=4){f=a+16|0;h=f+(v[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}u[b+52>>1]=0;Dv(f,b,c,c,1,e);if(w[b+54|0]){break d}e:{if(!w[b+53|0]){break e}if(w[b+52|0]){d=1;if(v[b+24>>2]==1){break c}g=1;if(w[a+8|0]&2){break e}break c}g=1;if(!(t[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}v[b+44>>2]=a;if(d&1){break a}}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}f=v[a+12>>2];g=a+16|0;ir(g,b,c,d,e);if((f|0)<2){break a}g=g+(f<<3)|0;f=a+24|0;a=v[a+8>>2];if(!(!(a&2)&v[b+36>>2]!=1)){while(1){if(w[b+54|0]){break a}ir(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(w[b+54|0]|v[b+36>>2]==1){break a}ir(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(w[b+54|0]|v[b+36>>2]==1&v[b+24>>2]==1){break a}ir(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function Fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;h=cb-16|0;cb=h;g=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];p=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;q=v[a+8>>2];r=v[a+12>>2];while(1){b=e;if(d){s=v[a+72>>2];t=v[a+32>>2];j=v[a+28>>2]+j|0;e=j>>12;f=v[a+64>>2];k=f;n=f>>31;f=Vb(b,-16777216,16776704);f=kka(k,n,f,f>>31);l=fb;n=e;o=f;e=v[a+60>>2];m=e;w=e>>31;e=(v[h+12>>2]<<1)+p|0;f=v[h+8>>2]>>>21&2040;k=(((B(u[e>>1],u[f+39826>>1])+B(u[e-2>>1],u[f+39824>>1])|0)+B(u[e+2>>1],u[f+39828>>1])|0)+B(u[e+4>>1],u[f+39830>>1])|0)/16384<<8;e=k;m=kka(m,w,e,e>>31);f=o+m|0;e=fb+l|0;e=f>>>0<m>>>0?e+1|0:e;o=f;f=v[a+68>>2];g=Vb(g,-16777216,16776704);l=kka(f,f>>31,g,g>>31);f=o+l|0;g=fb+e|0;g=f>>>0<l>>>0?g+1|0:g;e=f+8388608|0;g=e>>>0<8388608?g+1|0:g;g=Mc(e,g,24);e=(g|0)/256|0;v[c>>2]=B(n,e)+v[c>>2];i=i+t|0;v[c+4>>2]=v[c+4>>2]+B(e,i>>12);Jb(h+8|0,q,r);e=g-(s&k)|0;c=c+8|0;d=d-1|0;g=b;continue}break}c=v[h+12>>2];d=v[h+8>>2];v[a+36>>2]=j;v[a>>2]=d;v[a+4>>2]=c;v[a+40>>2]=i;v[a+48>>2]=g;v[a+44>>2]=b;v[a+20>>2]=j>>12;v[a+24>>2]=i>>12;cb=h+16|0}function Baa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=cb-32|0;cb=f;v[f+16>>2]=c;v[f+24>>2]=b;n=Af(a);while(1){if(ih(f+24|0,f+16|0)){ac(f+8|0,n);b=v[f+8>>2];l=f+24|0;i=od(l);k=cb-16|0;cb=k;m=0;j=cb-16|0;cb=j;g=cb-32|0;cb=g;e=g+28|0;c=g+24|0;d=cb-32|0;cb=d;v[d+24>>2]=b;a:{b:{if(!hc(b,v[ac(d+16|0,cg(a))>>2])){h=w[i|0];if(!By(h,od(d+24|0))){break b}}v[d+16>>2]=b;c=ac(d+8|0,bq(a));c:{if(!hc(v[d+16>>2],v[c>>2])){h=od(Wy(d+16|0));c=w[i|0];if(!Ay(h,c)){break c}}if(!v[b>>2]){v[e>>2]=b;break a}b=v[d+16>>2];v[e>>2]=b;b=b+4|0;break a}b=Cy(a,e,c);break a}if(Ay(od(d+24|0),h)){c=Uy(b);v[d+16>>2]=c;d:{if(!hc(c,v[ac(d+8|0,cg(a))>>2])){h=w[i|0];if(!By(h,od(d+16|0))){break d}}if(!v[v[d+24>>2]+4>>2]){v[e>>2]=b;b=b+4|0;break a}v[e>>2]=c;b=c;break a}b=Cy(a,e,h);break a}v[e>>2]=b;v[c>>2]=b;b=c}cb=d+32|0;d=v[b>>2];if(!d){d=cb-16|0;cb=d;e=bc(a);c=g+8|0;e=kh(c,lc(24),lh(d+8|0,e));nM(v[e>>2]+16|0,i);o=bc(e),p=1,t[o+4|0]=p;cb=d+16|0;Ig(a,v[g+28>>2],b,v[c>>2]);d=Vd(c);pk(c);m=1}Hg(j+8|0,ac(g+8|0,d),m);cb=g+32|0;cb=j+16|0;ac(k+8|0,v[j+8>>2]);cb=k+16|0;mk(l);continue}else{cb=f+32|0}break}}function h9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=cb-16|0;cb=h;c=rf(a,c);ke(h,v[a+36>>2]);a:{b:{if(!c){Cc(h,a+32|0,5);d=-1;if(!tb(v[v[h>>2]>>2],v[h+4>>2])){break b}break a}d=v[c+16>>2]}e=v[a+36>>2];c:{if(!((d|0)!=4&(d|0)!=-1)){d=cb-16|0;cb=d;v[d+8>>2]=0;gp(e,d+8|0);z[b>>2]=z[d+8>>2];cb=d+16|0;break c}i=cb-16|0;cb=i;v[i+12>>2]=d;v[i+8>>2]=4;g=v[Bb(i+12|0,i+8|0)>>2];j=cb-16|0;cb=j;BG(j+8|0,e);d=v[j+12>>2];if(er(-1,2147483647,g,0)^1){e=er(g,0,0,-2147483648)^1}else{e=0}if(e){d:{e=cb-48|0;cb=e;k=d+v[v[d>>2]-12>>2]|0;f=v[k+16>>2]&-3;Ml(k,f);ji(e+40|0,d,1);e:{f:{if(Ed(w[e+40|0])){k=v[(d+v[v[d>>2]-12>>2]|0)+24>>2];v[22440]=0;oE(e+24|0,k,g);g=v[22440];v[22440]=0;g:{if((g|0)!=1){f=iE(e+24|0,Xg(e+8|0,-1,-1))?f|4:f;break g}g=V(0)|0;O()|0;_(g|0)|0;f=f|1;ii(d+v[v[d>>2]-12>>2]|0,f);if(v[(d+v[v[d>>2]-12>>2]|0)+20>>2]&1){v[22440]=0;X(107);a=v[22440];v[22440]=0;if((a|0)!=1){break e}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)==1){break f}S(a|0);L()}$()}Mg(d+v[v[d>>2]-12>>2]|0,f)}cb=e+48|0;break d}V(0)|0;O()|0;Lb()}L()}}cb=j+16|0;v[b>>2]=0;cb=i+16|0}e=c}Se(a,e);cb=h+16|0}function eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=cb-16|0;cb=h;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];j=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=j;o=v[a+8>>2];p=v[a+12>>2];while(1){j=e;if(d){q=v[a+72>>2];e=v[a+64>>2];g=e;k=e>>31;e=Vb(j,-16777216,16776704);e=kka(g,k,e,e>>31);g=fb;k=e;e=v[a+68>>2];f=Vb(f,-16777216,16776704);i=kka(e,e>>31,f,f>>31);e=k+i|0;f=fb+g|0;f=e>>>0<i>>>0?f+1|0:f;k=e;e=v[a+60>>2];i=e;r=e>>31;e=v[h+12>>2]+n|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+b|0;g=(((((B(t[e+2|0],u[g+34>>1])+B(t[e+1|0],u[g+32>>1])|0)+B(t[e+3|0],u[g+36>>1])|0)+B(t[e+4|0],u[g+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[g+26>>1])+B(t[e-3|0],u[g+24>>1])|0)+B(t[e-1|0],u[g+28>>1])|0)+B(t[e|0],u[g+30>>1])<<8)/2|0)|0)/16384<<8;e=g;i=kka(i,r,e,e>>31);e=k+i|0;f=fb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Mc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Jb(h+8|0,o,p);e=f-(g&q)|0;c=c+8|0;d=d-1|0;f=j;continue}break}b=v[h+12>>2];c=v[h+8>>2];v[a+48>>2]=f;v[a+44>>2]=j;v[a>>2]=c;v[a+4>>2]=b;cb=h+16|0}function p9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=0,q=C(0);i=cb-16|0;cb=i;h=u[d+2>>1];j=u[d>>1];a:{if((h|0)<(j|0)){break a}l=v[b>>2];k=pc(l,v[b+4>>2]);if(!k){break a}g=u[e>>1];if((g|0)<(j|0)|(g|0)>(h|0)|(k-1&65535)>>>0>(h-g&65535)>>>0|y[a+36>>2]>65535){break a}g=0;while(1){if((g|0)!=(k|0)){n=Ib(l,g);g=g+1|0;if(!(z[n>>2]<C(0))){continue}break a}break}m=z[c>>2];if(m<=C(0)){break a}u[a+28>>1]=j;u[a>>1]=1;o=a,p=HK(k),u[o+30>>1]=p;z[a+32>>2]=D(m);ak(a+4|0,(h-j|0)+1|0);c=yb(v[b>>2]);b=yb(v[b+4>>2]);o=i,p=yb(v[a+4>>2]),v[o+8>>2]=p;f=c;c=nl(i+8|0,u[e>>1]-u[d>>1]|0);f=Bo(f,b,c);b=cb-16|0;cb=b;v[b+8>>2]=c;nl(b+8|0,f-c>>2);cb=b+16|0;c=u[a+28>>1];b=u[e>>1];f=b;while(1){if((b&65535)!=32768&(c|0)<(f|0)){b=v[a+4>>2];f=f-1|0;g=f-c|0;h=Ib(b,g+u[a+30>>1]|0);o=Ib(b,g),q=C(z[h>>2]/z[a+32>>2]),z[o>>2]=q;b=x[e>>1];continue}else{e=u[a+30>>1];b=b<<16>>16;f=e+b|0;d=u[d+2>>1];b=(b|0)<=(32767-e|0);while(1){if(b&(d|0)>=(f|0)){g=v[a+4>>2];h=Ib(g,f-(c+e|0)|0);o=Ib(g,f-c|0),q=C(z[a+32>>2]*z[h>>2]),z[o>>2]=q;f=f+1|0;continue}else{ip(a)}break}}break}f=1}cb=i+16|0;return f|0}function zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;f=cb-16|0;cb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){h=v[f+8>>2];m=((((v[f+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+j|0;e=(h>>>16&65520)+b|0;n=u[e+14>>1];o=u[e+12>>1];p=u[e+10>>1];q=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];t=u[e+2>>1];w=u[e>>1];h=0;while(1){if((h|0)!=2){e=(h<<1)+m|0;v[(h<<2)+f>>2]=(((((((B(u[e-8>>1],t)+B(u[e-12>>1],w)|0)+B(u[e-4>>1],s)|0)+B(u[e>>1],r)|0)+B(u[e+4>>1],q)|0)+B(u[e+8>>1],p)|0)+B(u[e+12>>1],o)|0)+B(u[e+16>>1],n)|0)/32768;h=h+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],k);Jb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;cb=f+16|0}function c8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=cb+-64|0;cb=c;g=Rb(a);v[22440]=0;Z(934,g|0);b=v[22440];v[22440]=0;a:{if((b|0)!=1){b=44672;b:{c:{d:{e:{f:{g:{h:{i:{j:{while(1){if((b|0)==44984){cb=c- -64|0;return a|0}k:{d=Dg(44);if(d){h=v[b>>2];f=v[b+4>>2];v[22440]=0;f=Q(56,c+32|0,f|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break k}v[22440]=0;R(935,c+48|0,f|0);e=v[22440];v[22440]=0;if((e|0)==1){break j}e=v[b+8>>2];v[22440]=0;e=Q(56,c|0,e|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break i}v[22440]=0;R(935,c+16|0,e|0);i=v[22440];v[22440]=0;if((i|0)==1){break h}v[22440]=0;da(936,d|0,h|0,c+48|0,c+16|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break g}Ab(c+16|0);rb(e);Ab(c+48|0);rb(f);v[c+60>>2]=d;v[22440]=0;R(937,g|0,c+60|0);f=v[22440];v[22440]=0;if((f|0)==1){break b}v[d+32>>2]=v[b+12>>2];v[d+36>>2]=v[b+16>>2];t[d+40|0]=w[b+20|0];t[d+41|0]=w[d+41|0]&253|w[b+21|0]<<1}b=b+24|0;continue}break}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;Ab(c+16|0)}rb(e)}Ab(c+48|0)}rb(f)}zb(d);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}fc(g);S(b|0);L()}function yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=cb-1072|0;cb=d;v[d+1068>>2]=c;o=d,p=He(b),t[o+8|0]=p;t[d+4|0]=1;c=d+8|0;g=w[ff(c,d+4|0)|0];f=iB(c,b);l=lq(f);v[22440]=0;c=T(204,b|0)|0;e=v[22440];v[22440]=0;a:{if((e|0)!=1){v[d+4>>2]=c;v[d>>2]=536870911;qc(d+1068|0,v[Bb(d+4|0,d)>>2]<<3);v[22440]=0;m=v[d+1068>>2];k=Q(344,a|0,m|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;c=8;h=Q(166,f|0,8)|0;a=v[22440];v[22440]=0;b:{if((a|0)!=1){c:{o=Eb(v[k>>2],0),p=h,t[o|0]=p;i=1;a=g;while(1){c=c&255;n=c>>>0>9?c:9;e=a;d:{e:{while(1){if(i>>>0>=m>>>0){break d}v[22440]=0;j=Q(166,f|0,c|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){if(j){break e}if((c|0)==(n|0)){break d}c=c+1|0;e=g;continue}break}break c}a=j>>>1|0;h=(j&1?0-a|0:a)+h|0;o=Eb(v[k>>2],i),p=h,t[o|0]=p;i=i+1|0;a=g;if(j>>>c-1|0){continue}a=e-1|0;e=a&255;a=e?a:g;c=c-(!e&(c&255)>>>0>1)|0;continue}break}a=lq(f);v[22440]=0;Q(157,b|0,((a-l|0)+3&-4)+l|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break b}}}c=P()|0;O()|0;_b(k);break a}sb(f);cb=d+1072|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0}sb(f);S(c|0);L()}function o_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=cb-448|0;cb=a;v[a+432>>2]=c;v[a+440>>2]=b;v[a+20>>2]=1181;b=re(a+24|0,a+32|0,a+20|0);h=a+16|0;Jc(h,e);v[22440]=0;h=T(1159,h|0)|0;i=v[22440];v[22440]=0;if((i|0)!=1){a:{t[a+15|0]=0;e=v[e+4>>2];v[22440]=0;c=pa(1189,a+440|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+432|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}d:{if(Ld(g)){qd(v[g>>2],0);td(g,0);break d}qd(g,0);Yd(g,0)}if(w[a+15|0]){v[22440]=0;c=Q(1177,h|0,45)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}v[22440]=0;R(50,g|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break a}}v[22440]=0;c=Q(1177,h|0,48)|0;d=v[22440];v[22440]=0;if((d|0)==1){break b}e=v[b>>2];d=v[a+20>>2];h=d-4|0;while(1){if(!((c|0)!=v[e>>2]|e>>>0>=h>>>0)){e=e+4|0;continue}break}v[22440]=0;Y(1194,g|0,e|0,d|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break c}break a}v[22440]=0;c=Q(1165,a+440|0,a+432|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}if(c){v[f>>2]=v[f>>2]|2}c=v[a+440>>2];Pb(a+16|0);Lc(b);cb=a+448|0;return c|0}}}c=P()|0;O()|0;Pb(a+16|0);Lc(b);S(c|0);L()}function g8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0;c=cb-32|0;cb=c;a:{b=v[a+20>>2];b:{if(!b){break b}v[b+148>>2]=-1;h=c,i=gb[v[v[a>>2]+40>>2]](a)|0,v[h+16>>2]=i;v[c+8>>2]=1073741822;f=v[ld(c+16|0,c+8|0)>>2];b=f<<2;if(!b){break b}d=v[a+20>>2];v[22440]=0;R(292,d+4|0,b+4|0);b=v[22440];v[22440]=0;c:{d:{if((b|0)!=1){d=c+8|0;b=v[a+20>>2];qe(d,v[b+4>>2],v[b+8>>2]);v[c>>2]=0;v[c+4>>2]=0;e=v[d+4>>2];b=c+16|0;v[b>>2]=v[d>>2];v[b+4>>2]=e;d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;e=cb-16|0;cb=e;v[e+12>>2]=0;d=e+12|0;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;fK(b,d);cb=e+16|0;b=v[v[a>>2]+180>>2];v[22440]=0;R(b|0,a|0,-1);b=v[22440];v[22440]=0;if((b|0)==1){break d}d=(f|0)>0?f:0;b=0;while(1){if((b|0)==(d|0)){b=v[v[a>>2]+184>>2];v[22440]=0;Z(b|0,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}break d}e=v[v[a>>2]+48>>2];v[22440]=0;g=C(Wa(e|0,a|0,b|0));e=v[22440];v[22440]=0;if((e|0)!=1){z[c+8>>2]=g;b=b+1|0;fK(c+16|0,c+8|0);continue}break}b=V(88360)|0;break c}b=V(88360)|0;break c}b=V(88360)|0}if((O()|0)!=(fa(88360)|0)){break a}_(b|0)|0;Ac(v[a+20>>2]+4|0);$()}cb=c+32|0;return}S(b|0);L()}function $U(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=cb-32|0;cb=g;t[g+12|0]=0;m=HB(g+16|0,d,g+12|0);f=v[m>>2];v[g+12>>2]=d;h=d;while(1){if(!(!b|!h)){a:{i=b-1|0;k=w[a|0];if(!(!i|(k|0)!=(e&255))){v[g+8>>2]=w[a+1|0];i=a+2|0;j=Bb(g+8|0,g+12|0);b:{k=b-2|0;if(!k){break b}j=v[j>>2];if(!(j&255)){break b}i=w[i|0];while(1){if(!(j&255)){break a}t[f|0]=i;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;j=j-1|0;continue}}t[f|0]=e;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;b=k;a=i;continue}a=a+1|0;t[f|0]=k;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;b=i;continue}b=b-3|0;a=a+3|0;continue}break}e=d-h|0;a=v[m>>2];k=0;f=128;b=0;i=0;c:while(1){if((e|0)==(i|0)){while(1){if(e){d=k<<24>>24;b=t[c|0];a=128;d:{if((b|0)==-128){break d}a=b;if((b|0)>=0){break d}a=0-(b&127)|0}k=d-(a&255)|0;t[c|0]=k;e=e-1|0;c=c+1|0;continue}break}_b(m);cb=g+32|0;return}n=w[a|0];h=0;j=0;while(1)if((j&65535)>>>0>=8){f=f&65535;f=(f<<8|f)>>>h&255;i=i+1|0;a=a+1|0;continue c}else{l=b+c|0;t[l|0]=w[l|0]|B(f&n,257)>>>(h-j&7);l=b+1|0;b=d>>>0>l>>>0?l:0;j=j+1|0;h=(d>>>0<=l>>>0)+h|0;f=(f<<8|f)>>>1&255;continue}}}function Gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=cb-16|0;cb=h;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];m=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;n=v[a+8>>2];o=v[a+12>>2];while(1){b=e;if(d){p=v[a+72>>2];q=v[a+32>>2];k=v[a+28>>2]+k|0;e=v[a+64>>2];g=e;l=e>>31;e=Vb(b,-16777216,16776704);e=kka(g,l,e,e>>31);g=fb;l=e;e=v[a+68>>2];f=Vb(f,-16777216,16776704);i=kka(e,e>>31,f,f>>31);e=l+i|0;f=fb+g|0;f=e>>>0<i>>>0?f+1|0:f;l=e;e=v[a+60>>2];i=e;r=e>>31;e=v[h+12>>2]+m|0;g=v[h+8>>2]>>>21&2040;g=(((B(t[e|0],u[g+39826>>1])+B(t[e-1|0],u[g+39824>>1])|0)+B(t[e+1|0],u[g+39828>>1])|0)+B(t[e+2|0],u[g+39830>>1])<<8)/16384<<8;e=g;i=kka(i,r,e,e>>31);e=l+i|0;f=fb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Mc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(k>>12,e)+v[c>>2];j=j+q|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Jb(h+8|0,n,o);e=f-(g&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];d=v[h+8>>2];v[a+36>>2]=k;v[a>>2]=d;v[a+4>>2]=c;v[a+40>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;cb=h+16|0}function fM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=cb-16|0;cb=f;e=B(b,872)+a|0;a:{if(c){ub(f+8|0,a+1074312|0,90);if(!tb(v[v[f+8>>2]>>2],v[f+12>>2])){t[(B(b,872)+a|0)+1075803|0]=c}t[(B(b,872)+a|0)+1075804|0]=c;break a}c=w[e+1075804|0]}e=e+1074992|0;h=c&255;j=0-h|0;i=d?i:!(v[a+480180>>2]&204473357);aM(a,b,j,i);g=v[a+480180>>2];b:{c:{if((g|0)!=268435456){if((g|0)!=16777216){break c}k=v[(B(b,872)+a|0)+1075648>>2];if(!k|!v[k+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){$L(v[a+1074392>>2],v[a+1074416>>2],e,240-h|0);break b}if(!(b>>>0<224|d)){_L(e,224-h|0);break b}ZL(e,j);break b}v[(B(b,872)+a|0)+1075700>>2]=65535}d:{if(!((c&255)>>>0>223&i)){break d}e:{d=h&15;if(!d){break e}c=c&240;if((c|0)!=224){if((c|0)!=240){break e}ry(a,e,d);break b}if((g|0)==524288){break d}cM(a,e,d);break b}if((g|0)!=524288){break b}}f:{if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break f}if(v[a+1074416>>2]==1){ub(f+8|0,a+1074312|0,6);if(tb(v[v[f+8>>2]>>2],v[f+12>>2])){break f}g=v[a+480180>>2]}if(g&32832){break f}if(!(v[a+480208>>2]&2)|(g|0)!=8){break b}}ck(a,e,(B(b,872)+a|0)+1075692|0,0-(h<<2)|0,0)}cb=f+16|0}function kt(a,b){var c=0,d=0,e=0;d=cb-48|0;cb=d;e=d+24|0;yP(e,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);yP(d,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);a=v[e>>2];c=wb(w[a|0]|w[a+1|0]<<8);a=v[d>>2];b=1;a:{if(c>>>0<wb(w[a|0]|w[a+1|0]<<8)>>>0){break a}a=v[d>>2];c=wb(w[a|0]|w[a+1|0]<<8);a=v[e>>2];b=0;if(c>>>0<wb(w[a|0]|w[a+1|0]<<8)>>>0){break a}a=v[e+4>>2];c=wb(w[a|0]|w[a+1|0]<<8);a=v[d+4>>2];b=1;b:{if(c>>>0<wb(w[a|0]|w[a+1|0]<<8)>>>0){break b}a=v[d+4>>2];c=wb(w[a|0]|w[a+1|0]<<8);a=v[e+4>>2];b=0;if(c>>>0<wb(w[a|0]|w[a+1|0]<<8)>>>0){break b}a=v[e+8>>2];c=wb(w[a|0]|w[a+1|0]<<8);a=v[d+8>>2];b=1;c:{if(c>>>0<wb(w[a|0]|w[a+1|0]<<8)>>>0){break c}a=v[d+8>>2];c=wb(w[a|0]|w[a+1|0]<<8);a=v[e+8>>2];b=0;if(c>>>0<wb(w[a|0]|w[a+1|0]<<8)>>>0){break c}a=v[e+12>>2];c=Rd((w[a|0]|w[a+1|0]<<8)<<16>>16);a=v[d+12>>2];b=1;d:{if((c|0)<(Rd((w[a|0]|w[a+1|0]<<8)<<16>>16)|0)){break d}a=v[d+12>>2];c=Rd((w[a|0]|w[a+1|0]<<8)<<16>>16);a=v[e+12>>2];b=0;if((c|0)<(Rd((w[a|0]|w[a+1|0]<<8)<<16>>16)|0)){break d}a=v[e+16>>2];b=wb(w[a|0]|w[a+1|0]<<8);a=v[d+16>>2];b=b>>>0<wb(w[a|0]|w[a+1|0]<<8)>>>0}}}}a=b;cb=d+48|0;return a}function Aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;f=cb-16|0;cb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){h=v[f+8>>2];m=(((v[f+12>>2]&2147483647)<<1|h>>>31)&-2)+j|0;e=(h>>>16&65520)+b|0;n=u[e+14>>1];o=u[e+12>>1];p=u[e+10>>1];q=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];w=u[e+2>>1];x=u[e>>1];h=0;while(1){if((h|0)!=2){e=h+m|0;v[(h<<2)+f>>2]=(((((((B(t[e-4|0],w)+B(t[e-6|0],x)|0)+B(t[e-2|0],s)|0)+B(t[e|0],r)|0)+B(t[e+2|0],q)|0)+B(t[e+4|0],p)|0)+B(t[e+6|0],o)|0)+B(t[e+8|0],n)<<8)/32768;h=h+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],k);Jb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;cb=f+16|0}function AR(a,b,c,d,e){var f=0,g=0;f=cb-16|0;cb=f;g=x[c>>1];a:{if((d&255)>>>0<=4){while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!mf(a,f+15|0)){break a}d=w[f+15|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!mf(a,f+14|0)){break a}d=w[f+14|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!mf(a,f+13|0)){break a}d=w[f+13|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break a}}while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!mf(a,f+12|0)){break a}d=w[f+12|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!mf(a,f+11|0)){break a}d=w[f+11|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break}}cb=f+16|0}function F9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=cb-32|0;cb=j;e=b;b=v[a>>2];f=B(vs(e,yb(b)),6)+b|0;a:{if(!c){break a}b=v[xb(a)>>2];h=v[a+4>>2];if((b-h|0)/6>>>0>=c>>>0){b=c;g=h-f|0;e=(g|0)/6|0;if(e>>>0<c>>>0){zA(a,c-e|0,d);b=e;if(!g){break a}}k=cb-16|0;cb=k;m=v[a+4>>2];g=B((m-(B(c,6)+f|0)|0)/6|0,6)+f|0;l=nq(k,a,(h-g|0)/6|0);i=v[l+4>>2];e=g;while(1){if(e>>>0>=h>>>0){dc(l);e=g-f|0;if(e){gj(m+B((e|0)/-6|0,6)|0,f,e)}cb=k+16|0}else{Ot(i,e);i=i+6|0;v[l+4>>2]=i;e=e+6|0;continue}break}e=f;d=e>>>0<=d>>>0?B(y[a+4>>2]>d>>>0?c:0,6)+d|0:d;while(1){if(b){a=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[e|0]=a;t[e+1|0]=a>>>8;t[e+2|0]=a>>>16;t[e+3|0]=a>>>24;a=w[d+4|0]|w[d+5|0]<<8;t[e+4|0]=a;t[e+5|0]=a>>>8;b=b-1|0;e=e+6|0;continue}break}break a}b=xb(a);e=tS(j+8|0,tA(a,ok(v[a>>2],h)+c|0),(f-v[a>>2]|0)/6|0,b);sS(e,c,d);b=v[e+4>>2];d=e+4|0;qS(v[a>>2],f,d);g=v[a+4>>2];c=e+8|0;while(1){if((f|0)!=(g|0)){Ot(v[c>>2],f);v[c>>2]=v[c>>2]+6;f=f+6|0;continue}break}ec(a,d);ec(a+4|0,c);ec(xb(a),mc(e));v[e>>2]=v[e+4>>2];f=b;rS(e)}yb(f);cb=j+32|0}function sn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=cb-80|0;cb=c;g=Rb(a);e=b+24|0;a:{b:{if(qj(v[e>>2]+484360|0)){b=0;c:{d:{e:while(1){if(qj(v[e>>2]+484360|0)>>>0<=b>>>0){break d}f=v[e>>2];a=rL(nR(c+40|0,1),b&255,0,0);v[22440]=0;d=v[a+12>>2];v[c+16>>2]=v[a+8>>2];v[c+20>>2]=d;d=v[a+20>>2];v[c+24>>2]=v[a+16>>2];v[c+28>>2]=d;d=v[a+4>>2];v[c+8>>2]=v[a>>2];v[c+12>>2]=d;W(1064,c- -64|0,f|0,0,c+8|0);a=v[22440];v[22440]=0;if((a|0)==1){break c}j=c,k=yb(v[c+64>>2]),v[j+32>>2]=k;f=yb(v[c+68>>2]);while(1){a=v[c+32>>2];if(!Qb(a,f)){b=b+1|0;Di(c- -64|0);continue e}h=A[a>>3];d=v[a+16>>2];i=x[a+24>>1];a=c+40|0;v[a+16>>2]=b;v[a+12>>2]=i;v[a+8>>2]=d;A[a>>3]=h;v[22440]=0;R(1083,g|0,a|0);a=v[22440];v[22440]=0;if((a|0)!=1){iz(c+32|0);continue}break}break}a=P()|0;O()|0;Di(c- -64|0);break b}cb=c+80|0;return}a=P()|0;O()|0;break b}b=aa(8)|0;v[22440]=0;c=Q(56,c+40|0,7270)|0;a=v[22440];v[22440]=0;if((a|0)!=1){oc(b,c);v[22440]=0;U(121,b|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;rb(c);break b}a=P()|0;O()|0;ba(b|0)}Rf(g);S(a|0)}L()}function gM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;f=cb-16|0;cb=f;e=B(b,872)+a|0;a:{if(c){ub(f+8|0,a+1074312|0,90);if(!tb(v[v[f+8>>2]>>2],v[f+12>>2])){t[(B(b,872)+a|0)+1075804|0]=c}t[(B(b,872)+a|0)+1075803|0]=c;break a}c=w[e+1075803|0]}e=e+1074992|0;h=c&255;i=d?i:!(v[a+480180>>2]&204473357);aM(a,b,h,i);g=v[a+480180>>2];b:{c:{if((g|0)!=268435456){if((g|0)!=16777216){break c}j=v[(B(b,872)+a|0)+1075648>>2];if(!j|!v[j+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){$L(v[a+1074392>>2],v[a+1074416>>2],e,h-240|0);break b}if(!(b>>>0<224|d)){_L(e,h-224|0);break b}ZL(e,h);break b}v[(B(b,872)+a|0)+1075700>>2]=1}d:{if(!((c&255)>>>0>223&i)){break d}e:{d=h&15;if(!d){break e}c=c&240;if((c|0)!=224){if((c|0)!=240){break e}sy(a,e,d);break b}if((g|0)==524288){break d}bM(a,e,d);break b}if((g|0)!=524288){break b}}f:{if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break f}if(v[a+1074416>>2]==1){ub(f+8|0,a+1074312|0,6);if(tb(v[v[f+8>>2]>>2],v[f+12>>2])){break f}g=v[a+480180>>2]}if(g&32832){break f}if(!(v[a+480208>>2]&2)|(g|0)!=8){break b}}ck(a,e,(B(b,872)+a|0)+1075692|0,h<<2,0)}cb=f+16|0}function EA(a,b,c,d){t[a+5|0]=c;a:{b:{switch((b|64)+-64|0){case 0:t[a+3|0]=c?37:0;return;case 1:t[a+3|0]=16;return;case 2:t[a+3|0]=12;return;case 3:t[a+3|0]=14;if(d){break a}t[a+5|0]=B(c>>>4|0,10)+(c&15);return;case 4:t[a+3|0]=11;return;case 5:t[a+3|0]=3;return;case 6:t[a+3|0]=2;return;case 7:t[a+3|0]=4;return;case 8:t[a+3|0]=5;return;case 9:t[a+3|0]=18;return;case 10:t[a+3|0]=1;return;case 11:t[a+3|0]=7;return;case 12:t[a+3|0]=6;return;case 13:t[a+3|0]=21;return;case 14:t[a+3|0]=22;return;case 15:t[a+3|0]=10;return;case 16:t[a+3|0]=29;return;case 17:t[a+3|0]=15;return;case 18:t[a+3|0]=8;return;case 19:t[a+3|0]=20;return;case 20:t[a+3|0]=17;return;case 21:t[a+3|0]=26;return;case 22:t[a+3|0]=23;return;case 23:t[a+3|0]=24;return;case 24:t[a+3|0]=9;return;case 25:t[a+3|0]=27;return;case 26:t[a+3|0]=31;return;case 28:t[a+3|0]=d?32:31;return;case 29:t[a+3|0]=d?33:0;return;case 27:t[a+3|0]=d?34:0;return;case 30:t[a+3|0]=d?35:0;return;case 31:t[a+3|0]=d?36:0;return;case 50:t[a+3|0]=d?25:0;return;case 51:t[a+3|0]=d?30:0;return;default:break b}}t[a+3|0]=0}}function Tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=cb-48|0;cb=f;m=v[a+16>>2];e=ee(f+16|0);v[e+8>>2]=a+112;h=v[a+128>>2];v[e+16>>2]=h;n=e,o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;k=v[a+8>>2];l=v[a+12>>2];if(h){n=e,o=kg(k,l,h),v[n>>2]=o;v[e+4>>2]=fb}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];g=v[a>>2];v[f+8>>2]=g;v[f+12>>2]=b;a:while(1){if(d){v[f+40>>2]=g;v[f+44>>2]=0;g=(b<<1)+m|0;b=v[e+16>>2];while(1)if((b|0)<=0){b=v[e+8>>2];j=v[b+8>>2];Jb(b,j,v[b+12>>2]);b=v[e+8>>2];j=v[b+4>>2];if(j){Jd(b,u[g+(v[f+44>>2]<<1)>>1]/4<<16>>16);Id(v[e+8>>2],j);b=v[e+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;g=v[a+32>>2];i=v[a+28>>2]+i|0;b=ig(b,v[e+12>>2]);v[c>>2]=B(i>>12,b)+v[c>>2];h=g+h|0;v[c+4>>2]=v[c+4>>2]+B(b,h>>12);Jb(f+8|0,k,l);c=c+8|0;g=v[f+8>>2];b=v[f+12>>2];continue a}else{Jd(v[e+8>>2],u[g+(v[f+44>>2]<<1)>>1]/4<<16>>16);Id(v[e+8>>2],4);Jb(f+40|0,v[e>>2],v[e+4>>2]);b=b-1|0;continue}}break}v[a+36>>2]=i;v[a>>2]=g;v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;cb=f+48|0}function Ln(a,b,c,d){var e=0;e=cb-16|0;cb=e;t[a+841|0]=0;v[a+708>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;t[a+797|0]=0;v[a+764>>2]=0;u[a+802>>1]=0;u[a+804>>1]=0;v[a+696>>2]=0;v[a+668>>2]=0;v[a+88>>2]=v[a+88>>2]|6144;ub(e+8|0,b+1074312|0,23);if(tb(v[v[e+8>>2]>>2],v[e+12>>2])){t[a+807|0]=1;t[a+808|0]=0}t[a+846|0]=0;t[a+839|0]=0;u[a+774>>1]=0;t[a+850|0]=255;v[a+660>>2]=0;t[a+851|0]=w[a+851|0]&224;Rn(a+788|0);v[a+84>>2]=0;v[a+76>>2]=0;v[a+80>>2]=0;v[a+700>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;v[a>>2]=0;v[a+4>>2]=0;t[a+845|0]=0;t[a+838|0]=0;v[a+688>>2]=0;v[a+672>>2]=0;v[a+676>>2]=0;u[a+820>>1]=0;t[a+819|0]=0;u[a+836>>1]=32512;u[a+842>>1]=0;v[a+20>>2]=0;v[a+24>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;v[a+852>>2]=0;v[a+856>>2]=0;t[a+851|0]=w[a+851|0]&159;a:{if(c>>>0<=126){b=(c<<5)+b|0;c=v[b+480280>>2];v[a+88>>2]=c;v[a+692>>2]=x[b+480284>>1];v[a+748>>2]=x[b+480286>>1];if(!(c&1024)){break a}v[a+88>>2]=c&-1025|d;break a}v[a+748>>2]=64;v[a+692>>2]=128;v[a+88>>2]=0}u[a+784>>1]=0;t[a+795|0]=0;t[a+796|0]=0;cb=e+16|0}function J9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=cb-16|0;cb=e;ed(c,0);d=a+36|0;u[e+14>>1]=w[d|0]|w[d+1|0]<<8;u[e+12>>1]=32767;g=c,h=(x[Kc(e+14|0,e+12|0)>>1]<<8>>>0)/32767|0,u[g+28>>1]=h;d=a+38|0;u[e+10>>1]=w[d|0]|w[d+1|0]<<8;u[e+8>>1]=32767;g=c,h=(x[Kc(e+10|0,e+8|0)>>1]<<8>>>0)/32767|0,u[g+30>>1]=h;u[c+32>>1]=64;d=a+44|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+56|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=w[b+166|0];if(d>>>0<=4){t[c+38|0]=w[d+42826|0]}d=b+167|0;d=w[d|0]|w[d+1|0]<<8;t[c+39|0]=d;f=b+171|0;f=(w[f|0]|w[f+1|0]<<8)>>>4|0;t[c+41|0]=f;b=b+169|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if((b|f)&255){t[c+39|0]=d^-1}b=a+40|0;a=w[b|0]|w[b+1|0]<<8;if(a&4){u[c+34>>1]=x[c+34>>1]|1;a=w[b|0]|w[b+1|0]<<8}if(a&8){u[c+34>>1]=x[c+34>>1]|2;a=w[b|0]|w[b+1|0]<<8}if(a&16){u[c+34>>1]=x[c+34>>1]|4;a=w[b|0]|w[b+1|0]<<8}if(a&32){u[c+34>>1]=x[c+34>>1]|32}cb=e+16|0}function Aia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=cb-16|0;cb=g;e=Bh(b,c);n=g,o=wb(w[a|0]|w[a+1|0]<<8),u[n+14>>1]=o;u[g+12>>1]=64;Qg(e,x[Kc(g+14|0,g+12|0)>>1]);b=a+14|0;n=e,o=wb(w[b|0]|w[b+1|0]<<8),t[n+13|0]=o;b=a+16|0;n=e,o=wb(w[b|0]|w[b+1|0]<<8),t[n+14|0]=o;b=a+20|0;n=e,o=wb(w[b|0]|w[b+1|0]<<8),t[n+15|0]=o;b=a+22|0;n=e,o=wb(w[b|0]|w[b+1|0]<<8),t[n+16|0]=o;j=v[e>>2];b=w[e+12|0]&-2|hc(j,v[e+4>>2])^1;t[e+12|0]=b;f=a+12|0;b=wb(w[f|0]|w[f+1|0]<<8)>>>3&2|b&-3;t[e+12|0]=b;n=e,o=wb(w[f|0]|w[f+1|0]<<8)>>>3&4|b&251,t[n+12|0]=o;b=0;f=4096;a:{b:{switch(c-1|0){case 0:i=-128;f=127;break a;case 1:break b;default:break a}}i=-1616;f=1616}c=f-i|0;l=c;f=c>>>1&32767;c=0;while(1){if(Dd(e)>>>0<=c>>>0){cb=g+16|0}else{d=Ib(j,c);u[d>>1]=b;m=d;k=(c<<2)+a|0;d=k+28|0;h=Rd((w[d|0]|w[d+1|0]<<8)<<16>>16)+i|0;d=h>>31;d=d<<6|h>>>26;h=f+(h<<6)|0;d=h>>>0<f>>>0?d+1|0:d;n=m,o=rg(yc(lka(h,d,l,0),fb)),t[n+2|0]=o;d=k+26|0;n=g,o=wb(w[d|0]|w[d+1|0]<<8),u[n+10>>1]=o;u[g+8>>1]=1;c=c+1|0;b=x[ie(g+10|0,g+8|0)>>1]+b|0;continue}break}}function u_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=cb-160|0;cb=a;v[a+144>>2]=c;v[a+152>>2]=b;v[a+20>>2]=1181;b=re(a+24|0,a+32|0,a+20|0);h=a+16|0;Jc(h,e);v[22440]=0;h=T(19,h|0)|0;i=v[22440];v[22440]=0;if((i|0)!=1){a:{t[a+15|0]=0;e=v[e+4>>2];v[22440]=0;c=pa(1182,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}dg(g);if(w[a+15|0]){v[22440]=0;c=Q(20,h|0,45)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}v[22440]=0;R(48,g|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break a}}v[22440]=0;c=Q(20,h|0,48)|0;d=v[22440];v[22440]=0;if((d|0)==1){break b}e=v[b>>2];d=v[a+20>>2];h=d-1|0;c=c&255;while(1){if(!((c|0)!=w[e|0]|e>>>0>=h>>>0)){e=e+1|0;continue}break}v[22440]=0;Y(1188,g|0,e|0,d|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break c}break a}v[22440]=0;c=Q(1149,a+152|0,a+144|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}if(c){v[f>>2]=v[f>>2]|2}c=v[a+152>>2];Pb(a+16|0);Lc(b);cb=a+160|0;return c|0}}}c=P()|0;O()|0;Pb(a+16|0);Lc(b);S(c|0);L()}function iK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=C(0);c=cb-80|0;cb=c;d=v[b>>2];e=v[b+4>>2];b=ee(c+48|0);b=Uq(c+56|0,d,e,v[b>>2],v[b+4>>2]);v[22440]=0;d=T(204,b|0)|0;e=v[22440];v[22440]=0;a:{if((e|0)==1){break a}v[22440]=0;d=Y(930,b|0,c+8|0,d|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break a}b:{if(!d){break b}if(Mb(c+8|0,17654,4)){break b}d=c+8|4;if(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)){break b}d=c+16|0;f=a,g=Pd((l(2,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)),q()),C(0)),z[f+4220>>2]=g;d=c+20|0;f=a,g=Pd((l(2,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)),q()),C(0)),z[f+4224>>2]=g;d=c+24|0;f=a,g=Pd((l(2,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)),q()),C(0)),z[f+4228>>2]=g;d=c+28|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);if(d>>>0<=5){v[a+4232>>2]=d}d=c+32|0;v[a+4236>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[a+4240|0]=w[c+36|0]!=0;t[a+4241|0]=w[c+37|0]!=0;t[a+4242|0]=w[c+38|0]!=0;t[a+4243|0]=w[c+39|0]!=0;t[a+4244|0]=w[c+40|0]!=0;ss(a)}sb(b);cb=c+80|0;return}a=P()|0;O()|0;sb(b);S(a|0);L()}function aH(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=cb-208|0;cb=d;v[d+8>>2]=1;v[d+12>>2]=0;h=b<<2;a:{if(!h){break a}v[d+16>>2]=4;v[d+20>>2]=4;b=4;f=4;e=2;while(1){g=b;b=(b+f|0)+4|0;v[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;f=g;if(b>>>0<h>>>0){continue}break}f=(a+h|0)-4|0;b:{if(f>>>0<=a>>>0){f=0;e=1;h=0;b=1;g=0;break b}e=1;b=1;while(1){c:{if((e&3)==3){Gw(a,c,b,d+16|0);Lr(d+8|0,2);b=b+2|0;break c}g=b-1|0;d:{if(y[(d+16|0)+(g<<2)>>2]>=f-a>>>0){Kr(a,c,e,v[d+12>>2],b,0,d+16|0);break d}Gw(a,c,b,d+16|0)}if((b|0)==1){Jr(d+8|0,1);b=0;break c}Jr(d+8|0,g);b=1}g=v[d+8>>2];e=g|1;v[d+8>>2]=e;a=a+4|0;if(f>>>0>a>>>0){continue}break}h=g>>>0>1;f=v[d+12>>2];g=(f|0)!=0}Kr(a,c,e,f,b,0,d+16|0);if(!(g?1:(b|0)!=1|h)){break a}while(1){e:{if((b|0)<=1){g=d+8|0;h=WG(g);Lr(g,h);f=v[d+12>>2];e=v[d+8>>2];b=b+h|0;break e}e=d+8|0;Jr(e,2);v[d+8>>2]=v[d+8>>2]^7;Lr(e,1);f=a-4|0;h=d+16|0;g=b-2|0;Kr(f-v[h+(g<<2)>>2]|0,c,v[d+8>>2],v[d+12>>2],b-1|0,1,h);Jr(e,1);e=v[d+8>>2]|1;v[d+8>>2]=e;b=f;f=v[d+12>>2];Kr(b,c,e,f,g,1,h);b=g}a=a-4|0;if((b|0)!=1|(e|0)!=1|f){continue}break}}cb=d+208|0}function Ps(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=cb-16|0;cb=e;f=a+1074312|0;ub(e+8|0,f,77);a:{if(j=tb(v[v[e+8>>2]>>2],v[e+12>>2]),k=0,l=v[c+88>>2]&134218752,l?j:k){break a}b:{c:{if(d){g=w[c+841|0];if(!g){break c}d=g-1|0;t[c+841|0]=d;if(d&255){break b}ub(e+8|0,f,16);if(!tb(v[v[e+8>>2]>>2],v[e+12>>2])&v[a+480180>>2]!=2){break a}a=v[b+48>>2]+1|0}else{a=v[b+48>>2]}v[c+764>>2]=a;break a}ub(e+8|0,f,17);d:{if(tb(v[v[e+8>>2]>>2],v[e+12>>2])|v[a+480180>>2]&3){break d}g=b+616|0;i=x[a+480188>>1];while(1){if((h&65535)>>>0>=i>>>0){break d}if(w[g+841|0]?(c|0)!=(g|0):0){break a}g=g+872|0;h=h+1|0;continue}}t[c+841|0]=d}d=v[c+764>>2];v[b+56>>2]=d;e:{if((d|0)==-1){break e}f:{if(v[b+60>>2]==-1){break f}ub(e+8|0,f,68);if(!tb(v[v[e+8>>2]>>2],v[e+12>>2])){break f}v[b+60>>2]=d}v[b+64>>2]=d;ub(e+8|0,f,103);if(!tb(v[v[e+8>>2]>>2],v[e+12>>2])){break e}u[b+68>>1]=65535}if(v[a+480180>>2]!=2){break a}d=x[a+480188>>1];a=0;while(1){if((a|0)==(d|0)){break a}f=B(a,872)+b|0;v[f+1380>>2]=v[c+764>>2];t[f+1457|0]=w[c+841|0];a=a+1|0;continue}}cb=e+16|0}function oQ(a){a=a|0;var b=0,c=0,d=0,e=0;c=cb-80|0;cb=c;v[c+72>>2]=0;v[c+76>>2]=0;b=c- -64|0;v[b>>2]=0;v[b+4>>2]=0;v[c+56>>2]=0;v[c+60>>2]=0;v[c+48>>2]=0;v[c+52>>2]=0;nz(a,oz(a),c+48|0);b=nc(c+40|0,14276);df(we(a,0),v[b>>2],v[b+4>>2]);b=nc(c+32|0,14380);df(we(a,1),v[b>>2],v[b+4>>2]);b=nc(c+24|0,5499);df(we(a,3),v[b>>2],v[b+4>>2]);b=nc(c+16|0,15737);df(we(a,4),v[b>>2],v[b+4>>2]);b=nc(c+8|0,9294);df(we(a,8),v[b>>2],v[b+4>>2]);e=we(a+288|0,0);b=cb-16|0;cb=b;d=e;e=nc(b+8|0,4935);df(d,v[e>>2],v[e+4>>2]);cb=b+16|0;e=a+800|0;b=0;a=cb-80|0;cb=a;a:{b:{while(1){if((b|0)==128){break a}v[a+76>>2]=b<<3;c:{d:{if(b>>>0<=15){nu(a+32|0,4087);v[22440]=0;R(294,a+16|0,a+76|0);d=v[22440];v[22440]=0;if((d|0)==1){break c}v[22440]=0;U(295,a+48|0,a+32|0,a+16|0);d=v[22440];v[22440]=0;if((d|0)!=1){d=a+48|0;se(a- -64|0,d);df(we(e,b),v[a+64>>2],v[a+68>>2]);rb(d);rb(a+16|0);Ab(a+32|0);break d}b=P()|0;O()|0;rb(a+16|0);break b}nc(a+8|0,21685);df(we(e,b),v[a+8>>2],v[a+12>>2])}b=b+1|0;continue}break}b=P()|0;O()|0}Ab(a+32|0);S(b|0);L()}cb=a+80|0;cb=c+80|0}function U7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),x=0,y=0,A=0,E=C(0);j=a+44|0;i=Ud(j,0);k=Ud(j,1);m=jd(j,0);n=jd(j,1);h=a+4208|0;g=pc(v[h>>2],v[a+4212>>2]);p=B(v[v[a+16>>2]+1074404>>2],w[a+4233|0]);f=p<<1;if(g>>>0<f>>>0){ak(h,f)}h=w[a+4232|0];a:{if(h){x=h-1|0;h=0;while(1){if((d|0)==(h|0)){break a}s=z[k>>2];f=v[a+4220>>2];f=f>>>0<p>>>0?f:0;g=f-p|0;o=v[a+4208>>2];g=((g|0)<0?f:g)<<1;y=Ib(o,g);e=z[Ib(o,g|1)>>2];t=z[i>>2];u=z[y>>2];q=C(t+u);z[m>>2]=q;r=C(s+e);z[n>>2]=r;e=C(0);l=C(0);b:{c:{switch(x|0){case 0:e=z[a+4224>>2];l=C(r*e);e=C(q*e);break b;case 1:case 2:e=z[a+4224>>2];l=C(q*e);e=C(r*e);break b;case 3:break c;default:break b}}e=C(C(C(C(t+s)*C(.5))+u)*z[a+4224>>2]);l=e}n=n+4|0;m=m+4|0;k=k+4|0;i=i+4|0;g=f<<1;A=Ib(o,g),E=C(D(e))<C(1.0000000195414814e-24)?C(0):e,z[A>>2]=E;A=Ib(o,g|1),E=C(D(l))<C(1.0000000195414814e-24)?C(0):l,z[A>>2]=E;v[a+4220>>2]=f+1;h=h+1|0;continue}}f=i;i=d<<2;zk(f,f+i|0,m);zk(k,i+k|0,n)}ti(a,b,c,jd(j,0),jd(j,1),d)}function fH(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=C(0),p=0;a:{if(w[b+21|0]){p=B(d,g);k=v[e>>2];l=v[f>>2];n=v[b>>2];b:{while(1){if((h|0)>0){if(v[a+1396>>2]<=9){Vk(a)}j=v[a+1392>>2];g=u[(((j&1023)<<1)+b|0)+36>>1];c:{if((g|0)>=0){i=j;j=w[g+v[b+8>>2]|0];v[a+1392>>2]=i>>>j;m=v[a+1396>>2]-j|0;j=(m|0)<0;v[a+1396>>2]=j?0:m;j=j?-1:g;break c}j=Xl(a,b)}if((j|0)>=v[b+2092>>2]?w[b+23|0]:0){break a}if((j|0)<0){if(!w[a+1376|0]){b=0;if(v[a+1384>>2]){break b}}Zb(a,21);return 0}g=0;m=B(d,l);n=((m+n|0)+k|0)>(p|0)?(p-m|0)+k|0:n;m=(n|0)>0?n:0;j=B(j,v[b>>2]);o=C(0);d:{if(w[b+22|0]){while(1){if((g|0)==(m|0)){break d}o=C(o+z[v[b+28>>2]+(g+j<<2)>>2]);i=v[(k<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=o+z[i>>2]}k=k+1|0;i=(k|0)==(d|0);k=i?0:k;g=g+1|0;l=i+l|0;continue}}while(1){if((g|0)==(m|0)){break d}i=v[(k<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+C(z[v[b+28>>2]+(g+j<<2)>>2]+C(0))}k=k+1|0;i=(k|0)==(d|0);k=i?0:k;g=g+1|0;l=i+l|0;continue}}h=h-n|0;continue}break}v[e>>2]=k;v[f>>2]=l;b=1}return b}Zb(a,21);return 0}ca(7512,13226,1887,6554);L()}function VM(a,b){var c=0,d=0,e=0,f=0;d=cb-16|0;cb=d;a:{b:{switch(w[a+480224|0]-1|0){default:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2]<<1;c=kka(c,c>>31,5e4,0);e=fb;b=v[Pc(d+12|0,d+8|0)>>2];c=yc(lka(c,e,b,b>>31),fb);break a;case 0:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2];c=kka(c,c>>31,1e4,0);e=fb;b=v[Pc(d+12|0,d+8|0)>>2];c=yc(lka(c,e,b,b>>31),fb);break a;case 1:break b}}f=60/(+y[b+44>>2]/1e4*(+(kka(v[b+32>>2],0,v[b+40>>2],0)>>>0)+ +(fb>>>0)*4294967296))*+y[a+24620>>2];c:{d:{c=a+484344|0;e=x[b+70>>1];if(!ve(c,e)){break d}c=Sb(c,e);if(!(hc(v[c+24>>2],v[c+28>>2])^1)){break d}c=c+24|0;break c}c=a+480248|0}e=v[c>>2];c=v[c+4>>2];if(!hc(e,c)){f=f*+y[Ib(e,y[b+48>>2]%(pc(e,c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(D(f)<2147483648){c=~~f;break e}c=-2147483648}f=A[b+8>>3]+(f-+(c>>>0));A[b+8>>3]=f;if(f>=1){A[b+8>>3]=f+-1;c=c+1|0;break a}if(!(A[a+1074384>>3]<=-1)){break a}A[b+8>>3]=f+1;c=c-1|0}b=kka(v[a+480244>>2],0,c,0)+32768|0;a=fb;a=b>>>0<32768?a+1|0:a;a=wc((a&65535)<<16|b>>>16,a>>>16|0);cb=d+16|0;return a?a:1}function cia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=cb-48|0;cb=c;i=a+484344|0;j=a+480280|0;while(1){a:{if(Kb(b,9)){e=c+44|0;Wn(b,e);d=Ag(b);b:{if(!Mb(e,14083,4)){break b}if(!Mb(c+44|0,13735,4)){break b}if(!Mb(c+44|0,13911,4)){break b}if(!Mb(c+44|0,13916,4)){break b}if(Kb(b,d)){break a}}xg(b,8)}cb=c+48|0;return k|0}Td(c,b,d);e=cc(c+24|0,c);sb(c);d=j;c:{d:{e:{if(!Mb(c+44|0,13594,4)){while(1){if((d|0)==(i|0)){break c}v[22440]=0;f=T(159,e|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break e}t[d+8|0]=f;d=d+32|0;continue}}if(w[c+44|0]!=70){break d}f=w[c+45|0];h=(f|0)==88;f:{if(!h){if((f-48&255)>>>0>9){break d}d=t[c+46|0];if((d|0)>47){break f}break d}d=t[c+46|0];if((d|0)<48){break d}}if(d>>>0>57){break d}g=t[c+47|0];if((g|0)<48|(g|0)>57){break d}d=(g+(h?-16:B(f,100)+48|0)|0)+B(d,10)&255;if(d>>>0>249){break c}v[22440]=0;R(451,e|0,(B(d,160)+a|0)+906300|0);d=v[22440];v[22440]=0;if((d|0)!=1){break c}}a=P()|0;O()|0;sb(c+24|0);S(a|0);L()}if(Mb(c+44|0,13610,4)){break c}v[a+1074308>>2]=0;k=1}sb(c+24|0);continue}}function kX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-32|0;cb=d;f=Rb(a);a=0;a:{b:{c:{d:{e:{while(1){if((Av(b,c,a)|0)==-1){break b}e=Av(b,c,a);v[22440]=0;W(124,d|0,b|0,a|0,e-a|0);e=v[22440];v[22440]=0;if((e|0)!=1){v[22440]=0;R(125,d+16|0,d|0);e=v[22440];v[22440]=0;if((e|0)==1){break e}v[22440]=0;R(126,f|0,d+16|0);e=v[22440];v[22440]=0;if((e|0)==1){break d}rb(d+16|0);rb(d);a=Av(b,c,a)+vb(c)|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;rb(d+16|0)}rb(d);break a}f:{g:{h:{i:{j:{k:{if(hc(v[f>>2],v[f+4>>2])){v[22440]=0;W(124,d+16|0,b|0,a|0,-1);c=v[22440];v[22440]=0;if((c|0)==1){break j}c=d+16|0;e=vb(c);rb(c);if(!e){break k}}v[22440]=0;W(124,d|0,b|0,a|0,-1);a=v[22440];v[22440]=0;if((a|0)==1){break i}v[22440]=0;R(125,d+16|0,d|0);a=v[22440];v[22440]=0;if((a|0)==1){break h}v[22440]=0;R(126,f|0,d+16|0);a=v[22440];v[22440]=0;if((a|0)==1){break g}rb(d+16|0);rb(d)}cb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break f}a=P()|0;O()|0;rb(d+16|0)}rb(d)}ad(f);S(a|0);L()}function x7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=C(0),s=0,t=0,u=0,w=0,x=C(0);a:{j=v[a+4272>>2];if(!j){break a}g=a+44|0;if(!Yh(g)){break a}m=Ud(g,0);n=Ud(g,1);o=jd(g,0);p=jd(g,1);q=d;while(1){if(q){e=z[n>>2];k=v[a+4256>>2];l=v[a+4268>>2];h=l<<1;i=Ib(k,h);f=z[m>>2];z[i>>2]=f;w=Ib(k,h|1),x=e,z[w>>2]=x;r=z[a+4276>>2];e=C(C(D(TJ(C(C(C(D(f))+C(D(e)))*C(536870912)),31,5)))*C(4.656612873077393e-10));e=C(C(C(r-e)*z[(e>=r?4236:4240)+a>>2])+e);z[a+4276>>2]=e;f=z[a+4244>>2];e=C(C(C(C(f-(e<f?f:e))*z[a+4248>>2])+C(.9999998807907104))*C(2147483648));b:{if(e<C(4294967296)&e>=C(0)){h=~~e>>>0;break b}h=0}s=((((v[a+4252>>2]+(l<<12)|0)+j|0)-1|0)/4096|0)%(j|0)<<1;f=z[Ib(k,s)>>2];i=h<<5;t=i;u=i|-2147483648;i=h>>>0<67108864;e=C(z[a+4232>>2]*C(C((i?t:u)>>>(i?31:32-(h>>>26|0)|0)>>>0)*C(4.656612873077393e-10)));z[o>>2]=f*e;w=p,x=C(z[Ib(k,s|1)>>2]*e),z[w>>2]=x;v[a+4268>>2]=((l?0:j)+l|0)-1;q=q-1|0;p=p+4|0;o=o+4|0;n=n+4|0;m=m+4|0;continue}else{ti(a,b,c,jd(g,0),jd(g,1),d)}break}}}function Xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=cb-16|0;cb=g;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;o=v[a+8>>2];p=v[a+12>>2];while(1){b=e;if(d){q=v[a+72>>2];r=v[a+32>>2];k=v[a+28>>2]+k|0;e=v[a+64>>2];i=e;h=e>>31;e=Vb(b,-16777216,16776704);e=kka(i,h,e,e>>31);i=fb;l=e;e=v[a+68>>2];f=Vb(f,-16777216,16776704);h=kka(e,e>>31,f,f>>31);e=l+h|0;f=fb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;e=v[a+60>>2];h=e;s=e>>31;m=v[g+12>>2]+n|0;e=t[m|0];l=i;i=((B(t[m+1|0]-e|0,v[g+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=i;h=kka(h,s,e,e>>31);e=l+h|0;f=fb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Mc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(k>>12,e)+v[c>>2];j=j+r|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Jb(g+8|0,o,p);e=f-(i&q)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];d=v[g+8>>2];v[a+36>>2]=k;v[a>>2]=d;v[a+4>>2]=c;v[a+40>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;cb=g+16|0}function xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=cb-16|0;cb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){m=v[a+32>>2];e=(v[f+12>>2]<<1)+l|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(u[e-4>>1],u[h+2>>1])+B(u[e-6>>1],u[h>>1])|0)+B(u[e-2>>1],u[h+4>>1])|0)+B(u[e>>1],u[h+6>>1])|0)+B(u[e+2>>1],u[h+8>>1])|0)+B(u[e+4>>1],u[h+10>>1])|0)+B(u[e+6>>1],u[h+12>>1])|0)+B(u[e+8>>1],u[h+14>>1])|0)/32768|0;k=v[a+28>>2]+k|0;v[c>>2]=v[c>>2]+B(e,k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(e,j>>12);Jb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];c=v[f+8>>2];v[a+36>>2]=k;v[a>>2]=c;v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;cb=f+16|0}function Wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=cb-16|0;cb=g;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;o=v[a+8>>2];p=v[a+12>>2];while(1){b=e;if(d){q=v[a+72>>2];r=v[a+32>>2];k=v[a+28>>2]+k|0;e=v[a+64>>2];i=e;h=e>>31;e=Vb(b,-16777216,16776704);e=kka(i,h,e,e>>31);i=fb;l=e;e=v[a+68>>2];f=Vb(f,-16777216,16776704);h=kka(e,e>>31,f,f>>31);e=l+h|0;f=fb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;e=v[a+60>>2];h=e;s=e>>31;m=(v[g+12>>2]<<1)+n|0;e=u[m>>1];l=i;i=e+((B(u[m+2>>1]-e|0,v[g+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;h=kka(h,s,e,e>>31);e=l+h|0;f=fb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Mc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(k>>12,e)+v[c>>2];j=j+r|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Jb(g+8|0,o,p);e=f-(i&q)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];d=v[g+8>>2];v[a+36>>2]=k;v[a>>2]=d;v[a+4>>2]=c;v[a+40>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;cb=g+16|0}function Uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=cb-48|0;cb=f;m=v[a+16>>2];e=ee(f+16|0);v[e+8>>2]=a+112;h=v[a+128>>2];v[e+16>>2]=h;n=e,o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;k=v[a+8>>2];l=v[a+12>>2];if(h){n=e,o=kg(k,l,h),v[n>>2]=o;v[e+4>>2]=fb}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];g=v[a>>2];v[f+8>>2]=g;v[f+12>>2]=b;a:while(1){if(d){v[f+40>>2]=g;v[f+44>>2]=0;g=b+m|0;b=v[e+16>>2];while(1)if((b|0)<=0){b=v[e+8>>2];j=v[b+8>>2];Jb(b,j,v[b+12>>2]);b=v[e+8>>2];j=v[b+4>>2];if(j){Jd(b,t[g+v[f+44>>2]|0]<<6);Id(v[e+8>>2],j);b=v[e+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;g=v[a+32>>2];i=v[a+28>>2]+i|0;b=ig(b,v[e+12>>2]);v[c>>2]=B(i>>12,b)+v[c>>2];h=g+h|0;v[c+4>>2]=v[c+4>>2]+B(b,h>>12);Jb(f+8|0,k,l);c=c+8|0;g=v[f+8>>2];b=v[f+12>>2];continue a}else{Jd(v[e+8>>2],t[g+v[f+44>>2]|0]<<6);Id(v[e+8>>2],4);Jb(f+40|0,v[e>>2],v[e+4>>2]);b=b-1|0;continue}}break}v[a+36>>2]=i;v[a>>2]=g;v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;cb=f+48|0}function eH(a,b,c,d,e){var f=C(0),g=C(0),h=0,i=C(0),j=C(0),k=0;if(!(a&3)){k=a>>2;a=(c<<2)+b|0;d=a+(d<<2)|0;while(1){if((k|0)>0){b=d-4|0;g=z[b>>2];i=z[a>>2];j=z[d>>2];z[a>>2]=i+j;c=a-4|0;f=z[c>>2];z[c>>2]=f+z[b>>2];i=C(i-j);f=C(f-g);z[d>>2]=C(i*z[e>>2])-C(z[e+4>>2]*f);z[b>>2]=C(f*z[e>>2])+C(i*z[e+4>>2]);b=d-12|0;i=z[b>>2];c=a-8|0;f=z[c>>2];h=c;c=d-8|0;j=z[c>>2];z[h>>2]=f+j;h=a-12|0;g=z[h>>2];z[h>>2]=g+z[b>>2];f=C(f-j);g=C(g-i);z[c>>2]=C(f*z[e+32>>2])-C(z[e+36>>2]*g);z[b>>2]=C(g*z[e+32>>2])+C(f*z[e+36>>2]);b=d-20|0;i=z[b>>2];c=a-16|0;f=z[c>>2];h=c;c=d-16|0;j=z[c>>2];z[h>>2]=f+j;h=a-20|0;g=z[h>>2];z[h>>2]=g+z[b>>2];f=C(f-j);g=C(g-i);z[c>>2]=C(f*z[e+64>>2])-C(z[e+68>>2]*g);z[b>>2]=C(g*z[e+64>>2])+C(f*z[e+68>>2]);b=d-28|0;i=z[b>>2];c=a-24|0;f=z[c>>2];h=c;c=d-24|0;j=z[c>>2];z[h>>2]=f+j;h=a-28|0;g=z[h>>2];z[h>>2]=g+z[b>>2];f=C(f-j);g=C(g-i);z[c>>2]=C(f*z[e+96>>2])-C(z[e+100>>2]*g);z[b>>2]=C(g*z[e+96>>2])+C(f*z[e+100>>2]);k=k-1|0;d=d-32|0;a=a-32|0;e=e+128|0;continue}break}return}ca(15826,13226,2423,9240);L()}function d9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=cb-16|0;cb=f;e=cb-160|0;cb=e;d=e+24|0;c=d+56|0;g=qs(c);v[d>>2]=73908;v[g>>2]=73928;v[d>>2]=73948;v[c>>2]=73968;h=c;c=d+4|0;un(h,c);v[d>>2]=73908;v[g>>2]=73928;js(c);v[c>>2]=73392;Db(c+32|0);v[c+44>>2]=0;v[c+48>>2]=16;c=v[v[d>>2]-12>>2];v[22440]=0;g=ha(63)|0;h=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{if((h|0)==1){break f}v[22440]=0;U(64,e+16|0,c+(e+24|0)|0,g|0);c=v[22440];v[22440]=0;if((c|0)==1){break f}Pb(e+16|0);c=cb-16|0;cb=c;v[c+8>>2]=17;cb=c+16|0;bm(v[v[d>>2]-12>>2]+d|0,v[c+8>>2]);i=A[b>>3];v[22440]=0;Xa(65,d|0,+i)|0;b=v[22440];v[22440]=0;if((b|0)==1){break e}v[22440]=0;R(66,e|0,d|0);b=v[22440];v[22440]=0;if((b|0)==1){break d}v[22440]=0;R(62,f|0,e|0);b=v[22440];v[22440]=0;if((b|0)==1){break c}rb(e);ep(d);cb=e+160|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;rb(e)}ep(d);S(a|0);L()}v[22440]=0;R(59,a|0,f|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(f);cb=f+16|0;return}a=P()|0;O()|0;rb(f);S(a|0);L()}function oja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=cb-16|0;cb=f;ed(b,32);e=a+4|0;h=b,i=Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24)),v[h>>2]=i;e=a+10|0;e=Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[b+4>>2]=e;g=e;e=a+14|0;h=b,i=g+Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))|0,v[h+8>>2]=i;if(!(d?0:c)){c=a+46|0;c=Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))}v[b+24>>2]=c;c=w[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=a+42|0;d=wb(w[d|0]|w[d+1|0]<<8);if(!d|(d|0)==48){break a}c=(c-(d<<7)|0)+6144|0}vl(b,+(c|0)*.0006510416666666666);t[f+15|0]=w[a+9|0];t[f+14|0]=64;h=b,i=w[Tb(f+15|0,f+14|0)|0]<<2,u[h+30>>1]=i;if(t[a+40|0]&1){u[b+34>>1]=x[b+34>>1]|64;v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}b:{if(w[a+41|0]<=8){a=v[b+4>>2];c=v[b+8>>2];break b}u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;a=v[b+4>>2]>>>1|0;v[b+4>>2]=a;c=v[b+8>>2]>>>1|0;v[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){u[b+34>>1]=x[b+34>>1]|2;break c}v[b+4>>2]=0;v[b+8>>2]=0}cb=f+16|0}function yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=cb-16|0;cb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){m=v[a+32>>2];e=v[f+12>>2]+l|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(t[e-2|0],u[h+2>>1])+B(t[e-3|0],u[h>>1])|0)+B(t[e-1|0],u[h+4>>1])|0)+B(t[e|0],u[h+6>>1])|0)+B(t[e+1|0],u[h+8>>1])|0)+B(t[e+2|0],u[h+10>>1])|0)+B(t[e+3|0],u[h+12>>1])|0)+B(t[e+4|0],u[h+14>>1])<<8)/32768|0;k=v[a+28>>2]+k|0;v[c>>2]=v[c>>2]+B(e,k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(e,j>>12);Jb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];c=v[f+8>>2];v[a+36>>2]=k;v[a>>2]=c;v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;cb=f+16|0}function x5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22440]=0;Z(996,a|0);e=v[22440];v[22440]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}v[22440]=0;Z(972,b|0);e=v[22440];v[22440]=0;if((e|0)==1){break e}e=0;v[22440]=0;Z(997,c|0);f=v[22440];v[22440]=0;if((f|0)==1){break e}a=Hb(c,0,d);if(!w[b|0]){break b}if(jj(b,7226)|(d|0)!=8){break d}v[a+4>>2]=998;v[a>>2]=999;break c}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,12312,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();return 0}if(!(jj(b,11277)|(d|0)!=64)){v[a+60>>2]=1e3;v[a+56>>2]=1001;v[a+52>>2]=1002;v[a+48>>2]=1003;v[a+44>>2]=1004;v[a+40>>2]=1005;v[a+36>>2]=1006;v[a+32>>2]=1007;v[a+28>>2]=1008;v[a+24>>2]=1009;v[a+20>>2]=1010;v[a+16>>2]=1011;v[a+12>>2]=1012;v[a+8>>2]=1013;v[a+4>>2]=1014;v[a>>2]=1015;break c}if(jj(b,15223)|(d|0)!=24){break b}v[a+20>>2]=1016;v[a+16>>2]=1017;v[a+12>>2]=1018;v[a+8>>2]=1019;v[a+4>>2]=1020;v[a>>2]=1021}e=1}return e|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function nz(a,b,c){var d=0,e=0;b=b-a>>5;while(1){if((b|0)>0){d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a|0]=e;t[a+1|0]=e>>>8;t[a+2|0]=e>>>16;t[a+3|0]=e>>>24;t[a+4|0]=d;t[a+5|0]=d>>>8;t[a+6|0]=d>>>16;t[a+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[a+24|0]=e;t[a+25|0]=e>>>8;t[a+26|0]=e>>>16;t[a+27|0]=e>>>24;t[a+28|0]=d;t[a+29|0]=d>>>8;t[a+30|0]=d>>>16;t[a+31|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[a+16|0]=e;t[a+17|0]=e>>>8;t[a+18|0]=e>>>16;t[a+19|0]=e>>>24;t[a+20|0]=d;t[a+21|0]=d>>>8;t[a+22|0]=d>>>16;t[a+23|0]=d>>>24;d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);e=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+8|0]=e;t[a+9|0]=e>>>8;t[a+10|0]=e>>>16;t[a+11|0]=e>>>24;t[a+12|0]=d;t[a+13|0]=d>>>8;t[a+14|0]=d>>>16;t[a+15|0]=d>>>24;b=b-1|0;a=a+32|0;continue}break}}function p$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=cb-32|0;cb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=gb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Jc(g,d);v[22440]=0;b=T(1159,g|0)|0;a=v[22440];v[22440]=0;d:{e:{f:{g:{if((a|0)!=1){Pb(g);Jc(g,d);v[22440]=0;a=T(1160,g|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break g}Pb(g);v[22440]=0;R(1161,g|0,a|0);d=v[22440];v[22440]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[22440]=0;R(1162,g|12,a|0);a=v[22440];v[22440]=0;if((a|0)==1){break f}v[22440]=0;d=g+24|0;a=qa(1163,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[22440];v[22440]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=Vc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Pb(g);break d}b=P()|0;O()|0;Pb(g);break d}b=P()|0;O()|0;Vc(g);break d}b=P()|0;O()|0;while(1){d=Vc(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}cb=g+32|0;return b|0}function lda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;h=cb-16|0;cb=h;o=v[a+16>>2];m=Zf(1,2);b=fb;p=b;Jb(a,m,b);f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;q=v[a+8>>2];r=v[a+12>>2];while(1){b=e;if(d){s=v[a+72>>2];t=v[a+32>>2];k=v[a+28>>2]+k|0;e=v[a+60>>2];g=e;i=e>>31;n=u[(v[h+12>>2]<<1)+o>>1]<<8;e=n;e=kka(g,i,e,e>>31);l=fb;g=e;e=v[a+64>>2];i=e;w=e>>31;e=Vb(b,-16777216,16776704);i=kka(i,w,e,e>>31);g=g+i|0;e=fb+l|0;e=g>>>0<i>>>0?e+1|0:e;i=g;g=v[a+68>>2];f=Vb(f,-16777216,16776704);l=kka(g,g>>31,f,f>>31);g=i+l|0;f=fb+e|0;f=g>>>0<l>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Mc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(k>>12,e)+v[c>>2];j=j+t|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Jb(h+8|0,q,r);e=f-(s&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];d=v[h+8>>2];v[a+36>>2]=k;v[a>>2]=d;v[a+4>>2]=c;v[a+40>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;lg(a,m,p);cb=h+16|0}function A$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=cb-32|0;cb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=gb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Jc(g,d);v[22440]=0;b=T(19,g|0)|0;a=v[22440];v[22440]=0;d:{e:{f:{g:{if((a|0)!=1){Pb(g);Jc(g,d);v[22440]=0;a=T(1142,g|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break g}Pb(g);v[22440]=0;R(1143,g|0,a|0);d=v[22440];v[22440]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[22440]=0;R(1144,g|12,a|0);a=v[22440];v[22440]=0;if((a|0)==1){break f}v[22440]=0;d=g+24|0;a=qa(1145,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[22440];v[22440]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=rb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Pb(g);break d}b=P()|0;O()|0;Pb(g);break d}b=P()|0;O()|0;rb(g);break d}b=P()|0;O()|0;while(1){d=rb(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}cb=g+32|0;return b|0}function ni(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;o(+a);b=j(1)|0;e=j(0)|0;f=b>>>20&2047;a:{if(f-969>>>0>=63){if(f>>>0<=968){return a+1}b:{if(f>>>0<1033){break b}c=0;if(!e&(b|0)==-1048576){break a}if((f|0)==2047){return a+1}if((b|0)>0|(b|0)>=0){return gr(3.105036184601418e231)}if(b>>>0<3230714880){break b}return gr(1.2882297539194267e-231)}b=b<<1|e>>>31;e=e<<1;f=(b|0)==-2129002496&(e|0)!=0|b>>>0>2165964800?0:f}c=A[177];g=c+a;a=a-(g-c);c=a*a;h=c*c*(a*A[182]+A[181]);c=c*(a*A[180]+A[179]);a=a*A[178];o(+g);j(1)|0;e=j(0)|0;d=e<<4&2032;a=h+(c+(a+A[d+1464>>3]));d=d+1472|0;i=v[d>>2];b=v[d+4>>2];d=i;i=0;d=d+i|0;b=(e<<13)+b|0;b=d>>>0<i>>>0?b+1|0:b;if(!f){c:{if(!(e&-2147483648)){l(0,d|0);l(1,b+-1048576|0);c=+n();a=c*a+c;a=a+a;break c}e=cb-16|0;l(0,d|0);l(1,b+1071644672|0);c=+n();g=c*a;a=g+c;if(a<1){b=e;v[b+8>>2]=0;v[b+12>>2]=1048576;A[b+8>>3]=A[b+8>>3]*2.2250738585072014e-308;h=a+1;a=h+(g+(c-a)+(a+(1-h)))+-1;a=a==0?0:a}a=a*2.2250738585072014e-308}return a}l(0,d|0);l(1,b|0);c=+n();c=c*a+c}return c}function mda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;h=cb-16|0;cb=h;o=v[a+16>>2];m=Zf(1,2);b=fb;p=b;Jb(a,m,b);f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;q=v[a+8>>2];r=v[a+12>>2];while(1){b=e;if(d){s=v[a+72>>2];u=v[a+32>>2];k=v[a+28>>2]+k|0;e=v[a+60>>2];g=e;i=e>>31;n=t[v[h+12>>2]+o|0]<<16;e=n;e=kka(g,i,e,e>>31);l=fb;g=e;e=v[a+64>>2];i=e;w=e>>31;e=Vb(b,-16777216,16776704);i=kka(i,w,e,e>>31);g=g+i|0;e=fb+l|0;e=g>>>0<i>>>0?e+1|0:e;i=g;g=v[a+68>>2];f=Vb(f,-16777216,16776704);l=kka(g,g>>31,f,f>>31);g=i+l|0;f=fb+e|0;f=g>>>0<l>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Mc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(k>>12,e)+v[c>>2];j=j+u|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Jb(h+8|0,q,r);e=f-(s&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];d=v[h+8>>2];v[a+36>>2]=k;v[a>>2]=d;v[a+4>>2]=c;v[a+40>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+20>>2]=k>>12;v[a+24>>2]=j>>12;lg(a,m,p);cb=h+16|0}function VO(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=cb-16|0;cb=h;c=v[a>>2];ac(h+8|0,c);a:{b:{c:{d:{e:{if(Bd(c+16|0)){d=NO(-1)+1|0;d=d-((d|0)!=32)|0;while(1){if(b>>>0>31){break e}f:{g:{if(d>>>0<=31){v[22440]=0;e=ha(44)|0;f=v[22440];v[22440]=0;if((f|0)==1){break f}g=e|g<<d;break g}v[22440]=0;e=ha(44)|0;f=v[22440];v[22440]=0;if((f|0)==1){break f}g=g|e}b=b+d|0;continue}break}b=V(88932)|0;if((O()|0)!=(fa(88932)|0)){break c}_(b|0)|0;t[c+20|0]=0;v[22440]=0;Z(30,c|0);b=v[22440];v[22440]=0;if((b|0)==1){break d}$();break e}t[c+20|0]=0}if(!w[c+20|0]){c=v[c+24>>2];b=0;d=1;while(1){if(d){d=0;b=v[c+2496>>2];e=c+(b<<2)|0;i=v[c+((b+397>>>0)%624<<2)>>2];f=(b+1>>>0)%624|0;b=v[c+(f<<2)>>2];b=i^(b&2147483647|v[e>>2]&-2147483648)>>>1^B(b&1,-1727483681);v[e>>2]=b;v[c+2496>>2]=f;b=b^b>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;b=b>>>18^b;continue}break}g=b^g}cb=h+16|0;break a}b=P()|0;O()|0;v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)==1){break b}}S(b|0);L()}V(0)|0;O()|0;Lb();L()}return v[a+28>>2]&g}function KA(a,b,c){var d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;t[d+15|0]=c;e=a;a:{b:{c:{switch(b-14|0){case 0:b=14;if(!c){break b}d:{if((c|0)!=15){if((c|0)!=240){break d}t[d+15|0]=239;break b}t[d+15|0]=254;break b}if(c>>>0>=16){t[d+15|0]=c|15;break b}t[d+15|0]=c|240;break b;case 1:t[d+15|0]=c^128;b=15;break b;case 6:case 7:if(c>>>0>=16){t[d+15|0]=c>>>4|240;break b}t[d+15|0]=c|224;break b;case 8:t[d+15|0]=((c^-1)&254)>>>1;b=22;break b;case 9:t[d+15|0]=c&15|128;b=23;break b;case 17:f=d,g=rg(c<<1),t[f+15|0]=g;b=31;break b;case 19:a=32;b=33;e:{f:{switch(c>>>4|0){default:b=0;break b;case 8:a=64;break e;case 10:a=176;break e;case 11:a=224;break e;case 12:case 13:b=c?33:0;break b;case 14:g:{switch(c&15){case 0:t[d+15|0]=119;break b;case 1:t[d+15|0]=119;break b;case 2:t[d+15|0]=121;break b;case 3:break g;default:break b}}t[d+15|0]=123;break b;case 3:break e;case 5:break f;case 0:break b}}a=48}t[d+15|0]=c&15|a;break b;default:break c}}a=0;if(b>>>0>35){break a}}a=w[b+26720|0]}ae(e,a,d+15|0);cb=d+16|0}function nw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;p=a;i=cb-1040|0;cb=i;q=v[114922];a:{b:{a=i+16|0;l=x[((b>>>0>149?0:b)<<1)+87296>>1]+85472|0;c=v[v[114924]+20>>2];if(c){j=v[c+4>>2];c=v[c>>2];e=v[c>>2]+1794895138|0;h=Ql(v[c+8>>2],e);f=Ql(v[c+12>>2],e);d=Ql(v[c+16>>2],e);c:{if(j>>>2>>>0<=h>>>0){break c}k=j-(h<<2)|0;if((d|f)&3|(k>>>0<=f>>>0|d>>>0>=k>>>0)){break c}r=d>>>2|0;s=f>>>2|0;f=0;while(1){k=h>>>1|0;m=k+f|0;n=m<<1;d=c+(n+s<<2)|0;o=Ql(v[d>>2],e);d=Ql(v[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|w[c+(d+o|0)|0]){break c}d=jj(l,c+d|0);if(!d){f=c+(r+n<<2)|0;h=Ql(v[f>>2],e);e=Ql(v[f+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break c}g=w[c+(e+h|0)|0]?0:c+e|0;break c}if((h|0)==1){break c}d=(d|0)<0;h=d?k:h-k|0;f=d?f:m;continue}}}g=g?g:l;c=Rg(g);d:{if(c>>>0>=1024){ic(a,g,1023);t[a+1023|0]=0;g=68;break d}ic(a,g,c+1|0);g=0}if(g){if((g|0)!=28){break b}a=21685}break a}ya();L()}if(!w[a|0]){v[i>>2]=b;a=i+16|0;hw(a,1024,13043,i)}v[114922]=q;Bc(p,a);cb=i+1040|0}function Kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=cb-16|0;cb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];e=v[a+44>>2];o=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;p=v[a+8>>2];q=v[a+12>>2];while(1){b=e;if(d){r=v[a+72>>2];e=v[a+64>>2];g=e;i=e>>31;e=Vb(b,-16777216,16776704);e=kka(g,i,e,e>>31);j=fb;l=e;e=v[a+60>>2];k=e;s=e>>31;e=(v[h+12>>2]<<1)+o|0;g=v[h+8>>2]>>>21&2040;i=(((B(u[e>>1],u[g+39826>>1])+B(u[e-2>>1],u[g+39824>>1])|0)+B(u[e+2>>1],u[g+39828>>1])|0)+B(u[e+4>>1],u[g+39830>>1])|0)/16384<<8;e=i;k=kka(k,s,e,e>>31);g=l+k|0;e=fb+j|0;e=g>>>0<k>>>0?e+1|0:e;l=g;g=v[a+68>>2];f=Vb(f,-16777216,16776704);j=kka(g,g>>31,f,f>>31);g=l+j|0;f=fb+e|0;f=g>>>0<j>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Mc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,n)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,m);Jb(h+8|0,p,q);e=f-(r&i)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];d=v[h+8>>2];v[a+48>>2]=f;v[a+44>>2]=b;v[a>>2]=d;v[a+4>>2]=c;cb=h+16|0}function Vj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=cb-32|0;cb=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;Jc(b,d);c=0;v[22440]=0;j=T(1159,b|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){Pb(i+8|0);v[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(Qk(i+24|0,i+16|0)){break b}c:{if((Ym(j,v[g>>2])|0)==37){c=g+4|0;if((h|0)==(c|0)){break b}d:{e:{b=Ym(j,v[c>>2]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+8|0)==(h|0)){break b}k=b;b=Ym(j,v[g+8>>2])}l=i,m=gb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+8|0;break c}if(Rk(j,8192,v[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(Rk(j,8192,v[g>>2])){continue}}break}while(1){if(!Cr(i+24|0,i+16|0)){break c}if(!Rk(j,8192,Sk(v[i+24>>2]))){break c}gn(i+24|0);continue}}if((Cl(j,Sk(v[i+24>>2]))|0)==(Cl(j,v[g>>2])|0)){g=g+4|0;gn(i+24|0);break c}v[e>>2]=4}c=v[e>>2];continue}break}v[e>>2]=4}if(Qk(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}cb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Pb(i+8|0);S(a|0);L()}function xc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{f=cb-48|0;cb=f;d=d&255;e=c-(((d|0)==1|(d|0)==4)&(c|0)!=0)|0;c=Db(a);b:{c:{d:{e:{f:{g:{h:{if((d-1&255)>>>0<=1){t[f+32|0]=0;a=yi(b,b+e|0,f+32|0);v[22440]=0;Y(54,c|0,b|0,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break b}if((d-3&255)>>>0>1){break h}v[22440]=0;b=Y(54,c|0,b|0,b+e|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break g}d=fd(b);e=gf(b);g=fd(b);a=cb-32|0;cb=a;v[a+16>>2]=e;v[a+24>>2]=d;v[a+8>>2]=g;while(1){if(oj(a+24|0,a+16|0)){d=a+8|0;e=a+24|0;g=t[v[e>>2]];t[v[d>>2]]=g?g:32;Fe(e);Fe(d);continue}break}cb=a+32|0;v[22440]=0;d=Q(55,f+16|0,b|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break f}v[22440]=0;e=Q(56,f|0,17856)|0;a=v[22440];v[22440]=0;if((a|0)==1){break e}v[22440]=0;U(57,f+32|0,d|0,e|0);a=v[22440];v[22440]=0;if((a|0)==1){break d}a=f+32|0;tc(b,a);rb(a);rb(e);rb(d)}cb=f+48|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;rb(e)}rb(d)}rb(c);S(a|0);L()}}function gka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=cb-32|0;cb=h;e=b;b=v[a>>2];b=(go(e,yb(b))<<1)+b|0;a:{f=v[a+4>>2];b:{if(f>>>0<y[xb(a)>>2]){if((b|0)==(f|0)){d=cb-16|0;cb=d;a=Xh(d,a,1);fo(v[a+4>>2],c);v[a+4>>2]=v[a+4>>2]+2;dc(a);cb=d+16|0;break b}i=cb-16|0;cb=i;j=v[a+4>>2];d=(j-(b+2|0)|0)+b|0;k=Xh(i,a,f-d>>1);g=v[k+4>>2];e=d;while(1){if(e>>>0>=f>>>0){dc(k);while(1){if((b|0)!=(d|0)){d=d-2|0;j=AU(j-2|0,d);continue}break}cb=i+16|0}else{fo(g,e);g=g+2|0;v[k+4>>2]=g;e=e+2|0;continue}break}c=b>>>0<=c>>>0?((y[a+4>>2]>c>>>0)<<1)+c|0:c;a=w[c|0];t[b+1|0]=w[c+1|0];t[b|0]=a;break b}d=xb(a);d=Mj(h+8|0,Nj(a,Fc(v[a>>2],f)+1|0),b-v[a>>2]>>1,d);v[22440]=0;R(299,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break a}c=v[d+4>>2];f=d+4|0;Pn(v[a>>2],b,f);g=v[a+4>>2];e=d+8|0;while(1){if((b|0)!=(g|0)){fo(v[e>>2],b);v[e>>2]=v[e>>2]+2;b=b+2|0;continue}break}ec(a,f);ec(a+4|0,e);ec(xb(a),mc(d));v[d>>2]=v[d+4>>2];b=c;Pi(d)}yb(b);cb=h+32|0;return}a=P()|0;O()|0;Pi(d);S(a|0);L()}function Wj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=cb-32|0;cb=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;Jc(b,d);c=0;v[22440]=0;j=T(19,b|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){Pb(i+8|0);v[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(Xj(i+24|0,i+16|0)){break b}c:{if((Zm(j,t[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}d:{e:{b=Zm(j,t[c|0]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=Zm(j,t[g+2|0])}l=i,m=gb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+2|0;break c}if(qh(j,8192,t[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(qh(j,8192,t[g|0])){continue}}break}while(1){if(!To(i+24|0,i+16|0)){break c}if(!qh(j,8192,Tk(v[i+24>>2]))){break c}Ul(i+24|0);continue}}if((bw(j,Tk(v[i+24>>2]))|0)==(bw(j,t[g|0])|0)){g=g+1|0;Ul(i+24|0);break c}v[e>>2]=4}c=v[e>>2];continue}break}v[e>>2]=4}if(Xj(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}cb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Pb(i+8|0);S(a|0);L()}function fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;f=cb-16|0;cb=f;h=v[a+40>>2];i=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){g=v[f+8>>2];m=((((v[f+12>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+j|0;e=(((g>>>16|0)+4&131064)<<1)+b|0;n=u[e+38>>1];o=u[e+36>>1];p=u[e+34>>1];q=u[e+32>>1];r=u[e+30>>1];s=u[e+28>>1];t=u[e+26>>1];w=u[e+24>>1];g=0;while(1){if((g|0)!=2){e=(g<<1)+m|0;v[(g<<2)+f>>2]=(((((B(u[e+8>>1],p)+B(u[e+4>>1],q)|0)+B(u[e+12>>1],o)|0)+B(u[e+16>>1],n)|0)/2|0)+((((B(u[e-8>>1],t)+B(u[e-12>>1],w)|0)+B(u[e-4>>1],s)|0)+B(u[e>>1],r)|0)/2|0)|0)/16384;g=g+1|0;continue}break}e=v[a+32>>2];i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(v[f>>2],i>>12);h=e+h|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],h>>12);Jb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];c=v[f+8>>2];v[a+36>>2]=i;v[a>>2]=c;v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;cb=f+16|0}function Sw(a,b,c,d){var e=0,f=0,g=0,h=0;g=cb-32|0;cb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=d<<4|c>>>28;f=c<<4|b>>>28;c=e;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){e=c+1073741824|0;a=f+1|0;e=a?e:e+1|0;f=a;break a}e=c+1073741824|0;if(b^134217728|a){break a}b=f&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){e=c;c=d<<4|e>>>28;f=e<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;Tf(g+16|0,a,b,c,e,h-15233|0);qm(g,a,b,c,e,15361-h|0);e=v[g+4>>2];h=e;a=v[g+8>>2];c=v[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;b=v[g>>2]|(v[g+16>>2]|v[g+24>>2]|(v[g+20>>2]|v[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){a=f+1|0;e=a?e:e+1|0;f=a;break a}if(a^134217728|b){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}cb=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function GO(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0;h=cb-16|0;cb=h;if(uj(v[a+656>>2])){e=w[(Rc(w[a+797|0])?797:799)+a|0];ub(h+8|0,d+1074312|0,34);if(!(!tb(v[v[h+8>>2]>>2],v[h+12>>2])|!e|e>>>0>120)){e=w[Eb(v[a+656>>2]+108|0,e-1|0)|0]}l=C(C(v[a+704>>2])*b);d=v[v[a+656>>2]+44>>2];f=(c+e<<16)-3997696>>16;a:{b:{c=v[a+852>>2]+u[a+772>>1]|0;if(c){g=v[d+36>>2];if(g){break b}}b=dm(d,c+f<<16>>16);break a}k=g+1|0;i=Gx(c,k);e=wn(c,k);b=C(1);j=u[d+28>>1];c=f+i<<16>>16;c:{if((j|0)>(c|0)){break c}f=v[d+4>>2];if((c|0)>(pc(f,v[d+8>>2])+j<<16)-65536>>16){break c}if(!e){b=z[Ib(f,c-j|0)>>2];break a}d:{e:{f:{switch(x[d>>1]-1|0){case 2:g=v[d+16>>2];if(!pc(g,v[d+20>>2])){break e}b=z[Ib(g,e-1|0)>>2];break d;case 0:break f;default:break e}}i=v[d+16>>2];if(!pc(i,v[d+20>>2])){break e}b=z[Ib(i,(e+B(g,wn(c,x[d+30>>1])<<16>>16)|0)-1|0)>>2];break d}b=te(C(dm(d,(c<<16)+65536>>16)/dm(d,c)),C(C(e|0)/C(k|0)))}b=C(b*z[Ib(f,c-j|0)>>2])}}m=a,n=tj(C(C(l*b)*C(16))),v[m+700>>2]=n}cb=h+16|0}function Uga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=cb-432|0;cb=d;sc(b);gA(b,d+376|0,d+296|0,d+8|0);f=d+408|0;if(Wb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){e=w[d+427|0]+1|0}else{e=1}m=d,n=rg(e),t[m+4|0]=n;i=w[Tb(26912,d+4|0)|0];t[d+7|0]=i;u[d+4>>1]=4;f=d+392|0;k=d+291|0;a:{b:{while(1){if((h&255)>>>0>=i>>>0){break b}e=d+8|0;e=wb(w[e|0]|w[e+1|0]<<8)<<16>>16;if(!((e|0)<0|w[k|0]>63)){g=e&65535;e=0;while(1){if((e|0)==(g|0)){c:{e=d+296|0;g=Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));if(g>>>0>l>>>0){if(Tc(b,g)){break c}}t[d+7|0]=h+1;break b}}else{d:{if(!Tc(b,Wb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))+(e<<2)|0)){break d}if(!Tc(b,Am(b))){break d}e:{if(!c){j=He(b);break e}j=Ii(b)}u[d+2>>1]=j;m=d,n=x[ie(d+4|0,d+2|0)>>1],u[m+4>>1]=n}e=e+1|0;continue}break}l=Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));gA(b,d+376|0,d+296|0,d+8|0);h=h+1|0;continue}break}Zu(a);break a}u[a>>1]=x[d+4>>1];t[a+2|0]=w[d+7|0]}cb=d+432|0}function Lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=cb-16|0;cb=h;f=v[a+48>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+44>>2];m=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;n=v[a+8>>2];o=v[a+12>>2];while(1){b=e;if(d){p=v[a+72>>2];e=v[a+64>>2];g=e;j=e>>31;e=Vb(b,-16777216,16776704);e=kka(g,j,e,e>>31);g=fb;j=e;e=v[a+68>>2];f=Vb(f,-16777216,16776704);i=kka(e,e>>31,f,f>>31);e=j+i|0;f=fb+g|0;f=e>>>0<i>>>0?f+1|0:f;j=e;e=v[a+60>>2];i=e;q=e>>31;e=v[h+12>>2]+m|0;g=v[h+8>>2]>>>21&2040;g=(((B(t[e|0],u[g+39826>>1])+B(t[e-1|0],u[g+39824>>1])|0)+B(t[e+1|0],u[g+39828>>1])|0)+B(t[e+2|0],u[g+39830>>1])<<8)/16384<<8;e=g;i=kka(i,q,e,e>>31);e=j+i|0;f=fb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Mc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,l)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,k);Jb(h+8|0,n,o);e=f-(g&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];d=v[h+8>>2];v[a+48>>2]=f;v[a+44>>2]=b;v[a>>2]=d;v[a+4>>2]=c;cb=h+16|0}function Xo(a,b,c,d,e,f){var g=C(0),h=0,i=C(0),j=0,k=C(0),l=C(0);b=(c<<2)+b|0;c=b+(d<<2)|0;a=a>>2;d=f<<2;while(1){if((a|0)>0){f=c-4|0;i=z[f>>2];k=z[b>>2];l=z[c>>2];z[b>>2]=k+l;h=b-4|0;g=z[h>>2];z[h>>2]=g+z[f>>2];k=C(k-l);g=C(g-i);z[c>>2]=C(k*z[e>>2])-C(z[e+4>>2]*g);z[f>>2]=C(g*z[e>>2])+C(k*z[e+4>>2]);f=c-12|0;k=z[f>>2];h=b-8|0;g=z[h>>2];j=h;h=c-8|0;l=z[h>>2];z[j>>2]=g+l;j=b-12|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=d+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);f=c-20|0;k=z[f>>2];h=b-16|0;g=z[h>>2];j=h;h=c-16|0;l=z[h>>2];z[j>>2]=g+l;j=b-20|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=d+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);f=c-28|0;k=z[f>>2];h=b-24|0;g=z[h>>2];j=h;h=c-24|0;l=z[h>>2];z[j>>2]=g+l;j=b-28|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=d+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);e=d+e|0;a=a-1|0;c=c-32|0;b=b-32|0;continue}break}}function Aja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=cb-32|0;cb=h;e=b;b=v[a>>2];b=$n(e,yb(b))+b|0;e=OT(c,d);a:{if((e|0)<=0){break a}f=v[xb(a)>>2];g=v[a+4>>2];if((f-g|0)>=(e|0)){v[h+8>>2]=d;k=g-b|0;if((k|0)<(e|0)){v[h+8>>2]=c;VT(h+8|0,k);f=v[h+8>>2];l=cb-16|0;cb=l;i=Ok(l,a,e-k|0);j=cb-16|0;cb=j;v[j+8>>2]=f;while(1){if(Qb(f,d)){kd(v[i+4>>2],w[f|0]);Fe(j+8|0);v[i+4>>2]=v[i+4>>2]+1;f=v[j+8>>2];continue}break}cb=j+16|0;dc(i);cb=l+16|0;if((k|0)<=0){break a}}f=cb-16|0;cb=f;j=v[a+4>>2];d=(j-(b+e|0)|0)+b|0;i=Ok(f,a,g-d|0);e=v[i+4>>2];a=d;while(1){if(a>>>0>=g>>>0){dc(i);iq(b,d,j);cb=f+16|0}else{kd(e,w[a|0]);e=e+1|0;v[i+4>>2]=e;a=a+1|0;continue}break}zk(c,v[h+8>>2],b);break a}f=xb(a);g=Sl(h+8|0,Ol(a,Uc(v[a>>2],g)+e|0),b-v[a>>2]|0,f);e=cb-32|0;cb=e;v[e+24>>2]=c;c=Iv(e+8|0,g+8|0,OT(c,d));while(1){d=v[c>>2];if((d|0)!=v[c+4>>2]){kd(d,w[v[e+24>>2]]);v[c>>2]=v[c>>2]+1;Fe(e+24|0);continue}break}Gd(c);cb=e+32|0;b=NT(a,g,b);Rl(g)}yb(b);cb=h+32|0}function Px(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=cb-16|0;cb=e;d=w[a+2|0];if(!(!d|(d|0)==255)){v[e+12>>2]=d+1;v[e+8>>2]=10;Qg(b,v[ld(e+12|0,e+8|0)>>2]);i=w[a+3|0];t[b+15|0]=i;t[b+16|0]=i;j=w[a+4|0];t[b+13|0]=j;k=w[a+5|0];t[b+14|0]=k;h=511;a:{b:{switch(c-1|0){case 1:f=4096;h=128;break a;case 0:break b;default:break a}}f=32768;h=1024}n=h>>>1|f;c=v[b>>2];f=0;c:{while(1){if(Dd(b)>>>0<=f>>>0){d:{c=w[b+12|0]&-2|t[a|0]&1;t[b+12|0]=c;if(w[a|0]&2){break d}c=c&251;break c}}else{l=Ib(c,f);m=(f<<2)+a|0;d=m+6|0;g=(w[d|0]|w[d+1|0]<<8)>>>4|0;u[l>>1]=g;e:{f:{if(!f){g=0;d=0;break f}d=x[Ib(c,f-1|0)>>1];if(g>>>0>=d>>>0){break e}g=d+1|0;d=f}o=Ib(c,d),p=g,u[o>>1]=p}d=m+8|0;v[e+12>>2]=(((w[d|0]|w[d+1|0]<<8)<<16>>16)+n|0)/(h|0);v[e+8>>2]=0;v[e+4>>2]=64;o=l,p=v[Gj(e+12|0,e+8|0,e+4|0)>>2],t[o+2|0]=p;f=f+1|0;continue}break}c=c&-5|(Dd(b)>>>0>=i>>>0)<<2}t[b+12|0]=c;if(j>>>0<=k>>>0?w[a|0]&4:0){a=c&-3|(Dd(b)>>>0>=j>>>0)<<1}else{a=c&253}t[b+12|0]=a}cb=e+16|0}function XW(a){a=a|0;var b=0,c=0,d=0,e=0;b=cb+-64|0;cb=b;e=Db(a);v[22440]=0;a=ha(128)|0;c=v[22440];v[22440]=0;a:{b:{if((c|0)==1){break b}c:{d:{if(!a){break d}v[22440]=0;c=Q(1,b+32|0,8992)|0;a=v[22440];v[22440]=0;if((a|0)==1){break c}v[22440]=0;a=ha(128)|0;d=v[22440];v[22440]=0;e:{f:{g:{h:{if((d|0)==1){break h}v[22440]=0;v[b+12>>2]=a;R(134,b+16|0,b+12|0);a=v[22440];v[22440]=0;if((a|0)==1){break h}v[22440]=0;U(2,b+48|0,c|0,b+16|0);a=v[22440];v[22440]=0;if((a|0)==1){break g}d=b+48|0;a=Cb(e,d);rb(d);rb(b+16|0);rb(c);v[22440]=0;c=ha(130)|0;d=v[22440];v[22440]=0;if((d|0)==1){break b}if(!c){break e}v[22440]=0;Q(135,a|0,17530)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break e}break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;rb(b+16|0)}rb(c);break a}v[22440]=0;c=ha(129)|0;d=v[22440];v[22440]=0;if((d|0)==1){break b}if(!c){break d}v[22440]=0;Q(135,a|0,16832)|0;a=v[22440];v[22440]=0;if((a|0)==1){break b}}cb=b- -64|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}rb(e);S(a|0);L()}function Ija(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=cb-2608|0;cb=d;iB(d,a);v[d+1060>>2]=0;v[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){t[a+4|0]=0;u[a>>1]=0;u[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}v[22440]=0;Z(327,d|0);a=v[22440];v[22440]=0;a:{b:{if((a|0)!=1){if((u[d+1068>>1]|u[d+1070>>1])<0){break a}c:{while(1){if((c|0)==(f|0)){break a}v[22440]=0;i=Q(166,d|0,1)|0;a=v[22440];v[22440]=0;if((a|0)==1){break c}a=0;d:{while(1){v[22440]=0;j=Q(166,d|0,1)|0;e=v[22440];v[22440]=0;if((e|0)==1){break d}a=u[(d+B(a,6)|0)+(j?1070:1068)>>1];e:{if((a|0)>255){break e}e=d+B(a,6)|0;g=w[e+1072|0];if(u[e+1068>>1]<0){break e}if(u[e+1070>>1]>=0){continue}}break}g=(i?-1:0)^g;h=(h&255)+(g&255)|0;t[b+f|0]=h;f=f+1|0;continue}break}a=V(30592)|0;break b}a=V(30592)|0;break b}a=V(30592)|0}if((O()|0)==(fa(30592)|0)){_(a|0)|0;v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0}sb(d);S(a|0);L()}a=lq(d);sb(d);cb=d+2608|0;return a|0}function R2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=cb-32|0;cb=h;f=Me(h+16|0,1,0);a:{b:{while(1){j=h+8|0;d=Fb(f);m=d;n=vb(f)+d|0;i=x[b>>1];d=0;c:{if((c|0)==10){mx(j,m,n,i);break c}e=i;k=B(c,c);l=B(k,c);o=B(k,k);d:{while(1){e=e&65535;g=d|1;if(e>>>0<c>>>0){break d}g=d|2;if(e>>>0<k>>>0){break d}g=d|3;if(e>>>0<l>>>0){break d}if(e>>>0<o>>>0){g=d+4|0}else{d=d+4|0;e=(e>>>0)/(o>>>0)|0;continue}break}}d=g;if((d|0)>(n-m|0)){v[j+4>>2]=61;v[j>>2]=n;break c}l=d+m|0;e=l;while(1){d=i&65535;i=(d|0)/(c|0)|0;e=e-1|0;t[e|0]=w[(d-B(c,i)|0)+4898|0];if(i&65535){continue}break}v[j+4>>2]=0;v[j>>2]=l}if(!v[h+12>>2]){break b}d=Yf(vb(f));v[22440]=0;R(60,f|0,d|0);d=v[22440];v[22440]=0;if((d|0)!=1){continue}break}break a}c=v[h+8>>2];b=Fb(f);v[22440]=0;R(61,f|0,c-b|0);b=v[22440];v[22440]=0;e:{if((b|0)!=1){v[22440]=0;R(74,a|0,f|0);a=v[22440];v[22440]=0;if((a|0)!=1){break e}break a}break a}rb(f);cb=h+32|0;return}a=P()|0;O()|0;rb(f);S(a|0);L()}function aW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=cb-96|0;cb=d;sc(b);Fo(a);a:{if(!fv(b,d+56|0)){break a}if(!bD(d+56|0)){break a}b:{if(!c){break b}c=d+56|4;if(!Kb(b,Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))-28|0)){break a}tv(a);g=d,h=sv(),v[g+32>>2]=h;e=d+32|0;rv(Sj(v[a+4>>2])+32|0,e);Wq(e);f=v[Sj(v[a+4>>2])+32>>2];v[22440]=0;R(193,e|0,b|0);b=v[22440];v[22440]=0;c:{if((b|0)==1){break c}e=v[d+32>>2];c=Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));b=w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24);v[22440]=0;c=da(194,e|0,c-28|0,f|0,Wb(b)|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break c}e=0;if(!c){break a}qe(d+16|0,v[f>>2],v[f+4>>2]);_g(d+24|0,v[d+16>>2],v[d+20>>2]);b=ee(d+8|0);b=Uq(d+32|0,v[d+24>>2],v[d+28>>2],v[b>>2],v[b+4>>2]);Sc(Sj(v[a+4>>2])+12|0,b);sb(b);break b}b=Da(88360,26168)|0;a=O()|0;d:{if((fa(88360)|0)==(a|0)){break d}if((fa(26168)|0)==(a|0)){break d}S(b|0);L()}_(b|0)|0;$();e=0;break a}e=1}cb=d+96|0;return e|0}function VY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=cb-16|0;cb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=v[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=v[a+8>>2];if((g-f|0)<=0){break a}v[a+8>>2]=f+1;t[f|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}c=v[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if((f|0)<4){break b}v[a+8>>2]=c+1;t[c|0]=b>>>18|240;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>12&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}b=v[a+12>>2]+4|0;v[a+12>>2]=b;continue}break}c=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];cb=a+16|0;return c|0}function gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;f=cb-16|0;cb=f;h=v[a+40>>2];i=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){g=v[f+8>>2];m=(((v[f+12>>2]&2147483647)<<1|g>>>31)&-2)+j|0;e=(((g>>>16|0)+4&131064)<<1)+b|0;n=u[e+38>>1];o=u[e+36>>1];p=u[e+34>>1];q=u[e+32>>1];r=u[e+30>>1];s=u[e+28>>1];w=u[e+26>>1];x=u[e+24>>1];g=0;while(1){if((g|0)!=2){e=g+m|0;v[(g<<2)+f>>2]=(((((B(t[e+4|0],p)+B(t[e+2|0],q)|0)+B(t[e+6|0],o)|0)+B(t[e+8|0],n)<<8)/2|0)+((((B(t[e-4|0],w)+B(t[e-6|0],x)|0)+B(t[e-2|0],s)|0)+B(t[e|0],r)<<8)/2|0)|0)/16384;g=g+1|0;continue}break}e=v[a+32>>2];i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(v[f>>2],i>>12);h=e+h|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],h>>12);Jb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];c=v[f+8>>2];v[a+36>>2]=i;v[a>>2]=c;v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;cb=f+16|0}function _I(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=cb-32|0;cb=d;a:{b:{c:{d:{e:{f:{g:{h:{if(fj(a)){If(d+24|0);break h}c=d+8|0;sn(c,a);v[22440]=0;c=T(1030,c|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break g}v[d+24>>2]=c;Rf(d+8|0)}if(fj(a)){c=a+36|0}else{c=v[d+24>>2]}if((b|0)==-1){f=v[c>>2];h=4194304;e=0;break e}if((b|0)>=0){e=b;f=v[c>>2];if((Ri(f,v[c+4>>2])|0)>(b|0)){break e}}b=aa(8)|0;v[22440]=0;c=Q(56,d+8|0,10935)|0;a=v[22440];v[22440]=0;if((a|0)==1){break f}oc(b,c);v[22440]=0;U(121,b|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}a=P()|0;O()|0;rb(c);break d}a=P()|0;O()|0;Rf(d+8|0);break c}a=P()|0;O()|0;ba(b|0);break d}v[a+8>>2]=b;b=a+24|0;g=v[b>>2];v[g+480208>>2]=v[g+480208>>2]&-4194305|h;Hi(v[b>>2]+484360|0,w[jf(f,e)+16|0]);b=jf(v[c>>2],e);c=v[b+8>>2];b=v[b+12>>2];v[22440]=0;+ra(1061,a|0,b|0,c|0);b=v[22440];v[22440]=0;if((b|0)!=1){break a}a=P()|0;O()|0}Xk(d+24|0)}S(a|0)}L()}v[a+16>>2]=0;v[a+20>>2]=0;Xk(d+24|0);cb=d+32|0}function Mia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;ed(b,32);_n(b);c=a+40|0;f=b,g=wb(w[c|0]|w[c+1|0]<<8)>>>2|0,u[f+32>>1]=g;e=x[b+34>>1];c=a+38|0;if((Rd((w[c|0]|w[c+1|0]<<8)<<16>>16)|0)>0){e=e|32;u[b+34>>1]=e;d=Rd((w[c|0]|w[c+1|0]<<8)<<16>>16);c=d>>>24|0;d=(d<<8&-256)+2047|0;c=c&255;f=b,g=wc(nka(d,d>>>0<2047?c+1|0:c,4095,0),fb),u[f+28>>1]=g}c=a+58|0;f=b,g=Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),v[f>>2]=g;c=a+62|0;f=b,g=Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),v[f+4>>2]=g;d=Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));c=a+66|0;f=b,g=d+Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))|0,v[f+8>>2]=g;d=a+44|0;c=e&-3|((wb(w[d|0]|w[d+1|0]<<8)|0)!=0)<<1;u[b+34>>1]=c;f=b,g=c&65531|wb(w[d|0]|w[d+1|0]<<8)<<1&4,u[f+34>>1]=g;c=a+54|0;f=b,g=Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))<<1,v[f+24>>2]=g;c=a+42|0;a=Rd((w[c|0]|w[c+1|0]<<8)<<16>>16);if(a){vl(b,+(a|0)/96);a=Rd((w[c|0]|w[c+1|0]<<8)<<16>>16)}t[b+37|0]=a<<4}function Xba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=cb-48|0;cb=g;k=v[a+16>>2];e=ee(g+16|0);v[e+8>>2]=a+112;f=v[a+128>>2];v[e+16>>2]=f;n=e,o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;i=v[a+8>>2];j=v[a+12>>2];if(f){n=e,o=kg(i,j,f),v[n>>2]=o;v[e+4>>2]=fb}l=v[a+24>>2];m=v[a+20>>2];b=v[a+4>>2];f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=b;a:while(1){if(d){v[g+40>>2]=f;v[g+44>>2]=0;f=(b<<1)+k|0;b=v[e+16>>2];while(1)if((b|0)<=0){b=v[e+8>>2];h=v[b+8>>2];Jb(b,h,v[b+12>>2]);b=v[e+8>>2];h=v[b+4>>2];if(h){Jd(b,u[f+(v[g+44>>2]<<1)>>1]/4<<16>>16);Id(v[e+8>>2],h);b=v[e+8>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}d=d-1|0;f=v[c>>2];b=ig(b,v[e+12>>2]);v[c>>2]=f+B(b,m);v[c+4>>2]=v[c+4>>2]+B(b,l);Jb(g+8|0,i,j);c=c+8|0;f=v[g+8>>2];b=v[g+12>>2];continue a}else{Jd(v[e+8>>2],u[f+(v[g+44>>2]<<1)>>1]/4<<16>>16);Id(v[e+8>>2],4);Jb(g+40|0,v[e>>2],v[e+4>>2]);b=b-1|0;continue}}break}v[a>>2]=f;v[a+4>>2]=b;cb=g+48|0}function Ax(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0);c=cb-48|0;cb=c;a:{b=v[a+20>>2];b:{if(!b){break b}d=v[b+4>>2];b=v[b+8>>2];if(Uc(d,b)>>>0<4){break b}qe(c+16|0,d,b);b=ee(c+8|0);d=QT(c+24|0,v[c+16>>2],v[c+20>>2],v[b>>2],v[b+4>>2]);v[22440]=0;b=T(159,d|0)|0;f=v[22440];v[22440]=0;c:{if((f|0)!=1){if(b){break c}b=v[v[a>>2]+40>>2];v[22440]=0;f=T(b|0,a|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break a}b=v[a+20>>2];if(Uc(v[b+4>>2],v[b+8>>2])-4>>>0<f<<2>>>0){break c}b=v[v[a>>2]+172>>2];v[22440]=0;R(b|0,a|0,-1);b=v[22440];v[22440]=0;if((b|0)==1){break a}b=0;while(1){if((b|0)==(f|0)){b=v[v[a>>2]+176>>2];v[22440]=0;Z(b|0,a|0);a=v[22440];v[22440]=0;if((a|0)!=1){break c}break a}v[22440]=0;g=C(Ba(474,d|0));e=v[22440];v[22440]=0;d:{if((e|0)==1){break d}e=v[v[a>>2]+44>>2];v[22440]=0;Aa(e|0,a|0,b|0,C(cm(g)?g:C(0)));e=v[22440];v[22440]=0;if((e|0)==1){break d}b=b+1|0;continue}break}break a}break a}sb(d)}cb=c+48|0;return}a=P()|0;O()|0;sb(d);S(a|0);L()}function yI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;v[a+4>>2]=b;v[a>>2]=89800;e=(b>>>0)/48|0;d=((0-b|0)!=(B(e,-48)|0))+e|0;v[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;v[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){g=-1<<c}else{g=(1<<c)-1&-1>>>32-c|-1<<c}c=0;v[a+24>>2]=c;f=f?g&65536:0;v[a+28>>2]=f;g=0-c|0;h=nka(c,f,d,0);c=65536-(f+((c|0)!=0)|0)|0;f=fb;if((c|0)==(f|0)&g>>>0>h>>>0|c>>>0>f>>>0){d=d+1|0;v[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;v[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){c=-1<<c}else{c=(1<<c)-1&-1>>>32-c|-1<<c}v[a+24>>2]=0;v[a+28>>2]=f?c&65536:0}v[a+16>>2]=d-((b>>>0)%(d>>>0)|0);b=e>>>0<63;d=63-e|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}v[a+48>>2]=b?c:-1;v[a+52>>2]=b?d:-1;d=64-e|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}v[a+40>>2]=e?c:0;v[a+44>>2]=e?d:0;c=e+1|0;e=c&31;if((c&63)>>>0>=32){d=-1<<e}else{d=(1<<e)-1&-1>>>32-e|-1<<e}v[a+32>>2]=0;v[a+36>>2]=b?d&65536:0;return a}function R8(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=cb-32|0;cb=d;v[22440]=0;g=Q(13,d+24|0,a|0)|0;c=v[22440];v[22440]=0;a:{b:{c:{if((c|0)!=1){d:{if(!w[g|0]){break d}c=d+16|0;Jc(c,v[v[a>>2]-12>>2]+a|0);v[22440]=0;c=T(70,c|0)|0;e=v[22440];v[22440]=0;e:{f:{if((e|0)!=1){Pb(d+16|0);e=Ni(d+8|0,a);f=v[v[a>>2]-12>>2];v[22440]=0;f=a+f|0;h=T(14,f|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break f}e=v[e>>2];v[22440]=0;c=Qa(71,c|0,e|0,f|0,h|0,+b)|0;e=v[22440];v[22440]=0;if((e|0)==1){break f}v[d+16>>2]=c;if(!Mu(d+16|0)){break d}c=v[v[a>>2]-12>>2];v[22440]=0;R(16,a+c|0,5);c=v[22440];v[22440]=0;if((c|0)!=1){break d}c=V(0)|0;O()|0;break e}c=V(0)|0;O()|0;Pb(d+16|0);break e}c=V(0)|0;O()|0}xk(g);break c}xk(g);break b}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[22440]=0;Z(17,a+c|0);c=v[22440];v[22440]=0;if((c|0)==1){break a}$()}cb=d+32|0;return a|0}a=P()|0;O()|0;v[22440]=0;X(18);d=v[22440];v[22440]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function Ef(a,b,c){t[a+5|0]=c;a:{b:{switch(b|0){case 0:if(!c){break a}t[a+3|0]=1;return;case 1:t[a+3|0]=2;return;case 2:t[a+3|0]=3;return;case 3:t[a+3|0]=4;return;case 4:t[a+3|0]=5;return;case 5:t[a+3|0]=6;return;case 6:t[a+3|0]=7;return;case 7:t[a+3|0]=8;return;case 8:t[a+3|0]=9;return;case 9:t[a+3|0]=10;return;case 10:t[a+3|0]=11;return;case 11:t[a+3|0]=12;return;case 12:t[a+3|0]=13;return;case 13:t[a+3|0]=14;t[a+5|0]=B(c>>>4|0,10)+(c&15);return;case 14:t[a+3|0]=19;return;case 15:if(c>>>0<=31){t[a+3|0]=16;return}t[a+3|0]=17;return;case 16:t[a+3|0]=23;return;case 17:t[a+3|0]=24;return;case 20:t[a+3|0]=25;return;case 21:t[a+3|0]=30;return;case 25:t[a+3|0]=29;return;case 27:t[a+3|0]=15;return;case 29:t[a+3|0]=18;return;case 32:t[a+3|0]=37;return;case 33:t[a+3|0]=28;return;case 34:t[a+3|0]=27;return;case 35:t[a+3|0]=31;return;case 36:t[a+3|0]=32;return;case 37:t[a+3|0]=32;return;case 38:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function p3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=cb-2144|0;cb=b;Hb(b+96|0,0,2048);a:{b:{c:{f=v[c+4>>2];if(!f){a=aa(8)|0;v[22440]=0;b=Q(56,b+80|0,10472)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}oc(a,b);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}c=P()|0;O()|0;rb(b);break b}g=v[c>>2];d=v[c+12>>2];c=v[c+8>>2];v[b+72>>2]=c;v[b+76>>2]=d;e=v[b+76>>2];v[b+32>>2]=v[b+72>>2];v[b+36>>2]=e;v[b+68>>2]=f;v[b+64>>2]=g;e=v[b+68>>2];v[b+24>>2]=v[b+64>>2];v[b+28>>2]=e;h=gI(b+24|0);if(h){v[b+56>>2]=c;v[b+60>>2]=d;c=v[b+60>>2];v[b+16>>2]=v[b+56>>2];v[b+20>>2]=c;v[b+52>>2]=f;v[b+48>>2]=g;c=v[b+52>>2];v[b+8>>2]=v[b+48>>2];v[b+12>>2]=c;c=$H(b+8|0)}else{c=0}v[b+80>>2]=c;v[b+84>>2]=0;c=0;d=2048;while(1){d:{e=gb[f|0](g,(b+96|0)+c|0,d)|0;c=e+c|0;if(!e){break d}d=d-e|0;if(d){continue}}break}d=a;a=$b(b+40|0,b+96|0,c);a=zs(d,v[a>>2],v[a+4>>2],h?b+80|0:0);cb=b+2144|0;return a|0}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}function uha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=cb-32|0;cb=d;b=cb-32|0;cb=b;v[b+16>>2]=1073741824;u[b+22>>1]=12;c=lc(64);v[22440]=0;e=T(859,c|0)|0;f=v[22440];v[22440]=0;a:{b:{c:{if((f|0)!=1){c=Sf(b+8|0,e);e=v[c>>2];v[22440]=0;R(860,e|0,a|0);a=v[22440];v[22440]=0;if((a|0)==1){break c}a=v[c>>2];v[22440]=0;a=Y(861,a|0,b+22|0,b+16|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}d:{if(!a){If(b+24|0);break d}a=v[c>>2];v[22440]=0;R(862,a|0,15);a=v[22440];v[22440]=0;if((a|0)==1){break c}bi(b+24|0,c)}qg(c);cb=b+32|0;a=v[b+24>>2];break a}a=P()|0;O()|0;zb(c);break b}a=P()|0;O()|0;qg(c)}S(a|0);L()}v[d+24>>2]=a;a=0;e:{f:{g:{while(1){if((a|0)==12){break e}c=v[d+24>>2];v[22440]=0;b=Q(1,d+8|0,(a<<2)+32288|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){v[22440]=0;U(499,c|0,a|0,b|0);c=v[22440];v[22440]=0;if((c|0)==1){break g}rb(b);a=a+1|0;continue}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;rb(b)}qg(d+24|0);S(a|0);L()}cb=d+32|0;return v[d+24>>2]}function Jaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=cb-16|0;cb=g;d=a+4|0;b=v[d>>2]+223860|0;if(YM(b)){$M(b)}v[a+24>>2]=0;v[a+28>>2]=0;v[v[d>>2]>>2]=0;b=v[a>>2];v[v[d>>2]+40>>2]=v[b+480196>>2];v[v[d>>2]+44>>2]=v[b+480204>>2];v[v[d>>2]+80>>2]=v[b+480200>>2];c=x[b+480188>>1];v[g+8>>2]=0;v[g+12>>2]=0;e=g+8|0;u[e+4>>1]=65280;v[e>>2]=0;f=cb-16|0;cb=f;v[f+12>>2]=c;b=a+8|0;a:{if(Vm(b)>>>0>=c>>>0){h=v[b>>2];i=Vg(h,v[b+4>>2]);v[f+8>>2]=i;j=v[Bb(f+12|0,f+8|0)>>2];while(1){if(j){v[h>>2]=v[e>>2];u[h+4>>1]=x[e+4>>1];j=j-1|0;h=h+8|0;continue}break}if(c>>>0>i>>>0){oM(b,c-i|0,e);break a}Nd(b,v[b>>2]+(c<<3)|0);break a}DN(b);RN(b,Rq(b,c));oM(b,c,e)}cb=f+16|0;b=0;while(1){e=v[a>>2];if(x[e+480188>>1]<=b>>>0){cb=g+16|0}else{c=B(b,872);Ln((c+v[d>>2]|0)+616|0,e,b&65535,134217728);t[(c+v[d>>2]|0)+1433|0]=0;t[(c+v[d>>2]|0)+1432|0]=0;t[(c+v[d>>2]|0)+1415|0]=0;t[(c+v[d>>2]|0)+1418|0]=0;t[(c+v[d>>2]|0)+1413|0]=0;b=b+1|0;continue}break}}function qx(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;o(+a);e=j(1)|0;c=j(0)|0;a:{b:{d=e>>>20&2047;if(d-969>>>0<63){k=d;break b}if(d>>>0<=968){return a+1}if(d>>>0<1033){break b}b=0;if(!c&(e|0)==-1048576){break a}if((d|0)==2047){return a+1}if((e|0)<0){return gr(1.2882297539194267e-231)}return gr(3.105036184601418e231)}b=A[170];f=A[169]*a+b;b=f-b;b=b*A[172]+(b*A[171]+a);a=b*b;g=a*a*(b*A[176]+A[175]);a=a*(b*A[174]+A[173]);o(+f);j(1)|0;h=j(0)|0;c=h<<4&2032;b=g+(a+(A[c+1464>>3]+b));d=c+1472|0;c=h<<13;e=0;i=v[d>>2]+e|0;c=c+v[d+4>>2]|0;c=e>>>0>i>>>0?c+1|0:c;d=i;if(!k){c:{if(!(h&-2147483648)){l(0,d|0);l(1,c-1058013184|0);a=+n();a=(a*b+a)*5.486124068793689e303;break c}e=cb-16|0;l(0,d|0);l(1,c+1071644672|0);g=+n();f=g*b;a=f+g;if(a<1){v[e+8>>2]=0;v[e+12>>2]=1048576;A[e+8>>3]=A[e+8>>3]*2.2250738585072014e-308;b=a+1;a=b+(f+(g-a)+(a+(1-b)))+-1;a=a==0?0:a}a=a*2.2250738585072014e-308}return a}l(0,d|0);l(1,c|0);a=+n();b=a*b+a}return b}function U8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];c=Oj(d,v[a+4>>2]);if(c>>>0<b>>>0){g=cb-32|0;cb=g;e=b-c|0;b=v[xb(a)>>2];c=v[a+4>>2];a:{if(e>>>0<=b-c>>11>>>0){b=cb-16|0;cb=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(e<<11);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){dc(b);cb=b+16|0}else{pK(a);a=a+2048|0;v[b+4>>2]=a;continue}break}break a}h=xb(a);i=g+8|0;b=a;f=Oj(v[a>>2],c)+e|0;c=cb-16|0;cb=c;v[c+12>>2]=f;d=cb-16|0;cb=d;v[d+12>>2]=2097151;v[d+8>>2]=2147483647;a=v[Bb(d+12|0,d+8|0)>>2];cb=d+16|0;b:{if(a>>>0>=f>>>0){d=Dx(b);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Pc(c+8|0,c+12|0)>>2]}cb=c+16|0;break b}nd();L()}d=rK(i,a,Oj(v[b>>2],v[b+4>>2]),h);c=d;a=cb-16|0;cb=a;v[a>>2]=v[c+8>>2];f=v[c+8>>2];v[a+8>>2]=c+8;v[a+4>>2]=f+(e<<11);c=v[a>>2];while(1){if(v[a+4>>2]!=(c|0)){pK(c);c=v[a>>2]+2048|0;v[a>>2]=c;continue}break}Gd(a);cb=a+16|0;Ad(b,d);qK(d)}cb=g+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<11)|0)}}function fP(a,b,c,d){var e=0,f=0;e=cb-16|0;cb=e;t[e+15|0]=c;f=b&15;b=w[f+27184|0];a:{b:{switch(f|0){case 0:b=c?d>>>0<51?0:b:0;break a;case 5:c:{d:{f=c&15;e:{if(!((f|0)!=2&(c&240)!=32)){c=159;t[e+15|0]=159;b=20;break e}if((f|0)==12){break d}}if(d>>>0<51){break a}if((c&240)==192){break c}break a}if(d>>>0<51){break a}}t[e+15|0]=0;b=25;break a;case 7:b=d>>>0<52?0:b;break a;case 10:c=c&240;if(!c){break a}t[e+15|0]=c;break a;case 11:t[e+15|0]=B(c&15,17);break a;case 12:t[e+15|0]=c>>>2;break a;case 13:t[e+15|0]=B(c>>>4|0,10)+(c&15);break a;case 14:f:{switch((c>>>4|0)-1|0){case 0:t[e+15|0]=c|240;b=2;break a;case 1:t[e+15|0]=c|240;b=3;break a;case 7:if(d>>>0<52){break a}t[e+15|0]=c&15|96;case 11:case 12:b=20;break a;case 8:b=15;t[e+15|0]=c&15;break a;case 9:t[e+15|0]=c<<4|15;b=11;break a;case 10:break f;default:break a}}t[e+15|0]=c|240;b=11;break a;case 15:break b;default:break a}}b=c>>>0>47?17:b}ae(a,b,e+15|0);cb=e+16|0}function sga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=cb-48|0;cb=f;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;Wn(b,f+44|0);d=w[f+45|0];e=w[f+46|0];a:{if(!PO(w[f+44|0],d,e)){break a}g=w[f+47|0];t[a+4|0]=1;h=d>>>3&3;c=(h|0)!=3;i=d>>>1&3;d=i^3;g=g>>>0<192;u[a+2>>1]=x[(B(c,6)+(d<<1)|0)+27480>>1]<<g;j=B(B(w[(d+B(c,3)|0)+27256|0],x[((B(c,90)+B(d,30)|0)+(e>>>3&30)|0)+27264>>1]),1e3);d=e>>>1|0;e=B(((j>>>0)/x[(B(h,6)+(d&6)|0)+27456>>1]|0)+(d&1)|0,(i|0)==3?4:1);u[a>>1]=e;d=w[(g|c<<1)+27492|0];if(d+8>>>0>(e&65535)>>>0){break a}c=cb-32|0;cb=c;v[c+28>>2]=d+4;v[c+8>>2]=36;e=v[Bb(c+28|0,c+8|0)>>2];if(!Kb(b,e)){e=_e(b)}g=c+8|0;Jq(g,f);h=$b(c+16|0,v[c+8>>2],e);Yb(c,b,v[h>>2],v[h+4>>2]);Jq(g,f);Hb(v[c+8>>2]+e|0,0,36-e|0);Ob(b,v[c+28>>2]);cb=c+32|0;b=2;c=d>>>0>2?d:2;while(1){if((b|0)!=(c|0)){e=b+f|0;b=b+1|0;if(!w[e|0]){continue}break a}break}b=d+f|0;if(Mb(b,9595,4)){b=Mb(b,11096,4)}else{b=0}t[a+5|0]=!b}cb=f+48|0;return a|0}function sI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=cb-32|0;cb=c;e=v[a>>2];a=v[e>>2];Pf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[e+4>>2];j=v[a+8>>2];h=v[a+4>>2];k=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=cb-32|0;cb=a;a:{b:{if(y[c+4>>2]>=h>>>0){if(Of(c)>>>0<j>>>0){break b}l=b+12|0;c:while(1){e=0;if((f|0)==(j|0)){break a}while(1)if((e|0)==(h|0)){f=f+1|0;continue c}else{i=ah(k,h,e,f);d=Ib(v[b>>2],e);g=ne(mg(A[i>>3])*134217728);i=d;d=(v[d>>2]>>1)+tm(g)|0;m=d;d=Ur(l)+d&-4096;v[i>>2]=m-d;A[a+24>>3]=+(d|0)*7.450580596923828e-9;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;g=ne(A[Fg(a+24|0,a+16|0,a+8|0)>>3]*32768);d:{if(D(g)<2147483648){d=~~g;break d}d=-2147483648}d=Wc(d);n=pn(c,e,f),o=d,u[n>>1]=o;e=e+1|0;continue}}}ca(7157,9074,78,8754);L()}ca(5870,9074,80,8754);L()}cb=a+32|0;cb=c+32|0}function lI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=cb-32|0;cb=c;e=v[a>>2];a=v[e>>2];Pf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[e+4>>2];j=v[a+8>>2];h=v[a+4>>2];k=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=cb-32|0;cb=a;a:{b:{if(y[c+4>>2]>=h>>>0){if(Of(c)>>>0<j>>>0){break b}l=b+12|0;c:while(1){e=0;if((f|0)==(j|0)){break a}while(1)if((e|0)==(h|0)){f=f+1|0;continue c}else{i=ah(k,h,e,f);d=Ib(v[b>>2],e);g=ne(mg(A[i>>3])*134217728);i=d;d=(v[d>>2]>>1)+tm(g)|0;m=d;d=Ur(l)+d&-4096;v[i>>2]=m-d;A[a+24>>3]=+(d|0)*7.450580596923828e-9;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;g=ne(A[Fg(a+24|0,a+16|0,a+8|0)>>3]*32768);d:{if(D(g)<2147483648){d=~~g;break d}d=-2147483648}d=Wc(d);n=on(c,e,f),o=d,u[n>>1]=o;e=e+1|0;continue}}}ca(7157,9074,78,8754);L()}ca(5870,9074,80,8754);L()}cb=a+32|0;cb=c+32|0}function YH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=cb-80|0;cb=e;v[e+72>>2]=c;c=bi(a,e+72|0);h=If(a+4|0);i=If(a+24|0);j=If(a+32|0);k=Rb(a+36|0);v[a+56>>2]=3;l=Rb(a+68|0);v[22440]=0;R(967,a|0,d|0);f=v[22440];v[22440]=0;a:{b:{c:{d:{if((f|0)!=1){f=v[b>>2];g=v[b+4>>2];m=v[b+12>>2];v[e+40>>2]=v[b+8>>2];v[e+44>>2]=m;v[e+32>>2]=f;v[e+36>>2]=g;b=ee(e+24|0);f=v[b+4>>2];b=v[b>>2];g=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=g;v[22440]=0;g=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=g;W(955,e+48|0,e+8|0,b|0,f|0);b=v[22440];v[22440]=0;if((b|0)==1){break d}v[22440]=0;U(969,a|0,e+48|0,d|0);b=v[22440];v[22440]=0;if((b|0)==1){break c}sb(e+48|0);v[22440]=0;Z(970,a|0);b=v[22440];v[22440]=0;if((b|0)==1){break b}Ae(e+72|0);cb=e+80|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;sb(e+48|0);break a}a=P()|0;O()|0}ad(l);Rf(k);_o(j);qi(i);pi(h);Ae(c);Ae(e+72|0);S(a|0);L()}function $v(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=cb-16|0;cb=m;t[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!vb(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!vb(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=yi(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=w[f+79696|0];d:{e:{switch((f&-2)-22|0){case 2:b=v[e>>2];if((b|0)!=(d|0)&(w[b-1|0]&95)!=(w[c|0]&127)){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!vb(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>21){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}cb=m+16|0;return a}function Yba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=cb-48|0;cb=g;k=v[a+16>>2];e=ee(g+16|0);v[e+8>>2]=a+112;f=v[a+128>>2];v[e+16>>2]=f;n=e,o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;i=v[a+8>>2];j=v[a+12>>2];if(f){n=e,o=kg(i,j,f),v[n>>2]=o;v[e+4>>2]=fb}l=v[a+24>>2];m=v[a+20>>2];b=v[a+4>>2];f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=b;a:while(1){if(d){v[g+40>>2]=f;v[g+44>>2]=0;f=b+k|0;b=v[e+16>>2];while(1)if((b|0)<=0){b=v[e+8>>2];h=v[b+8>>2];Jb(b,h,v[b+12>>2]);b=v[e+8>>2];h=v[b+4>>2];if(h){Jd(b,t[f+v[g+44>>2]|0]<<6);Id(v[e+8>>2],h);b=v[e+8>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}d=d-1|0;f=v[c>>2];b=ig(b,v[e+12>>2]);v[c>>2]=f+B(b,m);v[c+4>>2]=v[c+4>>2]+B(b,l);Jb(g+8|0,i,j);c=c+8|0;f=v[g+8>>2];b=v[g+12>>2];continue a}else{Jd(v[e+8>>2],t[f+v[g+44>>2]|0]<<6);Id(v[e+8>>2],4);Jb(g+40|0,v[e>>2],v[e+4>>2]);b=b-1|0;continue}}break}v[a>>2]=f;v[a+4>>2]=b;cb=g+48|0}function $ca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=cb-16|0;cb=g;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;o=v[a+8>>2];p=v[a+12>>2];while(1){b=e;if(d){q=v[a+72>>2];e=v[a+64>>2];i=e;h=e>>31;e=Vb(b,-16777216,16776704);e=kka(i,h,e,e>>31);i=fb;j=e;e=v[a+68>>2];f=Vb(f,-16777216,16776704);h=kka(e,e>>31,f,f>>31);e=j+h|0;f=fb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;e=v[a+60>>2];h=e;r=e>>31;k=v[g+12>>2]+n|0;e=t[k|0];j=i;i=((B(t[k+1|0]-e|0,v[g+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=i;h=kka(h,r,e,e>>31);e=j+h|0;f=fb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Mc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Jb(g+8|0,o,p);e=f-(i&q)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];d=v[g+8>>2];v[a+48>>2]=f;v[a+44>>2]=b;v[a>>2]=d;v[a+4>>2]=c;cb=g+16|0}function fq(a){var b=0,c=0,d=0,e=0,f=0;e=cb-16|0;cb=e;a:{b:{c:{d:{e:{f:{g:{h:{b=v[a+480180>>2];switch(b-1|0){case 7:break e;case 0:case 1:case 3:break f;case 2:case 4:case 5:case 6:break g;default:break h}}if((b|0)==16){break b}if((b|0)==32){break f}if((b|0)==64|(b|0)==256|((b|0)==512|(b|0)==2048)|(b|0)==8192){break b}if((b|0)==65536){break d}c=1;if((b|0)==2097152){break a}if((b|0)==4194304){break c}if((b|0)==536870912|(b|0)==67108864|(b|0)==134217728){break a}c=b;if((b|0)==16777216){break a}}c=32;break a}c=b;break a}c=4;if(x[a+480192>>1]){break a}a=a+484344|0;d=Pg(a);v[e+8>>2]=d;a=Og(a);while(1){if(!Qb(d,a)){c=1;break a}if(!(!Vh(d)|v[d+12>>2]==64)){break a}JL(e+8|0);d=v[e+8>>2];continue}}c=16777216;break a}c=32;f=x[a+480188>>1];if(f>>>0>16){break a}while(1){if((d|0)==(f|0)){break b}b=(d<<5)+a|0;if(t[b+480281|0]&1){break a}d=d+1|0;if(x[b+480286>>1]==64){continue}break}break a}c=2}cb=e+16|0;return c}function gW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=cb-32|0;cb=k;c=Pm(k+8|0,a);f=cb-48|0;cb=f;l=-1;a:{if(!cD(c,f+8|0)){break a}l=0;if(!gD(f+8|0)){break a}p=v[c+12>>2];b:{a=f+8|0;d=a+16|0;if(!ql(c,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))){break b}n=a+4|0;d=a+12|0;while(1){c:{if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0>o>>>0){if(gg(c,5)){break c}}g=m&1;break b}h=0;g=1;d:{if((w[n|0]|w[n+1|0]<<8)>>>0>=64){a=tq(c);i=a&63;j=a&128;e:{if(!(a&64)){break e}e=6;while(1){a=tq(c);i=(a&127)<<e|i;if(!(a&128)){break e}a=e>>>0<25;e=e+7|0;if(a){continue}break}}a=j?-2147483648:i;if(((j?(i|0)>=0?0-i|0:a:a)|0)<=0){break d}}while(1){e=tq(c);if(e){j=h>>>0>4;a=j&g;if(!((g^1)&1|j)){a=(Dp(e<<24>>24)&255)==w[h+13133|0]}g=a;h=h+1|0;continue}break}Yc(c,4);m=(h|0)==5?g&1?1:m:m}o=o+1|0;continue}}ql(c,p);if(!g){break a}l=ye(c,b,fD(f+8|0),0)}cb=f+48|0;cb=k+32|0;return l|0}function _ca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=cb-16|0;cb=g;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;o=v[a+8>>2];p=v[a+12>>2];while(1){b=e;if(d){q=v[a+72>>2];e=v[a+64>>2];i=e;h=e>>31;e=Vb(b,-16777216,16776704);e=kka(i,h,e,e>>31);i=fb;j=e;e=v[a+68>>2];f=Vb(f,-16777216,16776704);h=kka(e,e>>31,f,f>>31);e=j+h|0;f=fb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;e=v[a+60>>2];h=e;r=e>>31;k=(v[g+12>>2]<<1)+n|0;e=u[k>>1];j=i;i=e+((B(u[k+2>>1]-e|0,v[g+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;h=kka(h,r,e,e>>31);e=j+h|0;f=fb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Mc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Jb(g+8|0,o,p);e=f-(i&q)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];d=v[g+8>>2];v[a+48>>2]=f;v[a+44>>2]=b;v[a>>2]=d;v[a+4>>2]=c;cb=g+16|0}function Bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=cb-16|0;cb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){e=(v[f+12>>2]<<1)+j|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(u[e-4>>1],u[h+2>>1])+B(u[e-6>>1],u[h>>1])|0)+B(u[e-2>>1],u[h+4>>1])|0)+B(u[e>>1],u[h+6>>1])|0)+B(u[e+2>>1],u[h+8>>1])|0)+B(u[e+4>>1],u[h+10>>1])|0)+B(u[e+6>>1],u[h+12>>1])|0)+B(u[e+8>>1],u[h+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(e,l);v[c+4>>2]=v[c+4>>2]+B(e,k);Jb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;cb=f+16|0}function _F(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=cb-32|0;cb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[Ke(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;while(1){if((f|0)!=(h|0)){d=-1;g=vr(v[a+32>>2]);if((g|0)==-1){break a}t[(c+24|0)+f|0]=g;f=f+1|0;continue}break}b:{c:{if(w[a+53|0]){t[c+23|0]=w[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];g=v[d>>2];j=v[d+4>>2];i=c+24|0;f=i+e|0;e:{switch(mG(v[a+36>>2],d,i,f,c+16|0,c+23|0,h,c+12|0)-1|0){case 2:break d;case 0:break e;case 1:break b;default:break c}}d=v[a+40>>2];v[d>>2]=g;v[d+4>>2]=j;if((e|0)==8){break b}d=vr(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}t[c+23|0]=w[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((ur(sg(t[e+(c+24|0)|0]),v[a+32>>2])|0)!=-1){continue}break a}}d=sg(t[c+23|0]);v[a+48>>2]=d;break a}d=sg(t[c+23|0]);break a}d=-1}cb=c+32|0;return d}function Vz(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=cb-32|0;cb=g;lR(a,b);i=cb-16|0;cb=i;ed(c,1);a=b+22|0;h=wb(w[a|0]|w[a+1|0]<<8)<<1;v[c>>2]=h;t[c+37|0]=w[b+24|0]<<4;t[i+15|0]=w[b+25|0];t[i+14|0]=64;l=c,m=w[Tb(i+15|0,i+14|0)|0]<<2,u[l+30>>1]=m;a=b+26|0;f=wb(w[a|0]|w[a+1|0]<<8);a=f<<1;j=b+28|0;k=wb(w[j|0]|w[j+1|0]<<8);j=k<<1;a=k>>>0>=2?a+j>>>0<=h>>>0?a:f+j>>>0>h>>>0?a:f:a;a:{b:{switch(h|0){case 2:v[c>>2]=0;break a;case 0:break a;default:break b}}v[c+4>>2]=a;f=a+j|0;v[c+8>>2]=f;if(a>>>0>=h>>>0){a=h-1|0;v[c+4>>2]=a}if(!(!(f>>>0<4|a>>>0>f>>>0)&f-a>>>0>3)){v[c+4>>2]=0;v[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=h>>>0))){v[c+8>>2]=0;break a}if(a>>>0>=f>>>0){break a}u[c+34>>1]=x[c+34>>1]|2}cb=i+16|0;Bl(g,3,b);a=g+16|0;xc(a,v[g>>2],v[g+4>>2],w[g+8|0]);d=uc(d,a);c=d+32|0;rb(a);while(1){if((c|0)!=(d|0)){if((w[d|0]-1&255)>>>0<=30){t[d|0]=32}d=d+1|0;continue}break}a=Xz(b);cb=g+32|0;return a}function dha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=Lt(c,d);d=b&63;if(e>>>0>d>>>0){c=cS(c,d);d=0;g=cb-16|0;cb=g;t[a+12|0]=0;Ac(a);e=cb-32|0;cb=e;if(vh(a)>>>0<=14){f=xb(a);f=$f(e+8|0,15,pc(v[a>>2],v[a+4>>2]),f);Ad(a,f);_f(f)}cb=e+32|0;f=0-w[c+1|0]|0;while(1){a:{if((d|0)==15){break a}e=c+(d<<1)|0;h=w[e+1|0];if(!h){break a}t[g+7|0]=64;f=h+(f<<16>>16)|0;h=ul(g+8|0,f&65535,w[Tb(e+2|0,g+7|0)|0]);b:{if(y[a+4>>2]<y[xb(a)>>2]){_R(a,h);break b}i=cb-32|0;cb=i;e=xb(a);e=$f(i+8|0,Gg(a,pc(v[a>>2],v[a+4>>2])+1|0),pc(v[a>>2],v[a+4>>2]),e);sm(v[e+8>>2],h);v[e+8>>2]=v[e+8>>2]+4;Ad(a,e);_f(e);cb=i+32|0}d=d+1|0;continue}break}d=w[c+32|0];t[a+14|0]=d>>>4;t[a+13|0]=d&15;c=w[c+31|0];d=c&15;t[a+15|0]=d;t[a+16|0]=d;if(c&16){t[a+12|0]=w[a+12|0]|4}if(c&32){t[a+12|0]=w[a+12|0]|2}cb=g+16|0}c:{if(b<<24>>24>=0){c=w[a+12|0]&-2;a=a+12|0;break c}c=w[a+12|0]&-2|hc(v[a>>2],v[a+4>>2])^1;a=a+12|0}t[a|0]=c}function QY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;b=0;a=c;while(1){a:{if(a>>>0>=d>>>0|b>>>0>=e>>>0){break a}g=1;f=t[a|0];b:{if((f|0)>=0){break b}if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-a|0)<2){break a}g=2;if((w[a+1|0]&192)==128){break b}break a}g=f&255;c:{d:{if(f>>>0<=4294967279){if((d-a|0)<3){break a}h=w[a+2|0];f=w[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((f&224)==160){break c}break a}if((f&192)!=128){break a}break c}if((d-a|0)<4|f>>>0>4294967284|e-b>>>0<2){break a}h=w[a+3|0];i=w[a+2|0];f=w[a+1|0];e:{f:{switch(g-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(g<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=b+1|0;g=4;break b}if((f&224)!=128){break a}}g=3;if((h&192)!=128){break a}}b=b+1|0;a=a+g|0;continue}break}return a-c|0}function j7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=C(0),p=0,q=0,r=0,s=C(0),t=C(0),u=C(0),x=C(0),y=0,A=0,B=0,E=0,F=C(0);f=cb-16|0;cb=f;k=v[a+4240>>2];a:{if(!k){break a}g=a+44|0;if(!Yh(g)){break a}o=z[a+4220>>2];B=f,E=Ud(g,0),v[B+8>>2]=E;B=f,E=Ud(g,1),v[B+12>>2]=E;B=f,E=jd(g,0),v[B>>2]=E;B=f,E=jd(g,1),v[B+4>>2]=E;x=C(C(1)-o);l=d;b:while(1){if(l){m=v[a+4244>>2];y=m<<1;p=v[a+4208>>2];A=w[a+4264|0];e=0;n=0;while(1)if((e|0)==2){e=m+1|0;v[a+4244>>2]=(e|0)==(k|0)?0:e;l=l-1|0;continue b}else{h=(A?1-n|0:e)&255;j=v[((h<<2)+a|0)+4248>>2];q=e<<2;r=q+(f+8|0)|0;i=v[r>>2];v[r>>2]=i+4;j=m-j|0;s=z[Ib(p,h+((j>>31&k)+j<<1)|0)>>2];t=z[i>>2];u=C(C(s*z[a+4224>>2])+C(t*z[a+4260>>2]));B=Ib(p,e+y|0),F=C(D(u))<C(1.0000000195414814e-24)?C(0):u,z[B>>2]=F;h=f+q|0;i=v[h>>2];v[h>>2]=i+4;z[i>>2]=C(t*x)+C(o*s);n=n+1|0;e=e+1|0;continue}}break}ti(a,b,c,jd(g,0),jd(g,1),d)}cb=f+16|0}function HN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{g=b;c=cb-16|0;cb=c;d=Db(a);while(1){b:{c:{d:{e:{if(vb(g)>>>0>f>>>0){b=v[hk(g,f)>>2];if(b>>>0>=2097152){v[22440]=0;R(52,d|0,63);a=v[22440];v[22440]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;t[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(!a){v[22440]=0;R(52,d|0,w[c+10|0]);break e}b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}v[22440]=0;R(52,d|0,w[c+10|0]|64);break e}cb=c+16|0;break a}a=v[22440];v[22440]=0;if((a|0)!=1){break c}break b}i=(-1<<b^-1)<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}f:{if((a|0)==(b|0)){a=w[j|0];v[22440]=0;R(52,d|0,a|i&255);h=v[22440];v[22440]=0;a=e;break f}v[22440]=0;a=a-1|0;R(52,d|0,w[a+(c+10|0)|0]|128);h=v[22440];v[22440]=0}if((h|0)!=1){continue}break}break b}f=f+1|0;continue}break}a=P()|0;O()|0;rb(d);S(a|0);L()}}function $F(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=cb-32|0;cb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[Ke(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;while(1){if((f|0)!=(h|0)){d=-1;g=vr(v[a+32>>2]);if((g|0)==-1){break a}t[(c+24|0)+f|0]=g;f=f+1|0;continue}break}b:{c:{if(w[a+53|0]){v[c+20>>2]=t[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];g=v[d>>2];j=v[d+4>>2];i=c+24|0;f=i+e|0;e:{switch(mG(v[a+36>>2],d,i,f,c+16|0,c+20|0,h,c+12|0)-1|0){case 2:break d;case 0:break e;case 1:break b;default:break c}}d=v[a+40>>2];v[d>>2]=g;v[d+4>>2]=j;if((e|0)==8){break b}d=vr(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}v[c+20>>2]=t[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((ur(t[e+(c+24|0)|0],v[a+32>>2])|0)!=-1){continue}break a}}d=v[c+20>>2];v[a+48>>2]=d;break a}d=v[c+20>>2];break a}d=-1}cb=c+32|0;return d}function pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=cb-16|0;cb=h;m=v[a+16>>2];k=Zf(1,2);b=fb;n=b;Jb(a,k,b);f=v[a+48>>2];o=v[a+24>>2];p=v[a+20>>2];e=v[a+44>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;q=v[a+8>>2];r=v[a+12>>2];while(1){b=e;if(d){s=v[a+72>>2];e=v[a+60>>2];g=e;i=e>>31;l=u[(v[h+12>>2]<<1)+m>>1]<<8;e=l;e=kka(g,i,e,e>>31);j=fb;g=e;e=v[a+64>>2];i=e;t=e>>31;e=Vb(b,-16777216,16776704);i=kka(i,t,e,e>>31);g=g+i|0;e=fb+j|0;e=g>>>0<i>>>0?e+1|0:e;i=g;g=v[a+68>>2];f=Vb(f,-16777216,16776704);j=kka(g,g>>31,f,f>>31);g=i+j|0;f=fb+e|0;f=g>>>0<j>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Mc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,p)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,o);Jb(h+8|0,q,r);e=f-(s&l)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];d=v[h+8>>2];v[a+48>>2]=f;v[a+44>>2]=b;v[a>>2]=d;v[a+4>>2]=c;lg(a,k,n);cb=h+16|0}function Cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=cb-16|0;cb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){e=v[f+12>>2]+j|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(t[e-2|0],u[h+2>>1])+B(t[e-3|0],u[h>>1])|0)+B(t[e-1|0],u[h+4>>1])|0)+B(t[e|0],u[h+6>>1])|0)+B(t[e+1|0],u[h+8>>1])|0)+B(t[e+2|0],u[h+10>>1])|0)+B(t[e+3|0],u[h+12>>1])|0)+B(t[e+4|0],u[h+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(e,l);v[c+4>>2]=v[c+4>>2]+B(e,k);Jb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;cb=f+16|0}function wga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=cb-16|0;cb=e;u[e+12>>1]=0;v[e+8>>2]=0;j=8;n=B(c,d)<<1;while(1){if((d|0)!=(l|0)){h=(l<<1)+b|0;o=n+h|0;while(1){if(h>>>0<o>>>0){u[e+6>>1]=0;AR(a,e+15|0,e+12|0,j,e+6|0);g=x[e+6>>1];c=j;while(1){a:{if(!(c&255)){break a}f=x[e+12>>1]<<1;i=f&254;u[e+12>>1]=i;if(i){f=(f&65534)>>>0>255}else{if(!mf(a,e+5|0)){break a}f=w[e+5|0];u[e+12>>1]=f<<1&254|1;f=f>>>7|0}c=c-1|0;g=f|g<<1;continue}break}c=1;i=g&65535;b:{if(i>>>0<4){break b}f=15;while(1){c=f;m=f&255;if(i>>>m&1){break b}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;t[e+15|0]=f;g=f-1^(g&65534)>>>1;f=g+x[e+8>>1]|0;u[e+6>>1]=f;u[h>>1]=f;v[e+8>>2]=((g>>1)-(k<<16>>16)|0)+(f<<16>>16<<1);h=(d<<1)+h|0;j=(c+j&254)>>>1|0;c=-32768;k=v[e+8>>2];c:{if((k|0)>=-32768){c=32767;if((k|0)<32768){break c}}v[e+8>>2]=c}k=f;continue}break}l=l+1|0;continue}break}cb=e+16|0}function qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;h=cb-16|0;cb=h;m=v[a+16>>2];k=Zf(1,2);b=fb;n=b;Jb(a,k,b);f=v[a+48>>2];o=v[a+24>>2];p=v[a+20>>2];e=v[a+44>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;q=v[a+8>>2];r=v[a+12>>2];while(1){b=e;if(d){s=v[a+72>>2];e=v[a+60>>2];g=e;i=e>>31;l=t[v[h+12>>2]+m|0]<<16;e=l;e=kka(g,i,e,e>>31);j=fb;g=e;e=v[a+64>>2];i=e;u=e>>31;e=Vb(b,-16777216,16776704);i=kka(i,u,e,e>>31);g=g+i|0;e=fb+j|0;e=g>>>0<i>>>0?e+1|0:e;i=g;g=v[a+68>>2];f=Vb(f,-16777216,16776704);j=kka(g,g>>31,f,f>>31);g=i+j|0;f=fb+e|0;f=g>>>0<j>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Mc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,p)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,o);Jb(h+8|0,q,r);e=f-(s&l)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];d=v[h+8>>2];v[a+48>>2]=f;v[a+44>>2]=b;v[a>>2]=d;v[a+4>>2]=c;lg(a,k,n);cb=h+16|0}function TY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break a}f=1;b=t[a|0];b:{if((b|0)>=0){break b}if(b>>>0<4294967234){break a}if(b>>>0<=4294967263){if((d-a|0)<2){break a}f=2;if((w[a+1|0]&192)==128){break b}break a}g=b&255;c:{d:{if(b>>>0<=4294967279){if((d-a|0)<3){break a}h=w[a+2|0];b=w[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((b&224)==160){break c}break a}if((b&192)!=128){break a}break c}if((d-a|0)<4|b>>>0>4294967284){break a}f=w[a+3|0];h=w[a+2|0];b=w[a+1|0];e:{f:{switch(g-240|0){case 0:if((b+112&255)>>>0<48){break e}break a;case 4:if((b&240)==128){break e}break a;default:break f}}if((b&192)!=128){break a}}if((h&192)!=128|(f&192)!=128){break a}f=4;if((g<<18&1835008|(b&48)<<12)>>>0>1114111){break a}break b}if((b&224)!=128){break a}}f=3;if((h&192)!=128){break a}}i=i+1|0;a=a+f|0;continue}break}return a-c|0}function wu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=cb-560|0;cb=f;u[f+558>>1]=b;a:{if((b-256&65535)>>>0<65281){break a}e=((b<<2)+a|0)+900380|0;b=v[e>>2];b:{if(b){c=DO(f,c);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;d=w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24);e=w[c+7|0]|w[c+8|0]<<8|(w[c+9|0]<<16|w[c+10|0]<<24);t[b+7|0]=e;t[b+8|0]=e>>>8;t[b+9|0]=e>>>16;t[b+10|0]=e>>>24;t[b+11|0]=d;t[b+12|0]=d>>>8;t[b+13|0]=d>>>16;t[b+14|0]=d>>>24;t[b+15|0]=w[c+15|0];d=v[c+44>>2];v[b+40>>2]=v[c+40>>2];v[b+44>>2]=d;d=v[c+36>>2];v[b+32>>2]=v[c+32>>2];v[b+36>>2]=d;d=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=d;d=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=d;hy(b+48|0,c+48|0);hy(b+68|0,c+68|0);hy(b+88|0,c+88|0);ic(b+108|0,c+108|0,448);d=b;Jt(c);break b}b=Dg(556);if(!b){v[e>>2]=0;break a}d=DO(b,c);v[e>>2]=b}g=a,h=x[ie(a+480192|0,f+558|0)>>1],u[g+480192>>1]=h}cb=f+560|0;return d|0}function tga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=cb-16|0;cb=e;u[e+12>>1]=0;v[e+8>>2]=0;n=B(c,d);k=4;while(1){if((d|0)!=(l|0)){i=b+l|0;o=n+i|0;while(1){if(i>>>0<o>>>0){t[e+7|0]=0;zR(a,e+15|0,e+12|0,e+7|0);g=w[e+7|0];f=x[e+12>>1];c=k;a:{b:{while(1){if(!(c&255)){break b}c:{h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!mf(a,e+6|0)){break c}f=w[e+6|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}u[e+12>>1]=0;break a}u[e+12>>1]=f}c=1;h=g&255;e:{if(h>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(h>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;t[e+15|0]=f;g=f-1^(g&254)>>>1;f=g+w[e+8|0]|0;t[e+7|0]=f;t[i|0]=f;v[e+8>>2]=((g>>1)-(j<<24>>24)|0)+(f<<24>>24<<1);i=d+i|0;k=(c+k&254)>>>1|0;c=-128;j=v[e+8>>2];f:{if((j|0)>=-128){c=127;if((j|0)<128){break f}}v[e+8>>2]=c}j=f;continue}break}l=l+1|0;continue}break}cb=e+16|0}function Rea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=cb-144|0;cb=g;lo(a);a:{b:{if(!gg(a,64)){break b}c:{d:{if(!ql(a,60)){break d}if(!kQ(a,14226)){break d}c=15;d=450;break c}lo(a);if(!gg(a,128)){break b}b=0;if(!ql(a,124)){break a}if(!kQ(a,15423)){break a}c=31;d=930}lo(a);b=0;e:{while(1){if((b&65535)>>>0>=c>>>0){break e}b=b+1|0;if(iQ(a)>>>0<=131072){continue}break}b=0;break a}Yc(a,4);if(!gg(a,2)){break b}b=0;e=cb-16|0;cb=e;c=cb-16|0;cb=c;Km(c+8|0,e+8|0);f=v[c+12>>2];cd(c,a,v[c+8>>2],f);h=v[c+4>>2];if((f|0)==(h|0)){Yc(a,v[c+12>>2])}cb=c+16|0;if((f|0)==(h|0)){c=e+8|0;i=wb(w[c|0]|w[c+1|0]<<8)}cb=e+16|0;if(i>>>0<178){break a}b=-1;if(!gg(a,d)){break a}Yc(a,d);d=cb-16|0;cb=d;e=g+8|0;iR(d+8|0,e);c=v[d+12>>2];cd(d,a,v[d+8>>2],c);f=v[d+4>>2];if((f|0)==(c|0)){Yc(a,v[d+12>>2])}cb=d+16|0;a=(c|0)==(f|0);if(!a){Qz(e)}if(!a){break a}b=jQ(g+8|0);break a}b=-1}cb=g+144|0;return b|0}function Mda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=cb-32|0;cb=f;g=cb-16|0;cb=g;c=a+33|0;e=c+206|0;v[b>>2]=w[e|0]|w[e+1|0]<<8;ZK(c,b+48|0,w[c+192|0],w[c+200|0],w[c+194|0],w[c+195|0],w[c+196|0],0);ZK(c,b+68|0,w[c+193|0],w[c+201|0],w[c+197|0],w[c+198|0],w[c+199|0],1);e=b+236|0;while(1){if((d|0)==96){if(w[c+208|0]){t[b+31|0]=w[c+209|0]+1;e=w[b+31|0];a:{b:{if(!e){d=1;break b}d=16;if(e>>>0<17){break a}}t[b+31|0]=d}d=c+210|0;u[g+14>>1]=w[d|0]|w[d+1|0]<<8;u[g+12>>1]=127;i=b,j=w[Kc(g+14|0,g+12|0)|0]+1|0,t[i+30|0]=j}t[b+33|0]=w[c+212|0];cb=g+16|0}else{i=Xb(e,d+12|0),j=w[c+d|0],u[i>>1]=j;d=d+1|0;continue}break}c=b+236|0;while(1){if((h|0)!=96){e=Xb(c,h+12|0);d=w[(a+h|0)+33|0];u[e>>1]=d>>>0<(w[a+27|0]|w[a+28|0]<<8)>>>0?d:0;h=h+1|0;continue}break}Bl(f,3,a+4|0);c=f+16|0;xc(c,v[f>>2],v[f+4>>2],w[f+8|0]);uc(b+492|0,c);rb(c);if(!w[a+241|0]){t[b+30|0]=w[a+26|0]}cb=f+32|0}function Cu(a){var b=0,c=0,d=0,e=0,f=0;d=cb-16|0;cb=d;a:{if(w[a+3|0]!=19){break a}t[a+3|0]=20;c=a+5|0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=w[a+5|0];switch(b>>>4|0){case 4:break j;case 3:break k;case 2:break l;case 1:break m;case 0:break n;case 13:break b;case 12:break c;case 11:break d;case 10:break e;case 9:break f;case 7:break g;case 6:break h;case 5:break i;default:break a}}t[a+3|0]=0;break a}t[a+3|0]=2;t[a+5|0]=b|240;break a}t[a+3|0]=3;t[a+5|0]=b|240;break a}t[c|0]=b&15|16;break a}t[c|0]=b&3|48;break a}t[c|0]=b&15|32;break a}t[c|0]=b&15|176;break a}t[c|0]=b&3|64;break a}t[a+3|0]=15;t[a+5|0]=b&15;break a}if(b&15){t[a+3|0]=11;t[a+5|0]=b<<4|15;break a}t[a+3|0]=0;break a}if(b&15){t[a+3|0]=11;t[d+15|0]=14;e=a,f=w[Tb(c,d+15|0)|0]|240,t[e+5|0]=f;break a}t[a+3|0]=0;break a}if((b|0)!=192){break a}t[a|0]=254;t[a+3|0]=0;break a}if((b|0)!=208){break a}t[a+3|0]=0}cb=d+16|0}function eba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;l=cb-16|0;cb=l;d=v[ac(l+8|0,yb(v[a+4>>2]))>>2];i=cb-32|0;cb=i;e=d;d=v[a>>2];h=(go(e,yb(d))<<1)+d|0;g=jt(b,c);a:{if((g|0)<=0){break a}e=v[xb(a)>>2];d=v[a+4>>2];if((g|0)<=e-d>>1){f=d-h|0;j=f>>1;b:{if((j|0)>=(g|0)){e=c;break b}v[i+8>>2]=b;v[i+8>>2]=v[i+8>>2]+(j<<1);e=v[i+8>>2];mO(a,e,c,g-j|0);if((f|0)<=0){break a}}m=cb-16|0;cb=m;j=v[a+4>>2];f=(j-((g<<1)+h|0)|0)+h|0;g=Xh(m,a,d-f>>1);k=v[g+4>>2];c=f;while(1){if(c>>>0>=d>>>0){dc(g);iq(h,f,j);cb=m+16|0}else{Mi(k,x[c>>1]);k=k+2|0;v[g+4>>2]=k;c=c+2|0;continue}break}Hn(b,e,h);break a}f=xb(a);f=Mj(i+8|0,Nj(a,Fc(v[a>>2],d)+g|0),h-v[a>>2]>>1,f);d=cb-16|0;cb=d;e=uo(d,f+8|0,jt(b,c));c=v[e>>2];while(1){if(v[e+4>>2]!=(c|0)){Mi(c,x[b>>1]);c=v[e>>2]+2|0;v[e>>2]=c;b=b+2|0;continue}break}Gd(e);cb=d+16|0;h=sO(a,f,h);Pi(f)}yb(h);cb=i+32|0;cb=l+16|0;return a|0}function Eba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=cb-16|0;cb=g;v[g+12>>2]=1;a:{if(Tn(a)){c=v[a>>2];j=ag(c,v[a+4>>2]);v[g+8>>2]=j;k=v[Bb(g+12|0,g+8|0)>>2];while(1){if(k){k=k-1|0;if((b|0)!=(c|0)){d=yb(v[b>>2]);h=yb(v[b+4>>2]);f=cb-16|0;cb=f;i=uB(d,h);b:{if(i>>>0<=Lm(c)>>>0){v[f+8>>2]=h;l=v[c>>2];e=Fc(l,v[c+4>>2]);m=e>>>0>=i>>>0;if(m){e=h}else{v[f+8>>2]=d;vO(f+8|0,e);l=v[c>>2];e=v[f+8>>2]}d=Qi(d,e,l);if(!m){xO(c,v[f+8>>2],h,i-Fc(v[c>>2],v[c+4>>2])|0);break b}Nd(c,d);break b}wO(c);Lz(c,Nj(c,i));xO(c,d,h,i)}cb=f+16|0;Ho(c+12|0,b+12|0);u[c+28>>1]=x[b+28>>1]}c=c+32|0;continue}break}if(!j){hz(a,1-j|0,b);break a}nO(a,v[a>>2]+32|0);break a}if(v[a>>2]){pO(a);d=v[a>>2];Tn(a);zb(d);n=xb(a),o=0,v[n>>2]=o;v[a>>2]=0;v[a+4>>2]=0}e=Qp(a,1);if(nP()>>>0<e>>>0){nd();L()}d=kP(e);v[a>>2]=d;v[a+4>>2]=d;n=xb(a),o=d+(e<<5)|0,v[n>>2]=o;hz(a,1,b)}cb=g+16|0}function kF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=cb-32|0;cb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;i=e;h=c&33554431;if(!(!e&(h|0)==16777216?!(a|b):!e&h>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(h^16777216|a|(b|i)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;Tf(g+16|0,a,b,c,e,f-16129|0);qm(g,a,b,c,e,16257-f|0);b=v[g+8>>2];e=(v[g+12>>2]&33554431)<<7|b>>>25;h=v[g>>2]|(v[g+16>>2]|v[g+24>>2]|(v[g+20>>2]|v[g+28>>2]))!=0;f=v[g+4>>2];a=0;b=b&33554431;if(!(!a&(b|0)==16777216?!(h|f):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|h|(a|f)){break a}e=(e&1)+e|0}cb=g+32|0;return l(2,d&-2147483648|e),q()}function u9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=v[a>>2];d=vk(e,v[a+4>>2]);if(d>>>0<b>>>0){h=cb-32|0;cb=h;a:{b:{e=b-d|0;b=v[xb(a)>>2];f=v[a+4>>2];c:{if(e>>>0<=(b-f|0)/52>>>0){Lx(a,e,c);break c}d=xb(a);f=MK(a,vk(v[a>>2],f)+e|0);g=vk(v[a>>2],v[a+4>>2]);b=h+8|0;lf(b+12|0,d);if(f){d=KK(f)}else{d=0}v[b>>2]=d;g=d+B(g,52)|0;v[b+8>>2]=g;v[b+4>>2]=g;i=mc(b),j=d+B(f,52)|0,v[i>>2]=j;v[22440]=0;U(904,b|0,e|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}f=v[a>>2];c=v[a+4>>2];e=b+4|0;while(1){if((c|0)!=(f|0)){d=v[e>>2]-52|0;c=c-52|0;lk(d,c);v[d+20>>2]=v[c+20>>2];g=v[c+16>>2];v[d+12>>2]=v[c+12>>2];v[d+16>>2]=g;lk(d+24|0,c+24|0);zc(d+36|0,c+36|0);v[d+48>>2]=v[c+48>>2];v[e>>2]=v[e>>2]-52;continue}break}ec(a,e);ec(a+4|0,b+8|0);ec(xb(a),mc(b));v[b>>2]=v[b+4>>2];JK(b)}cb=h+32|0;break a}a=P()|0;O()|0;JK(b);S(a|0);L()}return}if(b>>>0<d>>>0){NK(a,e+B(b,52)|0)}}function jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;f=cb-16|0;cb=f;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){g=v[f+8>>2];m=((((v[f+12>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+j|0;e=(((g>>>16|0)+4&131064)<<1)+b|0;n=u[e+38>>1];o=u[e+36>>1];p=u[e+34>>1];q=u[e+32>>1];r=u[e+30>>1];s=u[e+28>>1];t=u[e+26>>1];w=u[e+24>>1];g=0;while(1){if((g|0)!=2){e=(g<<1)+m|0;v[(g<<2)+f>>2]=(((((B(u[e+8>>1],p)+B(u[e+4>>1],q)|0)+B(u[e+12>>1],o)|0)+B(u[e+16>>1],n)|0)/2|0)+((((B(u[e-8>>1],t)+B(u[e-12>>1],w)|0)+B(u[e-4>>1],s)|0)+B(u[e>>1],r)|0)/2|0)|0)/16384;g=g+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],i);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],h);Jb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;cb=f+16|0}function Hea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=gd(d,v[a+4>>2]);if(c>>>0<b>>>0){f=cb-32|0;cb=f;c=b-c|0;b=v[xb(a)>>2];d=v[a+4>>2];a:{if(c>>>0<=(b-d|0)/12>>>0){d=cb-16|0;cb=d;b=tt(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){dc(b);cb=d+16|0}else{MP(a);a=a+12|0;v[b+4>>2]=a;continue}break}break a}b=xb(a);b=Ll(f+8|0,Io(a,gd(v[a>>2],d)+c|0),gd(v[a>>2],v[a+4>>2]),b);e=cb-16|0;cb=e;d=NP(e,b+8|0,c);c=v[d>>2];while(1){if(v[d+4>>2]!=(c|0)){MP(c);c=v[d>>2]+12|0;v[d>>2]=c;continue}break}Gd(d);cb=e+16|0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-12|0;lk(v[d>>2]-12|0,c);v[d>>2]=v[d>>2]-12;continue}break}ec(a,d);ec(a+4|0,b+8|0);ec(xb(a),mc(b));v[b>>2]=v[b+4>>2];a=v[b+4>>2];while(1){c=v[b+8>>2];if((c|0)!=(a|0)){c=c-12|0;v[b+8>>2]=c;OP(c);continue}break}a=v[b>>2];if(a){br(b);zb(a)}}cb=f+32|0;return}if(b>>>0<c>>>0){PP(a,d+B(b,12)|0)}}function N8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=C(0),i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0),x=C(0),y=0,A=0,B=C(0);i=v[a+4220>>2];if(i){g=a+44|0;j=Ud(g,0);k=Ud(g,1);l=jd(g,0);m=jd(g,1);n=d;while(1){if(n){f=v[a+4208>>2];o=v[a+4224>>2];e=o-v[a+4228>>2]|0;e=(e>>31&i)+e<<1;y=Ib(f,e);p=z[Ib(f,e|1)>>2];t=z[a+4244>>2];q=z[y>>2];u=z[a+4252>>2];r=z[k>>2];w=z[a+4248>>2];s=z[j>>2];x=z[a+4256>>2];h=C(C(p*t)+C(C(q*u)+C(C(r*w)+C(s*x))));e=o<<1;A=Ib(f,e),B=C(D(h))<C(1.0000000195414814e-24)?C(0):h,z[A>>2]=B;h=C(C(q*t)+C(C(p*u)+C(C(s*w)+C(r*x))));A=Ib(f,e|1),B=C(D(h))<C(1.0000000195414814e-24)?C(0):h,z[A>>2]=B;f=o+1|0;v[a+4224>>2]=(f|0)==(i|0)?0:f;z[l>>2]=C(s*z[a+4240>>2])+C(q*z[a+4236>>2]);z[m>>2]=C(r*z[a+4240>>2])+C(p*z[a+4236>>2]);n=n-1|0;m=m+4|0;l=l+4|0;k=k+4|0;j=j+4|0;continue}else{ti(a,b,c,jd(g,0),jd(g,1),d)}break}}}function gea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=cb-16|0;cb=g;d=v[b>>2];e=vj(d,v[b+4>>2]);a:{if(e>>>0<c>>>0){i=cb-32|0;cb=i;f=c-e|0;e=v[xb(b)>>2];d=v[b+4>>2];b:{if(f>>>0<=e-d>>4>>>0){h=cb-16|0;cb=h;d=ht(h,b,f);e=v[d+4>>2];f=v[d+8>>2];while(1){if((e|0)==(f|0)){dc(d);cb=h+16|0}else{eu(e);e=e+16|0;v[d+4>>2]=e;continue}break}break b}e=xb(b);e=rP(i+8|0,sP(b,vj(v[b>>2],d)+f|0),vj(v[b>>2],v[b+4>>2]),e);d=cb-16|0;cb=d;v[d>>2]=v[e+8>>2];h=v[e+8>>2];v[d+8>>2]=e+8;v[d+4>>2]=h+(f<<4);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){eu(f);f=v[d>>2]+16|0;v[d>>2]=f;continue}break}Gd(d);cb=d+16|0;Ad(b,e);d=v[e+4>>2];f=v[e+8>>2];while(1){if((d|0)!=(f|0)){f=f-16|0;v[e+8>>2]=f;continue}break}d=v[e>>2];if(d){br(e);zb(d)}}cb=i+32|0;break a}if(c>>>0<e>>>0){Nd(b,d+(c<<4)|0)}}if(Kb(a,c<<4)){c=v[b>>2];Ub(g+8|0,c,vj(c,v[b+4>>2])<<4);md(g,a,v[g+8>>2],v[g+12>>2])}cb=g+16|0}function Xv(a,b,c,d,e,f,g,h,i,j,k,l){a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break a}f=0;t[b|0]=0;a=v[e>>2];v[e>>2]=a+1;t[a|0]=46;if(!vb(h)){break b}a=v[j>>2];if((a-i|0)>159){break b}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!vb(h)){break c}if(!w[b|0]){break a}f=0;a=v[j>>2];if((a-i|0)>159){break b}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b;v[k>>2]=0;return 0}f=-1;a=Zv(l,l+128|0,a)-l|0;if((a|0)>124){break b}g=w[(a>>2)+79696|0];d:{e:{f=a&-5;if((f|0)!=88){if((f|0)!=96){break e}a=v[e>>2];if((a|0)!=(d|0)){f=-1;if((w[a-1|0]&95)!=(w[c|0]&127)){break b}}v[e>>2]=a+1;t[a|0]=g;return 0}t[c|0]=80;break d}d=t[c|0];if((d|0)!=(g&95)){break d}t[c|0]=d|128;if(!w[b|0]){break d}t[b|0]=0;if(!vb(h)){break d}b=v[j>>2];if((b-i|0)>159){break d}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c}b=v[e>>2];v[e>>2]=b+1;t[b|0]=g;f=0;if((a|0)>84){break b}v[k>>2]=v[k>>2]+1}return f}return-1}function xZ(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=v[116308];c=pc(b,v[116309]);if(c>>>0<a>>>0){f=cb-32|0;cb=f;e=a-c|0;b=v[116309];a:{if(e>>>0<=v[116310]-b>>2>>>0){UE(e);break a}g=Tv(465232);c=f+8|0;d=pc(v[116308],b)+e|0;b=cb-16|0;cb=b;v[b+12>>2]=d;b:{a=Qn();if(d>>>0<=a>>>0){d=vh(465232);if(d>>>0<a>>>1>>>0){v[b+8>>2]=d<<1;a=v[Pc(b+8|0,b+12|0)>>2]}cb=b+16|0;break b}nd();L()}d=pc(v[116308],v[116309]);lf(c+12|0,g);if(a){b=PE(v[c+16>>2],a)}else{b=0}v[c>>2]=b;d=b+(d<<2)|0;v[c+8>>2]=d;v[c+4>>2]=d;h=mc(c),i=b+(a<<2)|0,v[h>>2]=i;d=cb-16|0;cb=d;a=Fl(d,c+8|0,e);b=v[a>>2];while(1){if(v[a+4>>2]!=(b|0)){QE(b);b=v[a>>2]+4|0;v[a>>2]=b;continue}break}Gd(a);cb=d+16|0;a=c+4|0;Pn(v[116308],v[116309],a);ec(465232,a);ec(465236,c+8|0);ec(465240,mc(c));v[c>>2]=v[c+4>>2];RP(c);a=v[c>>2];if(a){SE(v[c+16>>2],a,Cz(c))}}cb=f+32|0;return}if(a>>>0<c>>>0){td(465232,b+(a<<2)|0)}}function ip(a){a=a|0;var b=0,c=0,d=C(0),e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);b=v[a+36>>2];if(!b){Ac(a+16|0);return}a:{b:{switch(x[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Ac(c);return}ak(c,b);b=u[a+28>>1];d=C(dm(a,(b<<16)+65536>>16)/dm(a,b));a=v[a+36>>2];d=te(d,C(C(1)/C(a+1>>>0)));b=1;while(1){if(a>>>0<b>>>0){break a}f=te(d,C(b>>>0));m=Ib(v[c>>2],b-1|0),n=f,z[m>>2]=n;b=b+1|0;continue};case 1:c=a+16|0;g=x[a+30>>1];if(g>>>0>1e3/(b>>>0)>>>0){Ac(c);return}ak(c,B(b,g));j=x[a+30>>1];l=wn(u[a+28>>1],j);c:while(1){if((h&65535)>>>0>=g>>>0){break a}b=1;e=wn(h+l<<16>>16,j)<<16;k=e>>16;d=C(dm(a,e+65536>>16)/dm(a,k));e=v[a+36>>2];d=te(d,C(C(1)/C(e+1>>>0)));while(1){i=b&65535;if(e>>>0<i>>>0){h=h+1|0;continue c}else{f=te(d,C(i>>>0));m=Ib(v[c>>2],(B(e,k)+i|0)-1|0),n=f,z[m>>2]=n;b=b+1|0;continue}}};case 0:Ac(a+16|0);return;default:break b}}Ac(a+16|0);v[a+36>>2]=0}}function fX(){var a=0,b=0,c=0,d=0;c=cb-32|0;cb=c;a:{a=Bc(c+16|0,14836);if(!vb(a)){break a}b:{if((Bg(a,14732)|0)!=-1){b=Bg(a,14732);v[22440]=0;W(132,c|0,a|0,b+1|0,-1);b=v[22440];v[22440]=0;if((b|0)==1){break b}tc(a,c);rb(c)}if((Bg(a,16830)|0)!=-1){b=Bg(a,16830);v[22440]=0;W(132,c|0,a|0,b+1|0,-1);b=v[22440];v[22440]=0;if((b|0)==1){break b}tc(a,c);rb(c)}if((Bg(a,13945)|0)!=-1){b=Bg(a,13945);v[22440]=0;W(132,c|0,a|0,0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break b}tc(a,c);rb(c)}if((Bg(a,13794)|0)!=-1){b=Bg(a,13794);v[22440]=0;W(132,c|0,a|0,0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break b}tc(a,c);rb(c)}if((Bg(a,13837)|0)!=-1){b=Bg(a,13837);v[22440]=0;W(132,c|0,a|0,0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break b}tc(a,c);rb(c)}v[22440]=0;b=T(133,a|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){break a}}c=P()|0;O()|0;rb(a);S(c|0);L()}rb(a);cb=c+32|0;return b|0}function GB(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if((w[a|0]-16&255)>>>0>=241){f=a+1954|0;d=a+1698|0;a:{while(1){if((d|0)==(f|0)){d=0;f=0;while(1){if((d|0)==32){h=1;break a}b=B(d,13)+a|0;if(w[b+14|0]){break a}e=(d<<4)+a|0;c=e+418|0;if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){break a}c=e+422|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);if(w[b+942|0]|c>>>0>1048575){break a}b=B(d,11)+a|0;g=b+1346|0;if(w[g|0]>15|w[b+1351|0]>3|w[b+1356|0]>3){break a}b:{c:{d:{if(c){b=e+430|0;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(b>>>0<=1048574){if(b>>>0>c>>>0){break a}e=e+426|0;if(b>>>0<(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0){break a}}b=1;if(f){break b}if(c){break c}break d}b=1;if(f){break b}}if(Mb(g,26365,11)){break c}b=0;break b}b=1}f=b;d=d+1|0;continue}}e=t[d|0];d=d+1|0;if((e|0)>=-1){continue}break}return 0}a=f&h}else{a=0}return a}function Xl(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;Vk(a);a:{b:{c:{f=v[b+32>>2];d:{if(!f){e=v[b+2084>>2];if(e){break d}break b}c=v[b+4>>2];if((c|0)<9){break c}e=v[b+2084>>2];if(!e){break c}}h=v[a+1392>>2];j=Wl(h);d=v[b+2092>>2];c=0;while(1){if((d|0)>=2){f=d>>>1|0;i=f+c|0;g=y[(i<<2)+e>>2]>j>>>0;d=g?f:d-f|0;c=g?c:i;continue}break}d=v[a+1396>>2];c=w[b+23|0]?c:v[v[b+2088>>2]+(c<<2)>>2];b=w[c+v[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}v[a+1392>>2]=h>>>b;b=d-b|0}v[a+1396>>2]=b;return c}if(w[b+23|0]){break a}e=(c|0)>0?c:0;while(1){if((d|0)!=(e|0)){f:{c=w[v[b+8>>2]+d|0];if((c|0)==255){break f}g=v[a+1392>>2];if(v[f+(d<<2)>>2]!=(g&(-1<<c^-1))){break f}e=v[a+1396>>2];if((e|0)>=(c|0)){v[a+1392>>2]=g>>>c;v[a+1396>>2]=e-w[v[b+8>>2]+d|0];return d}v[a+1396>>2]=0;break b}d=d+1|0;continue}break}Zb(a,21);v[a+1396>>2]=0}return-1}ca(11414,13226,1705,5448);L()}function x2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=cb-32|0;cb=c;d=v[a>>2];a=v[d>>2];Pf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];g=v[a+8>>2];d=v[a+4>>2];i=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=cb-32|0;cb=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(Of(c)>>>0<g>>>0){break b}j=b+12|0;c:while(1){b=0;if((e|0)==(g|0)){break a}while(1)if((b|0)==(d|0)){e=e+1|0;continue c}else{k=a,l=+(tm(ne(mg(A[ah(i,d,b,e)>>3])*134217728))+bd(Tr(j),21)|0)*7.450580596923828e-9,A[k+24>>3]=l;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;h=ne(A[Fg(a+24|0,a+16|0,a+8|0)>>3]*32768);d:{if(D(h)<2147483648){f=~~h;break d}f=-2147483648}f=Wc(f);k=pn(c,b,e),m=f,u[k>>1]=m;b=b+1|0;continue}}}ca(7157,9074,78,8754);L()}ca(5870,9074,80,8754);L()}cb=a+32|0;cb=c+32|0}function n2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=cb-32|0;cb=c;d=v[a>>2];a=v[d>>2];Pf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];g=v[a+8>>2];d=v[a+4>>2];i=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=cb-32|0;cb=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(Of(c)>>>0<g>>>0){break b}j=b+12|0;c:while(1){b=0;if((e|0)==(g|0)){break a}while(1)if((b|0)==(d|0)){e=e+1|0;continue c}else{k=a,l=+(tm(ne(mg(A[ah(i,d,b,e)>>3])*134217728))+bd(Tr(j),21)|0)*7.450580596923828e-9,A[k+24>>3]=l;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;h=ne(A[Fg(a+24|0,a+16|0,a+8|0)>>3]*32768);d:{if(D(h)<2147483648){f=~~h;break d}f=-2147483648}f=Wc(f);k=on(c,b,e),m=f,u[k>>1]=m;b=b+1|0;continue}}}ca(7157,9074,78,8754);L()}ca(5870,9074,80,8754);L()}cb=a+32|0;cb=c+32|0}function RI(a,b){var c=0,d=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){a:{v[22440]=0;Z(837,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){a=v[c+4>>2];if(v[a>>2]?a:0){d=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(d|0)){b=b-4|0;qg(b);continue}break}v[a+4>>2]=d;b=v[a>>2];vh(a);zb(b)}zb(a);v[c+4>>2]=0;oy(c+1298408|0);Gs(c+1298344|0);rb(c+1298332|0);rb(c+1298320|0);rb(c+1298308|0);Fs(c+1298304|0);Es(c+1298300|0);xp(c+1298264|0);Ms(c+1074376|0);b=c+946300|0;a=c+906300|0;while(1){b=up(b-160|0);if((a|0)!=(b|0)){continue}break}qO(c+484360|0);ny(c+484344|0);fc(c+480248|0);break a}V(0)|0;O()|0;oy(c+1298408|0);Gs(c+1298344|0);rb(c+1298332|0);rb(c+1298320|0);rb(c+1298308|0);Fs(c+1298304|0);Es(c+1298300|0);xp(c+1298264|0);Ms(c+1074376|0);b=c+946300|0;a=c+906300|0;while(1){b=up(b-160|0);if((a|0)!=(b|0)){continue}break}qO(c+484360|0);ny(c+484344|0);fc(c+480248|0);Lb();L()}}zb(c)}}function Vl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=cb-16|0;cb=d;v[a+4>>2]=0;ji(d+8|0,a,1);if(Ed(w[d+8|0])){a:{b:{c:{if((b|0)==2147483647){while(1){b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[22440]=0;b=T(106,b|0)|0;c=v[22440];v[22440]=0;d:{if((c|0)!=1){if(!hc(b,-1)){break d}break b}break c}v[a+4>>2]=v[a+4>>2]+1;continue}}c=v[a+4>>2];while(1){if((b|0)<=(c|0)){break a}c=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[22440]=0;c=T(106,c|0)|0;f=v[22440];v[22440]=0;if((f|0)!=1){if(hc(c,-1)){break b}c=v[a+4>>2]+1|0;v[a+4>>2]=c;continue}break}}b=V(0)|0;O()|0;_(b|0)|0;e=1;ii(v[v[a>>2]-12>>2]+a|0,1);e:{f:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22440]=0;X(107);a=v[22440];v[22440]=0;if((a|0)!=1){break e}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)==1){break f}S(a|0);L()}$();break a}V(0)|0;O()|0;Lb()}L()}e=2}Mg(v[v[a>>2]-12>>2]+a|0,e)}cb=d+16|0;return a|0}function kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;f=cb-16|0;cb=f;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){g=v[f+8>>2];m=(((v[f+12>>2]&2147483647)<<1|g>>>31)&-2)+j|0;e=(((g>>>16|0)+4&131064)<<1)+b|0;n=u[e+38>>1];o=u[e+36>>1];p=u[e+34>>1];q=u[e+32>>1];r=u[e+30>>1];s=u[e+28>>1];w=u[e+26>>1];x=u[e+24>>1];g=0;while(1){if((g|0)!=2){e=g+m|0;v[(g<<2)+f>>2]=(((((B(t[e+4|0],p)+B(t[e+2|0],q)|0)+B(t[e+6|0],o)|0)+B(t[e+8|0],n)<<8)/2|0)+((((B(t[e-4|0],w)+B(t[e-6|0],x)|0)+B(t[e-2|0],s)|0)+B(t[e|0],r)<<8)/2|0)|0)/16384;g=g+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],i);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],h);Jb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;cb=f+16|0}function xfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=cb+-64|0;cb=c;n=c,o=_e(a)>>>5|0,u[n+32>>1]=o;u[c+16>>1]=3999;i=b+480190|0;d=x[Kc(c+32|0,c+16|0)>>1];u[i>>1]=d;j=c+58|0;k=c+56|0;l=c+62|0;g=c+52|0;m=c+60|0;h=1;while(1){f=h&65535;if(f>>>0<=d>>>0){d=Fi(b,f);e=c+32|0;zt(a,e);ed(d,0);Bj(c,2,e);e=c+16|0;xc(e,v[c>>2],v[c+4>>2],w[c+8|0]);uc(((f<<5)+b|0)+946304|0,e);rb(e);v[d+24>>2]=8287;n=c,o=wb(w[m|0]|w[m+1|0]<<8),u[n+16>>1]=o;u[c>>1]=64;n=d,o=x[Kc(e,c)>>1]<<2,u[n+30>>1]=o;n=d,o=Wb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))&-2,v[n>>2]=o;e=wb(w[l|0]|w[l+1|0]<<8);n=Ib(d+68|0,0),o=e,v[n>>2]=o;e=wb(w[k|0]|w[k+1|0]<<8);f=wb(w[j|0]|w[j+1|0]<<8);a:{if(f>>>0<2){break a}f=e+f<<1;if(f>>>0>y[d>>2]){break a}v[d+16>>2]=f;v[d+12>>2]=e<<1;u[d+34>>1]=x[d+34>>1]|8}h=h+1|0;d=x[i>>1];continue}break}cb=c- -64|0}function XC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=cb-32|0;cb=c;v[22440]=0;e=Q(13,c+24|0,462792)|0;d=v[22440];v[22440]=0;a:{b:{c:{if((d|0)!=1){d:{e:{if(!w[e|0]){break e}f=Ni(c+8|0,462792);d=v[v[115698]-12>>2]+462792|0;g=v[d+4>>2];v[22440]=0;h=T(14,d|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break d}f=v[f>>2];v[22440]=0;b=a+b|0;a=la(15,f|0,a|0,((g&176)==32?b:a)|0,b|0,d|0,h|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break d}v[c+16>>2]=a;if(!Mu(c+16|0)){break e}a=v[v[115698]-12>>2];v[22440]=0;R(16,a+462792|0,5);a=v[22440];v[22440]=0;if((a|0)!=1){break e}break d}xk(e);break b}a=V(0)|0;O()|0;xk(e);break c}a=V(0)|0;O()|0}_(a|0)|0;a=v[v[115698]-12>>2];v[22440]=0;Z(17,a+462792|0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$()}cb=c+32|0;return}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)==1){V(0)|0;O()|0;Lb();L()}S(a|0);L()}function daa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=cb-32|0;cb=d;e=Db(d+16|0);a:{b:{c:{if(c>>>0<64){break c}v[22440]=0;c=T(191,b|0)|0;f=v[22440];v[22440]=0;d:{if((f|0)!=1){v[d+12>>2]=c;if((c|0)>0){break d}v[22440]=0;Q(56,a|0,21685)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break b}}break a}v[22440]=0;c=T(204,b|0)|0;f=v[22440];v[22440]=0;if((f|0)!=1){g=d,h=Ei(c),v[g+8>>2]=h;c=v[ld(d+12|0,d+8|0)>>2];v[22440]=0;R(47,e|0,c|0);c=v[22440];v[22440]=0;if((c|0)!=1){break c}}break a}e:{while(1){f:{v[22440]=0;c=T(208,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break f}if(!c){break e}v[22440]=0;Y(872,e|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=v[22440];v[22440]=0;if((c|0)!=1){continue}}break}break a}v[22440]=0;Q(190,b|0,4)|0;b=v[22440];v[22440]=0;if((b|0)==1){break a}zc(a,e)}rb(e);cb=d+32|0;return}a=P()|0;O()|0;rb(e);S(a|0);L()}function rp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=cb-16|0;cb=c;a:{b:{switch(w[a+480224|0]-1|0){default:b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2]<<1;f=kka(b,d,5e4,0);e=fb;b=v[Pc(c+8|0,c)>>2];b=yc(lka(f,e,b,b>>31),fb);v[a+1074404>>2]=b;break a;case 1:b=v[a+24620>>2];v[c+8>>2]=1;v[c+12>>2]=0;g=c,h=kka(v[a+1074420>>2],0,kka(v[a+1074408>>2],0,v[a+1074416>>2],0),fb),v[g>>2]=h;v[c+4>>2]=fb;b=kka(b,0,6e5,0);d=c+8|0;e=b;f=fb;b=Uu(v[d>>2],v[d+4>>2],v[c>>2],v[c+4>>2])?c:d;b=nka(e,f,v[b>>2],v[b+4>>2]);v[a+1074404>>2]=b;break a;case 0:break b}}b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2];f=kka(b,d,1e4,0);e=fb;b=v[Pc(c+8|0,c)>>2];b=yc(lka(f,e,b,b>>31),fb);v[a+1074404>>2]=b}e=a+1074404|0;a=v[a+480244>>2];b=kka(a,a>>31,b,b>>31)+32768|0;a=fb;a=yc(lka(b,b>>>0<32768?a+1|0:a,65536,0),fb);v[e>>2]=a?a:1;cb=c+16|0}function lN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{e=cb-16|0;cb=e;d=Db(a);a=fd(b);v[e+8>>2]=a;f=gf(b);b=0;b:{while(1){c:{if(!Qb(a,f)){if(!b){break c}v[22440]=0;R(50,d|0,65533);a=v[22440];v[22440]=0;if((a|0)!=1){break c}break b}a=w[a|0];d:{if(!b){if(!(a&128)){b=0;v[22440]=0;R(50,d|0,a|0);a=v[22440];v[22440]=0;if((a|0)!=1){break d}break b}if((a&224)==192){c=a&31;b=1;break d}if((a&240)==224){c=a&15;b=2;break d}if((a&248)==240){c=a&7;b=3;break d}c=0;v[22440]=0;R(50,d|0,65533);a=v[22440];v[22440]=0;b=0;if((a|0)==1){break b}break d}if((a&192)!=128){c=0;v[22440]=0;R(50,d|0,65533);g=v[22440];v[22440]=0;b=0;if((g|0)==1){break b}}a=a&63|c<<6;b=b-1|0;if(b){c=a;break d}c=0;v[22440]=0;R(50,d|0,a|0);a=v[22440];v[22440]=0;b=0;if((a|0)==1){break b}}Fe(e+8|0);a=v[e+8>>2];continue}break}cb=e+16|0;break a}a=P()|0;O()|0;Vc(d);S(a|0);L()}}function o4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=cb-16|0;cb=d;v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22440]=0;R(1039,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break i}c=v[d>>2];e=gd(c,v[d+4>>2]);if(e>>>0<2147483647){break h}c=aa(8)|0;v[22440]=0;Q(1025,c|0,7389)|0;b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;U(121,c|0,88708,170);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}if((b|0)<0|(b|0)>=(e|0)){a=21685}else{a=Fb(rd(c,b))}b=le(a);ad(d);break d}b=V(0)|0;O()|0;ba(c|0)}ad(d)}_(b|0)|0;b=0;v[22440]=0;W(958,11853,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break c}$()}cb=d+16|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Lb()}L()}S(a|0);L()}function k4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=cb-16|0;cb=d;v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22440]=0;R(1041,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break i}c=v[d>>2];e=gd(c,v[d+4>>2]);if(e>>>0<2147483647){break h}c=aa(8)|0;v[22440]=0;Q(1025,c|0,7389)|0;b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;U(121,c|0,88708,170);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}if((b|0)<0|(b|0)>=(e|0)){a=21685}else{a=Fb(rd(c,b))}b=le(a);ad(d);break d}b=V(0)|0;O()|0;ba(c|0)}ad(d)}_(b|0)|0;b=0;v[22440]=0;W(958,11883,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break c}$()}cb=d+16|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Lb()}L()}S(a|0);L()}function c4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=cb-16|0;cb=d;v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22440]=0;R(1044,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break i}c=v[d>>2];e=gd(c,v[d+4>>2]);if(e>>>0<2147483647){break h}c=aa(8)|0;v[22440]=0;Q(1025,c|0,7389)|0;b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;U(121,c|0,88708,170);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}if((b|0)<0|(b|0)>=(e|0)){a=21685}else{a=Fb(rd(c,b))}b=le(a);ad(d);break d}b=V(0)|0;O()|0;ba(c|0)}ad(d)}_(b|0)|0;b=0;v[22440]=0;W(958,11979,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break c}$()}cb=d+16|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Lb()}L()}S(a|0);L()}function V4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=cb-16|0;cb=d;v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22440]=0;R(1024,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break i}c=v[d>>2];e=gd(c,v[d+4>>2]);if(e>>>0<2147483647){break h}c=aa(8)|0;v[22440]=0;Q(1025,c|0,7389)|0;b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;U(121,c|0,88708,170);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}if((b|0)<0|(b|0)>=(e|0)){a=21685}else{a=Fb(rd(c,b))}b=le(a);ad(d);break d}b=V(0)|0;O()|0;ba(c|0)}ad(d)}_(b|0)|0;b=0;v[22440]=0;W(958,11915,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break c}$()}cb=d+16|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Lb()}L()}S(a|0);L()}function N9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;ed(c,0);u[c+28>>1]=w[a+36|0]<<2;d=w[a+37|0];u[c+32>>1]=64;u[c+30>>1]=d<<2;d=a+40|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+44|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=w[b+151|0];if(d>>>0<=4){t[c+38|0]=w[d+42826|0]}d=b+152|0;d=w[d|0]|w[d+1|0]<<8;t[c+39|0]=d;e=b+156|0;e=(w[e|0]|w[e+1|0]<<8)>>>4|0;t[c+41|0]=e;b=b+154|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if((b|e)&255){t[c+39|0]=d^-1}b=a+38|0;a=w[b|0]|w[b+1|0]<<8;if(a&4){u[c+34>>1]=x[c+34>>1]|1;a=w[b|0]|w[b+1|0]<<8}if(a&8){u[c+34>>1]=x[c+34>>1]|2;a=w[b|0]|w[b+1|0]<<8}if(a&16){u[c+34>>1]=x[c+34>>1]|4;a=w[b|0]|w[b+1|0]<<8}if(a&32){u[c+34>>1]=x[c+34>>1]|32}}function C4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=cb-16|0;cb=d;v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22440]=0;R(1031,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break i}c=v[d>>2];e=gd(c,v[d+4>>2]);if(e>>>0<2147483647){break h}c=aa(8)|0;v[22440]=0;Q(1025,c|0,7389)|0;b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;U(121,c|0,88708,170);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}if((b|0)<0|(b|0)>=(e|0)){a=21685}else{a=Fb(rd(c,b))}b=le(a);ad(d);break d}b=V(0)|0;O()|0;ba(c|0)}ad(d)}_(b|0)|0;b=0;v[22440]=0;W(958,11818,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break c}$()}cb=d+16|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Lb()}L()}S(a|0);L()}function $3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=cb-16|0;cb=d;v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22440]=0;R(1045,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break i}c=v[d>>2];e=gd(c,v[d+4>>2]);if(e>>>0<2147483647){break h}c=aa(8)|0;v[22440]=0;Q(1025,c|0,7389)|0;b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;U(121,c|0,88708,170);b=v[22440];v[22440]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}if((b|0)<0|(b|0)>=(e|0)){a=21685}else{a=Fb(rd(c,b))}b=le(a);ad(d);break d}b=V(0)|0;O()|0;ba(c|0)}ad(d)}_(b|0)|0;b=0;v[22440]=0;W(958,11947,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break c}$()}cb=d+16|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Lb()}L()}S(a|0);L()}function lK(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0;o(+a);b=j(1)|0;c=j(0)|0;a:{b:{c:{d:{if((b|0)>0|(b|0)>=0){e=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|c)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(e>>>0>2146435071){break a}b=1072693248;k=-1023;if((e|0)!=1072693248){b=e;break b}if(c){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;c=j(0)|0;k=-1077}l(0,c|0);c=b+614242|0;l(1,(c&1048575)+1072079006|0);d=+n()+-1;f=d*(d*.5);g=d/(d+2);h=g*g;a=h*h;o(+(d-f));b=j(1)|0;j(0)|0;l(0,0);l(1,b|0);i=+n();m=i*1.4426950407214463;p=+((c>>>20|0)+k|0);q=m+p;a=g*(f+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+h*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+(d-i-f);a=q+(m+(p-q)+((a+i)*1.6751713164886512e-10+a*1.4426950407214463))}return a}function bV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=cb-16|0;cb=e;ed(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=xq(a+4|0,a);d=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=d;c=xq(a+8|0,a);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+8>>2]=f;c=a+15|0;g=(w[c|0]|w[c+1|0]<<8)<<1;v[b+24>>2]=g;c=w[c|0]|w[c+1|0]<<8?g:16726;v[b+24>>2]=c;g=a+14|0;h=b,i=(B(Eu(t[a+17|0],w[g|0]<<28>>24),c)>>>0)/8363|0,v[h+24>>2]=i;t[e+15|0]=w[a+18|0];t[e+14|0]=127;h=b,i=(((w[Tb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[h+30>>1]=i;c=w[g|0];if(c>>>0>=16){u[b+34>>1]=32;u[b+28>>1]=c&240}c=a+19|0;a=w[c|0];if(a&4){u[b+34>>1]=x[b+34>>1]|1;a=w[c|0]}a:{if(!(a&8)|d>>>0>=f>>>0){break a}f=x[b+34>>1];d=f|2;u[b+34>>1]=d;a=w[c|0];if(a&16){d=f|6;u[b+34>>1]=d;a=w[c|0]}if(!(a&64)){break a}u[b+34>>1]=d|128}cb=e+16|0}function yaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=cb-880|0;cb=b;c=Hb(a,0,76);v[c+84>>2]=0;v[c+88>>2]=0;v[c+80>>2]=256;u[c+76>>1]=65535;v[c+92>>2]=0;v[c+96>>2]=0;t[c+100|0]=1;e=c+223848|0;d=c+616|0;a=d;while(1){a=wP(a)+872|0;if((e|0)!=(a|0)){continue}break}e=Rb(c+223848|0);f=c+223860|0;uM(f);g=b+8|0;Hb(g,0,108);vz(b+120|0,48e3);Hb(b+664|0,0,72);t[b+754|0]=0;u[b+752>>1]=65535;t[b+746|0]=0;u[b+744>>1]=65535;t[b+738|0]=0;u[b+736>>1]=65535;v[b+748>>2]=0;v[b+740>>2]=0;Hb(b+756|0,0,103);v[b+868>>2]=0;v[b+872>>2]=0;t[b+875|0]=0;t[b+876|0]=0;t[b+877|0]=0;t[b+878|0]=0;v[b+860>>2]=0;v[b+864>>2]=0;t[b+859|0]=w[b+859|0]&128;a=((d+223232|0)-d|0)/872|0;while(1){if((a|0)>0){a=a-1|0;d=wp(d,g)+872|0;continue}break}v[22440]=0;R(551,e|0,32);a=v[22440];v[22440]=0;if((a|0)!=1){cb=b+880|0;return c|0}a=P()|0;O()|0;yp(f);_b(e);S(a|0);L()}function oT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;while(1){a:{g=c;if(!c){g=0;break a}c=g-1|0;if(!w[c+b|0]){continue}}break}b:{if((d|0)!=4){break b}c=0;while(1){if((c|0)==(g|0)){if((e|0)==(f|0)){d=2;if((e|0)==(h|0)){break b}}if(e){d=0;if(!f){break b}}d=e?3:f?1:3}else{c:{d:{e:{d=b+c|0;i=w[d|0];switch(i-10|0){case 0:break d;case 3:break e;default:break c}}e=e+1|0;break c}f=f+1|0}h=c?(w[d-1|0]==13&(i|0)==10)+h|0:h;c=c+1|0;continue}break}}e=0;f=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){c=((f&w[b+c|0]==13)+c|0)+1|0;e=e+1|0;continue}break}dg(a);at(a,e);f=(d|0)==1?32:13;h=d&-3?13:32;d=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){f:{g:{h:{i:{e=t[b+c|0];switch(e-10|0){case 1:case 2:break f;case 0:break g;case 3:break h;default:break i}}if(e){break f}e=32;break f}c=c+d|0;e=f;break f}e=h}Kp(a,e);c=c+1|0;continue}break}}function nH(a,b,c,d){var e=0,f=C(0),g=0,h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=0;e=cb-96|0;cb=e;o=(d|0)>0?d:0;while(1){if((j|0)!=(o|0)){z[e+48>>2]=-z[a>>2];z[e>>2]=z[a+68>>2];d=0;while(1){if((d|0)!=4){i=(e+48|0)+(d<<3)|0;g=(d<<4)+a|0;h=z[g+4>>2];f=z[g+8>>2];z[i+4>>2]=h+f;k=d<<1;z[(8-k<<2)+e>>2]=h-f;h=z[g+16>>2];f=z[g+12>>2];z[(7-k<<2)+e>>2]=h-f;z[i+8>>2]=-C(h+f);d=d+1|0;continue}break}mH(e+48|0);mH(e);z[e+4>>2]=-z[e+4>>2];z[e+12>>2]=-z[e+12>>2];z[e+20>>2]=-z[e+20>>2];z[e+28>>2]=-z[e+28>>2];g=0;while(1){if((g|0)!=9){d=g<<2;i=d+b|0;h=z[i>>2];f=z[d+(e+48|0)>>2];l=z[d+67120>>2];m=z[d+67156>>2];n=z[d+e>>2];z[i>>2]=C(f*l)-C(m*n);i=a+d|0;d=c+d|0;f=C(C(f*m)+C(n*l));z[i>>2]=C(h*z[d>>2])-C(z[d+36>>2]*f);z[(17-g<<2)+a>>2]=C(h*z[d+36>>2])+C(f*z[d>>2]);g=g+1|0;continue}break}b=b+36|0;a=a+72|0;j=j+1|0;continue}break}cb=e+96|0}function M5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=cb-32|0;cb=e;v[22440]=0;Z(971,a|0);d=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}v[22440]=0;Z(972,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break g}v[22440]=0;Z(972,c|0);d=v[22440];v[22440]=0;if((d|0)==1){break g}f=v[a+24>>2];v[22440]=0;d=Q(56,e+16|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;c=Q(56,e|0,c|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break f}v[22440]=0;W(987,f|0,d|0,c|0,1);b=v[22440];v[22440]=0;if((b|0)==1){break e}rb(c);rb(d);b=1;break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break d}b=V(0)|0;O()|0;rb(c)}rb(d)}_(b|0)|0;b=0;v[22440]=0;W(958,6412,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$()}cb=e+32|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function DM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=cb-16|0;cb=e;h=-1;a:{if(!by(a,b,2)){break a}f=v[b+656>>2];g=a+1074312|0;ub(e+8|0,g,31);b:{if(tb(v[v[e+8>>2]>>2],v[e+12>>2])){d=v[b+740>>2];if(d){break b}break a}d=v[b+740>>2]}ub(e+8|0,g,31);g=d-tb(v[v[e+8>>2]>>2],v[e+12>>2])|0;i=v[a+480180>>2];d=(i|0)==4096;j=f+88|0;f=d?64:(i|0)==16384?192:512;d=Lp(j,g,f,d?255:64)-(f>>>1|0)|0;if(w[b+746|0]&16){h=Cp(a,b,!(v[b+88>>2]&32768),d);break a}if(uj(v[b+656>>2])){if((d|0)==u[b+772>>1]){break a}k=b,l=Wc(d),u[k+772>>1]=l;t[b+851|0]=w[b+851|0]|64;break a}a=lj(a);v[e+8>>2]=d;c:{if((d|0)<0){v[e+8>>2]=0-d;Zh(e+8|0,255);a=(v[e+8>>2]<<2)+(a?38272:37248)|0;break c}Zh(e+8|0,255);a=(v[e+8>>2]<<2)+(a?37248:38272)|0}a=v[a>>2];b=a;d=a>>31;a=v[c>>2];k=c,l=yc(lka(kka(b,d,a,a>>31),fb,65536,0),fb),v[k>>2]=l}cb=e+16|0;return h}function wy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=x[a+480188>>1];h=d>>>0>256?d:256;f=a+1298300|0;c=d;a:{while(1){if((c|0)!=(h|0)){e=B(c,872)+a|0;if(!v[e+1075068>>2]){if(!dk(v[e+1075648>>2])|w[e+1075081|0]&24){break a}}if(w[e+1075081|0]&2){if(!Bd(f)){break a}if(!kM(v[f>>2],c&65535)){break a}}c=c+1|0;continue}break}e=0;f=65535;g=8388608;if(b>>>0<=255){b=B(b,872)+a|0;if(!v[b+1075688>>2]){c=65535;if(v[b+1075068>>2]){break a}}g=v[b+1075680>>2]|v[b+1075672>>2]<<9}while(1){if((d|0)==(h|0)){c=f;break a}b=B(d,872)+a|0;if(!(v[b+1075688>>2]?0:v[b+1075068>>2])){c=(v[b+1075680>>2]|v[b+1075672>>2]<<9)>>>(v[b+1075080>>2]>>>1&1)|0;b:{c:{if(c>>>0<g>>>0){b=v[(B(d,872)+a|0)+1075716>>2];break c}if((c|0)!=(g|0)){break b}b=v[(B(d,872)+a|0)+1075716>>2];if(e>>>0>=b>>>0){break b}}g=c;f=d;e=b}d=d+1|0;continue}break}c=d}return c&65535}function gw(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;a:{if(b&3){while(1){c=w[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}c=v[b>>2];b:{if((c^-1)&c-16843009&-2139062144){break b}while(1){if((c^1027423549)-16843009&(c^-1)&-2139062144){break b}c=v[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;d=w[b|0];if((d|0)!=61){b=c+1|0;if(d){continue}}break}b=c}f=b-a|0;if(!f){return 0}c:{if(w[a+f|0]){break c}e=v[115830];if(!e){break c}b=v[e>>2];if(!b){break c}while(1){d:{c=b;g=f;i=0;h=a;d=w[a|0];e:{if(!d){break e}while(1){f:{j=w[c|0];if(!j){break f}g=g-1|0;if(!g|(d|0)!=(j|0)){break f}c=c+1|0;d=w[h+1|0];h=h+1|0;if(d){continue}break e}break}i=d}if(w[c|0]==(i&255)){b=b+f|0;if(w[b|0]==61){break d}}b=v[e+4>>2];e=e+4|0;if(b){continue}break c}break}k=b+1|0}return k}function z6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0);i=cb-16|0;cb=i;j=a+44|0;if(Yh(j)){g=Ud(j,0);v[i+8>>2]=g;k=Ud(j,1);v[i+12>>2]=k;e=jd(j,0);v[i>>2]=e;h=jd(j,1);v[i+4>>2]=h;a:{if(z[a+4216>>2]!=C(.5)){g=d;b:while(1){k=0;if(!g){break a}while(1)if((k|0)==2){g=g-1|0;continue b}else{h=k<<2;e=h+(i+8|0)|0;f=v[e>>2];v[e>>2]=f+4;e=a+h|0;m=e+4248|0;p=z[m>>2];l=z[f>>2];q=z[a+4236>>2];r=z[a+4232>>2];s=z[a+4228>>2];t=z[a+4220>>2];u=z[a+4224>>2];f=e+4240|0;n=z[f>>2];z[m>>2]=n;z[f>>2]=l;f=e+4264|0;w=z[f>>2];e=e+4256|0;o=z[e>>2];z[f>>2]=o;l=C(C(C(C(s*p)+C(C(t*l)+C(u*n)))-C(r*o))-C(q*w));z[e>>2]=l;h=i+h|0;e=v[h>>2];v[h>>2]=e+4;z[e>>2]=l;k=k+1|0;continue}}}f=g;g=d<<2;ic(e,f,g);ic(h,k,g)}ti(a,b,c,jd(j,0),jd(j,1),d)}cb=i+16|0}function y4(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=cb-48|0;cb=c;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;a:{b:{c:{if((b|0)!=1){d=Db(c+32|0);v[22440]=0;Z(1036,c+16|0);b=v[22440];v[22440]=0;d:{e:{if((b|0)!=1){g=c,h=yb(v[c+16>>2]),v[g+8>>2]=h;e=1;while(1){f=yb(v[c+20>>2]);b=v[c+8>>2];if(!Qb(b,f)){b=le(Fb(d));ad(c+16|0);rb(d);break b}if(!e){v[22440]=0;Q(960,d|0,14707)|0;b=v[22440];v[22440]=0;if((b|0)==1){break e}b=v[c+8>>2]}v[22440]=0;Q(824,d|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break e}Vn(c+8|0);e=0;continue}}b=V(0)|0;O()|0;break d}b=V(0)|0;O()|0;ad(c+16|0)}rb(d);break c}b=V(0)|0;O()|0}_(b|0)|0;b=0;v[22440]=0;W(958,6594,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$()}cb=c+48|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);c=v[22440];v[22440]=0;if((c|0)==1){V(0)|0;O()|0;Lb();L()}S(a|0);L()}function T4(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=cb-48|0;cb=c;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;a:{b:{c:{if((b|0)!=1){d=Db(c+32|0);v[22440]=0;Z(1028,c+16|0);b=v[22440];v[22440]=0;d:{e:{if((b|0)!=1){g=c,h=yb(v[c+16>>2]),v[g+8>>2]=h;e=1;while(1){f=yb(v[c+20>>2]);b=v[c+8>>2];if(!Qb(b,f)){b=le(Fb(d));ad(c+16|0);rb(d);break b}if(!e){v[22440]=0;Q(960,d|0,14707)|0;b=v[22440];v[22440]=0;if((b|0)==1){break e}b=v[c+8>>2]}v[22440]=0;Q(824,d|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break e}Vn(c+8|0);e=0;continue}}b=V(0)|0;O()|0;break d}b=V(0)|0;O()|0;ad(c+16|0)}rb(d);break c}b=V(0)|0;O()|0}_(b|0)|0;b=0;v[22440]=0;W(958,7057,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$()}cb=c+48|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);c=v[22440];v[22440]=0;if((c|0)==1){V(0)|0;O()|0;Lb();L()}S(a|0);L()}function pd(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;a:{if(t[463604]&1){break a}if(!Xd(463604)){break a}b=cb-32|0;cb=b;b:{c:{while(1){e=(b+8|0)+(a<<2)|0;d=1<<a&2147483647;if(d|1){d=QF(a,d?14381:21685)}else{d=v[a<<2>>2]}v[e>>2]=d;if((d|0)!=-1){a=a+1|0;if((a|0)==6){break c}continue}break}break b}if(!PF(0)){c=85424;if(!Mb(b+8|0,85424,24)){break b}c=85448;if(!Mb(b+8|0,85448,24)){break b}a=0;if(!w[463376]){while(1){f=(a<<2)+463328|0,g=QF(a,21685),v[f>>2]=g;a=a+1|0;if((a|0)!=6){continue}break}t[463376]=1;v[115838]=v[115832]}c=463328;if(!Mb(b+8|0,463328,24)){break b}c=463352;if(!Mb(b+8|0,463352,24)){break b}c=Hd(24);if(!c){break b}}a=v[b+12>>2];v[c>>2]=v[b+8>>2];v[c+4>>2]=a;a=v[b+28>>2];v[c+16>>2]=v[b+24>>2];v[c+20>>2]=a;a=v[b+20>>2];v[c+8>>2]=v[b+16>>2];v[c+12>>2]=a}cb=b+32|0;v[115900]=c;Wd(463604)}return v[115900]}function CP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0;f=cb-16|0;cb=f;n=v[a+20>>2];e=x[a+34>>1]&65;v[f+8>>2]=e;v[f>>2]=e^65;h=a+24|0;o=d+1298224|0;e=d+1074992|0;i=lj(d);p=a+4|0;q=a+12|0;r=a+8|0;s=a+16|0;t=d+480180|0;while(1){if((e|0)!=(o|0)){if(v[e+104>>2]==(a|0)){if(v[e+16>>2]){v[e+16>>2]=b}if(y[e+4>>2]>c>>>0){v[e>>2]=0;v[e+4>>2]=0}if(v[e+76>>2]){qc(e+76|0,c)}d=ZC(e);g=v[(d?q:p)>>2];v[e+84>>2]=v[(d?s:r)>>2];v[e+80>>2]=g;d=v[e+88>>2]|v[f+8>>2];v[e+88>>2]=d;v[e+88>>2]=d&(v[f>>2]^-1);d=e+704|0;j=v[a+24>>2];a:{if(!v[e+704>>2]|!j){break a}if(vm(v[t>>2])){break a}g=v[(i?d:h)>>2];k=kka(v[(i?h:d)>>2],0,v[e+700>>2],0);l=k+(g>>>1|0)|0;m=fb;u=e,w=wc(nka(l,k>>>0>l>>>0?m+1|0:m,g,0),fb),v[u+700>>2]=w}v[d>>2]=j}e=e+872|0;continue}break}v[a>>2]=c;v[a+20>>2]=b;kz(n);cb=f+16|0}function ZK(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0;l=cb-16|0;cb=l;t[l+15|0]=c;t[l+14|0]=12;Qg(b,w[Tb(l+15|0,l+14|0)|0]);m=v[b>>2];c=0;while(1){if(Dd(b)>>>0<=c>>>0){c=0;t[b+12|0]=0;a:{if(!(d&1)){break a}if(hc(m,v[b+4>>2])){break a}c=1;t[b+12|0]=1}if(e>>>0<=11){if(d&2){c=c|4;t[b+12|0]=c}t[b+15|0]=e;t[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){t[b+12|0]=c|2}t[b+14|0]=g;t[b+13|0]=f}cb=l+16|0}else{b:{c:{d:{switch(h|0){case 0:i=Ib(m,c);j=(c<<2)+a|0;k=j+96|0;u[i>>1]=w[k|0]|w[k+1|0]<<8;j=j+98|0;break c;case 1:break d;default:break b}}i=Ib(m,c);j=(c<<2)+a|0;k=j+144|0;u[i>>1]=w[k|0]|w[k+1|0]<<8;j=j+146|0}t[i+2|0]=w[j|0]}e:{if(!c){break e}j=Ib(m,c);i=x[j>>1];k=Ib(m,c-1|0);n=x[k>>1];if(i>>>0>255|i>>>0>=n>>>0){break e}i=i|n&65280;u[j>>1]=i;if(i>>>0>=x[k>>1]){break e}u[j>>1]=i+256}c=c+1|0;continue}break}}function V8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{if((Oj(v[a>>2],v[a+4>>2])|0)==2){if((Oj(v[a+12>>2],v[a+16>>2])|0)==(b|0)){break a}}v[22440]=0;R(924,a|0,2);e=v[22440];v[22440]=0;b:{c:{d:{if((e|0)==1){break d}v[22440]=0;e=a;R(924,a+12|0,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break d}v[22440]=0;R(925,a+24|0,2);d=v[22440];v[22440]=0;if((d|0)==1){break d}v[22440]=0;d=a;R(925,a+36|0,b|0);c=v[22440];v[22440]=0;if((c|0)==1){break d}c=0;break c}b=V(88360)|0;if((O()|0)!=(fa(88360)|0)){break b}_(b|0)|0;Ac(a);tK(a);b=a+12|0;Ac(b);tK(b);b=a+24|0;Ac(b);sK(b);a=a+36|0;Ac(a);sK(a);$();break a}while(1){if((c|0)!=2){f=wo(v[a>>2],c);g=Ib(v[a+24>>2],c),h=f,v[g>>2]=h;c=c+1|0;continue}break}a=0;while(1){if((a|0)==(b|0)){break a}c=wo(v[e+12>>2],a);g=Ib(v[d+36>>2],a),h=c,v[g>>2]=h;a=a+1|0;continue}}S(b|0);L()}}function Mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=cb-16|0;cb=b;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+8>>2];l=((((v[b+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;e=f>>>21&2040;m=u[e+39830>>1];n=u[e+39828>>1];o=u[e+39826>>1];p=u[e+39824>>1];e=0;while(1){if((e|0)!=2){f=(e<<1)+l|0;v[(e<<2)+b>>2]=(((B(u[f>>1],o)+B(u[f-4>>1],p)|0)+B(u[f+4>>1],n)|0)+B(u[f+8>>1],m)|0)/16384;e=e+1|0;continue}break}e=v[a+32>>2];h=v[a+28>>2]+h|0;v[c>>2]=v[c>>2]+B(v[b>>2],h>>12);g=e+g|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g>>12);Jb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];d=v[b+8>>2];v[a+36>>2]=h;v[a>>2]=d;v[a+4>>2]=c;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+24>>2]=g>>12;cb=b+16|0}function iH(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=v[a+32>>2];a:{b:{b=v[a+1380>>2];if((b|0)==-1){d=1;b=-1;break b}e=v[a+1116>>2];d=(b|0)>(e|0)?b:e;while(1){c:{if((b|0)!=(d|0)){f=w[(a+b|0)+1120|0];c=f+c|0;if((f|0)==255){break c}d=b}if(y[a+40>>2]<c>>>0){Zb(a,1);break a}b=(d|0)==(e|0)?-1:d;d=0;break b}b=b+1|0;continue}}while(1){if((b|0)!=-1){return 1}e=v[a+40>>2];if(e>>>0<=c+26>>>0){Zb(a,1);break a}if(Mb(c,89272,4)){Zb(a,21);break a}if(w[c+4|0]){Zb(a,21);break a}d:{if(d){if(!v[a+992>>2]|!(t[c+5|0]&1)){break d}Zb(a,21);break a}if(t[c+5|0]&1){break d}Zb(a,21);break a}b=0;f=c+27|0;d=w[c+26|0];c=f+d|0;if(e>>>0<c>>>0){Zb(a,1);break a}while(1){e:{if((b|0)==(d|0)){b=d;break e}g=w[b+f|0];c=g+c|0;if((g|0)!=255){break e}b=b+1|0;continue}break}b=(b|0)==(d|0)?-1:b;d=0;if(c>>>0<=e>>>0){continue}break}Zb(a,1)}return 0}function tF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=cb-32|0;cb=h;a:{b:{c:{if((b|0)!=(c|0)){j=v[114922];v[114922]=0;g=cb-16|0;cb=g;pd();e=cb-16|0;cb=e;f=cb-16|0;cb=f;ew(f,b,h+28|0,2);k=v[f>>2];i=v[f+4>>2];b=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=b;v[e>>2]=k;v[e+4>>2]=i;cb=f+16|0;i=v[e>>2];f=v[e+4>>2];b=v[e+12>>2];v[g+8>>2]=v[e+8>>2];v[g+12>>2]=b;v[g>>2]=i;v[g+4>>2]=f;cb=e+16|0;f=v[g>>2];e=v[g+4>>2];b=v[g+12>>2];v[h+16>>2]=v[g+8>>2];v[h+20>>2]=b;v[h+8>>2]=f;v[h+12>>2]=e;cb=g+16|0;i=v[h+16>>2];f=v[h+20>>2];g=v[h+8>>2];e=v[h+12>>2];b=v[114922];if(!b){break c}if(v[h+28>>2]!=(c|0)){break b}l=g;m=e;n=i;o=f;if((b|0)!=68){break a}break b}v[d>>2]=4;break a}v[114922]=j;if(v[h+28>>2]==(c|0)){break a}}v[d>>2]=4;g=l;e=m;i=n;f=o}v[a>>2]=g;v[a+4>>2]=e;v[a+8>>2]=i;v[a+12>>2]=f;cb=h+32|0}function l9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=cb-16|0;cb=f;j=rf(a,c);ke(f,v[a+36>>2]);k=a;a:{if(!j){Cc(f,a+32|0,5);c=0;if(tb(v[v[f>>2]>>2],v[f+4>>2])){break a}}e=cb-48|0;cb=e;h=v[a+36>>2];Fk(h,e+40|0);c=v[e+44>>2];if(!c&y[e+40>>2]>=257|c){v[e+40>>2]=256;v[e+44>>2]=0}l=v[e+40>>2];m=v[e+44>>2];c=0;b:{c:{d:{e:{while(1){if(!m&c>>>0>=l>>>0){break b}bg(h,e+38|0);g=Db(e+24|0);v[22440]=0;Q(498,h|0,g|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;U(11,e+8|0,d|0,g|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}v[22440]=0;a=Q(913,b|0,e+38|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break d}i=a;a=e+8|0;Cb(i,a);rb(a);rb(g);c=c+1|0;continue}break}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;rb(e+8|0)}rb(g);S(c|0);L()}cb=e+48|0;c=j}Se(k,c);cb=f+16|0}function Cha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=cb-16|0;cb=f;c=rf(a,c);ke(f,v[a+36>>2]);a:{if(!c){b:{Cc(f,a+32|0,5);if(!tb(v[v[f>>2]>>2],v[f+4>>2])){break b}break a}}d=cb-32|0;cb=d;g=v[a+36>>2];bg(g,d+30|0);c:{d:{e:{f:{e=x[d+30>>1];if(e>>>0>=4001){i=v[b+12>>2];e=cb-16|0;cb=e;h=jc(e,15962);zc(d,h);rb(h);cb=e+16|0;v[22440]=0;U(491,d+16|0,d|0,d+30|0);e=v[22440];v[22440]=0;if((e|0)==1){break f}e=v[i+1298464>>2];v[22440]=0;U(388,e|0,2,d+16|0);e=v[22440];v[22440]=0;if((e|0)==1){break e}rb(d+16|0);Ab(d);e=4e3}Ff(xj(b,0),e);b=xj(b,0);j=d,k=yb(v[b>>2]),v[j+16>>2]=k;b=yb(v[b+4>>2]);break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;rb(d+16|0)}Ab(d);S(a|0);L()}while(1){e=v[d+16>>2];if(Qb(e,b)){bg(g,d);u[e>>1]=x[d>>1];Ne(d+16|0);continue}break}cb=d+32|0;d=c}Se(a,d);cb=f+16|0}function S2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=cb-32|0;cb=c;j=c,k=TI(),v[j+24>>2]=k;g=a+24|0;e=c+24|0;RI(g,Vd(e));qi(e);u[a+28>>1]=0;uP();f=cb-16|0;cb=f;d=lc(144);v[22440]=0;h=Q(1085,d|0,4)|0;i=v[22440];v[22440]=0;a:{if((i|0)!=1){d=v[Sf(f+8|0,h)>>2];cb=f+16|0;break a}a=P()|0;O()|0;zb(d);S(a|0);L()}v[c+24>>2]=d;QI(a+32|0,Vd(e));_o(e);j=c,k=SI(v[a>>2]),v[j+24>>2]=k;d=a+4|0;PI(d,Vd(e));pi(e);rn(v[g>>2],v[d>>2]);t[a+64|0]=1;v[a+60>>2]=0;v[a+48>>2]=1065353216;v[a+52>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;j=c,k=qk(b),v[j+24>>2]=k;j=c,k=Af(b),v[j+16>>2]=k;b:{while(1){if(!ih(c+24|0,c+16|0)){break b}d=od(c+24|0);b=qf(c,d);v[22440]=0;W(987,a|0,b|0,d+12|0,0);d=v[22440];v[22440]=0;if((d|0)!=1){rb(b);mk(c+24|0);continue}break}a=P()|0;O()|0;rb(b);S(a|0);L()}cb=c+32|0}function vK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=cb-16|0;cb=d;a:{if(pc(v[a>>2],v[a+4>>2])>>>0>511){break a}if(!Gh(v[v[b>>2]-12>>2]+b|0)){break a}g=cb-16|0;cb=g;e=lc(64);v[22440]=0;h=T(859,e|0)|0;f=v[22440];v[22440]=0;b:{c:{if((f|0)!=1){e=Sf(g,h);f=v[e>>2];v[22440]=0;h=Y(919,f|0,b|0,c|0)|0;f=v[22440];v[22440]=0;d:{e:{if((f|0)!=1){if((h|0)==1){break e}If(g+8|0);break d}a=P()|0;O()|0;qg(e);break c}bi(g+8|0,e)}qg(e);cb=g+16|0;f=v[g+8>>2];break b}a=P()|0;O()|0;zb(e)}S(a|0);L()}v[d+8>>2]=f;f:{g:{if(!Bd(d+8|0)){v[22440]=0;c=Q(918,b|0,c|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break g}v[d>>2]=c;AS(d+8|0,Vd(d));qg(d)}if(!Bd(d+8|0)){break f}b=d+8|0;i=v[b>>2];v[22440]=0;R(500,a|0,b|0);a=v[22440];v[22440]=0;if((a|0)!=1){break f}}a=P()|0;O()|0;qg(d+8|0);S(a|0);L()}qg(d+8|0)}cb=d+16|0;return i}function Nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=cb-16|0;cb=b;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+8>>2];l=(((v[b+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;e=f>>>21&2040;m=u[e+39830>>1];n=u[e+39828>>1];o=u[e+39826>>1];p=u[e+39824>>1];e=0;while(1){if((e|0)!=2){f=e+l|0;v[(e<<2)+b>>2]=(((B(t[f|0],o)+B(t[f-2|0],p)|0)+B(t[f+2|0],n)|0)+B(t[f+4|0],m)<<8)/16384;e=e+1|0;continue}break}e=v[a+32>>2];h=v[a+28>>2]+h|0;v[c>>2]=v[c>>2]+B(v[b>>2],h>>12);g=e+g|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g>>12);Jb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];d=v[b+8>>2];v[a+36>>2]=h;v[a>>2]=d;v[a+4>>2]=c;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+24>>2]=g>>12;cb=b+16|0}function eq(a,b){var c=0;c=cb-16|0;cb=c;a=qy(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(Gb(a,7,1),9,1),10,1),13,1),15,1),16,1),17,1),18,1),20,1),21,1),24,1),25,1),26,1),28,1),30,1),31,1),33,1),34,1),39,1),41,1),44,1),46,1),45,1),47,1),48,1),50,1),99,1),102,1),104,1),105,1),115,1);break a;case 1:ky(c,2);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Vf(a,107);break a;case 3:ky(c,4);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Vf(a,4);break a;case 2:break b;case 0:break c}}Gb(a,88,1);break a}ky(c,b);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b}cb=c+16|0}function rJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=cb-48|0;cb=j;k=v[a+4>>2];l=v[a>>2];a=v[a+8>>2];v[j+32>>2]=b;v[j+44>>2]=a;v[j+36>>2]=l;v[j+40>>2]=k;v[22440]=0;a=Q(951,(d?d:952)|0,e|0)|0;b=v[22440];v[22440]=0;a:{b:{c:{d:{if((b|0)!=1){v[j+16>>2]=a;a=v[bp(j+24|0,j+16|0)>>2];b=v[j+44>>2];v[j+8>>2]=v[j+40>>2];v[j+12>>2]=b;v[22440]=0;b=v[j+36>>2];v[j>>2]=v[j+32>>2];v[j+4>>2]=b;c=+za(953,j|0,+c,a|0);a=v[22440];v[22440]=0;if((a|0)==1){break d}Ae(j+16|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Ae(j+16|0)}_(a|0)|0;v[22440]=0;ja(954,15143,d|0,e|0,f|0,g|0,h|0,i|0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();c=0}cb=j+48|0;return+c}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=cb-16|0;cb=f;h=v[a+40>>2];i=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){m=v[a+32>>2];e=(v[f+12>>2]<<1)+j|0;g=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[g+34>>1])+B(u[e+2>>1],u[g+32>>1])|0)+B(u[e+6>>1],u[g+36>>1])|0)+B(u[e+8>>1],u[g+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[g+26>>1])+B(u[e-6>>1],u[g+24>>1])|0)+B(u[e-2>>1],u[g+28>>1])|0)+B(u[e>>1],u[g+30>>1])|0)/2|0)|0)/16384|0;i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(e,i>>12);h=h+m|0;v[c+4>>2]=v[c+4>>2]+B(e,h>>12);Jb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];c=v[f+8>>2];v[a+36>>2]=i;v[a>>2]=c;v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;cb=f+16|0}function y2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=cb-32|0;cb=b;c=v[a>>2];a=v[c>>2];Pf(b+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[c+4>>2];g=v[a+8>>2];f=v[a+4>>2];i=v[a>>2];a=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=a;a=v[b+20>>2];v[b>>2]=v[b+16>>2];v[b+4>>2]=a;a=cb-32|0;cb=a;a:{b:{if(y[b+4>>2]>=f>>>0){if(Of(b)>>>0<g>>>0){break b}c:while(1){c=0;if((d|0)==(g|0)){break a}while(1)if((c|0)==(f|0)){d=d+1|0;continue c}else{j=a,k=A[ah(i,f,c,d)>>3],A[j+24>>3]=k;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;h=ne(A[Fg(a+24|0,a+16|0,a+8|0)>>3]*32768);d:{if(D(h)<2147483648){e=~~h;break d}e=-2147483648}e=Wc(e);j=pn(b,c,d),l=e,u[j>>1]=l;c=c+1|0;continue}}}ca(7157,9074,78,8754);L()}ca(5870,9074,80,8754);L()}cb=a+32|0;cb=b+32|0}function o2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=cb-32|0;cb=b;c=v[a>>2];a=v[c>>2];Pf(b+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[c+4>>2];g=v[a+8>>2];f=v[a+4>>2];i=v[a>>2];a=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=a;a=v[b+20>>2];v[b>>2]=v[b+16>>2];v[b+4>>2]=a;a=cb-32|0;cb=a;a:{b:{if(y[b+4>>2]>=f>>>0){if(Of(b)>>>0<g>>>0){break b}c:while(1){c=0;if((d|0)==(g|0)){break a}while(1)if((c|0)==(f|0)){d=d+1|0;continue c}else{j=a,k=A[ah(i,f,c,d)>>3],A[j+24>>3]=k;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;h=ne(A[Fg(a+24|0,a+16|0,a+8|0)>>3]*32768);d:{if(D(h)<2147483648){e=~~h;break d}e=-2147483648}e=Wc(e);j=on(b,c,d),l=e,u[j>>1]=l;c=c+1|0;continue}}}ca(7157,9074,78,8754);L()}ca(5870,9074,80,8754);L()}cb=a+32|0;cb=b+32|0}function f8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);c=cb-4112|0;cb=c;h=gb[v[v[a>>2]+116>>2]](a)|0;if(!h){gb[v[v[a>>2]+120>>2]](a)}v[c+12>>2]=0;f=cb-16|0;cb=f;while(1){d=v[a+44>>2];if(Oj(d,v[a+48>>2])>>>0<=e>>>0){cb=f+16|0}else{v[f+12>>2]=0;d=wo(d,e);g=(d+2048|0)-d>>2;while(1){if((g|0)>0){z[d>>2]=z[f+12>>2];g=g-1|0;d=d+4|0;continue}break}e=e+1|0;continue}break}f=c+2064|0;a:while(1){if(b){v[c+8>>2]=b;qc(c+8|0,512);e=c+16|0;py(e);d=v[c+8>>2];gb[v[v[a>>2]+60>>2]](a,e,f,d);e=0;while(1)if((e|0)==(d|0)){b=b-d|0;continue a}else{g=(c+16|0)+(e<<2)|0;z[c+4>>2]=D(z[g>>2]);i=c,j=z[ux(c+12|0,c+4|0)>>2],z[i+12>>2]=j;z[c+4>>2]=D(z[g+2048>>2]);i=c,j=z[ux(c+12|0,c+4|0)>>2],z[i+12>>2]=j;e=e+1|0;continue}}break}if(!h){gb[v[v[a>>2]+124>>2]](a)}cb=c+4112|0;return C(z[c+12>>2])}function LU(a,b,c){var d=0,e=0;e=cb-16|0;cb=e;t[e+15|0]=c;a:{if(b>>>0>35){break a}b:{c:{d:{e:{f:{d=w[b+26400|0];switch(d-17|0){case 1:case 3:case 4:case 5:break a;case 0:break c;case 2:break d;case 6:break e;default:break f}}g:{if(d-6>>>0<2){break g}if((d|0)==31){break b}if((d|0)==11){break g}if((d|0)!=1){break a}d=(c|0)!=0;break a}b=c&240;if(!b|(b|0)==240|(c&15)==15){break a}t[e+15|0]=b;break a}if(c>>>0<=64){t[e+15|0]=c<<1;d=23;break a}t[e+15|0]=128;d=23;break a}d=19;h:{switch((c&240)-48>>>4|0){case 0:t[e+15|0]=159;d=20;break a;case 1:t[e+15|0]=192;d=20;break a;case 2:if(c&14){break a}t[e+15|0]=((c|0)!=80)<<6;d=21;break a;case 4:break h;default:break a}}t[e+15|0]=c&15|160;d=20;break a}d=c>>>0<32?16:17;break a}t[e+15|0]=(b<<5|c<<24>>>27)^128;d=31}ae(a,d,e+15|0);cb=e+16|0}function w3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=cb+-64|0;cb=d;a:{b:{if((b|0)>=0){e=a+24|0;if(rj(Nb(v[e>>2]+484360|0))>>>0>b>>>0){break b}}a=a+16|0;break a}f=Xb(v[Nb(v[e>>2]+484360|0)>>2],b);c:{g=v[e>>2]+484344|0;f=x[f>>1];if(!Dm(g,f)){break c}if((c|0)>=0){h=c;if(v[Sb(g,f)+12>>2]>(c|0)){break c}}a=a+16|0;break a}u[v[e>>2]+1074448>>1]=b;b=b&65535;AL(v[e>>2],b);v[v[e>>2]+1074428>>2]=h;v[v[e>>2]+1074392>>2]=-2;c=v[e>>2];e=w[a+64|0];u[d+28>>1]=0;t[d+30|0]=255;v[d+40>>2]=2;v[d+24>>2]=0;v[d+32>>2]=h;u[d+36>>1]=b;b=v[d+44>>2];v[d+16>>2]=v[d+40>>2];v[d+20>>2]=b;b=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=b;b=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=b;b=d+48|0;Ct(b,c,e?7:1,d);i=a,j=A[sL(v[d+52>>2])>>3],A[i+16>>3]=j;Di(b);a=a+16|0}cb=d- -64|0;return+A[a>>3]}function id(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=v[a+112>>2];d=v[a+116>>2];e=!!(b|d);c=b;a:{i=e;f=v[a+4>>2];e=v[a+44>>2];b=f-e|0;h=b;g=b+v[a+120>>2]|0;b=v[a+124>>2]+(b>>31)|0;b=g>>>0<h>>>0?b+1|0:b;if(!(i&(c>>>0<=g>>>0&(b|0)>=(d|0)|(b|0)>(d|0)))){h=lw(a);if((h|0)>=0){break a}f=v[a+4>>2];e=v[a+44>>2]}v[a+112>>2]=-1;v[a+116>>2]=-1;v[a+104>>2]=f;c=e-f|0;d=c+g|0;b=(c>>31)+b|0;v[a+120>>2]=d;v[a+124>>2]=d>>>0<c>>>0?b+1|0:b;return-1}d=g+1|0;b=d?b:b+1|0;f=v[a+4>>2];e=v[a+8>>2];c=v[a+112>>2];g=v[a+116>>2];b:{if(!(c|g)){break b}i=c-d|0;c=g-(b+(d>>>0>c>>>0)|0)|0;j=e-f|0;g=j>>31;if((c|0)>=(g|0)&i>>>0>=j>>>0|(c|0)>(g|0)){break b}e=f+i|0}v[a+104>>2]=e;c=v[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;v[a+120>>2]=d;v[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){t[f-1|0]=h}return h}function hj(a,b,c){var d=0,e=0,f=0,g=0;e=cb-48|0;cb=e;d=a+24|0;g=v[v[d>>2]+24620>>2];a:{if(!((g|0)!=(b|0)|v[v[d>>2]+24624>>2]!=(c|0))){if(w[a+29|0]){break a}qL(v[d>>2],1);break a}f=e+8|0;ic(f,v[d>>2]+24604|0,40);v[e+28>>2]=c;v[e+24>>2]=b;c=v[e+44>>2];Zr(f,v[e+40>>2]);Jn(f,c);gy(v[d>>2],f);if((b|0)==(g|0)){break a}b=v[d>>2];f=b+946300|0;c=b+906300|0;while(1){if((c|0)!=(f|0)){b=v[c>>2];b:{if(!b){break b}if(!(gb[v[v[b>>2]+116>>2]](b)|0)){break b}gb[v[v[b>>2]+108>>2]](b,0);gb[v[v[b>>2]+96>>2]](b);gb[v[v[b>>2]+124>>2]](b)}c=c+160|0;continue}break}b=v[d>>2];d=b+946300|0;c=b+906300|0;while(1){if((c|0)!=(d|0)){b=v[c>>2];c:{if(!b){break c}if(gb[v[v[b>>2]+116>>2]](b)|0){break c}gb[v[v[b>>2]+108>>2]](b,1);gb[v[v[b>>2]+120>>2]](b)}c=c+160|0;continue}break}}t[a+29|0]=1;cb=e+48|0}function g2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=cb-32|0;cb=c;v[c+28>>2]=0;ji(c+24|0,a,0);if(Ed(w[c+24|0])){d=c+16|0;Jc(d,v[v[a>>2]-12>>2]+a|0);v[22440]=0;d=T(1125,d|0)|0;e=v[22440];v[22440]=0;a:{b:{if((e|0)!=1){e=Ni(c+8|0,a);f=hh(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22440]=0;ka(1128,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0);d=v[22440];v[22440]=0;if((d|0)!=1){break b}}b=V(0)|0;O()|0;Pb(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;ii(v[v[a>>2]-12>>2]+a|0,b);c:{d:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22440]=0;X(107);a=v[22440];v[22440]=0;if((a|0)!=1){break c}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)==1){break d}S(a|0);L()}$();break a}V(0)|0;O()|0;Lb()}L()}Pb(c+16|0);v[b>>2]=v[c+20>>2]}Mg(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}cb=c+32|0;return a|0}function Bn(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=v[b+88>>2];d=c|2048;v[b+88>>2]=d;f=v[b+656>>2];if(!(!f|t[b+730|0]&1)){d=c|6144;v[b+88>>2]=d}a:{if(!v[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=v[b+104>>2];if(!c){break b}e=x[c+34>>1];if(e&2){d=(e&4?d|4:d&-135)|2;v[b+88>>2]=d;e=v[c>>2];v[b+76>>2]=e;g=v[c+4>>2];v[b+80>>2]=g;c=v[c+8>>2];v[b+84>>2]=c;if(c>>>0<e>>>0){v[b+76>>2]=c;h=c}else{h=e}e=v[b+4>>2];if(h>>>0>=e>>>0){break b}v[b>>2]=0;v[b+4>>2]=((e-g>>>0)%(c-g>>>0)|0)+g;break b}d=d&-135;v[b+88>>2]=d;v[b+76>>2]=v[c>>2]}if(!f){break a}if(!(!(v[a+480180>>2]&1064964?1:w[f+60|0]&2)|!v[f>>2])){v[b+88>>2]=d|4096}if(w[f+65|0]==255|x[b+728>>1]!=65535){break a}i=b,j=Wc(Lp(f+48|0,v[b+724>>2],256,64)),u[i+728>>1]=j;i=b,j=x[Ib(v[f+48>>2],w[f+65|0])>>1],v[i+724>>2]=j}}function ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=cb-16|0;cb=f;h=v[a+40>>2];i=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){m=v[a+32>>2];e=v[f+12>>2]+j|0;g=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[g+34>>1])+B(t[e+1|0],u[g+32>>1])|0)+B(t[e+3|0],u[g+36>>1])|0)+B(t[e+4|0],u[g+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[g+26>>1])+B(t[e-3|0],u[g+24>>1])|0)+B(t[e-1|0],u[g+28>>1])|0)+B(t[e|0],u[g+30>>1])<<8)/2|0)|0)/16384|0;i=v[a+28>>2]+i|0;v[c>>2]=v[c>>2]+B(e,i>>12);h=h+m|0;v[c+4>>2]=v[c+4>>2]+B(e,h>>12);Jb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];c=v[f+8>>2];v[a+36>>2]=i;v[a>>2]=c;v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+24>>2]=h>>12;cb=f+16|0}function hR(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;d=b+20|0;while(1){if((b|0)!=(d|0)){f=c;c=t[b|0];c=f+((c&255)!=0&(c|0)<32)|0;b=b+1|0;continue}break}d=c;a:{if(c>>>0>5){break a}while(1){if((g|0)!=15){c=0;e=B(g,30)+a|0;b=e+20|0;j=b+22|0;while(1){if((b|0)!=(j|0)){f=c;c=t[b|0];c=f+((c&255)!=0&(c|0)<32)|0;b=b+1|0;continue}break}d=c+d|0;if(d>>>0>48){break a}b=w[e+45|0];if(w[e+44|0]|b>>>0>64){break a}c=wb(w[e+42|0]|w[e+43|0]<<8);if(c>>>0>32768){break a}g=g+1|0;h=b|h;i=c+i|0;continue}break}if(!i|!(h&255)){break a}d=w[a+470|0];if(d>>>0>128){break a}e=w[a+471|0];if(e>>>0>220){break a}a=a+472|0;c=a+128|0;b:{if((a|0)==(c|0)){break b}b=a;while(1){b=b+1|0;if((c|0)==(b|0)){break b}a=w[a|0]<w[b|0]?b:a;continue}}a=w[a|0];if(a>>>0>63){break a}k=(e|(a|d))!=0}return k}function cp(a){var b=C(0),c=0,d=0,e=0,f=0;c=cb-16|0;cb=c;e=(p(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=C(1);if(d>>>0<964689920){break a}b=di(+a);break a}if(d>>>0<=1081824209){f=+a;if(d>>>0>=1075235812){b=C(-di(((e|0)>=0?-3.141592653589793:3.141592653589793)+f));break a}if((e|0)<0){b=ei(f+1.5707963267948966);break a}b=ei(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=di(((e|0)>=0?-6.283185307179586:6.283185307179586)+ +a);break a}if((e|0)<0){b=ei(-4.71238898038469-+a);break a}b=ei(+a+-4.71238898038469);break a}b=C(a-a);if(d>>>0>=2139095040){break a}b:{switch(Dw(a,c+8|0)&3){case 0:b=di(A[c+8>>3]);break a;case 1:b=ei(-A[c+8>>3]);break a;case 2:b=C(-di(A[c+8>>3]));break a;default:break b}}b=ei(A[c+8>>3])}a=b;cb=c+16|0;return a}function S1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=cb-32|0;cb=c;v[c+28>>2]=0;ji(c+24|0,a,0);a:{b:{c:{if(Ed(w[c+24|0])){e=c+16|0;Jc(e,v[v[a>>2]-12>>2]+a|0);v[22440]=0;e=T(1125,e|0)|0;d=v[22440];v[22440]=0;d:{e:{if((d|0)==1){break e}d=Ni(c+8|0,a);f=hh(c);g=v[v[a>>2]-12>>2];f=v[f>>2];d=v[d>>2];v[22440]=0;ka(1131,e|0,d|0,f|0,a+g|0,c+28|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break e}Pb(c+16|0);break d}b=V(0)|0;O()|0;Pb(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;ii(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22440]=0;X(107);a=v[22440];v[22440]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)==1){break c}S(a|0);L()}$()}Mg(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}cb=c+32|0;break a}V(0)|0;O()|0;Lb()}L()}return a|0}function O2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=cb-32|0;cb=c;v[c+28>>2]=0;ji(c+24|0,a,0);a:{b:{c:{if(Ed(w[c+24|0])){e=c+16|0;Jc(e,v[v[a>>2]-12>>2]+a|0);v[22440]=0;e=T(1125,e|0)|0;d=v[22440];v[22440]=0;d:{e:{if((d|0)==1){break e}d=Ni(c+8|0,a);f=hh(c);g=v[v[a>>2]-12>>2];f=v[f>>2];d=v[d>>2];v[22440]=0;ka(1126,e|0,d|0,f|0,a+g|0,c+28|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break e}Pb(c+16|0);break d}b=V(0)|0;O()|0;Pb(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;ii(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22440]=0;X(107);a=v[22440];v[22440]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)==1){break c}S(a|0);L()}$()}Mg(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}cb=c+32|0;break a}V(0)|0;O()|0;Lb()}L()}return a|0}function M1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=cb-32|0;cb=c;v[c+28>>2]=0;ji(c+24|0,a,0);a:{b:{c:{if(Ed(w[c+24|0])){e=c+16|0;Jc(e,v[v[a>>2]-12>>2]+a|0);v[22440]=0;e=T(1125,e|0)|0;d=v[22440];v[22440]=0;d:{e:{if((d|0)==1){break e}d=Ni(c+8|0,a);f=hh(c);g=v[v[a>>2]-12>>2];f=v[f>>2];d=v[d>>2];v[22440]=0;ka(1129,e|0,d|0,f|0,a+g|0,c+28|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break e}Pb(c+16|0);break d}b=V(0)|0;O()|0;Pb(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;ii(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22440]=0;X(107);a=v[22440];v[22440]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)==1){break c}S(a|0);L()}$()}Mg(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}cb=c+32|0;break a}V(0)|0;O()|0;Lb()}L()}return a|0}function D1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=cb-32|0;cb=c;v[c+28>>2]=0;ji(c+24|0,a,0);a:{b:{c:{if(Ed(w[c+24|0])){e=c+16|0;Jc(e,v[v[a>>2]-12>>2]+a|0);v[22440]=0;e=T(1125,e|0)|0;d=v[22440];v[22440]=0;d:{e:{if((d|0)==1){break e}d=Ni(c+8|0,a);f=hh(c);g=v[v[a>>2]-12>>2];f=v[f>>2];d=v[d>>2];v[22440]=0;ka(1130,e|0,d|0,f|0,a+g|0,c+28|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break e}Pb(c+16|0);break d}b=V(0)|0;O()|0;Pb(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;ii(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22440]=0;X(107);a=v[22440];v[22440]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)==1){break c}S(a|0);L()}$()}Mg(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}cb=c+32|0;break a}V(0)|0;O()|0;Lb()}L()}return a|0}function A2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=cb-32|0;cb=c;v[c+28>>2]=0;ji(c+24|0,a,0);a:{b:{c:{if(Ed(w[c+24|0])){e=c+16|0;Jc(e,v[v[a>>2]-12>>2]+a|0);v[22440]=0;e=T(1125,e|0)|0;d=v[22440];v[22440]=0;d:{e:{if((d|0)==1){break e}d=Ni(c+8|0,a);f=hh(c);g=v[v[a>>2]-12>>2];f=v[f>>2];d=v[d>>2];v[22440]=0;ka(1127,e|0,d|0,f|0,a+g|0,c+28|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break e}Pb(c+16|0);break d}b=V(0)|0;O()|0;Pb(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;ii(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22440]=0;X(107);a=v[22440];v[22440]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)==1){break c}S(a|0);L()}$()}Mg(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}cb=c+32|0;break a}V(0)|0;O()|0;Lb()}L()}return a|0}function Yu(a,b,c,d){var e=0,f=0,g=0,h=0;g=cb-16|0;cb=g;a:{if(!c){break a}if(d){b=$b(g+8|0,a,b);a=cb-16|0;cb=a;v[a+12>>2]=c;d=v[b+4>>2];b:{if(!d){d=v[b>>2];break b}e=32-d|0;v[a+8>>2]=e;c=v[b>>2];h=e;e=v[Bb(a+8|0,a+12|0)>>2];v[c>>2]=-1<<d&-1>>>h-e|v[c>>2];f=v[a+12>>2];d=c+4|0;v[b>>2]=d;c=f-e|0}e=d;d=c>>>5<<2;Hb(e,255,d);c=c&31;v[a+12>>2]=c;if(c){e=b;b=d+v[b>>2]|0;v[e>>2]=b;v[b>>2]=v[b>>2]|-1>>>32-c}cb=a+16|0;break a}b=$b(g,a,b);a=cb-16|0;cb=a;v[a+12>>2]=c;d=v[b+4>>2];c:{if(!d){d=v[b>>2];break c}e=32-d|0;v[a+8>>2]=e;c=v[b>>2];f=v[c>>2];h=e;e=v[Bb(a+8|0,a+12|0)>>2];v[c>>2]=(-1<<d&-1>>>h-e^-1)&f;f=v[a+12>>2];d=c+4|0;v[b>>2]=d;c=f-e|0}e=d;d=c>>>5<<2;Hb(e,0,d);c=c&31;v[a+12>>2]=c;if(c){e=b;b=d+v[b>>2]|0;v[e>>2]=b;v[b>>2]=v[b>>2]&(-1>>>32-c^-1)}cb=a+16|0}cb=g+16|0}function q7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=C(0),o=0,p=0,q=0,r=0;g=cb-16|0;cb=g;i=a+44|0;if(Yh(i)){q=g,r=Ud(i,0),v[q+8>>2]=r;q=g,r=Ud(i,1),v[q+12>>2]=r;q=g,r=jd(i,0),v[q>>2]=r;q=g,r=jd(i,1),v[q+4>>2]=r;l=d;a:while(1){if(l){o=w[a+4273|0];p=w[a+4272|0];k=0;while(1)if((k|0)==2){l=l-1|0;continue a}else{j=k<<2;h=j+(g+8|0)|0;e=v[h>>2];v[h>>2]=e+4;f=C(z[e>>2]*z[a+4240>>2]);e=a+j|0;h=e+4228|0;f=C(f+C(z[h>>2]*z[a+4236>>2]));z[h>>2]=f;f=TJ(C(f*C(1073741824)),p,o);h=e+4244|0;e=e+4252|0;m=z[e>>2];n=z[a+4264>>2];f=C(C(C(f*z[a+4260>>2])-C(z[a+4268>>2]*z[h>>2]))-C(m*n));z[e>>2]=f;z[h>>2]=m+C(f*n);e=g+j|0;j=v[e>>2];v[e>>2]=j+4;z[j>>2]=f*C(9.313225746154785e-10);k=k+1|0;continue}}break}ti(a,b,c,jd(i,0),jd(i,1),d)}cb=g+16|0}function mH(a){var b=C(0),c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=C(0),o=C(0);f=z[a>>2];i=z[a+24>>2];c=C(f-i);d=z[a+16>>2];b=z[a+32>>2];g=z[a+8>>2];e=C(d+C(b-g));z[a+16>>2]=c+e;j=C(c-C(e*C(.5)));c=z[a+4>>2];e=z[a+20>>2];h=z[a+28>>2];k=C(C(C(c-e)-h)*C(.8660253882408142));z[a+4>>2]=j+k;l=C(C(d-b)*C(.1736481785774231));f=C(f+C(i*C(.5)));i=C(C(g+b)*C(.7660444378852844));m=C(l+C(f-i));n=C(C(c+e)*C(.9848077297210693));b=C(z[a+12>>2]*C(.8660253882408142));c=C(C(c+h)*C(.6427876353263855));o=C(C(n-b)-c);z[a+12>>2]=m+o;z[a+20>>2]=m-o;z[a+28>>2]=j-k;d=C(C(g+d)*C(.9396926164627075));g=C(C(f+d)-l);e=C(C(e-h)*C(.3420201539993286));h=C(C(e-b)-n);z[a+32>>2]=g+h;d=C(C(f-d)+i);b=C(C(b+e)-c);z[a+24>>2]=d+b;z[a+8>>2]=d-b;z[a>>2]=g-h}function WJ(a){var b=0,c=0,d=0,e=0;b=cb-16|0;cb=b;e=(p(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=ei(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=C(-di(d+1.5707963267948966));break a}a=di(d+-1.5707963267948966);break a}a=ei(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){d=+a;if(c>>>0<=1085271519){if((e|0)<0){a=di(d+4.71238898038469);break a}a=C(-di(d+-4.71238898038469));break a}a=ei(((e|0)>=0?-6.283185307179586:6.283185307179586)+d);break a}if(c>>>0>=2139095040){a=C(a-a);break a}b:{switch(Dw(a,b+8|0)&3){case 0:a=ei(A[b+8>>3]);break a;case 1:a=di(A[b+8>>3]);break a;case 2:a=ei(-A[b+8>>3]);break a;default:break b}}a=C(-di(A[b+8>>3]))}cb=b+16|0;return a}function pea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=cb-16|0;cb=f;j=f,k=yj(b),v[j>>2]=k;c=cb-16|0;cb=c;e=b;h=a;a=Kd(a);a:{b:{if(a){b=bc(h);while(1){c:{d=a+13|0;if(lt(e,d)){d=v[a>>2];if(!d){break b}break c}if(lt(d,e)){b=a+4|0;d=v[a+4>>2];if(d){a=b;break c}v[c+12>>2]=a;a=b;break a}v[c+12>>2]=a;a=b;break a}b=a;a=d;continue}}a=bc(h)}v[c+12>>2]=a}d=a;b=v[a>>2];if(!b){g=cb-16|0;cb=g;a=bc(h);i=kh(c,lc(20),lh(g+8|0,a));b=v[i>>2]+13|0;e=cb-16|0;cb=e;v[e+8>>2]=v[f>>2];a=v[e+8>>2];a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[b+4|0]=0;t[b|0]=a;t[b+1|0]=a>>>8;t[b+2|0]=a>>>16;t[b+3|0]=a>>>24;cb=e+16|0;j=bc(i),k=1,t[j+4|0]=k;cb=g+16|0;Ig(h,v[c+12>>2],d,v[c>>2]);b=Vd(c);pk(c);g=1}Hg(f+8|0,ac(c,b),g);cb=c+16|0;cb=f+16|0;return v[f+8>>2]+17|0}function g_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=cb-16|0;cb=k;a:{if(a){a=$E(c);b:{if(b){Jk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ik(k,a);break b}jr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Hh(k,a)}Ui(i,k);Vc(k);l=e,m=Yi(a),v[l>>2]=m;l=f,m=Zi(a),v[l>>2]=m;Zg(k,a);tc(g,k);rb(k);Ih(k,a);Ui(h,k);Vc(k);a=Hk(a);break a}a=_E(c);c:{if(b){Jk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ik(k,a);break c}jr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Hh(k,a)}Ui(i,k);Vc(k);l=e,m=Yi(a),v[l>>2]=m;l=f,m=Zi(a),v[l>>2]=m;Zg(k,a);tc(g,k);rb(k);Ih(k,a);Ui(h,k);Vc(k);a=Hk(a)}v[j>>2]=a;cb=k+16|0}function gX(a){a=a|0;var b=0,c=0,d=0,e=0;c=cb-192|0;cb=c;b=c+16|0;Cg(b,a);v[22440]=0;R(90,c+32|0,b|0);a=v[22440];v[22440]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22440]=0;a=Q(91,c+48|0,c+32|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break e}rb(c+32|0);rb(c+16|0);b=v[v[a>>2]-12>>2];v[22440]=0;d=ha(63)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}v[22440]=0;U(64,c+8|0,b+(c+48|0)|0,d|0);b=v[22440];v[22440]=0;if((b|0)==1){break c}Pb(c+8|0);b=a+v[v[a>>2]-12>>2]|0;v[b+4>>2]=v[b+4>>2]&-75;v[b+4>>2]=v[b+4>>2]|8;v[22440]=0;Q(97,a|0,c+32|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break c}b=Zj(v[v[a>>2]-12>>2]+(c+48|0)|0);d=v[c+32>>2];uf(a);cb=c+192|0;a=b?0:d;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;rb(c+32|0)}rb(c+16|0);break b}b=P()|0;O()|0;uf(a)}S(b|0);L()}return a|0}function eW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;h=cb-16|0;cb=h;e=c+32|0;Tc(b,w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));e=Rb(a);a=c+28|0;g=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[22440]=0;R(186,e|0,g|0);g=v[22440];v[22440]=0;if((g|0)!=1){a:{g=c+4|0;c=0;while(1){b:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<=c>>>0){break b}v[22440]=0;f=Q(158,b|0,4)|0;i=v[22440];v[22440]=0;if((i|0)==1){break a}if(!f){break b}f=w[g|0]|w[g+1|0]<<8;v[22440]=0;f=Q(187,b|0,f|0)|0;i=v[22440];v[22440]=0;c:{if((i|0)!=1){v[h+12>>2]=f;if(gd(v[d>>2],v[d+4>>2])>>>0<=f>>>0){break c}v[22440]=0;R(188,e|0,h+12|0);f=v[22440];v[22440]=0;if((f|0)!=1){break c}}break a}c=c+1|0;continue}break}cb=h+16|0;return}}a=P()|0;O()|0;fc(e);S(a|0);L()}function k_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=cb-16|0;cb=k;a:{if(a){a=cF(c);b:{if(b){Jk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ik(k,a);break b}jr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Hh(k,a)}tc(i,k);rb(k);l=e,m=Yi(a),t[l|0]=m;l=f,m=Zi(a),t[l|0]=m;Zg(k,a);tc(g,k);rb(k);Ih(k,a);tc(h,k);rb(k);a=Hk(a);break a}a=bF(c);c:{if(b){Jk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ik(k,a);break c}jr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Hh(k,a)}tc(i,k);rb(k);l=e,m=Yi(a),t[l|0]=m;l=f,m=Zi(a),t[l|0]=m;Zg(k,a);tc(g,k);rb(k);Ih(k,a);tc(h,k);rb(k);a=Hk(a)}v[j>>2]=a;cb=k+16|0}function uga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=cb-16|0;cb=e;t[e+15|0]=0;u[e+12>>1]=0;n=B(c,d);j=4;while(1){if((d|0)!=(k|0)){h=b+k|0;o=n+h|0;while(1){if(h>>>0<o>>>0){t[e+11|0]=0;zR(a,e+15|0,e+12|0,e+11|0);i=w[e+11|0];f=x[e+12>>1];c=j;a:{b:{while(1){if(!(c&255)){break b}c:{g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!mf(a,e+10|0)){break c}f=w[e+10|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}u[e+12>>1]=0;break a}u[e+12>>1]=f}c=1;g=i&255;e:{if(g>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(g>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=i&1;t[e+15|0]=f;l=(f-1^(i&254)>>>1)+l|0;t[e+11|0]=l;t[h|0]=l;h=d+h|0;j=(c+j&254)>>>1|0;continue}break}k=k+1|0;continue}break}cb=e+16|0}function Wda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=cb+-64|0;cb=c;a:{d=v[a+4>>2];b:{if(d>>>0<b>>>0){f=ee(c+56|0);e=b-d|0;b=ft(a);c:{if(!(e>>>0>b>>>0|d>>>0>b-e>>>0)){pl(c+40|0,v[a>>2],v[a+4>>2]);$b(f,v[c+40>>2],v[c+44>>2]);v[a+4>>2]=v[a+4>>2]+e;break c}b=Nn(c+40|0);d=v[a+4>>2];v[22440]=0;d=Q(750,a|0,d+e|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break a}v[22440]=0;R(751,b|0,d|0);d=v[22440];v[22440]=0;if((d|0)==1){break a}v[b+4>>2]=v[a+4>>2]+e;kk(c+24|0,v[a>>2]);pl(c+16|0,v[a>>2],v[a+4>>2]);kk(c+8|0,v[b>>2]);zQ(c+32|0,v[c+24>>2],v[c+28>>2],v[c+16>>2],v[c+20>>2],v[c+8>>2],v[c+12>>2]);$b(f,v[c+32>>2],v[c+36>>2]);pt(a,b);Re(b)}a=$b(c,v[f>>2],v[f+4>>2]);Yu(v[a>>2],v[a+4>>2],e,0);break b}v[a+4>>2]=b}cb=c- -64|0;return}a=P()|0;O()|0;Re(b);S(a|0);L()}function jK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=cb-48|0;cb=c;v[c+8>>2]=542066252;f=c+8|0;d=f|4;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;d=c+16|0;e=v[b+4220>>2];t[d|0]=e;t[d+1|0]=e>>>8;t[d+2|0]=e>>>16;t[d+3|0]=e>>>24;d=c+20|0;e=v[b+4224>>2];t[d|0]=e;t[d+1|0]=e>>>8;t[d+2|0]=e>>>16;t[d+3|0]=e>>>24;d=c+24|0;e=v[b+4228>>2];t[d|0]=e;t[d+1|0]=e>>>8;t[d+2|0]=e>>>16;t[d+3|0]=e>>>24;d=c+28|0;e=v[b+4232>>2];t[d|0]=e;t[d+1|0]=e>>>8;t[d+2|0]=e>>>16;t[d+3|0]=e>>>24;d=c+32|0;e=v[b+4236>>2];t[d|0]=e;t[d+1|0]=e>>>8;t[d+2|0]=e>>>16;t[d+3|0]=e>>>24;t[c+36|0]=w[b+4240|0];t[c+37|0]=w[b+4241|0];t[c+38|0]=w[b+4242|0];t[c+39|0]=w[b+4243|0];t[c+40|0]=w[b+4244|0];d=b+4208|0;Si(d,33);ic(v[d>>2],f,33);qe(c,v[d>>2],v[b+4212>>2]);$b(a,v[c>>2],v[c+4>>2]);cb=c+48|0}function vga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=cb-16|0;cb=e;t[e+15|0]=0;u[e+12>>1]=0;j=8;n=B(c,d)<<1;while(1){if((d|0)!=(k|0)){g=(k<<1)+b|0;o=n+g|0;while(1){if(g>>>0<o>>>0){u[e+10>>1]=0;AR(a,e+15|0,e+12|0,j,e+10|0);h=x[e+10>>1];c=j;while(1){a:{if(!(c&255)){break a}f=x[e+12>>1]<<1;i=f&254;u[e+12>>1]=i;if(i){f=(f&65534)>>>0>255}else{if(!mf(a,e+9|0)){break a}f=w[e+9|0];u[e+12>>1]=f<<1&254|1;f=f>>>7|0}c=c-1|0;h=f|h<<1;continue}break}c=1;i=h&65535;b:{if(i>>>0<4){break b}f=15;while(1){c=f;m=f&255;if(i>>>m&1){break b}f=c-1|0;if(m>>>0>1){continue}break}}f=h&1;t[e+15|0]=f;l=(f-1^(h&65534)>>>1)+l|0;u[e+10>>1]=l;u[g>>1]=l;g=(d<<1)+g|0;j=(c+j&254)>>>1|0;continue}break}k=k+1|0;continue}break}cb=e+16|0}function uy(a,b,c,d){var e=0,f=0,g=0,h=0;e=cb-16|0;cb=e;a:{if(!d){break a}if(c){t[b+815|0]=c;break a}c=w[b+815|0]}f=v[a+480180>>2];d=f&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){a=v[a+480208>>2]&4096;if(!d){break h}if(!a){break b}a=0-(d>>>2|0)|0;break d}a=v[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!a){break b}c=c<<2;break c}d=0;if(!a){break f}break b}if(a){break b}if(!c){break e}}c=c<<2;if(!(f&16777248)|!d){break c}break b}a=0-(d>>>2|0)|0;break d}if(w[a+480209|0]&16){break b}ub(e+8|0,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;if(!tb(v[v[e+8>>2]>>2],v[e+12>>2])){break d}a=(a|0)/4<<24>>24}c=a;if(!c){break b}}a=v[b+692>>2];u[b+784>>1]=0;g=b,h=Vb(a+c|0,0,256),v[g+692>>2]=h}cb=e+16|0}function Yea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=cb-32|0;cb=e;ed(c,2);t[e+16|0]=w[b+13|0];t[e|0]=64;d=e+16|0;h=c,i=w[Tb(d,e)|0]<<2,u[h+30>>1]=i;f=b+14|0;v[c+24>>2]=(w[f|0]|w[f+1|0]<<8)<<1;sk(e,2,b+1|0);xc(d,v[e>>2],v[e+4>>2],w[e+8|0]);pe(c+43|0,d);rb(d);f=Nc(a,8,1,0,2);a:{if((w[b|0]&3)!=1){break a}a=b;d=b+22|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+26|0;g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[c+4>>2]=g;d=b+30|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[c+8>>2]=d-(d>>>0>g>>>0);b=w[b|0];if(b&4){u[c+34>>1]=x[c+34>>1]|2;b=w[a|0]}if(b&8){u[c+34>>1]=x[c+34>>1]|4;b=w[a|0]}if(!(b&16)){break a}kd(f,16);Hf(f,9);v[c>>2]=v[c>>2]>>>1;v[c+4>>2]=v[c+4>>2]>>>1;v[c+8>>2]=v[c+8>>2]>>>1}cb=e+32|0}function jp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;d=j(0)|0;a:{b:{c:{d:{if((b|0)>0|(b|0)>=0){f=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|d)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(f>>>0>2146435071){break a}b=1072693248;g=-1023;if((f|0)!=1072693248){b=f;break b}if(d){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;d=j(0)|0;g=-1077}b=b+614242|0;h=+((b>>>20|0)+g|0);e=h*.6931471803691238;l(0,d|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);i=e;k=a;m=c;e=a*(a*.5);c=c*c;a=c*c;a=i+(k+(m*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+h*1.9082149292705877e-10-e))}return a}function via(){var a=0,b=0,c=0;b=cb-16|0;cb=b;Db(89772);v[22446]=0;t[89788]=0;v[22448]=0;v[22440]=0;a=ha(28)|0;c=v[22440];v[22440]=0;a:{b:{c:{d:{e:{if((c|0)!=1){v[b+8>>2]=a;a=b+8|0;AA(89784,Vd(a));sl(a);t[89788]=0;break e}a=Da(88360,88932)|0;c=O()|0;if((fa(88360)|0)==(c|0)){_(a|0)|0;v[22440]=0;X(29);a=v[22440];v[22440]=0;if((a|0)==1){break c}L()}if((fa(88932)|0)!=(c|0)){break b}_(a|0)|0;v[22440]=0;t[89788]=0;X(18);a=v[22440];v[22440]=0;if((a|0)==1){a=P()|0;O()|0;break b}if(w[89788]){break d}}v[22440]=0;Z(30,89768);a=v[22440];v[22440]=0;if((a|0)!=1){break d}a=P()|0;O()|0;break b}cb=b+16|0;return}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)==1){break a}}sl(89792);sl(89784);rb(89772);S(a|0);L()}V(0)|0;O()|0;Lb();L()}function cka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=cb-48|0;cb=f;g=a+8|0;c=v[a+8>>2];j=mc(a);a:{if((c|0)!=v[j>>2]){break a}i=a+4|0;e=v[a+4>>2];d=v[a>>2];if(e>>>0>d>>>0){a=e;d=((a-d>>1)+1|0)/-2<<1;e=a+d|0;while(1){if((a|0)!=(c|0)){e=AU(e,a)+2|0;a=a+2|0;continue}break}c=e;v[g>>2]=c;v[i>>2]=d+v[i>>2];break a}v[f+24>>2]=c-d;v[f+44>>2]=1;e=f+24|0;c=v[Pc(e,f+44|0)>>2];c=Mj(e,c,c>>>2|0,v[a+16>>2]);d=ac(f+16|0,v[a+4>>2]);h=v[ac(f+8|0,v[a+8>>2])>>2];e=cb-32|0;cb=e;d=v[d>>2];v[e+24>>2]=d;d=uo(e+8|0,c+8|0,uB(d,h));while(1){h=v[d>>2];if((h|0)!=v[d+4>>2]){fo(h,v[e+24>>2]);v[d>>2]=v[d>>2]+2;Ne(e+24|0);continue}break}Gd(d);cb=e+32|0;ec(a,c);ec(i,c+4|0);ec(g,c+8|0);ec(j,mc(c));Pi(c);c=v[a+8>>2]}fo(c,b);v[g>>2]=v[g>>2]+2;cb=f+48|0}function I2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=cb-80|0;cb=d;a=v[a+4>>2];Bv(d+16|0,b);v[22440]=0;b=Q(1,d|0,17800)|0;e=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){v[22440]=0;U(2,d+32|0,d+16|0,b|0);e=v[22440];v[22440]=0;if((e|0)==1){break h}v[22440]=0;U(490,d+48|0,d+32|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break g}v[22440]=0;R(1033,d- -64|0,d+48|0);c=v[22440];v[22440]=0;if((c|0)==1){break f}c=v[v[a>>2]+8>>2];v[22440]=0;R(c|0,a|0,d- -64|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}rb(d- -64|0);rb(d+48|0);rb(d+32|0);rb(b);rb(d+16|0);cb=d+80|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;rb(d- -64|0)}rb(d+48|0)}rb(d+32|0)}rb(b)}rb(d+16|0);S(a|0);L()}function Gaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=cb-48|0;cb=e;g=Fb(b);d=vb(b);i=Fb(c);h=vb(c);d=d+g|0;f=-1;a:{while(1){if((d|0)==(g|0)){break a}d=d-1|0;if(qp(i,h,d)){continue}break}f=d-g|0}b:{c:{if((f|0)!=-1){k=e,l=fd(b),v[k+16>>2]=l;k=e,l=je(e+16|0,f),v[k+24>>2]=l;k=e,l=je(e+24|0,1),v[k+32>>2]=l;c=kj(e+40|0,e+32|0);k=e,l=gf(b),v[k>>2]=l;d=kj(e+8|0,e);QL(b,v[c>>2],v[d>>2]);break c}if(!vb(b)){break c}g=Fb(b);d=vb(b);i=Fb(c);h=vb(c);if(!d|!h){c=-1}else{c=g;f=d+c|0;h=h+i|0;while(1){d:{d=i;e:{if((c|0)!=(f|0)){while(1){if((d|0)==(h|0)){break e}j=t[d|0];d=d+1|0;if(!hc(t[c|0],j)){continue}break}}else{c=f}break d}c=c+1|0;continue}break}c=(c|0)==(f|0)?-1:c-g|0}if(c){break c}Db(a);break b}zc(a,b)}cb=e+48|0}function IL(a,b){var c=C(0),d=C(0),e=C(0);a:{b:{c:{switch(b|0){case 0:mp(a,C(1));bk(a,C(3.725290298461914e-9));lp(a,C(268435456));kp(a,0);break b;case 1:mp(a,C(32));bk(a,C(4.656612873077393e-10));lp(a,C(2147483648));kp(a,0);break b;case 2:mp(a,C(2));bk(a,C(7.450580596923828e-9));lp(a,C(134217728));kp(a,1);break b;default:mp(a,C(1));bk(a,C(7.450580596923828e-9));lp(a,C(134217728));kp(a,1);_x(a,0);Zx(a,1);Xx(a,1);d=C(256);c=C(128);e=C(128);b=0;break a;case 4:case 5:break c}}mp(a,C(.75));bk(a,C(7.450580596923828e-9));lp(a,C(134217728));kp(a,1);_x(a,0);b=(b|0)==4;Zx(a,b?2:3);Xx(a,1);d=C(256);c=b?C(256):C(192);e=c;b=1;break a}_x(a,1);Zx(a,0);Xx(a,0);d=C(128);e=C(100);c=C(256);b=4}z[a+16>>2]=c;z[a+20>>2]=e;z[a+24>>2]=d;v[a+28>>2]=b}function MG(a,b,c,d){a:{switch(b-9|0){case 0:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];return;case 6:b=v[c>>2];v[c>>2]=b+4;b=u[b>>1];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 7:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=x[b>>1];v[a+4>>2]=0;return;case 8:b=v[c>>2];v[c>>2]=b+4;b=t[b|0];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 9:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=w[b|0];v[a+4>>2]=0;return;case 16:b=v[c>>2]+7&-8;v[c>>2]=b+8;A[a>>3]=A[b>>3];return;case 17:gb[d|0](a,c);default:return;case 1:case 4:case 14:b=v[c>>2];v[c>>2]=b+4;b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];v[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=v[c>>2]+7&-8;v[c>>2]=b+8;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c}function E9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=cb-32|0;cb=f;c=Hj(v[v[a+48>>2]+12>>2]);if(b){c=B(b,c);a:{b:{if(v[a+12>>2]!=(b|0)){break b}if((ok(v[a>>2],v[a+4>>2])|0)!=(c|0)){break b}b=cb-16|0;cb=b;d=yb(v[a>>2]);a=yb(v[a+4>>2]);Ej(b+8|0);e=vs(a,d);c=cb-16|0;cb=c;v[c+8>>2]=d;while(1){if((e|0)>0){a=v[c+8>>2];d=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;d=w[b+12|0]|w[b+13|0]<<8;t[a+4|0]=d;t[a+5|0]=d>>>8;e=e-1|0;Ki(c+8|0);continue}break}cb=c+16|0;cb=b+16|0;break a}e=f+8|0;Ej(e);c=IS(f+16|0,c,e);QK(a);v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];e=xb(c);g=xb(a),h=v[e>>2],v[g>>2]=h;v[e>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Th(c);v[a+12>>2]=b}a=1}else{a=0}cb=f+32|0;return a|0}function W5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=cb-48|0;cb=f;v[f+40>>2]=d;d=bi(a,f+40|0);g=If(a+4|0);h=If(a+24|0);i=If(a+32|0);j=Rb(a+36|0);v[a+56>>2]=3;k=Rb(a+68|0);v[22440]=0;R(967,a|0,e|0);l=v[22440];v[22440]=0;a:{b:{c:{d:{if((l|0)!=1){Ub(f+8|0,b,c);b=ee(f);c=v[b+4>>2];b=v[b>>2];v[22440]=0;ga(968,f+16|0,v[f+8>>2],v[f+12>>2],b|0,c|0);b=v[22440];v[22440]=0;if((b|0)==1){break d}v[22440]=0;U(969,a|0,f+16|0,e|0);b=v[22440];v[22440]=0;if((b|0)==1){break c}sb(f+16|0);v[22440]=0;Z(970,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;sb(f+16|0)}ad(k);Rf(j);_o(i);qi(h);pi(g);Ae(d);Ae(f+40|0);S(a|0);L()}Ae(f+40|0);cb=f+48|0;return a|0}function AJ(a){var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);g=C(C(z[a+4220>>2]*C(.9980000257492065))+C(.0010000000474974513));c=-3e3/+C(C(C(z[a+4216>>2]*C(2999.9990234375))+C(.0010000000474974513))*C(y[v[a+16>>2]+24620>>2]));m=a,n=C(_j(10,c*+y[a+4288>>2])),z[m+4232>>2]=n;m=a+4236|0,n=C(_j(10,c*+y[a+4292>>2])),z[m>>2]=n;l=c*(1/+g+-1);h=a+4272|0;i=a+4232|0;while(1){if((d|0)==4){c=_j(10,+yJ(z[a+4208>>2])*.05);b=_j(10,+yJ(z[a+4212>>2])*.1);z[a+4228>>2]=4/K(j)*c*K(b);z[a+4224>>2]=c*K(1-b)}else{k=v[(d<<2)+h>>2];e=d<<1&-4;f=_j(10,l*+(k+v[(e+h|0)+16>>2]>>>0));b=_j(10,c*+(k>>>0));g=z[e+i>>2];e=(d<<3)+i|0;f=(1-f)*.5;z[e+12>>2]=b*f;z[e+8>>2]=b*(1-f);b=b*+g;b=b*(b*(b*(b+1)+1)+1)+1;j=b*b+j;d=d+1|0;continue}break}}function Cn(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=cb-16|0;cb=g;if(e){v[e>>2]=0}a:{h=a+484344|0;if(!ve(h,b)){break a}d=Zc(Sb(h,b),c,d);f=w[d+5|0];b:{c:{d:{e:{i=w[d+3|0];switch(i-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(i-35>>>0>=2){break a}}v[g+12>>2]=1;j=0;if((i|0)!=17){break b}j=v[a+480180>>2]==4;break b}v[g+12>>2]=2;j=0}m=g,n=v[Sb(h,b)+12>>2]+(c^-1)|0,v[m+8>>2]=n;c=0;k=v[Bb(g+8|0,g+12|0)>>2];a=k;while(1){f:{if(a){d=B(Hj(v[v[Sb(h,b)+48>>2]+12>>2]),6)+d|0;if(w[d+3|0]==34){break f}k=c}f=(i-37&255)>>>0<254?f:k?f:f<<8;if(!e){break a}v[e>>2]=k;break a}l=f<<8;f=w[d+5|0]|(j?f>>>0<256?l+-8192|0:l:l);c=c+1|0;a=a-1|0;continue}}cb=g+16|0;return f}function nC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=cb-16|0;cb=g;e=v[b>>2];d=Fc(e,v[b+4>>2]);a:{if(d>>>0<c>>>0){i=cb-32|0;cb=i;d=c-d|0;f=v[xb(b)>>2];e=v[b+4>>2];b:{if(d>>>0<=f-e>>1>>>0){f=cb-16|0;cb=f;e=Xh(f,b,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){dc(e);cb=f+16|0}else{no(d);d=d+2|0;v[e+4>>2]=d;continue}break}break b}f=xb(b);e=Mj(i+8|0,Nj(b,Fc(v[b>>2],e)+d|0),Fc(v[b>>2],v[b+4>>2]),f);h=cb-16|0;cb=h;d=uo(h,e+8|0,d);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){no(f);f=v[d>>2]+2|0;v[d>>2]=f;continue}break}Gd(d);cb=h+16|0;Ad(b,e);Pi(e)}cb=i+32|0;break a}if(c>>>0<d>>>0){Nd(b,e+(c<<1)|0)}}c=Kb(a,c<<1);if(c){d=v[b>>2];Ub(g+8|0,d,Fc(d,v[b+4>>2])<<1);md(g,a,v[g+8>>2],v[g+12>>2])}cb=g+16|0;return c|0}function XF(a,b,c,d,e,f){var g=0;g=cb-80|0;cb=g;a:{if((f|0)>=16384){Fd(g+32|0,b,c,d,e,0,0,0,2147352576);d=v[g+40>>2];e=v[g+44>>2];b=v[g+32>>2];c=v[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}Fd(g+16|0,b,c,d,e,0,0,0,2147352576);f=(f>>>0<49149?f:49149)-32766|0;d=v[g+24>>2];e=v[g+28>>2];b=v[g+16>>2];c=v[g+20>>2];break a}if((f|0)>-16383){break a}Fd(g- -64|0,b,c,d,e,0,0,0,7471104);d=v[g+72>>2];e=v[g+76>>2];b=v[g+64>>2];c=v[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}Fd(g+48|0,b,c,d,e,0,0,0,7471104);f=(f>>>0>4294918376?f:-48920)+32538|0;d=v[g+56>>2];e=v[g+60>>2];b=v[g+48>>2];c=v[g+52>>2]}Fd(g,b,c,d,e,0,0,0,f+16383<<16);b=v[g+12>>2];v[a+8>>2]=v[g+8>>2];v[a+12>>2]=b;b=v[g+4>>2];v[a>>2]=v[g>>2];v[a+4>>2]=b;cb=g+80|0}function FH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=cb-16|0;cb=f;a:{b:{c:{d:{e:{if((b|0)>=0){if(($o(a+8|0)|0)>(b|0)){break e}}a=aa(8)|0;v[22440]=0;c=Q(56,f|0,10725)|0;b=v[22440];v[22440]=0;if((b|0)==1){break d}oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break b}b=P()|0;O()|0;rb(c);break c}d=a+32|0;a=(v[d>>2]+(b<<5)|0)+480280|0;c=c?134218752:0;v[a>>2]=c|v[a>>2]&-134218753;a=(v[d>>2]+B(b,872)|0)+1075080|0;v[a>>2]=c|v[a>>2]&-134218753;a=x[v[d>>2]+480188>>1];g=a>>>0>256?a:256;b=b+1|0;while(1){if((a|0)==(g|0)){break a}e=B(a,872);if((b|0)==x[(e+v[d>>2]|0)+1075778>>1]){e=(e+v[d>>2]|0)+1075080|0;v[e>>2]=c|v[e>>2]&-134218753}a=a+1|0;continue}}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}cb=f+16|0}function d6(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;b=cb-48|0;cb=b;c=Db(b+32|0);v[22440]=0;Z(959,b+16|0);a=v[22440];v[22440]=0;a:{b:{c:{d:{if((a|0)!=1){f=b,g=yb(v[b+16>>2]),v[f+8>>2]=g;d=1;while(1){e=yb(v[b+20>>2]);a=v[b+8>>2];if(!Qb(a,e)){a=le(Fb(c));ad(b+16|0);rb(c);break b}if(!d){v[22440]=0;Q(960,c|0,14707)|0;a=v[22440];v[22440]=0;if((a|0)==1){break d}a=v[b+8>>2]}v[22440]=0;Q(824,c|0,a|0)|0;a=v[22440];v[22440]=0;if((a|0)==1){break d}Vn(b+8|0);d=0;continue}}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;ad(b+16|0)}rb(c);_(a|0)|0;a=0;v[22440]=0;W(958,6988,0,0,0);c=v[22440];v[22440]=0;if((c|0)==1){break a}$()}cb=b+48|0;return a|0}b=P()|0;O()|0;v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)==1){V(0)|0;O()|0;Lb();L()}S(b|0);L()}function eN(a,b,c,d){var e=0,f=C(0),g=0,h=0,i=0,j=0;g=cb-16|0;cb=g;v[g+12>>2]=c>>>3;v[g+8>>2]=v[a>>2];a=v[a+20>>2];h=v[Bb(g+12|0,g+8|0)>>2];c=h;while(1){if(c){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);f=Qf((l(2,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)),q()));f=zf(C(Pd(C((ng(f)?f>=C(0)?C(1):C(-1):f)*d),C(-1))*C(32768)));a:{if(C(D(f))<C(2147483648)){e=~~f;break a}e=-2147483648}i=a,j=Wc(e),u[i>>1]=j;e=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);f=Qf((l(2,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)),q()));f=zf(C(Pd(C((ng(f)?f>=C(0)?C(1):C(-1):f)*d),C(-1))*C(32768)));b:{if(C(D(f))<C(2147483648)){e=~~f;break b}e=-2147483648}i=a,j=Wc(e),u[i+2>>1]=j;a=a+4|0;b=b+8|0;c=c-1|0;continue}break}cb=g+16|0;return h<<3}function pR(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;o=v[b>>2];while(1){if((i|0)==128){Ff(b,c);c=v[a+8>>2];d=c+d|0;i=x[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(Ck(a)&-2)){break c}Tc(a,c+(f<<10)|0);if(!Uz(a,16,1)){break b}u[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((Ck(a)|0)!=(d+B(f,i)|0)){break a}}Tc(a,c+B(f,x[e>>1])|0);h=Uz(a,64,1)?h:k}Tc(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(B(c,x[e>>1])<<8)|0)==(Ck(a)|0)){break d}}if(c>>>0>=255){Tz(b,254,65534);Tz(b,255,65535)}l=h}a=l&65535}else{j=x[Xb(o,i)>>1];m=j+1|0;n=(h&65535)>>>0>j>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=(l&65535)>>>0>j>>>0?l:m;h=n?h:m;i=i+1|0;continue}break}return a}function _5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=cb-16|0;cb=e;i=e,j=yj(b),v[i>>2]=j;c=cb-16|0;cb=c;f=b;g=a;a=Kd(a);a:{b:{if(a){b=bc(g);while(1){c:{d=a+16|0;if(Ss(f,d)){d=v[a>>2];if(!d){break b}break c}if(Ss(d,f)){b=a+4|0;d=v[a+4>>2];if(d){a=b;break c}v[c+12>>2]=a;a=b;break a}v[c+12>>2]=a;a=b;break a}b=a;a=d;continue}}a=bc(g)}v[c+12>>2]=a}b=v[a>>2];if(!b){d=cb-16|0;cb=d;b=bc(g);h=kh(c,lc(40),lh(d+8|0,b));f=v[h>>2]+16|0;b=cb-16|0;cb=b;v[b+8>>2]=v[e>>2];zc(f,v[b+8>>2]);Db(f+12|0);cb=b+16|0;i=bc(h),j=1,t[i+4|0]=j;cb=d+16|0;Ig(g,v[c+12>>2],a,v[c>>2]);b=Vd(c);a=v[c>>2];v[c>>2]=0;if(a){if(w[bc(c)+4|0]){jm(a+16|0)}if(a){zb(a)}}h=1}a=e+8|0;Hg(a,ac(c,b),h);cb=c+16|0;a=od(a);cb=e+16|0;return a+12|0}function iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=cb-16|0;cb=g;e=v[b>>2];d=ag(e,v[b+4>>2]);a:{if(d>>>0<c>>>0){i=cb-32|0;cb=i;d=c-d|0;f=v[xb(b)>>2];e=v[b+4>>2];b:{if(d>>>0<=f-e>>5>>>0){f=cb-16|0;cb=f;e=sz(f,b,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){dc(e);cb=f+16|0}else{lP(d);d=d+32|0;v[e+4>>2]=d;continue}break}break b}f=xb(b);e=gt(i+8|0,Qp(b,ag(v[b>>2],e)+d|0),ag(v[b>>2],v[b+4>>2]),f);h=cb-16|0;cb=h;d=mP(h,e+8|0,d);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){lP(f);f=v[d>>2]+32|0;v[d>>2]=f;continue}break}Gd(d);cb=h+16|0;Ad(b,e);oP(e)}cb=i+32|0;break a}if(c>>>0<d>>>0){Nd(b,e+(c<<5)|0)}}if(Kb(a,c<<5)){c=v[b>>2];Ub(g+8|0,c,ag(c,v[b+4>>2])<<5);md(g,a,v[g+8>>2],v[g+12>>2])}cb=g+16|0}function SL(a){var b=0,c=0,d=0,e=0;e=a+128e3|0;while(1){if((a|0)!=(e|0)){d=cb-32|0;cb=d;ct(d);b=v[d+28>>2];c=v[d+24>>2];t[a+24|0]=c;t[a+25|0]=c>>>8;t[a+26|0]=c>>>16;t[a+27|0]=c>>>24;t[a+28|0]=b;t[a+29|0]=b>>>8;t[a+30|0]=b>>>16;t[a+31|0]=b>>>24;b=v[d+20>>2];c=v[d+16>>2];t[a+16|0]=c;t[a+17|0]=c>>>8;t[a+18|0]=c>>>16;t[a+19|0]=c>>>24;t[a+20|0]=b;t[a+21|0]=b>>>8;t[a+22|0]=b>>>16;t[a+23|0]=b>>>24;b=v[d+12>>2];c=v[d+8>>2];t[a+8|0]=c;t[a+9|0]=c>>>8;t[a+10|0]=c>>>16;t[a+11|0]=c>>>24;t[a+12|0]=b;t[a+13|0]=b>>>8;t[a+14|0]=b>>>16;t[a+15|0]=b>>>24;b=v[d+4>>2];c=v[d>>2];t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;t[a+4|0]=b;t[a+5|0]=b>>>8;t[a+6|0]=b>>>16;t[a+7|0]=b>>>24;cb=d+32|0;a=a+32|0;continue}break}}function Dw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=cb-16|0;cb=e;g=(p(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;A[b>>3]=d;g=d<-.7853981852531433;if(D(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;A[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;A[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){A[b>>3]=C(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;A[e+8>>3]=(l(2,i-(c<<23)|0),q());c=RG(e+8|0,e,c,1,0);d=A[e>>3];if((g|0)<0){A[b>>3]=-d;c=0-c|0;break a}A[b>>3]=d}cb=e+16|0;return c}function j0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=v[b+44>>2];i=v[b+24>>2];if(h>>>0<i>>>0){v[b+44>>2]=i;h=i}l=-1;m=-1;n=f&24;a:{if(!n|(e|0)==1&(n|0)==24){break a}if(h){g=h-Fb(b+32|0)|0;o=g;g=g>>31}b:{c:{switch(e|0){case 1:if(f&8){e=v[b+12>>2]-v[b+8>>2]|0;j=e;k=e>>31;break b}e=i-v[b+20>>2]|0;j=e;k=e>>31;break b;case 0:break b;case 2:break c;default:break a}}j=o;k=g}d=d+k|0;c=c+j|0;d=j>>>0>c>>>0?d+1|0:d;e=c;c=d;if((g|0)<=(d|0)&e>>>0>o>>>0|(d|0)>(g|0)|(d|0)<0){break a}d=f&8;d:{if(!(c|e)){break d}if(v[b+12>>2]?0:d){break a}if(!(f&16)){break d}if(!i){break a}}if(d){d=v[b+8>>2];fn(b,d,d+e|0,h)}if(f&16){rw(b,v[b+20>>2],v[b+28>>2]);zr(b,e)}l=e;m=c}Xg(a,l,m)}function I5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=cb-32|0;cb=d;v[22440]=0;Z(971,a|0);e=v[22440];v[22440]=0;a:{b:{c:{if((e|0)==1){break c}v[22440]=0;Z(972,b|0);e=v[22440];v[22440]=0;if((e|0)==1){break c}v[22440]=0;Z(972,c|0);f=v[22440];v[22440]=0;e=1;if((f|0)==1){break c}f=v[a+24>>2];b=nc(d+24|0,b);c=nc(d+16|0,c);v[22440]=0;g=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=g;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;W(993,f|0,d+8|0,d|0,1);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,5510,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();e=0}cb=d+32|0;return e|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function vi(a,b,c,d){var e=0,f=0,g=0,h=0;v[a+20>>2]=d;v[a+16>>2]=c;v[a+12>>2]=b;v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=44416;b=a+24|0;v[b>>2]=0;v[b+4>>2]=0;v[b+16>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;c=a+44|0;d=Rb(c);e=Rb(c+12|0);f=Rb(c+24|0);g=Rb(c+36|0);v[22440]=0;R(922,c|0,0);h=v[22440];v[22440]=0;if((h|0)==1){a=P()|0;O()|0;fc(g);fc(f);vx(e);vx(d);S(a|0);L()}v[a+4196>>2]=1065353216;v[a+4200>>2]=0;u[a+4204>>1]=0;d=v[a+16>>2];v[d+946300>>2]=v[d+946300>>2]+1;v[22440]=0;d=T(923,a+92|0)|0;e=v[22440];v[22440]=0;a:{if((e|0)!=1){c=a+4200|0;v[b>>2]=d;b=w[a+4200|0];d=v[a+16>>2];e=v[a+20>>2];while(1){if((e|0)==((d+B(b,160)|0)+906300|0)|b>>>0>248){break a}b=b+1|0;t[c|0]=b;continue}}a=P()|0;O()|0;gK(c);S(a|0);L()}return a}function rI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=cb-32|0;cb=c;e=v[a>>2];a=v[e>>2];Pf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[e+4>>2];g=v[a+8>>2];e=v[a+4>>2];i=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(y[c+4>>2]>=e>>>0){if(Of(c)>>>0<g>>>0){break b}j=b+12|0;c:while(1){a=0;if((f|0)==(g|0)){break a}while(1)if((a|0)==(e|0)){f=f+1|0;continue c}else{d=Kh(i,e,a,f);h=Ib(v[b>>2],a);d=v[d>>2]+(v[h>>2]>>1)|0;k=d;d=Ur(j)+d&-4096;v[h>>2]=k-d;d=bd(d|2048,12);d=(d|0)<32767?d:32767;l=pn(c,a,f),m=(d|0)>-32768?d:-32768,u[l>>1]=m;a=a+1|0;continue}}}ca(7157,9074,34,8787);L()}ca(5870,9074,36,8787);L()}cb=c+32|0}function kI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=cb-32|0;cb=c;e=v[a>>2];a=v[e>>2];Pf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[e+4>>2];g=v[a+8>>2];e=v[a+4>>2];i=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(y[c+4>>2]>=e>>>0){if(Of(c)>>>0<g>>>0){break b}j=b+12|0;c:while(1){a=0;if((f|0)==(g|0)){break a}while(1)if((a|0)==(e|0)){f=f+1|0;continue c}else{d=Kh(i,e,a,f);h=Ib(v[b>>2],a);d=v[d>>2]+(v[h>>2]>>1)|0;k=d;d=Ur(j)+d&-4096;v[h>>2]=k-d;d=bd(d|2048,12);d=(d|0)<32767?d:32767;l=on(c,a,f),m=(d|0)>-32768?d:-32768,u[l>>1]=m;a=a+1|0;continue}}}ca(7157,9074,34,8787);L()}ca(5870,9074,36,8787);L()}cb=c+32|0}function aga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=cb-528|0;cb=b;e=-1;a:{if(!gg(a,1468)){break a}ql(a,1464);c=b+524|0;wR(a,c);if(!me(c,27001)){e=0;if(!me(b+524|0,15563)){break a}}ql(a,20);c=1;while(1){if((c&65535)>>>0<=31){if(tR(a,b)){c=c+1|0;d=Xz(b)+d|0;continue}else{e=-1;break a}}break}e=0;if(d>>>0>40){break a}d=b+520|0;c=cb-16|0;cb=c;b:{if(!gg(a,2)){t[c|0]=0;dC(d,c);break b}Km(c+8|0,d);Wz(c,a,v[c+8>>2],v[c+12>>2])}cb=c+16|0;if(w[b+520|0]>128){break a}d=Ec(b+520|0);c=cb-16|0;cb=c;c:{if(!gg(a,512)){dR(b);break c}ru(c+8|0,b);Wz(c,a,v[c+8>>2],v[c+12>>2])}cb=c+16|0;a=b+512|0;c=b;e=1;d=w[d|0];while(1){if((a|0)==(c|0)){break a}f=w[c|0];c=c+1|0;if(d>>>0>=f>>>0){continue}break}e=0}cb=b+528|0;return e|0}function an(a,b,c,d,e,f,g,h,i,j){var k=0,l=0,m=0,n=0;l=cb-16|0;cb=l;t[l+15|0]=a;a:{b:{c:{k=v[d>>2];if((k|0)!=(c|0)){break c}m=43;n=a&255;if((n|0)!=w[j+24|0]){m=45;if(w[j+25|0]!=(n|0)){break c}}v[d>>2]=c+1;t[c|0]=m;break b}if(!(!vb(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;f=yi(j,j+26|0,l+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}if((c|0)==(k|0)|(k-c|0)>2|w[k-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=k+1;t[k|0]=w[f+79696|0];break a}v[d>>2]=k+1;t[k|0]=w[f+79696|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}cb=l+16|0;return a}function ada(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=cb-16|0;cb=b;f=v[a+40>>2];g=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[b+8>>2];m=e>>>18|0;n=((((v[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){h=(e<<1)+n|0;i=u[h>>1];v[(e<<2)+b>>2]=i+((B(u[h+4>>1]-i|0,m)|0)/16384|0);e=e+1|0;continue}break}e=v[a+32>>2];g=v[a+28>>2]+g|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=e+f|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Jb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];d=v[b+8>>2];v[a+36>>2]=g;v[a>>2]=d;v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+24>>2]=f>>12;cb=b+16|0}function QF(a,b){var c=0,d=0,e=0;a:{if(w[b|0]){break a}b=gw(13947);if(w[b|0]?b:0){break a}b=gw(B(a,12)+75536|0);if(w[b|0]?b:0){break a}b=gw(14231);if(w[b|0]?b:0){break a}b=14846}b:{while(1){d=w[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=14846;c:{d:{c=w[b|0];e:{f:{if(!(w[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!w[e+1|0]){break e}}if(!jj(e,14846)){break e}if(jj(e,13557)){break d}}if(!a){c=75608;if(w[e+1|0]==46){break c}}return 0}b=0;c=v[115831];if(c){while(1){if(!jj(e,c+8|0)){break c}c=v[c+32>>2];if(c){continue}break}}c=Hd(36);if(c){v[c+4>>2]=20;v[c>>2]=75504;b=c+8|0;ic(b,e,d);t[b+d|0]=0;v[c+32>>2]=v[115831];v[115831]=c;b=c}c=a|b?b:75608}return c}function lV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=cb-16|0;cb=d;ed(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=xq(a+4|0,a);e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=e;c=xq(a+8|0,a);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+8>>2]=f;t[d+15|0]=127;t[d+14|0]=w[a+15|0];i=b,j=(((w[Tb(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[i+30>>1]=j;g=a+12|0;c=w[g|0];if(c>>>0>=16){u[b+34>>1]=32;u[b+28>>1]=c&240}c=a+13|0;h=(w[c|0]|w[c+1|0]<<8)<<1;v[b+24>>2]=h;c=w[c|0]|w[c+1|0]<<8?h:16726;v[b+24>>2]=c;i=b,j=(B(Eu(0,w[g|0]<<28>>24),c)>>>0)/8363|0,v[i+24>>2]=j;if(e>>>0<f>>>0){u[b+34>>1]=x[b+34>>1]|2}if(w[a+16|0]&132){u[b+34>>1]=x[b+34>>1]|1}cb=d+16|0}function Qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=cb-16|0;cb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+8>>2];l=((((v[b+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;e=f>>>21&2040;m=u[e+39830>>1];n=u[e+39828>>1];o=u[e+39826>>1];p=u[e+39824>>1];e=0;while(1){if((e|0)!=2){f=(e<<1)+l|0;v[(e<<2)+b>>2]=(((B(u[f>>1],o)+B(u[f-4>>1],p)|0)+B(u[f+4>>1],n)|0)+B(u[f+8>>1],m)|0)/16384;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g);Jb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;cb=b+16|0}function efa(a){a=a|0;var b=0,c=0,d=0,e=0;b=cb-192|0;cb=b;c=b+16|0;Cg(c,a);v[22440]=0;R(90,b+32|0,c|0);a=v[22440];v[22440]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22440]=0;a=Q(91,b+48|0,b+32|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break e}rb(b+32|0);rb(b+16|0);c=v[v[a>>2]-12>>2];v[22440]=0;d=ha(63)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}v[22440]=0;U(64,b+8|0,c+(b+48|0)|0,d|0);c=v[22440];v[22440]=0;if((c|0)==1){break c}Pb(b+8|0);v[22440]=0;Q(92,a|0,b+32|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}c=Zj(v[v[a>>2]-12>>2]+(b+48|0)|0);d=x[b+32>>1];uf(a);cb=b+192|0;a=(c?0:d)&65535;break a}c=P()|0;O()|0;break d}c=P()|0;O()|0;rb(b+32|0)}rb(b+16|0);break b}c=P()|0;O()|0;uf(a)}S(c|0);L()}return a|0}function Aba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=cb-16|0;cb=g;c=rf(a,c);ke(g,v[a+36>>2]);a:{if(!c){b:{Cc(g,a+32|0,5);if(!tb(v[v[g>>2]>>2],v[g+4>>2])){break b}break a}}h=v[a+36>>2];d=cb-16|0;cb=d;v[d+12>>2]=0;jH(h,d+12|0,1);e=v[d+12>>2];f=e>>>2&3;t[d+11|0]=f;if(f){t[d+4|0]=3;f=w[Tb(d+4|0,d+11|0)|0];t[d+4|0]=0;t[d|0]=0;t[d+10|0]=0;c:{if(!f){break c}li(h,d+4|0);if((f|0)==1){break c}li(h,d);if(f>>>0<3){break c}li(h,d+10|0);i=w[d+10|0]<<24}e=e&255|w[d+4|0]<<8|w[d|0]<<16|i;v[d+12>>2]=e}f=e>>>4|0;v[d+4>>2]=f;v[d>>2]=1e6;Qx(b,v[Bb(d+4|0,d)>>2]);e=0;while(1){i=vb(b);if(i>>>0<=e>>>0){b=f-i|0;if(b){Vl(h,b)}cb=d+16|0}else{Uk(h,rc(b,e),1);e=e+1|0;continue}break}d=c}Se(a,d);cb=g+16|0}function bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=cb-16|0;cb=b;f=v[a+40>>2];g=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[b+8>>2];m=e>>>10&4194048;n=(((v[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){h=e+n|0;i=t[h|0];v[(e<<2)+b>>2]=((B(t[h+2|0]-i|0,m)|0)/16384|0)+(i<<8);e=e+1|0;continue}break}e=v[a+32>>2];g=v[a+28>>2]+g|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=e+f|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Jb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];d=v[b+8>>2];v[a+36>>2]=g;v[a>>2]=d;v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+24>>2]=f>>12;cb=b+16|0}function Uj(a,b){var c=0,d=0,e=0,f=0;c=cb+-64|0;cb=c;d=v[v[a>>2]-12>>2]+a|0;e=v[d+16>>2]&-3;Ml(d,e);ji(c+56|0,a,1);a:{b:{if(Ed(w[c+56|0])){d=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[22440]=0;f=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=f;f=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=f;U(110,c+40|0,d|0,c+8|0);b=v[22440];v[22440]=0;c:{if((b|0)!=1){b=iE(c+40|0,Xg(c+24|0,-1,-1))?e|4:e;break c}b=V(0)|0;O()|0;_(b|0)|0;b=e|1;ii(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22440]=0;X(107);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)==1){break b}S(a|0);L()}$()}Mg(v[v[a>>2]-12>>2]+a|0,b)}cb=c- -64|0;return a}V(0)|0;O()|0;Lb()}L()}function sh(a,b){var c=C(0),d=C(0),e=C(0),f=C(0),g=C(0);f=EJ(z[a+4252>>2]);c=C(C(z[a+4224>>2]*C(1.899999976158142))+C(.10000000149011612));g=z[a+4268>>2];d=te(C(10),C(C(C(C(C(v[((b<<2)+a|0)+4292>>2])/g)*C(-60))/C(C(z[a+4220>>2]*C(19.899999618530273))+C(.10000000149011612)))/C(20)));c=C(C(te(d,C(C(2)-C(C(2)/c)))+C(-1))/C(C(1)-cp(c>C(1)?C(3.1415927410125732):C(f*C(C(6.2831854820251465)/g)))));a:{if(c==C(0)){break a}if(!cm(c)){break a}g=C(c+c);f=C(C(-2)-g);c=C(C(f*f)+C(C(c*c)*C(-4)));if(c>C(0)){e=C(K(c))}c=C(C(e-f)/g);if(C(D(c))>C(1)){c=C(C(C(-f)-e)/g)}e=Qf(c)}b=(b<<3)+a|0;z[b+4404>>2]=e;z[b+4400>>2]=d;c=z[a+4272>>2];c=C(c*c);e=C(C(1)-c);d=C(d*d);return C(C(C(e*C(d/C(C(1)-C(c*d))))*e)+c)}function Zz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=cb-16|0;cb=f;d=w[a|0];if(d&1){t[b+12|0]=w[b+12|0]|1;d=w[a|0]}if(d&2){t[b+12|0]=w[b+12|0]|4;d=w[a|0]}if(d&4){t[b+12|0]=w[b+12|0]|2;d=w[a|0]}if(d&16){t[b+12|0]=w[b+12|0]|16;d=w[a|0]}if(d&32){t[b+12|0]=w[b+12|0]|8}t[f+15|0]=w[a+1|0];t[f+14|0]=25;Qg(b,w[Tb(f+15|0,f+14|0)|0]);t[b+15|0]=w[a+2|0];t[b+16|0]=w[a+3|0];t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];h=v[b>>2];d=0;while(1){if(Dd(b)>>>0>d>>>0){g=Ib(h,d);i=(d<<2)+a|0;e=i+6|0;e=w[e|0]|w[e+1|0]<<8;u[g>>1]=e;a:{if(!d){break a}j=e;e=x[Ib(h,d-1|0)>>1];if(j>>>0>=e>>>0){break a}u[g>>1]=e+1}e=i+8|0;k=g,l=Vb((w[e|0]|w[e+1|0]<<8)<<16>>16>>c,0,64),t[k+2|0]=l;d=d+1|0;continue}break}cb=f+16|0}function eR(a,b){var c=0,d=0,e=0;c=cb-32|0;cb=c;a:{if(!Kb(a,1024)){v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;a=64;while(1){if(a){d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+8|0]=e;t[b+9|0]=e>>>8;t[b+10|0]=e>>>16;t[b+11|0]=e>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;a=a-1|0;b=b+16|0;continue}break}break a}Rz(c+8|0,b);md(c+16|0,a,v[c+8>>2],v[c+12>>2])}cb=c+32|0}function dX(a){a=a|0;var b=0,c=0,d=0,e=0;b=cb-192|0;cb=b;c=b+16|0;Cg(c,a);v[22440]=0;R(90,b+32|0,c|0);a=v[22440];v[22440]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22440]=0;a=Q(91,b+48|0,b+32|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break e}rb(b+32|0);rb(b+16|0);c=v[v[a>>2]-12>>2];v[22440]=0;d=ha(63)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}v[22440]=0;U(64,b+8|0,c+(b+48|0)|0,d|0);c=v[22440];v[22440]=0;if((c|0)==1){break c}Pb(b+8|0);v[22440]=0;Q(95,a|0,b+32|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}c=Zj(v[v[a>>2]-12>>2]+(b+48|0)|0);d=v[b+32>>2];uf(a);cb=b+192|0;a=c?0:d;break a}c=P()|0;O()|0;break d}c=P()|0;O()|0;rb(b+32|0)}rb(b+16|0);break b}c=P()|0;O()|0;uf(a)}S(c|0);L()}return a|0}function V5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=cb-32|0;cb=d;v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[22440]=0;Z(972,b|0);c=v[22440];v[22440]=0;if((c|0)==1){break f}e=v[a+24>>2];v[22440]=0;c=Q(56,d|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break e}v[22440]=0;W(973,d+16|0,e|0,c|0,1);b=v[22440];v[22440]=0;if((b|0)==1){break d}a=d+16|0;b=le(Fb(a));rb(a);rb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;rb(c)}_(b|0)|0;b=0;v[22440]=0;W(958,6435,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$()}cb=d+32|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function A4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=cb-32|0;cb=d;v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[22440]=0;Z(972,b|0);c=v[22440];v[22440]=0;if((c|0)==1){break f}e=v[a+24>>2];v[22440]=0;c=Q(56,d|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break e}v[22440]=0;U(1032,d+16|0,e|0,c|0);b=v[22440];v[22440]=0;if((b|0)==1){break d}a=d+16|0;b=le(Fb(a));rb(a);rb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;rb(c)}_(b|0)|0;b=0;v[22440]=0;W(958,13335,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$()}cb=d+32|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function O6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=vi(a,b,c,d);v[a+4260>>2]=0;v[a>>2]=46812;c=a+4960|0;e=a+4504|0;b=e;while(1){b=bf(b)+24|0;if((c|0)!=(b|0)){continue}break}t[a+5046|0]=1;u[a+5044>>1]=0;v[a+4208>>2]=1063675494;v[a+4212>>2]=1065185444;v[a+4256>>2]=1059760811;b=a+4248|0;v[b>>2]=1065353216;v[b+4>>2]=1048525618;b=a+4240|0;v[b>>2]=1038174126;v[b+4>>2]=1065353216;b=a+4232|0;v[b>>2]=1047457519;v[b+4>>2]=1062836634;b=a+4224|0;v[b>>2]=1053079357;v[b+4>>2]=1059859440;b=a+4216|0;v[b>>2]=0;v[b+4>>2]=1032805417;v[22440]=0;R(922,a+44|0,2);b=v[22440];v[22440]=0;if((b|0)==1){a=P()|0;O()|0;while(1){c=c-24|0;fc(c);if((c|0)!=(e|0)){continue}break}vf(d);S(a|0);L()}ui(d);return a|0}function cT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=cb-16|0;cb=e;j=e,k=yj(b),v[j>>2]=k;f=v[b>>2];c=cb-16|0;cb=c;g=a;a=Kd(a);a:{b:{if(a){b=bc(g);while(1){c:{if(Yn(f,v[a+16>>2])){d=v[a>>2];if(!d){break b}break c}if(Yn(v[a+16>>2],f)){b=a+4|0;d=v[a+4>>2];if(d){a=b;break c}v[c+12>>2]=a;a=b;break a}v[c+12>>2]=a;a=b;break a}b=a;a=d;continue}}a=bc(g)}v[c+12>>2]=a}b=a;a=v[a>>2];if(!a){d=cb-16|0;cb=d;a=bc(g);h=kh(c,lc(24),lh(d+8|0,a));f=v[h>>2];a=cb-16|0;cb=a;v[a+8>>2]=v[e>>2];i=v[v[a+8>>2]>>2];v[f+20>>2]=0;v[f+16>>2]=i;cb=a+16|0;j=bc(h),k=1,t[j+4|0]=k;cb=d+16|0;Ig(g,v[c+12>>2],b,v[c>>2]);a=Vd(c);pk(c);h=1}b=e+8|0;Hg(b,ac(c,a),h);cb=c+16|0;a=od(b);cb=e+16|0;return a+4|0}function bX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=cb-32|0;cb=e;g=Fb(b);d=vb(b);i=Fb(c);h=vb(c);d=d+g|0;f=-1;a:{while(1){if((d|0)==(g|0)){break a}d=d-1|0;if(Yt(i,h,d)){continue}break}f=d-g|0}b:{c:{if((f|0)!=-1){k=e,l=fd(b),v[k+8>>2]=l;k=e,l=je(e+8|0,f),v[k+16>>2]=l;c=ac(e+24|0,je(e+16|0,1));d=ac(e,gf(b));hD(b,v[c>>2],v[d>>2]);break c}if(!vb(b)){break c}g=Fb(b);d=vb(b);i=Fb(c);h=vb(c);if(!d|!h){c=-1}else{c=g;f=d+c|0;h=h+i|0;while(1){d:{d=i;e:{if((c|0)!=(f|0)){while(1){if((d|0)==(h|0)){break e}j=w[d|0];d=d+1|0;if(!hc(w[c|0],j)){continue}break}}else{c=f}break d}c=c+1|0;continue}break}c=(c|0)==(f|0)?-1:c-g|0}if(c){break c}Db(a);break b}zc(a,b)}cb=e+32|0}function Lp(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=cb-16|0;cb=f;g=Dd(a)-1|0;while(1){a:{if(Dd(a)-1>>>0>e>>>0){if(x[Gc(v[a>>2],v[a+4>>2],e)>>1]<(b|0)){break a}g=e}h=x[Gc(v[a>>2],v[a+4>>2],g)>>1];v[f+12>>2]=0;b:{if((b|0)>=(h|0)){j=f,k=(w[Gc(v[a>>2],v[a+4>>2],g)+2|0]<<16)/(d|0)|0,v[j+12>>2]=k;break b}e=0;if(g){e=g-1|0;i=(w[Gc(v[a>>2],v[a+4>>2],e)+2|0]<<16)/(d|0)|0;v[f+12>>2]=i;e=x[Gc(v[a>>2],v[a+4>>2],e)>>1]}if((b|0)<=(e|0)|e>>>0>=h>>>0){break b}a=((w[Gc(v[a>>2],v[a+4>>2],g)+2|0]<<16)/(d|0)|0)-i|0;d=a;g=a>>31;a=b-e|0;b=kka(d,g,a,a>>31);a=h-e|0;j=f,k=yc(lka(b,fb,a,a>>31),fb)+i|0,v[j+12>>2]=k}oe(f+12|0,0,65536);cb=f+16|0;return(B(v[f+12>>2],c)+32768|0)/65536|0}e=e+1|0;continue}}function N0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=cb-32|0;cb=d;e=v[a+28>>2];v[d+16>>2]=e;f=v[a+20>>2];v[d+28>>2]=c;v[d+24>>2]=b;b=f-e|0;v[d+20>>2]=b;e=b+c|0;f=2;b=d+16|0;a:{while(1){b:{c:{d:{if(!Ew(Fa(v[a+60>>2],b|0,f|0,d+12|0)|0)){g=v[d+12>>2];if((g|0)==(e|0)){break d}if((g|0)>=0){break c}break b}if((e|0)!=-1){break b}}b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];a=c;break a}h=v[b+4>>2];i=h>>>0<g>>>0;j=(i<<3)+b|0;h=g-(i?h:0)|0;v[j>>2]=h+v[j>>2];j=(i?12:4)+b|0;v[j>>2]=v[j>>2]-h;b=i?b+8|0:b;e=e-g|0;f=f-i|0;continue}break}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a>>2]=v[a>>2]|32;a=0;if((f|0)==2){break a}a=c-v[b+4>>2]|0}cb=d+32|0;return a|0}function b2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=cb-80|0;cb=e;v[e+76>>2]=d;v[e+72>>2]=c;v[22440]=0;c=v[b+12>>2];v[e+16>>2]=v[b+8>>2];v[e+20>>2]=c;c=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=c;c=T(1104,e+8|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){a:{b:{if(c){v[22440]=0;R(1105,e+48|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){d=e+56|0;lv(d,v[e+48>>2],v[e+52>>2]);b=Wf(e- -64|0,d);c=Wf(e+40|0,e+72|0);break b}break a}v[22440]=0;R(1106,e+48|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}d=e+56|0;lv(d,v[e+48>>2],v[e+52>>2]);b=Wf(e+32|0,d);c=Wf(e+24|0,e+72|0)}DD(a,v[b>>2],v[b+4>>2],v[c>>2],v[c+4>>2]);Md(d);Md(e+48|0);Md(e+72|0);cb=e+80|0;return}}a=P()|0;O()|0;Md(e+72|0);S(a|0);L()}function Gda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=cb-16|0;cb=g;ed(b,4);u[b+30>>1]=w[a+12|0]<<2;Kf(b+30|0,256);c=w[a+15|0];u[b+34>>1]=32;u[b+28>>1]=c;t[b+37|0]=w[a+13|0];t[b+36|0]=w[a+16|0];e=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=e;c=a+4|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=c;d=a+8|0;d=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+c|0;v[b+8>>2]=d;f=a+14|0;a=w[f|0];if(a&16){d=d>>>1|0;v[b+8>>2]=d;c=c>>>1|0;v[b+4>>2]=c;e=e>>>1|0;v[b>>2]=e;a=w[f|0]}if(a&32){d=d>>>1|0;v[b+8>>2]=d;c=c>>>1|0;v[b+4>>2]=c;v[b>>2]=e>>>1;a=w[f|0]}if(!(!(a&3)|c>>>0>=d>>>0)){u[b+34>>1]=34;u[b+34>>1]=w[f|0]&2?38:34}a=Bc(g,21685);pe(b+43|0,a);rb(a);cb=g+16|0}function rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=cb-16|0;cb=b;i=v[a+16>>2];h=Zf(1,2);e=fb;j=e;Jb(a,h,e);f=v[a+40>>2];g=v[a+36>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){m=((((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&2147483646)<<1)+i|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=u[(e<<1)+m>>1];e=e+1|0;continue}break}e=v[a+32>>2];g=v[a+28>>2]+g|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=e+f|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Jb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+8>>2];d=v[b+12>>2];v[a+36>>2]=g;v[a>>2]=c;v[a+4>>2]=d;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+24>>2]=f>>12;lg(a,h,j);cb=b+16|0}function Nga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=cb-16|0;cb=e;j=e,k=yj(b),v[j>>2]=k;f=x[b>>1];c=cb-16|0;cb=c;g=a;a=Kd(a);a:{b:{if(a){b=bc(g);while(1){c:{d=a+14|0;if(wA(f,d)){d=v[a>>2];if(!d){break b}break c}if(vA(d,f)){b=a+4|0;d=v[a+4>>2];if(d){a=b;break c}v[c+12>>2]=a;a=b;break a}v[c+12>>2]=a;a=b;break a}b=a;a=d;continue}}a=bc(g)}v[c+12>>2]=a}b=a;a=v[a>>2];if(!a){d=cb-16|0;cb=d;a=bc(g);h=kh(c,lc(20),lh(d+8|0,a));f=v[h>>2]+14|0;a=cb-16|0;cb=a;v[a+8>>2]=v[e>>2];i=x[v[a+8>>2]>>1];u[f+2>>1]=0;u[f>>1]=i;cb=a+16|0;j=bc(h),k=1,t[j+4|0]=k;cb=d+16|0;Ig(g,v[c+12>>2],b,v[c>>2]);a=Vd(c);pk(c);h=1}b=e+8|0;Hg(b,ac(c,a),h);cb=c+16|0;a=Xn(b);cb=e+16|0;return a+2|0}function Iba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=cb-48|0;cb=f;g=a+8|0;c=v[a+8>>2];j=mc(a);a:{if((c|0)!=v[j>>2]){break a}i=a+4|0;d=v[a+4>>2];e=v[a>>2];if(d>>>0>e>>>0){a=((d-e>>2)+1|0)/-2<<2;c=Qi(d,c,a+d|0);v[g>>2]=c;v[i>>2]=a+v[i>>2];break a}v[f+24>>2]=c-e>>1;v[f+44>>2]=1;d=f+24|0;c=v[Pc(d,f+44|0)>>2];c=$f(d,c,c>>>2|0,v[a+16>>2]);e=ac(f+16|0,v[a+4>>2]);h=v[ac(f+8|0,v[a+8>>2])>>2];d=cb-32|0;cb=d;e=v[e>>2];v[d+24>>2]=e;e=Fl(d+8|0,c+8|0,It(h,e));while(1){h=v[e>>2];if((h|0)!=v[e+4>>2]){sm(h,v[d+24>>2]);v[e>>2]=v[e>>2]+4;Ge(d+24|0);continue}break}Gd(e);cb=d+32|0;ec(a,c);ec(i,c+4|0);ec(g,c+8|0);ec(j,mc(c));_f(c);c=v[a+8>>2]}sm(c,b);v[g>>2]=v[g>>2]+4;cb=f+48|0}function Rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=cb-16|0;cb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+8>>2];l=(((v[b+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;e=f>>>21&2040;m=u[e+39830>>1];n=u[e+39828>>1];o=u[e+39826>>1];p=u[e+39824>>1];e=0;while(1){if((e|0)!=2){f=e+l|0;v[(e<<2)+b>>2]=(((B(t[f|0],o)+B(t[f-2|0],p)|0)+B(t[f+2|0],n)|0)+B(t[f+4|0],m)<<8)/16384;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g);Jb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;cb=b+16|0}function Xaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=cb-80|0;cb=d;e=of(d+48|0);v[22440]=0;c=Q(817,b|0,e|0)|0;f=v[22440];v[22440]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22440]=0;T(818,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break b}}break a}c=e+4|0;c=Wb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));c=c?c:-1;v[22440]=0;U(192,d|0,b|0,c|0);f=v[22440];v[22440]=0;if((f|0)==1){break a}f=cc(d+24|0,d);Sc(e+8|0,f);sb(f);sb(d);d:{c=c&1;if(!c){break d}v[22440]=0;Q(190,b|0,2-c|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break d}break a}Cj(a,e)}Xc(e);cb=d+80|0;return}a=P()|0;O()|0;Xc(e);S(a|0);L()}function nia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb-96|0;cb=d;e=v[c>>2];as(d- -64|0,c);v[22440]=0;U(87,d|0,b|0,(e&2?16:10)|0);b=v[22440];v[22440]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=d+16|0;$r(b,d,v[d+64>>2]);v[22440]=0;W(84,d+32|0,b|0,v[d+64>>2],v[d+68>>2]);b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;U(85,d+48|0,d+32|0,d- -64|0);b=v[22440];v[22440]=0;if((b|0)==1){break f}v[22440]=0;R(73,a|0,d+48|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}rb(d+48|0);rb(d+32|0);rb(d+16|0);rb(d);Qc(d- -64|0);cb=d+96|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;rb(d+48|0)}rb(d+32|0)}rb(d+16|0);rb(d)}Qc(d- -64|0);S(a|0);L()}}function kga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb-96|0;cb=d;e=v[c>>2];is(d- -64|0,c);v[22440]=0;U(81,d|0,b|0,(e&2?16:10)|0);b=v[22440];v[22440]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=d+16|0;gs(b,d,v[d+64>>2]);v[22440]=0;W(77,d+32|0,b|0,v[d+64>>2],v[d+68>>2]);b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;U(78,d+48|0,d+32|0,d- -64|0);b=v[22440];v[22440]=0;if((b|0)==1){break f}v[22440]=0;R(59,a|0,d+48|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}rb(d+48|0);rb(d+32|0);rb(d+16|0);rb(d);Qc(d- -64|0);cb=d+96|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;rb(d+48|0)}rb(d+32|0)}rb(d+16|0);rb(d)}Qc(d- -64|0);S(a|0);L()}}function jga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb-96|0;cb=d;e=v[c>>2];is(d- -64|0,c);v[22440]=0;U(80,d|0,b|0,(e&2?16:10)|0);b=v[22440];v[22440]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=d+16|0;gs(b,d,v[d+64>>2]);v[22440]=0;W(77,d+32|0,b|0,v[d+64>>2],v[d+68>>2]);b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;U(78,d+48|0,d+32|0,d- -64|0);b=v[22440];v[22440]=0;if((b|0)==1){break f}v[22440]=0;R(59,a|0,d+48|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}rb(d+48|0);rb(d+32|0);rb(d+16|0);rb(d);Qc(d- -64|0);cb=d+96|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;rb(d+48|0)}rb(d+32|0)}rb(d+16|0);rb(d)}Qc(d- -64|0);S(a|0);L()}}function bka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb-96|0;cb=d;e=v[c>>2];is(d- -64|0,c);v[22440]=0;U(82,d|0,b|0,(e&2?16:10)|0);b=v[22440];v[22440]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=d+16|0;gs(b,d,v[d+64>>2]);v[22440]=0;W(77,d+32|0,b|0,v[d+64>>2],v[d+68>>2]);b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;U(78,d+48|0,d+32|0,d- -64|0);b=v[22440];v[22440]=0;if((b|0)==1){break f}v[22440]=0;R(59,a|0,d+48|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}rb(d+48|0);rb(d+32|0);rb(d+16|0);rb(d);Qc(d- -64|0);cb=d+96|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;rb(d+48|0)}rb(d+32|0)}rb(d+16|0);rb(d)}Qc(d- -64|0);S(a|0);L()}}function GW(){var a=0,b=0,c=0,d=0;a=SC(v[v[115698]-12>>2]+462792|0,10);c=cb-16|0;cb=c;v[22440]=0;b=Q(13,c+8|0,462792)|0;d=v[22440];v[22440]=0;a:{b:{c:{d:{if((d|0)!=1){e:{if(!w[b|0]){break e}d=Ni(c,462792);v[22440]=0;a=Q(21,d|0,a|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){if(!Mu(a)){break e}a=v[v[115698]-12>>2];v[22440]=0;R(16,a+462792|0,1);a=v[22440];v[22440]=0;if((a|0)!=1){break e}}a=V(0)|0;O()|0;xk(b);break d}xk(b);break c}a=V(0)|0;O()|0}_(a|0)|0;b=v[v[115698]-12>>2];v[22440]=0;Z(17,b+462792|0);b=v[22440];v[22440]=0;if((b|0)==1){break b}$()}cb=c+16|0;break a}c=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(c|0);L()}V(0)|0;O()|0;Lb();L()}_u(462792)}function z1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb-96|0;cb=d;e=v[c>>2];is(d- -64|0,c);v[22440]=0;U(76,d|0,b|0,(e&2?16:10)|0);b=v[22440];v[22440]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=d+16|0;gs(b,d,v[d+64>>2]);v[22440]=0;W(77,d+32|0,b|0,v[d+64>>2],v[d+68>>2]);b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;U(78,d+48|0,d+32|0,d- -64|0);b=v[22440];v[22440]=0;if((b|0)==1){break f}v[22440]=0;R(59,a|0,d+48|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}rb(d+48|0);rb(d+32|0);rb(d+16|0);rb(d);Qc(d- -64|0);cb=d+96|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;rb(d+48|0)}rb(d+32|0)}rb(d+16|0);rb(d)}Qc(d- -64|0);S(a|0);L()}}function aV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb-96|0;cb=d;e=v[c>>2];as(d- -64|0,c);v[22440]=0;U(83,d|0,b|0,(e&2?16:10)|0);b=v[22440];v[22440]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=d+16|0;$r(b,d,v[d+64>>2]);v[22440]=0;W(84,d+32|0,b|0,v[d+64>>2],v[d+68>>2]);b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;U(85,d+48|0,d+32|0,d- -64|0);b=v[22440];v[22440]=0;if((b|0)==1){break f}v[22440]=0;R(73,a|0,d+48|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}rb(d+48|0);rb(d+32|0);rb(d+16|0);rb(d);Qc(d- -64|0);cb=d+96|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;rb(d+48|0)}rb(d+32|0)}rb(d+16|0);rb(d)}Qc(d- -64|0);S(a|0);L()}}function ZV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb-96|0;cb=d;e=v[c>>2];as(d- -64|0,c);v[22440]=0;U(89,d|0,b|0,(e&2?16:10)|0);b=v[22440];v[22440]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=d+16|0;$r(b,d,v[d+64>>2]);v[22440]=0;W(84,d+32|0,b|0,v[d+64>>2],v[d+68>>2]);b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;U(85,d+48|0,d+32|0,d- -64|0);b=v[22440];v[22440]=0;if((b|0)==1){break f}v[22440]=0;R(73,a|0,d+48|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}rb(d+48|0);rb(d+32|0);rb(d+16|0);rb(d);Qc(d- -64|0);cb=d+96|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;rb(d+48|0)}rb(d+32|0)}rb(d+16|0);rb(d)}Qc(d- -64|0);S(a|0);L()}}function T0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb-96|0;cb=d;e=v[c>>2];as(d- -64|0,c);v[22440]=0;U(88,d|0,b|0,(e&2?16:10)|0);b=v[22440];v[22440]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=d+16|0;$r(b,d,v[d+64>>2]);v[22440]=0;W(84,d+32|0,b|0,v[d+64>>2],v[d+68>>2]);b=v[22440];v[22440]=0;if((b|0)==1){break g}v[22440]=0;U(85,d+48|0,d+32|0,d- -64|0);b=v[22440];v[22440]=0;if((b|0)==1){break f}v[22440]=0;R(73,a|0,d+48|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}rb(d+48|0);rb(d+32|0);rb(d+16|0);rb(d);Qc(d- -64|0);cb=d+96|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;rb(d+48|0)}rb(d+32|0)}rb(d+16|0);rb(d)}Qc(d- -64|0);S(a|0);L()}}function eI(a){var b=0,c=0,d=0,e=0,f=0;b=cb-192|0;cb=b;c=b+16|0;Cg(c,a);v[22440]=0;R(90,b+32|0,c|0);a=v[22440];v[22440]=0;a:{b:{c:{d:{if((a|0)!=1){v[22440]=0;a=Q(91,b+48|0,b+32|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break d}rb(b+32|0);rb(b+16|0);c=v[v[a>>2]-12>>2];v[22440]=0;d=ha(63)|0;e=v[22440];v[22440]=0;if((e|0)==1){break b}v[22440]=0;U(64,b+8|0,c+(b+48|0)|0,d|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}Pb(b+8|0);v[22440]=0;Q(96,a|0,b+32|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break b}c=Zj(v[v[a>>2]-12>>2]+(b+48|0)|0);f=A[b+32>>3];uf(a);cb=b+192|0;return c?0:f}c=P()|0;O()|0;break c}c=P()|0;O()|0;rb(b+32|0)}rb(b+16|0);break a}c=P()|0;O()|0;uf(a)}S(c|0);L()}function lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=cb-16|0;cb=f;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=(v[f+12>>2]<<1)+j|0;g=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[g+34>>1])+B(u[e+2>>1],u[g+32>>1])|0)+B(u[e+6>>1],u[g+36>>1])|0)+B(u[e+8>>1],u[g+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[g+26>>1])+B(u[e-6>>1],u[g+24>>1])|0)+B(u[e-2>>1],u[g+28>>1])|0)+B(u[e>>1],u[g+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Jb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;cb=f+16|0}function _u(a){var b=0,c=0,d=0,e=0;d=cb-16|0;cb=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[22440]=0;c=Q(13,d+8|0,a|0)|0;b=v[22440];v[22440]=0;c:{if((b|0)!=1){d:{if(!w[c|0]){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[22440]=0;b=T(22,b|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[22440]=0;R(16,a+b|0,1);b=v[22440];v[22440]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;xk(c);break c}xk(c);break b}b=V(0)|0;O()|0}_(b|0)|0;c=v[v[a>>2]-12>>2];v[22440]=0;Z(17,a+c|0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$()}cb=d+16|0;return}a=P()|0;O()|0;v[22440]=0;X(18);c=v[22440];v[22440]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function JI(a,b,c){var d=0,e=0,f=0,g=0;e=cb-16|0;cb=e;v[e+12>>2]=c;a:{b:{if(!b){a=a+120|0;qn(a);b=v[e+12>>2];c=yd(a);if(b){v[22440]=0;R(1092,a|0,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break a}DI(a,b)}t[a+20|0]=0;break b}d=cb-16|0;cb=d;v[d+12>>2]=c;c:{if((b|0)==1){b=a+120|0;qn(b);II(b,a,v[d+12>>2]);t[b+20|0]=1;break c}f=cb-16|0;cb=f;v[f+12>>2]=c;d:{if((b|0)==2){a=a+120|0;qn(a);b=v[f+12>>2];c=yd(a);if(b){v[22440]=0;R(1091,a|0,b|0);g=v[22440];v[22440]=0;if((g|0)==1){break a}DI(a,b)}ee(a+12|0);t[a+20|0]=2;break d}b=cb-16|0;cb=b;v[b+12>>2]=c;c=a+120|0;qn(c);II(c,a,v[b+12>>2]);t[c+20|0]=3;cb=b+16|0}cb=f+16|0}cb=d+16|0}cb=e+16|0;return}a=P()|0;O()|0;_b(c);S(a|0);L()}function xha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=cb-32|0;cb=d;v[d+28>>2]=0;nk(a,d+28|0);a:{b:{i=v[d+28>>2];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Db(d+16|0);v[22440]=0;u[d+14>>1]=0;e=Y(496,a|0,g|0,255)|0;h=v[22440];v[22440]=0;if((h|0)==1){break b}if(!e){break d}v[22440]=0;R(485,a|0,d+14|0);e=v[22440];v[22440]=0;if((e|0)==1){break b}v[22440]=0;U(11,d|0,c|0,g|0);e=v[22440];v[22440]=0;if((e|0)!=1){v[22440]=0;e=Q(497,b|0,d+14|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break e}Cb(e,d);rb(d);rb(g);f=f+1|0;continue}break}f=P()|0;O()|0;break a}f=P()|0;O()|0;rb(d);break a}rb(g)}cb=d+32|0;return}f=P()|0;O()|0}rb(g);S(f|0);L()}function TM(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=cb-112|0;cb=f;v[f+108>>2]=0;d=Cn(a,e&65535,d,c,f+108|0);c=w[b+790|0];if(!v[f+108>>2]){e=(c|0)==15;h=e&!w[b+792|0];d=d<<8;a:{if(d){v[b+664>>2]=d;break a}d=0;if(e){break a}d=v[b+664>>2]}h=h?0:w[b+836|0]<<16}if((c|0)==15){c=w[b+792|0];b:{if(!c){c=v[b+76>>2];v[f>>2]=1;e=v[Pc(f,f+108|0)>>2]<<3;g=kka(c,0,d,0);d=(256<<e>>>1|0)+g|0;c=fb;c=d>>>0<g>>>0?c+1|0:c;g=d;e=e+8|0;d=e&31;if((e&63)>>>0>=32){e=0;c=c>>>d|0}else{e=c>>>d|0;c=((1<<d)-1&c)<<32-d|g>>>d}d=wc(c,e);break b}QA(f);if(c>>>0>9){break b}c=v[b+104>>2];if(!c){break b}d=v[Ib(c+68|0,w[b+792|0]-1|0)>>2]+d|0}v[b+664>>2]=d}Gn(a,b,d+h|0);cb=f+112|0}function jy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=cb-16|0;cb=e;b=v[a>>2];if(!hc(b,v[a+4>>2])){b=yb(b);v[e+8>>2]=b;c=yb(v[a+4>>2]);while(1){if(Qb(b,c)){xo(b,4194304,67108864);g=v[b>>2];f=g+f|0;b=d;b=f>>>0<g>>>0?b+1|0:b;d=b;Ge(e+8|0);b=v[e+8>>2];continue}else{c=v[a>>2];b=pc(c,v[a+4>>2]);l=e,m=yb(c),v[l>>2]=m;d=nka(f,d,b,0);h=d;g=((fb&1)<<31|d>>>1)&2147483647;f=b<<24;d=0;i=yb(v[a+4>>2]);while(1){b=v[e>>2];if(Qb(b,i)){j=b;c=v[b>>2];b=c>>>8|0;c=g+(c<<24)|0;b=b+k|0;b=wc(nka(c,c>>>0<g>>>0?b+1|0:b,h,k),fb);v[j>>2]=b;c=f;f=c-b|0;d=d-(b>>>0>c>>>0)|0;Ge(e);continue}else{d=v[a>>2];if(!pc(d,v[a+4>>2])){Pu();L()}v[d>>2]=f+v[d>>2]}break}}break}}cb=e+16|0}function GK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=C(0),k=0,l=C(0);g=cb-16|0;cb=g;e=u[d>>1];f=u[d+2>>1];if(!(!x[b>>1]|(e|0)>(f|0)|(!(z[c>>2]>C(0))|(f-e|0)>32766))){u[a>>1]=3;f=a+4|0;Ac(f);u[a+28>>1]=65472;v[g+12>>2]=1065353216;IK(f,g+12|0);v[a+32>>2]=0;u[a+30>>1]=0;Ac(a+16|0);h=u[d>>1];u[a+28>>1]=h;e=cb-16|0;cb=e;u[e+14>>1]=x[b>>1];u[e+12>>1]=32767;b=u[Kc(e+14|0,e+12|0)>>1];cb=e+16|0;u[a+30>>1]=b;i=C(D(z[c>>2]));z[a+32>>2]=i;i=te(i,C(C(1)/C(b|0)));ak(f,(u[d+2>>1]-h|0)+1|0);b=u[d+2>>1];d=u[d>>1];while(1){if((b|0)<(d|0)){ip(a)}else{j=te(i,C(d|0));k=Ib(v[a+4>>2],d-u[a+28>>1]|0),l=j,z[k>>2]=l;d=d+1|0;continue}break}h=1}cb=g+16|0;return h|0}function sda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=cb-16|0;cb=b;i=v[a+16>>2];h=Zf(1,2);e=fb;j=e;Jb(a,h,e);f=v[a+40>>2];g=v[a+36>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){m=(((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&-2)+i|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=t[e+m|0]<<8;e=e+1|0;continue}break}e=v[a+32>>2];g=v[a+28>>2]+g|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=e+f|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Jb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+8>>2];d=v[b+12>>2];v[a+36>>2]=g;v[a>>2]=c;v[a+4>>2]=d;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+24>>2]=f>>12;lg(a,h,j);cb=b+16|0}function hja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=cb-32|0;cb=e;v[e+24>>2]=b;k=e,l=fd(a),v[k+8>>2]=l;g=xn(e+24|0,e+8|0);a:{b:{h=Oh(c,d);if(!h){break b}if(!Js(a,c)){b=vb(a);f=Dc(a);c:{if(f-b>>>0>=h>>>0){f=Fb(a);i=b-g|0;if(!i){break c}j=g+f|0;Rh(j+h|0,j,i);break c}fm(a,f,(b+h|0)-f|0,b,g,0,h);f=v[a>>2]}b=b+h|0;Bf(a,b);t[e+8|0]=0;$d(b+f|0,e+8|0);b=g+f|0;while(1){if((c|0)==(d|0)){break b}$d(b,c);c=c+1|0;b=b+1|0;continue}}d=Ph(e+8|0,c,d);c=Fb(d);g=vb(d);v[22440]=0;c=da(367,a|0,b|0,c|0,c+g|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){rb(d);break a}a=P()|0;O()|0;rb(d);S(a|0);L()}k=e,l=fd(a),v[k+8>>2]=l;c=je(e+8|0,g)}cb=e+32|0;return c|0}function yK(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{e=cb-48|0;cb=e;d=Db(e+32|0);v[22440]=0;R(914,b|0,e+24|0);f=v[22440];v[22440]=0;if((f|0)!=1){b:{g=v[e+28>>2];f=v[e+24>>2];dg(d);v[22440]=0;f=!g&f>>>0<255?f:255;R(61,d|0,f|0);g=v[22440];v[22440]=0;if((g|0)==1){break b}c:{while(1){if((f|0)==(h|0)){b=CU(Fb(d),vb(d));if((b|0)==-1){break c}v[22440]=0;R(61,d|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break c}break b}g=rc(d,h);v[22440]=0;Q(915,b|0,g|0)|0;g=v[22440];v[22440]=0;if((g|0)!=1){h=h+1|0;continue}break}break b}v[22440]=0;U(11,e+8|0,a|0,d|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}a=e+8|0;Cb(c,a);rb(a);rb(d);cb=e+48|0;break a}}a=P()|0;O()|0;rb(d);S(a|0);L()}}function wha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=cb-32|0;cb=d;u[d+30>>1]=0;bg(a,d+30|0);a:{b:{i=x[d+30>>1];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Db(d+16|0);v[22440]=0;u[d+14>>1]=0;e=Q(498,a|0,g|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break b}if(!e){break d}v[22440]=0;R(485,a|0,d+14|0);e=v[22440];v[22440]=0;if((e|0)==1){break b}v[22440]=0;U(11,d|0,c|0,g|0);e=v[22440];v[22440]=0;if((e|0)!=1){v[22440]=0;e=Q(497,b|0,d+14|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break e}Cb(e,d);rb(d);rb(g);f=f+1|0;continue}break}f=P()|0;O()|0;break a}f=P()|0;O()|0;rb(d);break a}rb(g)}cb=d+32|0;return}f=P()|0;O()|0}rb(g);S(f|0);L()}function bx(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=C(0);g=cb-80|0;cb=g;h=a+24|0;op(v[h>>2]);t[v[h>>2]+1298420|0]=v[a+52>>2]!=0;v[g+76>>2]=f;v[g+72>>2]=e;v[g+68>>2]=d;v[g+64>>2]=c;c=g- -64|0;c=pg(g+16|0,c,wI(c),b);d=v[c>>2];e=v[c+4>>2];f=v[c+8>>2];j=v[a+32>>2];k=z[a+48>>2];c=g+32|0;Vr(c);v[c+20>>2]=f;v[c+16>>2]=e;v[c+12>>2]=d;v[c+8>>2]=j;v[c+4>>2]=0;v[c>>2]=54704;z[c+24>>2]=k;v[c>>2]=53908;a:{if(b){while(1){b:{d=v[h>>2];v[g+8>>2]=b;v[g+12>>2]=0;v[g>>2]=134217727;v[g+4>>2]=0;d=Wr(d,v[Dl(g+8|0,g)>>2],c);i=d+i|0;if(!d){break b}b=b-d|0;if(b){continue}}break}if(i){break a}}i=0;if(v[a+52>>2]!=1){break a}a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}cb=g+80|0;return i}function ax(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=C(0);g=cb-80|0;cb=g;h=a+24|0;op(v[h>>2]);t[v[h>>2]+1298420|0]=v[a+52>>2]!=0;v[g+76>>2]=f;v[g+72>>2]=e;v[g+68>>2]=d;v[g+64>>2]=c;c=g- -64|0;c=pg(g+16|0,c,wI(c),b);d=v[c>>2];e=v[c+4>>2];f=v[c+8>>2];j=v[a+32>>2];k=z[a+48>>2];c=g+32|0;Vr(c);v[c+20>>2]=f;v[c+16>>2]=e;v[c+12>>2]=d;v[c+8>>2]=j;v[c+4>>2]=0;v[c>>2]=55548;z[c+24>>2]=k;v[c>>2]=54784;a:{if(b){while(1){b:{d=v[h>>2];v[g+8>>2]=b;v[g+12>>2]=0;v[g>>2]=134217727;v[g+4>>2]=0;d=Wr(d,v[Dl(g+8|0,g)>>2],c);i=d+i|0;if(!d){break b}b=b-d|0;if(b){continue}}break}if(i){break a}}i=0;if(v[a+52>>2]!=1){break a}a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}cb=g+80|0;return i}function mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=cb-16|0;cb=f;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[f+12>>2]+j|0;g=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[g+34>>1])+B(t[e+1|0],u[g+32>>1])|0)+B(t[e+3|0],u[g+36>>1])|0)+B(t[e+4|0],u[g+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[g+26>>1])+B(t[e-3|0],u[g+24>>1])|0)+B(t[e-1|0],u[g+28>>1])|0)+B(t[e|0],u[g+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Jb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;cb=f+16|0}function Fn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(c){t[b+809|0]=c;break a}c=w[b+809|0]}e=v[a+480180>>2];d=e&202376205?(c&240?-16:15)&c:c;c=v[b+688>>2];b:{if(e&69206029){break b}f=d&240;g=d&15;c:{if((g|0)==15){if(f){En(a,b,(d&240)>>>4|0,0);return}f=-60;if(t[b+851|0]&1){break c}break b}if((f|0)!=240){break b}if(g){Dn(a,b,g,0);return}f=60;if(!(t[b+851|0]&1)){break b}}c=(w[a+480208|0]&2?0:f)+c|0}d:{if(!(!(t[b+851|0]&1)|w[a+480208|0]&2)&(v[a+1074416>>2]!=1|(e|0)!=524288)){break d}a=d&255;d=d&15;e:{if(d){if(a&240?e&16777248:0){break d}c=c-(d<<2)|0;break e}c=(a>>>2&60)+c|0}if((e|0)!=1){break d}v[b+88>>2]=v[b+88>>2]|2097152}h=b,i=Vb(c,0,256),v[h+688>>2]=i}function nh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=cb+-64|0;cb=e;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}if(ve(a,b)){break b}c:{d:{d=v[a>>2];if(vk(d,v[a+4>>2])>>>0<=b>>>0){d=Mx(e+8|0,a);v[22440]=0;U(203,a|0,b+1|0,d|0);f=v[22440];v[22440]=0;if((f|0)==1){break d}bl(d);d=v[a>>2]}v[22440]=0;Q(213,fg(d,b)|0,c|0)|0;c=v[22440];v[22440]=0;e:{if((c|0)!=1){c=fg(v[a>>2],b);v[c+16>>2]=0;v[c+20>>2]=0;c=v[a>>2];v[22440]=0;Z(214,fg(c,b)|0);c=v[22440];v[22440]=0;if((c|0)!=1){break e}}b=V(88360)|0;a=O()|0;break c}g=Vh(fg(v[a>>2],b));break b}b=V(88360)|0;a=O()|0;bl(d)}if((fa(88360)|0)!=(a|0)){break a}_(b|0)|0;$()}cb=e- -64|0;return g|0}S(b|0);L()}function WK(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=cb-16|0;cb=h;t[h+15|0]=b;t[h+14|0]=10;Qg(g,w[Tb(h+15|0,h+14|0)|0]);t[g+15|0]=c;t[g+16|0]=c;t[g+14|0]=e;t[g+13|0]=d;k=v[g>>2];b=0;a:{while(1){if(Dd(g)>>>0<=b>>>0){b:{b=w[g+12|0]&-2|a&1;t[g+12|0]=b;if(a&2){break b}b=b&251;break a}}else{m=Ib(k,b);l=B(b,3)+f|0;i=(w[l|0]|w[l+1|0]<<8)>>>4|0;u[m>>1]=i;c:{d:{if(!b){j=0;i=0;break d}j=x[Ib(k,b-1|0)>>1];if(i>>>0>=j>>>0){break c}j=j+1|0;i=b}n=Ib(k,i),o=j,u[n>>1]=o}n=m,o=wd(w[l+2|0],0,64),t[n+2|0]=o;b=b+1|0;continue}break}b=b&-5|(Dd(g)>>>0>=c>>>0)<<2}t[g+12|0]=b;if(d>>>0<=e>>>0?a&4:0){a=b&-3|(Dd(g)>>>0>=d>>>0)<<1}else{a=b&253}t[g+12|0]=a;cb=h+16|0}function pv(a,b,c,d){var e=0,f=0,g=0;e=cb-48|0;cb=e;v[e+44>>2]=d;a:{f=v[b>>2];b:{if(!(gb[v[v[f>>2]+36>>2]](f,c,d)|0)){ED(a);break b}Jl(e+24|0,v[b>>2],v[b+4>>2]);b=v[b>>2];d=v[v[b>>2]+24>>2];v[22440]=0;b=T(d|0,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}v[e+20>>2]=b-c;d=v[e+24>>2];f=v[e+28>>2];g=v[Bb(e+44|0,e+20|0)>>2];b=cb-16|0;cb=b;v[b+12>>2]=f;v[b+8>>2]=d;d=Jl(b,d,f);f=v[d+4>>2];d=v[d>>2];v[22440]=0;ga(174,e+32|0,d|0,f|0,c|0,g|0);c=v[22440];v[22440]=0;c:{if((c|0)!=1){Md(b+8|0);cb=b+16|0;break c}a=P()|0;O()|0;Md(b+8|0);S(a|0);L()}b=ee(e+8|0);DD(a,v[e+32>>2],v[e+36>>2],v[b>>2],v[b+4>>2])}cb=e+48|0;return}a=P()|0;O()|0;Md(e+24|0);S(a|0);L()}function faa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=cb-16|0;cb=h;f=cb-16|0;cb=f;g=b;b=Kd(b);a:{b:{if(b){d=bc(g);while(1){c:{e=b+16|0;if(eL(c,e)){e=v[b>>2];if(!e){break b}break c}if(eL(e,c)){d=b+4|0;e=v[b+4>>2];if(e){b=d;break c}v[f+12>>2]=b;b=d;break a}v[f+12>>2]=b;b=d;break a}d=b;b=e;continue}}b=bc(g)}v[f+12>>2]=b}d=v[b>>2];if(!d){d=cb-16|0;cb=d;e=bc(g);e=kh(f,lc(28),lh(d+8|0,e));i=v[e>>2];v[22440]=0;R(870,i+16|0,c|0);c=v[22440];v[22440]=0;d:{if((c|0)!=1){j=bc(e),k=1,t[j+4|0]=k;cb=d+16|0;break d}a=P()|0;O()|0;dL(e);S(a|0);L()}Ig(g,v[f+12>>2],b,v[f>>2]);d=Vd(f);dL(f);i=1}b=h+8|0;Hg(b,ac(f,d),i);cb=f+16|0;CO(a,b);cb=h+16|0}function C1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=cb-32|0;cb=d;g=b+24|0;h=Db(a);a=Db(d+16|0);b=1;a:{b:{c:{while(1){c=b&65535;if(c>>>0>x[v[g>>2]+480192>>1]){if(!(i&1)){break c}v[22440]=0;R(253,h|0,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){break c}b=P()|0;O()|0;break a}c=xL(v[g>>2],c);v[22440]=0;c=Q(56,d|0,c|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break b}e=xd(c);v[22440]=0;f=Q(824,a|0,c|0)|0;j=v[22440];v[22440]=0;d:{if((j|0)==1){break d}v[22440]=0;Q(960,f|0,21655)|0;f=v[22440];v[22440]=0;if((f|0)==1){break d}i=e^1|i;rb(c);b=b+1|0;continue}break}b=P()|0;O()|0;rb(c);break a}rb(a);cb=d+32|0;return}b=P()|0;O()|0}rb(a);rb(h);S(b|0);L()}function B1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=cb-32|0;cb=e;g=b+24|0;h=Db(a);a=Db(e+16|0);b=1;a:{b:{c:{while(1){c=b&65535;if(c>>>0>x[v[g>>2]+480190>>1]){if(!(i&1)){break c}v[22440]=0;R(253,h|0,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){break c}b=P()|0;O()|0;break a}d=v[g>>2];v[22440]=0;c=Q(56,e|0,yL(d,c)|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break b}d=xd(c);v[22440]=0;f=Q(824,a|0,c|0)|0;j=v[22440];v[22440]=0;d:{if((j|0)==1){break d}v[22440]=0;Q(960,f|0,21655)|0;f=v[22440];v[22440]=0;if((f|0)==1){break d}i=d^1|i;rb(c);b=b+1|0;continue}break}b=P()|0;O()|0;rb(c);break a}rb(a);cb=e+32|0;return}b=P()|0;O()|0}rb(a);rb(h);S(b|0);L()}function v2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b;b=0;c=cb-32|0;cb=c;e=v[a>>2];a=v[e>>2];Pf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[e+4>>2];f=v[a+8>>2];e=v[a+4>>2];g=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(e>>>0<=y[c+4>>2]){if(Of(c)>>>0<f>>>0){break b}h=d+12|0;c:while(1){a=0;if((b|0)==(f|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue c}else{d=bd((v[Kh(g,e,a,b)>>2]+bd(Tr(h),21)|0)+2048|0,12);d=(d|0)<32767?d:32767;i=pn(c,a,b),j=(d|0)>-32768?d:-32768,u[i>>1]=j;a=a+1|0;continue}}}ca(7157,9074,34,8787);L()}ca(5870,9074,36,8787);L()}cb=c+32|0}function k2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b;b=0;c=cb-32|0;cb=c;e=v[a>>2];a=v[e>>2];Pf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[e+4>>2];f=v[a+8>>2];e=v[a+4>>2];g=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(e>>>0<=y[c+4>>2]){if(Of(c)>>>0<f>>>0){break b}h=d+12|0;c:while(1){a=0;if((b|0)==(f|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue c}else{d=bd((v[Kh(g,e,a,b)>>2]+bd(Tr(h),21)|0)+2048|0,12);d=(d|0)<32767?d:32767;i=on(c,a,b),j=(d|0)>-32768?d:-32768,u[i>>1]=j;a=a+1|0;continue}}}ca(7157,9074,34,8787);L()}ca(5870,9074,36,8787);L()}cb=c+32|0}function $m(a,b,c,d,e,f,g,h,i,j){var k=0,l=0;a:{b:{k=v[d>>2];if((k|0)!=(c|0)){break b}l=43;if(v[j+96>>2]!=(a|0)){l=45;if(v[j+100>>2]!=(a|0)){break b}}v[d>>2]=c+1;t[c|0]=l;break a}c:{if(!(!vb(g)|(a|0)!=(f|0))){g=0;a=v[i>>2];if((a-h|0)>159){break c}b=v[e>>2];v[i>>2]=a+4;v[a>>2]=b;break a}g=-1;f=Zv(j,j+104|0,a)-j|0;if((f|0)>92){break c}a=f>>2;d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<88){break d}if((c|0)==(k|0)|(k-c|0)>2|w[k-1|0]!=48){break c}v[e>>2]=0;v[d>>2]=k+1;t[k|0]=w[a+79696|0];return 0}v[d>>2]=k+1;t[k|0]=w[a+79696|0];v[e>>2]=v[e>>2]+1;g=0}return g}v[e>>2]=0;return 0}function uia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=cb-80|0;cb=e;f=of(e+48|0);v[22440]=0;c=Q(412,b|0,f|0)|0;d=v[22440];v[22440]=0;a:{b:{c:{d:{if((d|0)!=1){if(c){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22440]=0;T(413,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break a}}break c}c=cb-16|0;cb=c;d=f+4|0;g=c,h=Wb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)),v[g+12>>2]=h;v[c+8>>2]=8;d=v[Pc(c+12|0,c+8|0)>>2];cb=c+16|0;v[22440]=0;U(192,e|0,b|0,d-8|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Xc(f);S(a|0);L()}b=cc(e+24|0,e);Sc(f+8|0,b);sb(b);sb(e);Cj(a,f)}Xc(f);cb=e+80|0}function im(a,b,c,d){var e=0,f=0;e=cb-16|0;cb=e;f=a+1074312|0;ub(e+8|0,f,84);a:{if(tb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}b:{if(v[a+480208>>2]&16384){break b}if((d|0)!=8){ub(e+8|0,f,10);if(!tb(v[v[e+8>>2]>>2],v[e+12>>2])){break b}}v[b+88>>2]=v[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(v[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}v[b+88>>2]=v[b+88>>2]|256;c=128}v[b+692>>2]=c}u[b+784>>1]=0;v[b+88>>2]=v[b+88>>2]|2097152;ub(e+8|0,f,10);if(!tb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}t[b+831|0]=0;u[b+778>>1]=0}cb=e+16|0}function Oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=cb-16|0;cb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){l=v[a+32>>2];e=(v[b+12>>2]<<1)+i|0;h=v[b+8>>2]>>>21&2040;e=(((B(u[e>>1],u[h+39826>>1])+B(u[e-2>>1],u[h+39824>>1])|0)+B(u[e+2>>1],u[h+39828>>1])|0)+B(u[e+4>>1],u[h+39830>>1])|0)/16384|0;g=v[a+28>>2]+g|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+l|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Jb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];d=v[b+8>>2];v[a+36>>2]=g;v[a>>2]=d;v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+24>>2]=f>>12;cb=b+16|0}function afa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=cb-32|0;cb=d;ed(b,0);Wh(d,1,a);e=d+16|0;xc(e,v[d>>2],v[d+4>>2],w[d+8|0]);pe(b+43|0,e);rb(e);c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;vl(b,+((w[a+60|0]^8)-120|0)/192);t[d+16|0]=w[a+61|0];t[d|0]=64;g=b,h=w[Tb(e,d)|0]<<2,u[g+30>>1]=h;u[b+34>>1]=0;e=a+47|0;a=w[e|0];if(a&4){u[b+34>>1]=1;v[b>>2]=v[b>>2]>>>1;f=1;a=w[e|0]}if(a&32){f=f|4;u[b+34>>1]=f;a=w[e|0]}if(a<<24>>24<0){u[b+34>>1]=f|2}cb=d+32|0}function H0(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=cb-32|0;cb=e;if(Ea(1,e+16|0)|0){Gr(v[114922],12747);L()}c=Fr(e+8|0,v[e+16>>2]);g=Fr(e,v[e+20>>2]);d=cb-32|0;cb=d;b=cb-16|0;cb=b;a=cb-16|0;cb=a;h=a,i=kka(v[c>>2],v[c+4>>2],1e9,0),v[h>>2]=i;v[a+4>>2]=fb;c=mt(a+8|0,a);f=v[c+4>>2];c=v[c>>2];cb=a+16|0;v[b+8>>2]=c;v[b+12>>2]=f;a=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=a;cb=b+16|0;f=v[d+8>>2];c=v[d+12>>2];a=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=a;a=d;c=v[a+4>>2]+c|0;b=v[a>>2];f=f+b|0;v[a+16>>2]=f;v[a+20>>2]=b>>>0>f>>>0?c+1|0:c;a=mt(a+24|0,a+16|0);b=v[a+4>>2];a=v[a>>2];cb=d+32|0;a=Zl(e+24|0,a,b);b=v[a+4>>2];a=v[a>>2];cb=e+32|0;fb=b;return a|0}function k0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=cb-16|0;cb=g;a:{b:{if(!hc(b,-1)){i=v[a+8>>2];j=v[a+12>>2];d=v[a+24>>2];if((d|0)==v[a+28>>2]){e=-1;if(!(w[a+48|0]&16)){break a}h=v[a+20>>2];k=v[a+44>>2];v[22440]=0;c=a+32|0;R(48,c|0,0);f=v[22440];v[22440]=0;if((f|0)==1){break b}f=Dc(c);v[22440]=0;R(61,c|0,f|0);f=v[22440];v[22440]=0;if((f|0)==1){break b}e=Fb(c);rw(a,e,vb(c)+e|0);zr(a,d-h|0);v[a+44>>2]=v[a+20>>2]+(k-h|0);d=v[a+24>>2]}v[g+12>>2]=d+1;d=v[Pc(g+12|0,a+44|0)>>2];v[a+44>>2]=d;if(w[a+48|0]&8){c=Fb(a+32|0);fn(a,c,c+(j-i|0)|0,d)}e=uG(a,Vo(b));break a}e=qw(b);break a}a=V(0)|0;O()|0;_(a|0)|0;$()}cb=g+16|0;return e|0}function b4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=cb-32|0;cb=c;f=Rb(a);g=b+24|0;a=x[v[g>>2]+480190>>1];v[22440]=0;R(183,f|0,a|0);a=v[22440];v[22440]=0;a:{if((a|0)!=1){a=1;b:{c:{d:{e:{while(1){e=a&65535;if(e>>>0>x[v[g>>2]+480190>>1]){break b}d=v[g>>2];v[22440]=0;e=Q(56,c|0,yL(d,e)|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){v[22440]=0;U(1027,c+16|0,b|0,e|0);d=v[22440];v[22440]=0;if((d|0)==1){break e}v[22440]=0;R(185,f|0,c+16|0);d=v[22440];v[22440]=0;if((d|0)==1){break d}rb(c+16|0);rb(e);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;rb(c+16|0)}rb(e);break a}cb=c+32|0;return}a=P()|0;O()|0}ad(f);S(a|0);L()}function HH(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=cb-16|0;cb=d;a:{b:{c:{d:{if((b|0)>=0){if(($o(a+8|0)|0)>(b|0)){break d}}a=aa(8)|0;v[22440]=0;d=Q(56,d|0,10725)|0;b=v[22440];v[22440]=0;if((b|0)==1){break c}oc(a,d);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}b=P()|0;O()|0;rb(d);break b}if(c<0|c>1){a=aa(8)|0;v[22440]=0;d=Q(56,d|0,11788)|0;b=v[22440];v[22440]=0;if((b|0)!=1){oc(a,d);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}b=P()|0;O()|0;rb(d);break b}b=P()|0;O()|0;ba(a|0);break b}e=tl(c*64);v[(v[a+32>>2]+B(b,872)|0)+1075740>>2]=e;cb=d+16|0;return}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function B4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=cb-32|0;cb=d;f=Rb(a);g=b+24|0;a=x[v[g>>2]+480192>>1];v[22440]=0;R(183,f|0,a|0);a=v[22440];v[22440]=0;a:{if((a|0)!=1){a=1;b:{c:{d:{e:{while(1){c=a&65535;if(c>>>0>x[v[g>>2]+480192>>1]){break b}c=xL(v[g>>2],c);v[22440]=0;c=Q(56,d|0,c|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){v[22440]=0;U(1027,d+16|0,b|0,c|0);e=v[22440];v[22440]=0;if((e|0)==1){break e}v[22440]=0;R(185,f|0,d+16|0);e=v[22440];v[22440]=0;if((e|0)==1){break d}rb(d+16|0);rb(c);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;rb(d+16|0)}rb(c);break a}cb=d+32|0;return}a=P()|0;O()|0}ad(f);S(a|0);L()}function gD(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if(Mb(a,3878,4)){break a}b=a+16|0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(c>>>0<36){break a}b=a+24|0;d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(d>>>0<36){break a}b=a+32|0;e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(e>>>0<36){break a}b=a+12|0;f=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(f-1>>>0>858993458){break a}b=a+20|0;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(b-1>>>0>536870910){break a}a=a+28|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);if(B(f,-5)-1>>>0<c>>>0|a-1>>>0>1073741822|(b<<3^-1)>>>0<d>>>0){break a}g=(a<<2^-1)>>>0>=e>>>0}return g}function Np(a,b,c){var d=0,e=0,f=0;d=Db(a);a=vb(b);v[22440]=0;R(47,d|0,a|0);a=v[22440];v[22440]=0;if((a|0)!=1){a:{while(1){if(vb(b)>>>0>e>>>0){f=v[hk(b,e)>>2];a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if(v[(a<<2)+c>>2]==(f|0)){v[22440]=0;R(48,d|0,a<<24>>24);a=v[22440];v[22440]=0;if((a|0)!=1){break b}break a}else{a=a+1|0;continue}}break}d:{while(1){if((a|0)==32){break d}if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}break}v[22440]=0;R(48,d|0,a<<24>>24);a=v[22440];v[22440]=0;if((a|0)!=1){break b}break a}v[22440]=0;R(48,d|0,63);a=v[22440];v[22440]=0;if((a|0)!=1){break b}break a}e=e+1|0;continue}break}return}}a=P()|0;O()|0;rb(d);S(a|0);L()}function j4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=cb-32|0;cb=c;e=Rb(a);f=b+24|0;a=Xs(v[f>>2]+484344|0);v[22440]=0;R(183,e|0,a|0);a=v[22440];v[22440]=0;a:{if((a|0)!=1){a=0;b:{c:{d:{e:{while(1){if(Xs(v[f>>2]+484344|0)>>>0<=a>>>0){break b}d=Sb(v[f>>2]+484344|0,a);v[22440]=0;R(1040,c|0,d|0);d=v[22440];v[22440]=0;if((d|0)!=1){v[22440]=0;U(1027,c+16|0,b|0,c|0);d=v[22440];v[22440]=0;if((d|0)==1){break e}v[22440]=0;R(185,e|0,c+16|0);d=v[22440];v[22440]=0;if((d|0)==1){break d}a=a+1|0;rb(c+16|0);rb(c);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;rb(c+16|0)}rb(c);break a}cb=c+32|0;return}a=P()|0;O()|0}ad(e);S(a|0);L()}function Vaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=cb-80|0;cb=d;e=of(d+48|0);v[22440]=0;g=Q(821,b|0,e|0)|0;f=v[22440];v[22440]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22440]=0;T(822,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break b}}break a}g=om(e);v[22440]=0;U(192,d|0,b|0,g|0);f=v[22440];v[22440]=0;if((f|0)==1){break a}f=cc(d+24|0,d);Sc(e+8|0,f);sb(f);sb(d);d:{if(c>>>0<2){break d}c=g&1;if(!c){break d}v[22440]=0;Q(190,b|0,2-c|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break d}break a}Cj(a,e)}Xc(e);cb=d+80|0;return}a=P()|0;O()|0;Xc(e);S(a|0);L()}function Pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=cb-16|0;cb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){l=v[a+32>>2];e=v[b+12>>2]+i|0;h=v[b+8>>2]>>>21&2040;e=(((B(t[e|0],u[h+39826>>1])+B(t[e-1|0],u[h+39824>>1])|0)+B(t[e+1|0],u[h+39828>>1])|0)+B(t[e+2|0],u[h+39830>>1])<<8)/16384|0;g=v[a+28>>2]+g|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+l|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Jb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];d=v[b+8>>2];v[a+36>>2]=g;v[a>>2]=d;v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+24>>2]=f>>12;cb=b+16|0}function sr(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=cb-16|0;cb=h;f=d?d:463316;d=v[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=w[b|0];d=a<<24>>24;if((d|0)>=0){v[i>>2]=a;e=(d|0)!=0;break a}if(!v[v[114924]>>2]){v[i>>2]=d&57343;e=1;break a}a=a-194|0;if(a>>>0>50){break c}d=v[(a<<2)+79488>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=w[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){v[f>>2]=0;v[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=w[b|0];if((g&192)==128){continue}break}}v[f>>2]=0;v[114922]=25;e=-1;break a}v[f>>2]=d}cb=h+16|0;return e}function waa(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){if((b|0)==(c|0)){Ds(a+484344|0);dg(a+1298308|0);Dt(a+1298320|0);dg(a+1298332|0);Ac(a+1298408|0);c=a+900380|0;b=a+484380|0;while(1){if((b|0)==(c|0)){a:{d=a+901404|0;b=a+900380|0;while(1){if((b|0)==(d|0)){c=a+946300|0;b=a+906300|0;while(1){if((b|0)==(c|0)){break a}IU(b);b=b+160|0;continue}}c=v[b>>2];if(c){Jt(c)}zb(c);v[b>>2]=0;b=b+4|0;continue}}}else{pm(b);b=b+104|0;continue}break}v[a+480180>>2]=0;v[a+480184>>2]=0;a=a+480186|0;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;u[a+6>>1]=0}else{v[b+104>>2]=0;v[b+656>>2]=0;v[b+76>>2]=0;v[b+16>>2]=0;b=b+872|0;continue}break}}function fia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=v[a>>2];d=mq(c,v[a+4>>2]);if(d>>>0<b>>>0){f=cb-32|0;cb=f;c=b-d|0;b=v[xb(a)>>2];e=v[a+4>>2];a:{if(c>>>0<=(b-e|0)/48>>>0){d=cb-16|0;cb=d;b=eU(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){dc(b);cb=d+16|0}else{iS(a);a=a+48|0;v[b+4>>2]=a;continue}break}break a}b=xb(a);d=bU(f+8|0,cU(a,mq(v[a>>2],e)+c|0),mq(v[a>>2],v[a+4>>2]),b);b=cb-16|0;cb=b;v[b>>2]=v[d+8>>2];e=v[d+8>>2];v[b+8>>2]=d+8;v[b+4>>2]=B(c,48)+e;c=v[b>>2];while(1){if(v[b+4>>2]!=(c|0)){iS(c);c=v[b>>2]+48|0;v[b>>2]=c;continue}break}Gd(b);cb=b+16|0;aU(a,d);$T(d)}cb=f+32|0;return}if(b>>>0<d>>>0){Nd(a,c+B(b,48)|0)}}function fN(a,b,c,d){var e=C(0),f=0,g=0,h=0,i=0,j=0;f=cb-16|0;cb=f;v[f+12>>2]=c>>>3;v[f+8>>2]=v[a>>2];a=v[a+20>>2];h=v[Bb(f+12|0,f+8|0)>>2];c=h;while(1){if(c){e=Qf((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()));e=zf(C(Pd(C((ng(e)?e>=C(0)?C(1):C(-1):e)*d),C(-1))*C(32768)));a:{if(C(D(e))<C(2147483648)){g=~~e;break a}g=-2147483648}i=a,j=Wc(g),u[i>>1]=j;e=Qf((l(2,w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24)),q()));e=zf(C(Pd(C((ng(e)?e>=C(0)?C(1):C(-1):e)*d),C(-1))*C(32768)));b:{if(C(D(e))<C(2147483648)){g=~~e;break b}g=-2147483648}i=a,j=Wc(g),u[i+2>>1]=j;a=a+4|0;b=b+8|0;c=c-1|0;continue}break}cb=f+16|0;return h<<3}function $u(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=cb-16|0;cb=f;t[f+15|0]=d;t[b+12|0]=w[a|0]&15|w[b+12|0]&240;i=a+1|0;e=f+15|0;Qg(b,w[Tb(i,e)|0]);g=w[Tb(a+2|0,e)|0];t[b+13|0]=g;k=b,l=wd(w[a+3|0],g,d),t[k+14|0]=l;e=w[Tb(a+4|0,e)|0];t[b+15|0]=e;k=b,l=wd(w[a+5|0],e,d),t[k+16|0]=l;g=v[b>>2];b=0;while(1){t[f+14|0]=25;if(w[Tb(f+14|0,i)|0]>b>>>0){e=B(b,3)+a|0;h=Vb(w[e+6|0]+c<<24>>24,0,64);d=Ib(g,b);t[d+2|0]=h;e=e+7|0;e=w[e|0]|w[e+1|0]<<8;u[d>>1]=e;a:{if(!b){break a}h=Ib(g,b-1|0);j=x[h>>1];if(e>>>0>255|e>>>0>=j>>>0){break a}e=e|j&65280;u[d>>1]=e;if(x[h>>1]<=(e&65535)>>>0){break a}u[d>>1]=e+256}b=b+1|0;continue}break}cb=f+16|0}function FO(a,b,c){a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}t[a+798|0]=0;return}t[a+798|0]=1;return}t[a+798|0]=2;return}t[a+798|0]=3;return}t[a+730|0]=w[a+730|0]&254;return}t[a+730|0]=w[a+730|0]|1;return}t[a+738|0]=w[a+738|0]&254;return}t[a+738|0]=w[a+738|0]|1;return}t[a+746|0]=w[a+746|0]&254;return}t[a+746|0]=w[a+746|0]|1;return}if(v[c+480180>>2]!=16777216){break a}c=a;a=w[a+746|0];t[c+746|0]=(b|0)==13?a&238|1:a|17}}function iU(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{if(!d){break a}i=w[e|0];if(!i){break a}g=d-6|0;j=35>>>g&(g&255)>>>0<6;l=d-2|0;m=0-c|0;while(1){if(!b){break a}k=(l&255)>>>0>2;h=B(m,6);c=a;a=h+c|0;f=w[a+3|0];b:{if(!(k|(f-2&255)>>>0>2)){g=1;if(w[(c+h|0)+5|0]<224){break b}break a}g=(d|0)==(f|0);if(!(1<<f&2240)|(!j|f>>>0>11)){break b}g=1}c:{if(k){break c}f=c+h|0;if((w[f+2|0]-11&255)>>>0>2){break c}if(w[f+4|0]){break a}}d:{if(!j){break d}f=c+h|0;if((w[f+2|0]-3&255)>>>0>3){break d}if(w[f+4|0]){break a}}b=b-1|0;if(!g){continue}c=w[(c+h|0)+5|0];if(c?(c|0)!=(i|0):0){break a}if((c|0)!=(i|0)){continue}break}t[e|0]=0}}function Raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=cb-48|0;cb=d;f=Fb(b);e=vb(b);h=Fb(c);i=vb(c);g=-1;a:{if(!e){break a}j=e+f|0;e=f;while(1){if((e|0)==(j|0)){break a}if(qp(h,i,e)){e=e+1|0;continue}break}g=e-f|0}b:{c:{if((g|0)!=-1){k=d,l=fd(b),v[k+32>>2]=l;f=kj(d+40|0,d+32|0);k=d,l=fd(b),v[k+8>>2]=l;k=d,l=je(d+8|0,g),v[k+16>>2]=l;c=kj(d+24|0,d+16|0);QL(b,v[f>>2],v[c>>2]);break c}i=vb(b);if(!i){break c}h=Fb(b);j=vb(b);e=Fb(c);g=-1;f=vb(c);if(f){c=h+j|0;d:{while(1){if((c|0)==(h|0)){break d}c=c-1|0;if(!qp(e,f,c)){continue}break}g=c-h|0}}if((i-1|0)!=(g|0)){break c}Db(a);break b}zc(a,b)}cb=d+48|0}function I9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=cb-80|0;cb=d;e=of(d+48|0);v[22440]=0;g=Q(893,b|0,e|0)|0;f=v[22440];v[22440]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22440]=0;T(894,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break b}}break a}g=om(e);v[22440]=0;U(192,d|0,b|0,g|0);f=v[22440];v[22440]=0;if((f|0)==1){break a}f=cc(d+24|0,d);Sc(e+8|0,f);sb(f);sb(d);d:{if(!(g&1)|c>>>0<2){break d}v[22440]=0;Q(190,b|0,1)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break d}break a}Cj(a,e)}Xc(e);cb=d+80|0;return}a=P()|0;O()|0;Xc(e);S(a|0);L()}function UR(a){var b=0,c=0,d=0,e=0,f=0;b=cb-32|0;cb=b;e=b,f=Wb(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+788|0,v[e>>2]=f;v[b+4>>2]=0;e=b,f=Wb(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24)),v[e+8>>2]=f;v[b+12>>2]=0;c=Wb(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24));v[b+16>>2]=c?c:52;v[b+20>>2]=0;e=b,f=Wb(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))+80|0,v[e+24>>2]=f;v[b+28>>2]=0;a=b;d=Xe(a,4);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+8|0;if((d|0)==(c|0)){break a}a=Uu(v[a>>2],v[a+4>>2],v[c>>2],v[c+4>>2])?c:a;continue}}cb=b+32|0;c=v[a>>2];b=c-52|0;fb=v[a+4>>2]-(c>>>0<52)|0;return b}function PG(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=cb-208|0;cb=f;v[f+204>>2]=c;c=f+160|0;Hb(c,0,40);v[f+200>>2]=v[f+204>>2];a:{if((OG(0,b,f+200|0,f+80|0,c,d,e)|0)<0){b=-1;break a}i=v[a+76>>2]>=0;g=v[a>>2];if(v[a+72>>2]<=0){v[a>>2]=g&-33}b:{c:{d:{if(!v[a+48>>2]){v[a+48>>2]=80;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;h=v[a+44>>2];v[a+44>>2]=f;break d}if(v[a+16>>2]){break c}}c=-1;if(BC(a)){break b}}c=OG(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){gb[v[a+36>>2]](a,0,0)|0;v[a+48>>2]=0;v[a+44>>2]=h;v[a+28>>2]=0;b=v[a+20>>2];v[a+16>>2]=0;v[a+20>>2]=0;c=b?c:-1}b=a;a=v[a>>2];v[b>>2]=a|g&32;b=a&32?-1:c;if(!i){break a}}cb=f+208|0;return b}function w2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=0;c=cb-32|0;cb=c;d=v[a>>2];a=v[d>>2];Pf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];f=v[a+8>>2];d=v[a+4>>2];g=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(Of(c)>>>0<f>>>0){break b}c:while(1){a=0;if((b|0)==(f|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{e=bd(v[Kh(g,d,a,b)>>2]+2048|0,12);e=(e|0)<32767?e:32767;h=pn(c,a,b),i=(e|0)>-32768?e:-32768,u[h>>1]=i;a=a+1|0;continue}}}ca(7157,9074,34,8787);L()}ca(5870,9074,36,8787);L()}cb=c+32|0}function m2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=0;c=cb-32|0;cb=c;d=v[a>>2];a=v[d>>2];Pf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];f=v[a+8>>2];d=v[a+4>>2];g=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(Of(c)>>>0<f>>>0){break b}c:while(1){a=0;if((b|0)==(f|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{e=bd(v[Kh(g,d,a,b)>>2]+2048|0,12);e=(e|0)<32767?e:32767;h=on(c,a,b),i=(e|0)>-32768?e:-32768,u[h>>1]=i;a=a+1|0;continue}}}ca(7157,9074,34,8787);L()}ca(5870,9074,36,8787);L()}cb=c+32|0}function g$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=cb-48|0;cb=f;v[f+40>>2]=b;a:{if(!(v[c+4>>2]&1)){c=gb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+24|0;Jc(a,c);v[22440]=0;a=T(1142,a|0)|0;b=v[22440];v[22440]=0;b:{if((b|0)!=1){Pb(f+24|0);c:{if(e){Ih(f+24|0,a);break c}Hh(f+24|0,a)}g=f,h=fd(f+24|0),v[g+16>>2]=h;while(1){g=f,h=gf(f+24|0),v[g+8>>2]=h;if(!oj(f+16|0,f+8|0)){c=v[f+40>>2];rb(f+24|0);break a}a=t[v[f+16>>2]];v[22440]=0;Q(21,f+40|0,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){Fe(f+16|0);continue}break}c=P()|0;O()|0;rb(f+24|0);break b}c=P()|0;O()|0;Pb(f+24|0)}S(c|0);L()}cb=f+48|0;return c|0}function Zw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);b=0;c=cb-32|0;cb=c;d=v[a>>2];a=v[d>>2];Pf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];e=v[a+8>>2];d=v[a+4>>2];f=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(Of(c)>>>0<e>>>0){break b}c:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{g=tm(ne(mg(A[ah(f,d,a,b)>>3])*134217728));h=Yw(c,a,b),i=C(+(g|0)*7.450580596923828e-9),z[h>>2]=i;a=a+1|0;continue}}}ca(7157,9074,78,8754);L()}ca(5870,9074,80,8754);L()}cb=c+32|0}function $w(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);b=0;c=cb-32|0;cb=c;d=v[a>>2];a=v[d>>2];Pf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];e=v[a+8>>2];d=v[a+4>>2];f=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(Of(c)>>>0<e>>>0){break b}c:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{g=tm(ne(mg(A[ah(f,d,a,b)>>3])*134217728));h=_w(c,a,b),i=C(+(g|0)*7.450580596923828e-9),z[h>>2]=i;a=a+1|0;continue}}}ca(7157,9074,78,8754);L()}ca(5870,9074,80,8754);L()}cb=c+32|0}function Zaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=cb-80|0;cb=c;e=of(c+48|0);v[22440]=0;d=Q(813,b|0,e|0)|0;f=v[22440];v[22440]=0;a:{b:{c:{if((f|0)!=1){if(d){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22440]=0;T(814,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break b}}break a}d=sB(e);v[22440]=0;U(192,c|0,b|0,d|0);f=v[22440];v[22440]=0;if((f|0)==1){break a}f=cc(c+24|0,c);Sc(e+8|0,f);sb(f);sb(c);d:{d=d&1;if(!d){break d}v[22440]=0;Q(190,b|0,2-d|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break d}break a}Cj(a,e)}Xc(e);cb=c+80|0;return}a=P()|0;O()|0;Xc(e);S(a|0);L()}function zD(a,b){var c=0,d=0,e=0,f=0;c=v[a>>2];d=Vg(c,v[a+4>>2]);if(d>>>0<b>>>0){f=cb-32|0;cb=f;c=b-d|0;b=v[xb(a)>>2];e=v[a+4>>2];a:{if(c>>>0<=b-e>>3>>>0){d=cb-16|0;cb=d;b=Oq(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){dc(b);cb=d+16|0}else{Rj(a);a=a+8|0;v[b+4>>2]=a;continue}break}break a}b=xb(a);d=Qq(f+8|0,Rq(a,Vg(v[a>>2],e)+c|0),Vg(v[a>>2],v[a+4>>2]),b);b=cb-16|0;cb=b;v[b>>2]=v[d+8>>2];e=v[d+8>>2];v[b+8>>2]=d+8;v[b+4>>2]=(c<<3)+e;c=v[b>>2];while(1){if(v[b+4>>2]!=(c|0)){Rj(c);c=v[b>>2]+8|0;v[b>>2]=c;continue}break}Gd(b);cb=b+16|0;Ad(a,d);Pq(d)}cb=f+32|0;return}if(b>>>0<d>>>0){Nd(a,c+(b<<3)|0)}}function bB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=cb-16|0;cb=e;f=cb-32|0;cb=f;c=Me(f+16|0,1,0);b:{c:{d:{while(1){d=Fb(c);Nx(f+8|0,d,vb(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break d}d=Yf(vb(c));v[22440]=0;R(60,c|0,d|0);d=v[22440];v[22440]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=Fb(c);v[22440]=0;R(61,c|0,b-d|0);b=v[22440];v[22440]=0;e:{if((b|0)!=1){v[22440]=0;R(74,e|0,c|0);b=v[22440];v[22440]=0;if((b|0)!=1){break e}break c}break c}rb(c);cb=f+32|0;break b}a=P()|0;O()|0;rb(c);S(a|0);L()}v[22440]=0;R(73,a|0,e|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(e);cb=e+16|0;break a}a=P()|0;O()|0;rb(e);S(a|0);L()}}function Xm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=cb-16|0;cb=e;f=cb-32|0;cb=f;c=Me(f+16|0,1,0);b:{c:{d:{while(1){d=Fb(c);Ux(f+8|0,d,vb(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break d}d=Yf(vb(c));v[22440]=0;R(60,c|0,d|0);d=v[22440];v[22440]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=Fb(c);v[22440]=0;R(61,c|0,b-d|0);b=v[22440];v[22440]=0;e:{if((b|0)!=1){v[22440]=0;R(74,e|0,c|0);b=v[22440];v[22440]=0;if((b|0)!=1){break e}break c}break c}rb(c);cb=f+32|0;break b}a=P()|0;O()|0;rb(c);S(a|0);L()}v[22440]=0;R(73,a|0,e|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(e);cb=e+16|0;break a}a=P()|0;O()|0;rb(e);S(a|0);L()}}function r3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=cb-16|0;cb=g;a:{if(!(c&1024)){break a}k=g,l=fd(b),v[k+8>>2]=l;b:{if(!vb(b)){break b}if(w[Fb(b)|0]!=43){if(w[Fb(b)|0]!=45){break b}}d=d+1|0;iJ(g+8|0)}if(vb(b)>>>0>=d>>>0){break a}e=v[ac(g,v[g+8>>2])>>2];d=d-vb(b)|0;c=cb-16|0;cb=c;c:{e=$n(e,fd(b));h=vb(b);if(e>>>0<=h>>>0){if(d){f=Dc(b);d:{if(d>>>0<=f-h>>>0){f=Fb(b);i=h-e|0;if(!i){break d}j=e+f|0;Rh(d+j|0,j,i);break d}Sy(b,f,(d+h|0)-f|0,h,e,d);f=v[b>>2]}UI(e+f|0,d,48);d=d+h|0;Bf(b,d);kd(d+f|0,0)}break c}tk();L()}k=c,l=fd(b),v[k+8>>2]=l;je(c+8|0,e);cb=c+16|0}zc(a,b);cb=g+16|0}function az(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=cb-16|0;cb=g;i=hl(a,b);a:{if((i|0)==255){break a}if(gk(a)){break a}b:{if(c>>>0>6208431){f=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}c=kka(1<<20-f,0,c,0)+24858e3|0;h=fb;c=wc(nka(c,c>>>0<24858e3?h+1|0:h,49716e3,0),fb)}if(e){u[g+14>>1]=(b&3)+c;u[g+12>>1]=1023;c=x[Kc(g+14|0,g+12|0)>>1]}h=$s(i);e=Eb(a+8|0,i);t[e|0]=(f<<10|c)>>>8|(d?0:32);fh(a,b,h|160,c&255);fh(a,b,h|176,w[e|0]);t[a+534|0]=1}cb=g+16|0}function Ig(a,b,c,d){v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;b=v[v[a>>2]>>2];if(b){v[a>>2]=b;d=v[c>>2]}c=v[bc(a)>>2];t[d+12|0]=(c|0)==(d|0);while(1){a:{if(w[v[d+8>>2]+12|0]|(c|0)==(d|0)){break a}b:{b=v[d+8>>2];if(wh(b)){b=v[v[b+8>>2]+4>>2];if(!(!b|w[b+12|0])){break b}if(!wh(d)){d=v[d+8>>2];aq(d)}b=v[d+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=0;$p(b);break a}b=v[v[b+8>>2]>>2];if(!(!b|w[b+12|0])){break b}if(wh(d)){d=v[d+8>>2];$p(d)}b=v[d+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=0;aq(b);break a}d=v[d+8>>2];t[d+12|0]=1;d=v[d+8>>2];t[d+12|0]=(c|0)==(d|0);t[b+12|0]=1;continue}break}a=xb(a);v[a>>2]=v[a>>2]+1}function FX(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=cb-32|0;cb=k;m=v[c>>2];l=v[c+8>>2];c=v[c+4>>2];v[k+8>>2]=c;v[k+12>>2]=l;v[k+24>>2]=c;v[k+28>>2]=l;v[k+20>>2]=m;v[k+16>>2]=d;v[22440]=0;c=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=c;a=La(1067,a|0,b|0,k|0)|0;b=v[22440];v[22440]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[22440]=0;ja(954,10434,e|0,f|0,g|0,h|0,i|0,j|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}$();a=-255}cb=k+32|0;break a}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}return a|0}function hp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=cb-16|0;cb=e;f=cb-32|0;cb=f;c=Me(f+16|0,1,0);a:{b:{c:{while(1){d=Fb(c);Ux(f+8|0,d,vb(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break c}d=Yf(vb(c));v[22440]=0;R(60,c|0,d|0);d=v[22440];v[22440]=0;if((d|0)!=1){continue}break}break b}b=v[f+8>>2];d=Fb(c);v[22440]=0;R(61,c|0,b-d|0);b=v[22440];v[22440]=0;d:{if((b|0)!=1){v[22440]=0;R(62,e|0,c|0);b=v[22440];v[22440]=0;if((b|0)!=1){break d}break b}break b}rb(c);cb=f+32|0;break a}a=P()|0;O()|0;rb(c);S(a|0);L()}v[22440]=0;R(59,a|0,e|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(e);cb=e+16|0;return}a=P()|0;O()|0;rb(e);S(a|0);L()}function haa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=cb-16|0;cb=e;f=cb-32|0;cb=f;c=Me(f+16|0,1,0);a:{b:{c:{while(1){d=Fb(c);Ux(f+8|0,d,vb(c)+d|0,w[b|0]);if(!v[f+12>>2]){break c}d=Yf(vb(c));v[22440]=0;R(60,c|0,d|0);d=v[22440];v[22440]=0;if((d|0)!=1){continue}break}break b}b=v[f+8>>2];d=Fb(c);v[22440]=0;R(61,c|0,b-d|0);b=v[22440];v[22440]=0;d:{if((b|0)!=1){v[22440]=0;R(62,e|0,c|0);b=v[22440];v[22440]=0;if((b|0)!=1){break d}break b}break b}rb(c);cb=f+32|0;break a}a=P()|0;O()|0;rb(c);S(a|0);L()}v[22440]=0;R(59,a|0,e|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(e);cb=e+16|0;return}a=P()|0;O()|0;rb(e);S(a|0);L()}function cX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=cb-32|0;cb=c;a:{b:{c:{d:{if(h=xd(b),i=1,j=v[b+12>>2],j?h:i){Db(a);break d}e=Db(c+16|0);d=vb(b);f=Sq(14402);g=Fb(b);v[22440]=0;W(104,e|0,g|0,d|0,d+f|0);d=v[22440];v[22440]=0;e:{if((d|0)!=1){v[22440]=0;Y(105,e|0,14402,f|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){break e}}a=P()|0;O()|0;rb(e);S(a|0);L()}v[22440]=0;R(134,c|0,b+12|0);b=v[22440];v[22440]=0;if((b|0)==1){break c}v[22440]=0;U(2,a|0,c+16|0,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}rb(c);rb(c+16|0)}cb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;rb(c)}rb(c+16|0);S(b|0);L()}function rfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=cb-32|0;cb=e;a:{c=v[a+12>>2];b:{if((c|0)==(b|0)){break b}d=b>>>0>c>>>0;c=B(Hj(v[v[a+48>>2]+12>>2]),d?b-c|0:c-b|0);c:{if(d){d=ac(e+24|0,yb(v[a+4>>2]));f=e+16|0;Ej(f);d=v[d>>2];v[22440]=0;W(654,a|0,d|0,c|0,f|0);c=v[22440];v[22440]=0;if((c|0)!=1){break c}a=V(88360)|0;if((O()|0)!=(fa(88360)|0)){break a}_(a|0)|0;$();break b}g=e,h=yb(v[a+4>>2]),v[g+16>>2]=h;c=ac(e+8|0,VA(e+16|0,c));d=v[ac(e,yb(v[a+4>>2]))>>2];f=v[c>>2];c=v[a>>2];c=B(vs(f,yb(c)),6)+c|0;if(Qb(f,d)){Nd(a,RK(c+B(vs(d,f),6)|0,v[a+4>>2],c))}yb(c)}v[a+12>>2]=b}cb=e+32|0;return}S(a|0);L()}function _aa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(v[a+4>>2]!=v[xb(a)>>2]){c=cb-16|0;cb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+7;kN(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+7;dc(c);cb=c+16|0;return}f=cb-32|0;cb=f;h=xb(a);i=f+8|0;c=a;g=Ry(v[a>>2],v[a+4>>2])+1|0;e=cb-16|0;cb=e;v[e+12>>2]=g;d=cb-16|0;cb=d;v[d+12>>2]=613566756;v[d+8>>2]=2147483647;a=v[Bb(d+12|0,d+8|0)>>2];cb=d+16|0;a:{if(a>>>0>=g>>>0){d=Qy(c);if(d>>>0<a>>>1>>>0){v[e+8>>2]=d<<1;a=v[Pc(e+8|0,e+12|0)>>2]}cb=e+16|0;break a}nd();L()}a=pN(i,a,Ry(v[c>>2],v[c+4>>2]),h);kN(v[a+8>>2],b);v[a+8>>2]=v[a+8>>2]+7;oN(c,a);nN(a);cb=f+32|0}function Q2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=cb+-64|0;cb=c;e=c+16|0;i=cb-16|0;cb=i;j=_O(i+8|0);while(1){if((k|0)==12){cb=i+16|0}else{g=cb+-64|0;cb=g;f=v[j>>2];d=v[j+4>>2]-f|0;a:{if(!d){break a}h=d+1|0;if(!h){f=xI(yI(g+8|0,32));break a}d=E(h);f=yI(g+8|0,(h<<d+1?32:31)-d|0);while(1){d=xI(f);if(h>>>0<=d>>>0){continue}break}f=v[j>>2]+d|0}cb=g- -64|0;l=Ib(e,k),m=f,v[l>>2]=m;k=k+1|0;continue}break}e=eP(c,e,jP(e));cP(a,e);fc(e);cb=c- -64|0;c=a+120|0;GI(c,a,b);t[c+20|0]=1;v[22440]=0;R(1093,a|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){a=P()|0;O()|0;qn(c);S(a|0);L()}return a|0}function q_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=cb-16|0;cb=k;a:{if(a){a=$E(b);Jk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Ik(k,a);Ui(i,k);Vc(k);Hh(k,a);Ui(h,k);Vc(k);l=d,m=Yi(a),v[l>>2]=m;l=e,m=Zi(a),v[l>>2]=m;Zg(k,a);tc(f,k);rb(k);Ih(k,a);Ui(g,k);Vc(k);a=Hk(a);break a}a=_E(b);Jk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Ik(k,a);Ui(i,k);Vc(k);Hh(k,a);Ui(h,k);Vc(k);l=d,m=Yi(a),v[l>>2]=m;l=e,m=Zi(a),v[l>>2]=m;Zg(k,a);tc(f,k);rb(k);Ih(k,a);Ui(g,k);Vc(k);a=Hk(a)}v[j>>2]=a;cb=k+16|0}function ke(a,b){var c=0,d=0,e=0;c=cb-32|0;cb=c;a=Xg(a,-1,-1);ji(c+24|0,b,1);a:{b:{if(Ed(w[c+24|0])){d=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[22440]=0;oE(c+8|0,d,0);d=v[22440];v[22440]=0;c:{if((d|0)!=1){d=v[c+12>>2];v[a>>2]=v[c+8>>2];v[a+4>>2]=d;d=v[c+20>>2];v[a+8>>2]=v[c+16>>2];v[a+12>>2]=d;break c}a=V(0)|0;O()|0;_(a|0)|0;e=1;ii(v[v[b>>2]-12>>2]+b|0,1);if(v[(v[v[b>>2]-12>>2]+b|0)+20>>2]&1){v[22440]=0;X(107);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)==1){break b}S(a|0);L()}$()}Mg(v[v[b>>2]-12>>2]+b|0,e)}cb=c+32|0;return}V(0)|0;O()|0;Lb()}L()}function O5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-32|0;cb=c;v[22440]=0;Z(971,a|0);d=v[22440];v[22440]=0;a:{b:{c:{if((d|0)==1){break c}v[22440]=0;Z(972,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break c}d=v[a+24>>2];b=nc(c+8|0,b);v[22440]=0;e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;W(984,c+16|0,d|0,c|0,1);b=v[22440];v[22440]=0;if((b|0)==1){break c}a=c+16|0;b=le(Fb(a));rb(a);break b}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[22440]=0;W(958,5538,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$()}cb=c+32|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function oI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);e=cb+-64|0;cb=e;f=a+24|0;op(v[f>>2]);t[v[f>>2]+1298420|0]=v[a+52>>2]!=0;c=pg(e+16|0,d,c,b);d=v[c>>2];h=v[c+4>>2];i=v[c+8>>2];j=v[a+32>>2];k=z[a+48>>2];c=e+32|0;Vr(c);v[c+20>>2]=i;v[c+16>>2]=h;v[c+12>>2]=d;v[c+8>>2]=j;v[c+4>>2]=0;v[c>>2]=56376;z[c+24>>2]=k;v[c>>2]=55604;a:{if(b){while(1){b:{d=v[f>>2];v[e+8>>2]=b;v[e+12>>2]=0;v[e>>2]=134217727;v[e+4>>2]=0;d=Wr(d,v[Dl(e+8|0,e)>>2],c);g=d+g|0;if(!d){break b}b=b-d|0;if(b){continue}}break}if(g){break a}}g=0;if(v[a+52>>2]!=1){break a}a=v[f>>2];v[a+480208>>2]=v[a+480208>>2]&-513}cb=e- -64|0;return g}function jI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);e=cb+-64|0;cb=e;f=a+24|0;op(v[f>>2]);t[v[f>>2]+1298420|0]=v[a+52>>2]!=0;c=pg(e+16|0,d,c,b);d=v[c>>2];h=v[c+4>>2];i=v[c+8>>2];j=v[a+32>>2];k=z[a+48>>2];c=e+32|0;Vr(c);v[c+20>>2]=i;v[c+16>>2]=h;v[c+12>>2]=d;v[c+8>>2]=j;v[c+4>>2]=0;v[c>>2]=57204;z[c+24>>2]=k;v[c>>2]=56432;a:{if(b){while(1){b:{d=v[f>>2];v[e+8>>2]=b;v[e+12>>2]=0;v[e>>2]=134217727;v[e+4>>2]=0;d=Wr(d,v[Dl(e+8|0,e)>>2],c);g=d+g|0;if(!d){break b}b=b-d|0;if(b){continue}}break}if(g){break a}}g=0;if(v[a+52>>2]!=1){break a}a=v[f>>2];v[a+480208>>2]=v[a+480208>>2]&-513}cb=e- -64|0;return g}function dV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=cb-208|0;cb=d;KB(c,a);JB(c,d+16|0,B(w[a+4|0],3));a:{if(w[a+4|0]<2){break a}c=cb-16|0;cb=c;v[c+12>>2]=64;v[c+8>>2]=255;e=w[Bb(c+12|0,c+8|0)|0];cb=c+16|0;t[d+12|0]=e;Qg(b,w[Tb(a+4|0,d+12|0)|0]);t[b+13|0]=w[a+2|0];t[b+14|0]=w[a+3|0];a=w[a+1|0];t[b+15|0]=a;t[b+16|0]=a;e=v[b>>2];a=0;while(1){if(Dd(b)>>>0<=a>>>0){break a}b:{if(!a){c=w[d+18|0];f=Ib(e,0);break b}g=x[Ib(e,a-1|0)>>1];v[d+12>>2]=1;c=(d+16|0)+B(a,3)|0;v[d+8>>2]=(t[c+1|0]&1)<<8|w[c|0];h=Ke(d+12|0,d+8|0);f=Ib(e,a);u[f>>1]=x[h>>1]+g;c=w[c+2|0]}t[f+2|0]=c;a=a+1|0;continue}}cb=d+208|0}function JA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=cb-16|0;cb=e;d=(c<<3)+a|0;g=w[d+356|0];t[b+12|0]=w[b+12|0]&248|g&1|g<<1&4|g>>>1&2;Qg(b,wd(w[d+352|0],2,16));t[b+13|0]=w[d+354|0];t[b+14|0]=w[d+355|0];d=w[d+353|0];t[b+15|0]=d;t[b+16|0]=d;d=0;u[e+14>>1]=0;g=((c|0)!=0)<<1;j=v[b>>2];a=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){if(Dd(b)>>>0<=d>>>0){IA(b,32);cb=e+16|0}else{h=a+(d<<2)|0;f=h+160|0;u[e+12>>1]=w[f|0]|w[f+1|0]<<8;f=ie(e+14|0,e+12|0);i=Ib(j,d);f=x[f>>1];u[i>>1]=f;u[e+14>>1]=f+1;t[e+11|0]=(c^w[h+162|0])>>>g;t[e+10|0]=64;k=i,l=w[Tb(e+11|0,e+10|0)|0],t[k+2|0]=l;d=d+1|0;continue}break}}function DX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=cb-16|0;cb=e;v[22440]=0;Z(971,a|0);f=v[22440];v[22440]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[22440]=0;Z(972,b|0);f=v[22440];v[22440]=0;if((f|0)==1){break d}f=v[a+24>>2];b=nc(e+8|0,b);v[22440]=0;g=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=g;Na(992,f|0,e|0,c|0,d|0,1);c=v[22440];v[22440]=0;b=1;if((c|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,8671,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break b}$();b=0}cb=e+16|0;break a}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}return b|0}function fK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=cb-16|0;cb=f;Eh(f+8|0,b);g=cb-16|0;cb=g;_g(g+8|0,v[f+8>>2],v[f+12>>2]);j=v[g+8>>2];e=v[g+12>>2];h=cb-16|0;cb=h;k=h,l=yb(a),v[k+8>>2]=l;b=cb-16|0;cb=b;i=v[h+8>>2];d=i;a=v[d+12>>2];d=v[d+8>>2];a:{if((a|0)<0){break a}c=v[i+4>>2];if(!a&c>>>0<d>>>0|a){break a}v[b+8>>2]=c-d;v[b+12>>2]=0-(a+(d>>>0>c>>>0)|0);a=e;v[b>>2]=a;v[b+4>>2]=0;c=uu(b+8|0,b);if((Oy(v[c>>2],v[c+4>>2])|0)!=(a|0)){break a}Qi(j,e+j|0,d+v[i>>2]|0);e=v[h+8>>2];c=e;d=a+v[c+8>>2]|0;e=v[c+12>>2];v[c+8>>2]=d;v[c+12>>2]=a>>>0>d>>>0?e+1|0:e}cb=b+16|0;cb=h+16|0;cb=g+16|0;cb=f+16|0}function CJ(a,b){var c=0,d=0,e=0,f=0;a:{e=cb-16|0;cb=e;f=cb-32|0;cb=f;c=Me(f+16|0,1,0);b:{c:{d:{while(1){d=Fb(c);mx(f+8|0,d,vb(c)+d|0,x[b>>1]);if(!v[f+12>>2]){break d}d=Yf(vb(c));v[22440]=0;R(60,c|0,d|0);d=v[22440];v[22440]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=Fb(c);v[22440]=0;R(61,c|0,b-d|0);b=v[22440];v[22440]=0;e:{if((b|0)!=1){v[22440]=0;R(74,e|0,c|0);b=v[22440];v[22440]=0;if((b|0)!=1){break e}break c}break c}rb(c);cb=f+32|0;break b}a=P()|0;O()|0;rb(c);S(a|0);L()}v[22440]=0;R(73,a|0,e|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(e);cb=e+16|0;break a}a=P()|0;O()|0;rb(e);S(a|0);L()}}function x_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=cb-16|0;cb=k;a:{if(a){a=cF(b);Jk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Ik(k,a);tc(i,k);rb(k);Hh(k,a);tc(h,k);rb(k);l=d,m=Yi(a),t[l|0]=m;l=e,m=Zi(a),t[l|0]=m;Zg(k,a);tc(f,k);rb(k);Ih(k,a);tc(g,k);rb(k);a=Hk(a);break a}a=bF(b);Jk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Ik(k,a);tc(i,k);rb(k);Hh(k,a);tc(h,k);rb(k);l=d,m=Yi(a),t[l|0]=m;l=e,m=Zi(a),t[l|0]=m;Zg(k,a);tc(f,k);rb(k);Ih(k,a);tc(g,k);rb(k);a=Hk(a)}v[j>>2]=a;cb=k+16|0}function Or(a,b,c){var d=0,e=0;d=a,e=ej(C(C(z[c+1792>>2]*C(75038))+C(C(C(z[c+2048>>2]-z[c+1536>>2])*C(37489))+C(C(C(z[c+1280>>2]+z[c+2304>>2])*C(6574))+C(C(C(z[c+2560>>2]-z[c+1024>>2])*C(5153))+C(C(C(z[c+768>>2]+z[c+2816>>2])*C(2037))+C(C(C(z[c+3072>>2]-z[c+512>>2])*C(459))+C(C(C(z[c+256>>2]+z[c+3328>>2])*C(213))+C(C(z[c+3584>>2]-z[c>>2])*C(29)))))))))),u[d>>1]=e;d=(b<<5)+a|0,e=ej(C(C(z[c+8>>2]*C(-5))+C(C(z[c+520>>2]*C(146))+C(C(z[c+1032>>2]*C(-45))+C(C(z[c+1544>>2]*C(-9975))+C(C(z[c+2056>>2]*C(64019))+C(C(z[c+2568>>2]*C(9727))+C(C(z[c+3080>>2]*C(1567))+C(z[c+3592>>2]*C(104)))))))))),u[d>>1]=e}function KJ(a,b){var c=0,d=0,e=0,f=0;a:{e=cb-16|0;cb=e;f=cb-32|0;cb=f;c=Me(f+16|0,1,0);b:{c:{d:{while(1){d=Fb(c);HJ(f+8|0,d,vb(c)+d|0,w[b|0]);if(!v[f+12>>2]){break d}d=Yf(vb(c));v[22440]=0;R(60,c|0,d|0);d=v[22440];v[22440]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=Fb(c);v[22440]=0;R(61,c|0,b-d|0);b=v[22440];v[22440]=0;e:{if((b|0)!=1){v[22440]=0;R(74,e|0,c|0);b=v[22440];v[22440]=0;if((b|0)!=1){break e}break c}break c}rb(c);cb=f+32|0;break b}a=P()|0;O()|0;rb(c);S(a|0);L()}v[22440]=0;R(73,a|0,e|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(e);cb=e+16|0;break a}a=P()|0;O()|0;rb(e);S(a|0);L()}}function Z2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[xb(a)>>2]){c=cb-16|0;cb=c;a=ht(c,a,1);ex(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+16;dc(a);cb=c+16|0;return}e=cb-32|0;cb=e;c=xb(a);c=rP(e+8|0,sP(a,vj(v[a>>2],v[a+4>>2])+1|0),vj(v[a>>2],v[a+4>>2]),c);ex(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+16;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-16|0;ex(v[b>>2]-16|0,d);v[b>>2]=v[b>>2]-16;continue}break}ec(a,b);ec(a+4|0,c+8|0);ec(xb(a),mc(c));v[c>>2]=v[c+4>>2];a=v[c+4>>2];while(1){b=v[c+8>>2];if((b|0)!=(a|0)){b=b-16|0;v[c+8>>2]=b;rl(b);continue}break}a=v[c>>2];if(a){br(c);zb(a)}cb=e+32|0}function IM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=cb-16|0;cb=c;a:{if(w[b+791|0]!=27){a=t[b+831|0];break a}d=c+8|0;f=a+1074312|0;ub(d,f,21);e=a;a=w[b+821|0];a=dy(e,w[b+828|0],tb(v[v[c+8>>2]>>2],v[c+12>>2])?a:a+16>>>2|0);ub(d,f,45);b:{if(!(!tb(v[v[c+8>>2]>>2],v[c+12>>2])|w[b+828|0]!=3)){d=w[b+821|0];c:{if(!(!d|d>>>0>=w[b+829|0])){a=w[b+832|0];e=d+1|0;break c}t[b+832|0]=a;e=1}t[b+821|0]=e;a=a<<24>>24;break b}t[b+821|0]=w[b+821|0]+w[b+829|0]}ub(c+8|0,f,47);if(!tb(v[v[c+8>>2]>>2],v[c+12>>2])){break a}t[b+831|0]=a}if(a){g=b,h=Vb(v[b+684>>2]+((B(w[b+830|0],a)+2|0)/8|0)|0,0,256),v[g+684>>2]=h}cb=c+16|0}function qX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=cb+-64|0;cb=g;Dh(g+16|0,c);v[22440]=0;c=g+28|0;R(115,c|0,d|0);d=v[22440];v[22440]=0;b:{c:{d:{if((d|0)==1){break d}v[22440]=0;c=g+40|0;R(115,c|0,e|0);d=v[22440];v[22440]=0;if((d|0)==1){break d}v[22440]=0;c=g+52|0;R(115,c|0,f|0);d=v[22440];v[22440]=0;if((d|0)==1){break d}Cv(g+8|0,g+16|0);v[22440]=0;W(116,a|0,b|0,v[g+8>>2],v[g+12>>2]);a=v[22440];v[22440]=0;if((a|0)==1){break c}fE(g+16|0);cb=g- -64|0;break a}a=P()|0;O()|0;while(1){c=rb(c-12|0);if((c|0)!=(g+16|0)){continue}break}break b}a=P()|0;O()|0;fE(g+16|0)}S(a|0);L()}}function hH(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(Ve(a)){Zb(a,31);return 0}g=a,h=Ve(a),t[g+1375|0]=h;d=dj(a);b=dj(a);dj(a);g=a,h=dj(a),v[g+1112>>2]=h;dj(a);c=Ve(a);v[a+1116>>2]=c;if(!Kw(a,a+1120|0,c)){Zb(a,10);return 0}v[a+1404>>2]=-2;a:{if((d|0)==-1&(b|0)==-1){break a}b=v[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(w[(b+a|0)+1120|0]==255){continue}break}v[a+1408>>2]=d;v[a+1404>>2]=b}if(w[a+1377|0]){b=0;e=v[a+1116>>2];f=(e|0)>0?e:0;c=0;while(1){if((b|0)!=(f|0)){c=w[(a+b|0)+1120|0]+c|0;b=b+1|0;continue}break}v[a- -64>>2]=d;v[a+60>>2]=(v[a+56>>2]+(c+e|0)|0)+27}v[a+1380>>2]=0;return 1}function Bk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=cb-16|0;cb=e;f=a+36|0;c=v[a+32>>2];a:{b:{while(1){if((b|0)<=(c|0)){break b}c:{d=v[a+20>>2];if(d>>>0>=y[a+24>>2]){hn(e,f,f+1024|0);md(e+8|0,a,v[e>>2],v[e+4>>2]);c=v[e+12>>2];v[a+24>>2]=c;v[a+20>>2]=0;if(!c){break c}d=0;c=v[a+32>>2]}v[a+20>>2]=d+1;g=w[(a+d|0)+36|0];d=c+8|0;v[a+32>>2]=d;v[a+28>>2]=v[a+28>>2]|g<<c;c=d;continue}break}a=aa(8)|0;v[22440]=0;T(169,a|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ba(a|0);S(b|0);L()}v[a+32>>2]=c-b;d=a;a=v[a+28>>2];v[d+28>>2]=a>>>b;cb=e+16|0;return a&(-1<<b^-1)}ia(a|0,30592,170);L()}function Sr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);b=0;c=cb-32|0;cb=c;d=v[a>>2];a=v[d>>2];Pf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];e=v[a+8>>2];d=v[a+4>>2];f=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(Of(c)>>>0<e>>>0){break b}c:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{g=Kh(f,d,a,b);h=_w(c,a,b),i=C(C(v[g>>2])*C(7.450580596923828e-9)),z[h>>2]=i;a=a+1|0;continue}}}ca(7157,9074,34,8787);L()}ca(5870,9074,36,8787);L()}cb=c+32|0}function Rr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);b=0;c=cb-32|0;cb=c;d=v[a>>2];a=v[d>>2];Pf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];e=v[a+8>>2];d=v[a+4>>2];f=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(Of(c)>>>0<e>>>0){break b}c:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{g=Kh(f,d,a,b);h=Yw(c,a,b),i=C(C(v[g>>2])*C(7.450580596923828e-9)),z[h>>2]=i;a=a+1|0;continue}}}ca(7157,9074,34,8787);L()}ca(5870,9074,36,8787);L()}cb=c+32|0}function p6(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=cb-80|0;cb=d;v[d+72>>2]=c;c=v[a>>2];e=v[a+4>>2];f=v[a+12>>2];v[d+40>>2]=v[a+8>>2];v[d+44>>2]=f;v[d+32>>2]=c;v[d+36>>2]=e;a=ee(d+24|0);c=v[a+4>>2];a=v[a>>2];e=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=e;v[22440]=0;e=v[d+36>>2];v[d>>2]=v[d+32>>2];v[d+4>>2]=e;W(955,d+48|0,d|0,a|0,c|0);a=v[22440];v[22440]=0;a:{b:{if((a|0)!=1){a=v[bi(d+16|0,d+72|0)>>2];v[22440]=0;b=+za(956,d+48|0,+b,a|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}sb(d+48|0);Ae(d+72|0);cb=d+80|0;return+b}a=P()|0;O()|0;break a}a=P()|0;O()|0;sb(d+48|0)}Ae(d+72|0);S(a|0);L()}function eda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=cb-16|0;cb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[b+8>>2];m=e>>>18|0;n=((((v[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){f=(e<<1)+n|0;g=u[f>>1];v[(e<<2)+b>>2]=g+((B(u[f+4>>1]-g|0,m)|0)/16384|0);e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],i);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],h);Jb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;cb=b+16|0}function I0(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;d=cb-32|0;cb=d;if(Ea(0,d+16|0)|0){Gr(v[114922],12710);L()}b=Fr(d+8|0,v[d+16>>2]);e=Fr(d,v[d+20>>2]/1e3|0);c=cb-32|0;cb=c;a=cb-16|0;cb=a;f=cb-16|0;cb=f;b=Zl(f+8|0,kka(v[b>>2],v[b+4>>2],1e6,0),fb);g=v[b+4>>2];b=v[b>>2];cb=f+16|0;v[a+8>>2]=b;v[a+12>>2]=g;b=v[a+12>>2];v[c+16>>2]=v[a+8>>2];v[c+20>>2]=b;cb=a+16|0;a=v[c+16>>2];f=v[c+20>>2];b=v[e+4>>2];v[c+8>>2]=v[e>>2];v[c+12>>2]=b;e=v[c+8>>2];b=a+e|0;a=v[c+12>>2]+f|0;a=Zl(c+24|0,b,b>>>0<e>>>0?a+1|0:a);b=v[a+4>>2];a=v[a>>2];cb=c+32|0;c=Zl(d+24|0,a,b);a=v[c+4>>2];c=v[c>>2];cb=d+32|0;fb=a;return c|0}function DH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-16|0;cb=d;a:{b:{c:{e=a+8|0;f=cs(e);d:{if(!f){if(bs(e)>>>0<=b>>>0){break d}a=Fi(v[a+32>>2],b+1&65535);u[a+34>>1]=x[a+34>>1]&64511|(c?1024:0);break b}if(b>>>0<f>>>0){break c}}a=aa(8)|0;v[22440]=0;b=Q(56,d|0,6003)|0;c=v[22440];v[22440]=0;e:{if((c|0)!=1){oc(a,b);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}c=P()|0;O()|0;rb(b);break e}c=P()|0;O()|0;ba(a|0)}S(c|0);L()}b=b+1<<2;a=a+32|0;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}a=v[(b+v[a>>2]|0)+900380>>2];t[a+15|0]=w[a+15|0]&253|(c?2:0)}cb=d+16|0;return}L()}function Y8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[xb(a)>>2]){c=cb-16|0;cb=c;a=pz(c,a);Ex(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+4;dc(a);cb=c+16|0;return}e=cb-32|0;cb=e;c=xb(a);c=$f(e+8|0,Gg(a,pc(v[a>>2],v[a+4>>2])+1|0),pc(v[a>>2],v[a+4>>2]),c);Ex(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-4|0;Ex(v[b>>2]-4|0,d);v[b>>2]=v[b>>2]-4;continue}break}ec(a,b);ec(a+4|0,c+8|0);ec(xb(a),mc(c));v[c>>2]=v[c+4>>2];a=v[c+4>>2];while(1){b=v[c+8>>2];if((b|0)!=(a|0)){b=b-4|0;v[c+8>>2]=b;qg(b);continue}break}a=v[c>>2];if(a){Cz(c);zb(a)}cb=e+32|0}function EX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=cb-16|0;cb=d;v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[22440]=0;Z(972,b|0);c=v[22440];v[22440]=0;if((c|0)==1){break d}c=v[a+24>>2];e=nc(d+8|0,b);v[22440]=0;b=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=b;b=qE(c,d,1);e=v[22440];v[22440]=0;c=fb;if((e|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,8702,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break b}$();b=0;c=0}cb=d+16|0;a=c;break a}b=P()|0;O()|0;v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Lb();L()}ua(a|0);return b|0}function wm(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function K5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-16|0;cb=d;v[22440]=0;Z(971,a|0);e=v[22440];v[22440]=0;a:{b:{c:{if((e|0)==1){break c}v[22440]=0;Z(972,b|0);e=v[22440];v[22440]=0;if((e|0)==1){break c}e=v[a+24>>2];b=nc(d+8|0,b);v[22440]=0;f=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=f;W(989,e|0,d|0,(c|0)!=0|0,1);c=v[22440];v[22440]=0;b=1;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,10024,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=0}cb=d+16|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function fda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=cb-16|0;cb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[b+8>>2];m=e>>>10&4194048;n=(((v[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){f=e+n|0;g=t[f|0];v[(e<<2)+b>>2]=((B(t[f+2|0]-g|0,m)|0)/16384|0)+(g<<8);e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],i);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],h);Jb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;cb=b+16|0}function Yv(a,b,c,d,e){var f=0,g=0;f=cb-16|0;cb=f;g=f+8|0;Jc(g,b);v[22440]=0;b=T(1159,g|0)|0;g=v[22440];v[22440]=0;a:{if((g|0)==1){break a}v[22440]=0;W(1171,b|0,79696,79728,c|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}v[22440]=0;b=T(1160,f+8|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}v[22440]=0;c=T(1172,b|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break a}v[d>>2]=c;v[22440]=0;c=T(1169,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}v[e>>2]=c;v[22440]=0;R(1170,a|0,b|0);a=v[22440];v[22440]=0;if((a|0)==1){break a}Pb(f+8|0);cb=f+16|0;return}a=P()|0;O()|0;Pb(f+8|0);S(a|0);L()}function Gba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=cb-16|0;cb=g;h=x[c>>1];i=c;e=cb-16|0;cb=e;f=b;b=Kd(b);a:{b:{if(b){c=bc(f);while(1){c:{d=x[b+14>>1];if(Hl(h,d)){d=v[b>>2];if(!d){break b}break c}if(Hl(d,h)){c=b+4|0;d=v[b+4>>2];if(d){b=c;break c}v[e+12>>2]=b;b=c;break a}v[e+12>>2]=b;b=c;break a}c=b;b=d;continue}}b=bc(f)}v[e+12>>2]=b}c=v[b>>2];if(!c){c=cb-16|0;cb=c;d=bc(f);d=kh(e,lc(16),lh(c+8|0,d));Mi(v[d>>2]+14|0,x[i>>1]);k=bc(d),l=1,t[k+4|0]=l;cb=c+16|0;Ig(f,v[e+12>>2],b,v[e>>2]);c=Vd(e);pk(e);j=1}b=g+8|0;Hg(b,ac(e,c),j);cb=e+16|0;CO(a,b);cb=g+16|0}function QX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if(Wg(a,v[b+8>>2],f)){Hv(b,c,d,e);return}h=w[b+53|0];g=v[a+12>>2];t[b+53|0]=0;i=w[b+52|0];t[b+52|0]=0;j=a+16|0;Dv(j,b,c,d,e,f);k=w[b+53|0];h=h|k;l=w[b+52|0];i=i|l;a:{if((g|0)<2){break a}j=j+(g<<3)|0;g=a+24|0;while(1){if(w[b+54|0]){break a}b:{if(l){if(v[b+24>>2]==1){break a}if(w[a+8|0]&2){break b}break a}if(!k){break b}if(!(t[a+8|0]&1)){break a}}u[b+52>>1]=0;Dv(g,b,c,d,e,f);k=w[b+53|0];h=k|h;l=w[b+52|0];i=l|i;g=g+8|0;if(j>>>0>g>>>0){continue}break}}t[b+53|0]=(h&255)!=0;t[b+52|0]=(i&255)!=0}function Y_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=cb-32|0;cb=f;v[f+24>>2]=b;a:{if(!(v[c+4>>2]&1)){c=gb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+8|0;Jc(a,c);v[22440]=0;a=T(1160,a|0)|0;b=v[22440];v[22440]=0;b:{if((b|0)!=1){Pb(f+8|0);c:{if(e){Ih(f+8|0,a);break c}Hh(f+8|0,a)}g=f,h=fd(f+8|0),v[g>>2]=h;while(1){a=Mk(f+8|0);b=v[f>>2];if(!Qb(b,a)){c=v[f+24>>2];Vc(f+8|0);break a}a=v[b>>2];v[22440]=0;Q(1175,f+24|0,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){Ge(f);continue}break}c=P()|0;O()|0;Vc(f+8|0);break b}c=P()|0;O()|0;Pb(f+8|0)}S(c|0);L()}cb=f+32|0;return c|0}function aw(a,b,c,d,e){var f=0,g=0;f=cb-16|0;cb=f;g=f+8|0;Jc(g,b);v[22440]=0;b=T(19,g|0)|0;g=v[22440];v[22440]=0;a:{if((g|0)==1){break a}v[22440]=0;W(1157,b|0,79696,79728,c|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}v[22440]=0;b=T(1142,f+8|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}v[22440]=0;c=T(1158,b|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break a}t[d|0]=c;v[22440]=0;c=T(1155,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}t[e|0]=c;v[22440]=0;R(1156,a|0,b|0);a=v[22440];v[22440]=0;if((a|0)==1){break a}Pb(f+8|0);cb=f+16|0;return}a=P()|0;O()|0;Pb(f+8|0);S(a|0);L()}function Qg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=pc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=cb-32|0;cb=e;b=b-c|0;c=v[xb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){c=cb-16|0;cb=c;b=uh(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){dc(b);cb=c+16|0}else{Zu(a);a=a+4|0;v[b+4>>2]=a;continue}break}break a}c=xb(a);c=$f(e+8|0,Gg(a,pc(v[a>>2],d)+b|0),pc(v[a>>2],v[a+4>>2]),c);f=cb-16|0;cb=f;b=Fl(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){Zu(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Gd(b);cb=f+16|0;Ad(a,c);_f(c)}cb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}function J5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=cb-16|0;cb=e;v[22440]=0;Z(971,a|0);d=v[22440];v[22440]=0;a:{b:{c:{if((d|0)==1){break c}v[22440]=0;Z(972,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break c}d=v[a+24>>2];b=nc(e+8|0,b);v[22440]=0;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;Va(991,d|0,e|0,+c,1);d=v[22440];v[22440]=0;b=1;if((d|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,5929,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=0}cb=e+16|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function fD(a){var b=0,c=0,d=0;b=cb-16|0;cb=b;v[b+4>>2]=B(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24),5)+(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24));v[b+8>>2]=(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))+((w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))<<3);v[b+12>>2]=(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))+((w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24))<<2);a=b+4|0;d=Ib(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=Yn(v[a>>2],v[c>>2])?c:a;continue}}cb=b+16|0;return v[a>>2]-36|0}function rea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=yd(a);a:{if(b){v[22440]=0;R(729,a|0,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break a}d=cb-16|0;cb=d;v[d>>2]=a;c=v[a+4>>2];v[d+4>>2]=c;v[d+8>>2]=c+B(b,36);b=v[d+4>>2];e=v[d+8>>2];while(1){if((b|0)==(e|0)){dc(d);cb=d+16|0}else{c=Hb(b,0,36);v[c>>2]=0;v[c+4>>2]=0;u[c+22>>1]=0;u[c+24>>1]=0;u[c+26>>1]=0;u[c+28>>1]=0;t[c+21|0]=64;t[c+19|0]=64;t[c+20|0]=100;t[c+15|0]=0;t[c+16|0]=0;t[c+17|0]=0;t[c+18|0]=0;v[c+8>>2]=0;v[c+12>>2]=0;u[c+30>>1]=0;u[c+32>>1]=0;b=b+36|0;v[d+4>>2]=b;continue}break}}return a|0}a=P()|0;O()|0;yz(c);S(a|0);L()}function oga(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=C(0),i=0,j=0,k=0,l=0,m=0;g=cb-16|0;cb=g;a:{b:{if((c|0)==(f|0)){if((b|0)!=(e|0)){break b}v[g+12>>2]=f;v[g+8>>2]=f;c=v[Bb(g+12|0,g+8|0)>>2];v[g+12>>2]=e;v[g+8>>2]=e;j=v[Bb(g+12|0,g+8|0)>>2];e=0;c:while(1){f=0;if((c|0)==(e|0)){break a}while(1)if((f|0)==(j|0)){e=e+1|0;continue c}else{k=(B(b,e)+f|0)+a|0;h=zf(C(Pd(z[Wp(d,f,e)>>2],C(-1))*C(128)));d:{if(C(D(h))<C(2147483648)){i=~~h;break d}i=-2147483648}l=k,m=xR(i),t[l|0]=m;f=f+1|0;continue}}}ca(17367,9012,27,9539);L()}ca(17317,9012,28,9539);L()}cb=g+16|0}function TQ(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1196314451){break a}b=a+4|0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(c>>>0<1108){break a}b=a+1104|0;if((c-1108|0)!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|c>>>0>262144){break a}b=a+1094|0;if(w[b|0]|w[b+1|0]<<8){break a}b=a+1096|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-5>>>0<4294967292){break a}if(!yt(a+8|0)){break a}b=a+1094|0;a=a+40|0;while(1){if((a|0)==(b|0)){return 1}if(w[a+32|0]>15|w[a+33|0]>64){break a}c=yt(a);a=a+34|0;if(c){continue}break}}return 0}function R$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=cb-32|0;cb=c;a:{b:{c:{if(hc(b,-1)){break c}i=c,j=Vo(b),t[i+23|0]=j;if(w[a+44|0]){d=-1;if((uk(c+23|0,1,1,v[a+32>>2])|0)==1){break c}break a}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=xr(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((uk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((uk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}d=qw(b);break a}d=-1}cb=c+32|0;return d|0}function RW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=cb-32|0;cb=f;e=Fb(b);d=vb(b);h=Fb(c);i=vb(c);g=-1;a:{if(!d){break a}j=d+e|0;d=e;while(1){if((d|0)==(j|0)){break a}if(Yt(h,i,d)){d=d+1|0;continue}break}g=d-e|0}b:{c:{if((g|0)!=-1){e=ac(f+24|0,fd(b));k=f,l=fd(b),v[k+8>>2]=l;c=ac(f+16|0,je(f+8|0,g));hD(b,v[e>>2],v[c>>2]);break c}i=vb(b);if(!i){break c}h=Fb(b);j=vb(b);d=Fb(c);g=-1;e=vb(c);if(e){c=h+j|0;d:{while(1){if((c|0)==(h|0)){break d}c=c-1|0;if(!Yt(d,e,c)){continue}break}g=c-h|0}}if((i-1|0)!=(g|0)){break c}Db(a);break b}zc(a,b)}cb=f+32|0}function Bfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=cb-80|0;cb=d;e=of(d+48|0);v[22440]=0;c=Q(641,b|0,e|0)|0;f=v[22440];v[22440]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22440]=0;T(642,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break a}}break c}c=e+4|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22440]=0;U(192,d|0,b|0,(c>>>0<9?0:c-8|0)|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Xc(e);S(a|0);L()}b=cc(d+24|0,d);Sc(e+8|0,b);sb(b);sb(d);Cj(a,e)}Xc(e);cb=d+80|0}function vda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=cb-16|0;cb=b;g=v[a+16>>2];f=Zf(1,2);e=fb;h=e;Jb(a,f,e);i=v[a+24>>2];j=v[a+20>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){m=((((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&2147483646)<<1)+g|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=u[(e<<1)+m>>1];e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],i);Jb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;lg(a,f,h);cb=b+16|0}function ji(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=cb-32|0;cb=e;t[a|0]=0;a:{d=v[v[b>>2]-12>>2]+b|0;b:{if(Gh(d)){d=v[d+72>>2];if(d){_u(d)}c:{if(c){break c}c=v[v[b>>2]-12>>2]+b|0;if(!(v[c+4>>2]&4096)){break c}d=e+24|0;Jc(d,c);v[22440]=0;f=T(19,d|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}Pb(e+24|0);c=Ni(e+16|0,b);d=hh(e+8|0);while(1){d:{if(!To(c,d)){break d}if(!qh(f,8192,Tk(v[c>>2]))){break d}Ul(c);continue}break}if(!Xj(c,d)){break c}Mg(v[v[b>>2]-12>>2]+b|0,6)}g=a,h=Gh(v[v[b>>2]-12>>2]+b|0),t[g|0]=h;break b}Mg(d,4)}cb=e+32|0;return}a=P()|0;O()|0;Pb(e+24|0);S(a|0);L()}function aia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=b;c=cb-48|0;cb=c;g=a;a:{if(Nt(g)){v[f>>2]=0;break a}nS(c+16|0,c+32|0);Yb(c+24|0,g,v[c+16>>2],v[c+20>>2]);h=v[c+28>>2];i=w[c+32|0];e=i&127;v[f>>2]=e;if(e){a=NO(e)+1|0}else{a=0}d=1;while(1){b=(B(h,7)+a|0)+B(d,-7)|0;b:{while(1){if(i<<24>>24>=0|d>>>0>=h>>>0){break b}i=w[(c+32|0)+d|0];e=i&127|e<<7;v[f>>2]=e;a=a+7|0;d=d+1|0;if((h|0)!=(d|0)){continue}break}Ob(g,h);nS(c+8|0,c+32|0);Yb(c+24|0,g,v[c+8>>2],v[c+12>>2]);h=v[c+28>>2];e=v[f>>2];d=0;a=b;continue}break}Ob(g,d);if(a>>>0<33){break a}v[f>>2]=-1}cb=c+48|0}function R5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=cb-16|0;cb=c;v[22440]=0;Z(971,a|0);d=v[22440];v[22440]=0;a:{b:{c:{if((d|0)==1){break c}v[22440]=0;Z(972,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break c}d=v[a+24>>2];b=nc(c+8|0,b);v[22440]=0;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;e=+ra(982,d|0,c|0,1);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,5966,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();e=0}cb=c+16|0;return+e}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function J$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=cb-32|0;cb=c;d=w[a+52|0];a:{if(hc(b,-1)){if(d){break a}b=v[a+48>>2];e=a,f=hc(b,-1)^1,t[e+52|0]=f;break a}b:{if(!d){break b}e=c,f=Vo(v[a+48>>2]),t[e+19|0]=f;c:{d:{e:{d=c+20|0;switch(xr(v[a+36>>2],v[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((ur(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}cb=c+32|0;return b|0}function pga(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=C(0),i=0,j=0,k=0,l=0;g=cb-16|0;cb=g;a:{b:{if((c|0)==(f|0)){if((b|0)!=(e|0)){break b}v[g+12>>2]=f;v[g+8>>2]=f;i=v[Bb(g+12|0,g+8|0)>>2];v[g+12>>2]=e;v[g+8>>2]=e;j=v[Bb(g+12|0,g+8|0)>>2];e=0;c:while(1){f=0;if((e|0)==(i|0)){break a}while(1)if((f|0)==(j|0)){e=e+1|0;continue c}else{h=zf(C(Pd(z[Wp(d,f,e)>>2],C(-1))*C(32768)));d:{if(C(D(h))<C(2147483648)){c=~~h;break d}c=-2147483648}c=Wc(c);k=yR(a,b,f,e),l=c,u[k>>1]=l;f=f+1|0;continue}}}ca(17367,9012,27,9539);L()}ca(17317,9012,28,9539);L()}cb=g+16|0}function T5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=cb-16|0;cb=d;v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;a:{b:{c:{if((c|0)==1){break c}v[22440]=0;Z(972,b|0);c=v[22440];v[22440]=0;if((c|0)==1){break c}c=v[a+24>>2];b=nc(d+8|0,b);v[22440]=0;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=Y(978,c|0,d|0,1)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,10055,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=0}cb=d+16|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function r2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);b=0;c=cb-32|0;cb=c;d=v[a>>2];a=v[d>>2];Pf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];e=v[a+8>>2];d=v[a+4>>2];f=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(Of(c)>>>0<e>>>0){break b}c:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{g=ah(f,d,a,b);h=_w(c,a,b),i=C(A[g>>3]),z[h>>2]=i;a=a+1|0;continue}}}ca(7157,9074,78,8754);L()}ca(5870,9074,80,8754);L()}cb=c+32|0}function h2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);b=0;c=cb-32|0;cb=c;d=v[a>>2];a=v[d>>2];Pf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];e=v[a+8>>2];d=v[a+4>>2];f=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(Of(c)>>>0<e>>>0){break b}c:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{g=ah(f,d,a,b);h=Yw(c,a,b),i=C(A[g>>3]),z[h>>2]=i;a=a+1|0;continue}}}ca(7157,9074,78,8754);L()}ca(5870,9074,80,8754);L()}cb=c+32|0}function j6(a){a=a|0;var b=0;b=8045;a:{b:{c:{switch(a-277|0){default:if((a|0)==357){break b}d:{if((a|0)!=257){if((a|0)==267){break d}if(a){break a}b=21685;break a}b=8078;break a}b=17585;break a;case 0:b=5014;break a;case 9:b=8101;break a;case 10:b=8115;break a;case 11:b=5391;break a;case 12:b=5411;break a;case 19:b=8127;break a;case 20:b=8059;break a;case 21:b=12866;break a;case 22:b=12189;break a;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 23:break c}}b=6022;break a}b=8012}return le(b)|0}function dda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=cb-16|0;cb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){l=v[a+32>>2];h=v[b+12>>2]+i|0;e=t[h|0];e=((B(t[h+1|0]-e|0,v[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;g=v[a+28>>2]+g|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+l|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Jb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];d=v[b+8>>2];v[a+36>>2]=g;v[a>>2]=d;v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+24>>2]=f>>12;cb=b+16|0}function Uk(a,b,c){var d=0,e=0;e=cb-16|0;cb=e;v[a+4>>2]=0;ji(e+8|0,a,1);d=4;a:{b:{c:{if(!Ed(w[e+8|0])){break c}d=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[22440]=0;b=Y(108,d|0,b|0,c|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){v[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=V(0)|0;O()|0;_(b|0)|0;d=1;ii(v[v[a>>2]-12>>2]+a|0,1);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22440]=0;X(107);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)==1){break b}S(a|0);L()}$()}Mg(v[v[a>>2]-12>>2]+a|0,d);cb=e+16|0;return a}V(0)|0;O()|0;Lb()}L()}function AV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=cb-32|0;cb=e;ed(b,0);Wh(e,1,a+33|0);d=e+16|0;xc(d,v[e>>2],v[e+4>>2],w[e+8|0]);pe(b+43|0,d);rb(d);f=a+50|0;f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[b>>2]=f;g=a+54|0;v[b+24>>2]=w[g|0]|w[g+1|0]<<8;t[e+16|0]=w[a+56|0];t[e|0]=64;h=b,i=w[Tb(d,e)|0]<<2,u[h+30>>1]=i;d=a+57|0;g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[b+4>>2]=g;d=a+61|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);c=c?g?f:d:d;v[b+8>>2]=c;if(!(!w[a|0]|c>>>0<=g+2>>>0|c>>>0>f>>>0)){u[b+34>>1]=x[b+34>>1]|2}cb=e+32|0}function cda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=cb-16|0;cb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){l=v[a+32>>2];h=(v[b+12>>2]<<1)+i|0;e=u[h>>1];e=e+((B(u[h+2>>1]-e|0,v[b+8>>2]>>>18|0)|0)/16384|0)|0;g=v[a+28>>2]+g|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+l|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Jb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];d=v[b+8>>2];v[a+36>>2]=g;v[a>>2]=d;v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+24>>2]=f>>12;cb=b+16|0}function tN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=cb-16|0;cb=c;v[c+12>>2]=b;if(b>>>0<4294967280){a:{if(Dc(a)>>>0>=b>>>0){break a}h=c,i=vb(a),v[h+8>>2]=i;d=Kg(v[Pc(c+12|0,c+8|0)>>2]);if((d|0)==(Dc(a)|0)){break a}f=vb(a);b:{c:{if((d|0)==10){g=1;b=a;e=v[a>>2];break c}b=d+1|0;d:{if(Dc(a)>>>0<d>>>0){b=lc(b);break d}v[22440]=0;b=T(53,b|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){break d}a=V(0)|0;O()|0;_(a|0)|0;$();break b}g=Ld(a);e=Fb(a)}b=Ce(b,e,vb(a)+1|0);if(g){zb(e)}if((d|0)!=10){cf(a,d+1|0);td(a,f);qd(a,b);break b}Yd(a,f)}}cb=c+16|0;return}Ye();L()}function Nw(a,b,c){var d=0,e=0,f=C(0),g=0,h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0);e=cb-32|0;cb=e;lH(C(-z[a>>2]),C(z[a+24>>2]+z[a+12>>2]),C(z[a+48>>2]+z[a+36>>2]),e+20|0);lH(z[a+60>>2],C(z[a+48>>2]-z[a+36>>2]),C(z[a+24>>2]-z[a+12>>2]),e+8|0);z[e+12>>2]=-z[e+12>>2];a=0;while(1){if((a|0)!=3){d=a<<2;g=d+c|0;h=z[g>>2];f=z[d+(e+20|0)>>2];i=z[d+67200>>2];j=z[d+67212>>2];k=z[d+(e+8|0)>>2];z[g>>2]=C(f*i)-C(j*k);g=b+d|0;l=z[(0-a<<2)+67208>>2];d=5-a<<2;m=z[d+67200>>2];f=C(C(f*j)+C(k*i));z[g>>2]=C(h*l)-C(m*f);z[b+d>>2]=C(h*m)+C(f*l);a=a+1|0;continue}break}cb=e+32|0}function J7(a){a=a|0;var b=0,c=0;c=cb-16|0;cb=c;b=v[v[a+16>>2]+24620>>2];b=yc(lka(kka(b,b>>31,3840,0),fb,1e3,0),fb);v[a+4316>>2]=b;v[22440]=0;v[c+12>>2]=0;U(928,a+4264|0,b|0,c+12|0);b=v[22440];v[22440]=0;a:{b:{c:{if((b|0)!=1){d:{if(!w[a+4260|0]){break d}b=v[a+4316>>2];v[22440]=0;v[c+12>>2]=0;U(928,a+4276|0,b|0,c+12|0);b=v[22440];v[22440]=0;if((b|0)!=1){break d}b=V(88360)|0;break c}v[c+12>>2]=0;b=c+12|0;$J(a+4288|0,b);v[c+12>>2]=0;$J(a+4300|0,b);break b}b=V(88360)|0}if((O()|0)!=(fa(88360)|0)){break a}_(b|0)|0;v[a+4316>>2]=0;$()}cb=c+16|0;return}S(b|0);L()}function io(a,b,c,d,e,f){var g=0;g=cb-16|0;cb=g;t[g+14|0]=d;t[g+15|0]=c;t[g+13|0]=e;t[g+12|0]=f;f=0;a:{while(1){c=f&255;if(c>>>0<=3){d=w[g+15|0];uq(g+10|0,d,w[g+14|0],c>>>0>1);if(!(w[g+10|0]?0:d)){c=x[g+10>>1];t[b+2|0]=c;t[b+4|0]=c>>>8;c=w[g+13|0];t[b+5|0]=w[g+12|0];t[b+3|0]=c;t[g+9|0]=0;ae(a,0,g+9|0);break a}f=f+1|0;xh(g+15|0,g+13|0);xh(g+14|0,g+12|0);continue}break}f=w[g+15|0];c=Ji(f);e=w[g+13|0];if(c>>>0>Ji(e)>>>0){xh(g+15|0,g+13|0);xh(g+14|0,g+12|0);f=w[g+15|0];e=w[g+13|0]}t[b+4|0]=0;t[b+2|0]=0;t[b+5|0]=w[g+12|0];t[b+3|0]=e;ae(a,f,g+14|0)}cb=g+16|0}function Zq(a,b){a=a|0;b=b|0;var c=0,d=0;d=cb-16|0;cb=d;a=Db(a);a:{b:{c:{switch(b|0){case 0:v[22440]=0;b=Q(1,d|0,15892)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}Cb(a,b);rb(b);break b;case 1:v[22440]=0;b=Q(1,d|0,15917)|0;c=v[22440];v[22440]=0;if((c|0)!=1){Cb(a,b);rb(b);break b}break a;case 2:v[22440]=0;b=Q(1,d|0,15865)|0;c=v[22440];v[22440]=0;if((c|0)!=1){Cb(a,b);rb(b);break b}break a;case 3:break c;default:break b}}v[22440]=0;b=Q(1,d|0,15839)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}Cb(a,b);rb(b)}cb=d+16|0;return}b=P()|0;O()|0;rb(a);S(b|0);L()}function CH(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=cb-16|0;cb=d;a:{b:{c:{c=a+8|0;e=cs(c);d:{if(!e){if(bs(c)>>>0<=b>>>0){break d}c=(w[Fi(v[a+32>>2],b+1&65535)+35|0]&4)>>>2|0;break b}if(b>>>0<e>>>0){break c}}a=aa(8)|0;v[22440]=0;b=Q(56,d|0,6003)|0;c=v[22440];v[22440]=0;e:{if((c|0)!=1){oc(a,b);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}c=P()|0;O()|0;rb(b);break e}c=P()|0;O()|0;ba(a|0)}S(c|0);L()}b=b+1<<2;a=a+32|0;c=1;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}c=(w[v[(b+v[a>>2]|0)+900380>>2]+15|0]&2)>>>1|0}cb=d+16|0;return c|0}L()}function U$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=cb-32|0;cb=c;a:{b:{c:{if(jn(b)){break c}v[c+20>>2]=b;if(w[a+44|0]){d=-1;if((uk(c+20|0,4,1,v[a+32>>2])|0)==1){break c}break a}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=xr(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((uk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((uk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}d=jn(b)?0:b;break a}d=-1}cb=c+32|0;return d|0}function tZ(){var a=0;a:{if(t[464832]&1){break a}if(!Xd(464832)){break a}a=464544;while(1){a=Db(a)+12|0;if((a|0)!=464832){continue}break}Wd(464832)}hd(464544,84696);hd(464556,84728);hd(464568,84764);hd(464580,84788);hd(464592,84812);hd(464604,84828);hd(464616,84848);hd(464628,84868);hd(464640,84896);hd(464652,84936);hd(464664,84968);hd(464676,85004);hd(464688,85040);hd(464700,85056);hd(464712,85072);hd(464724,85088);hd(464736,84812);hd(464748,85104);hd(464760,85120);hd(464772,85136);hd(464784,85152);hd(464796,85168);hd(464808,85184);hd(464820,85200)}function fha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=cb-48|0;cb=e;v[22440]=0;d=Q(158,a|0,1)|0;c=v[22440];v[22440]=0;a:{if((c|0)==1){break a}b:{if(!d){break b}v[22440]=0;Z(515,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break a}v[22440]=0;d=T(208,a|0)|0;c=v[22440];v[22440]=0;c:{if((c|0)!=1){while(1){if(!(d&255)){break b}v[22440]=0;c=Q(516,a|0,e+8|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break c}d:{if(!c){break d}c=w[e+8|0];if(c>>>0>63){break d}ic(cS(v[b>>2],c),e+8|0,33)}d=d-1|0;continue}}break a}break a}sb(a);cb=e+48|0;return}b=P()|0;O()|0;sb(a);S(b|0);L()}function Yga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=cb-80|0;cb=d;e=of(d+48|0);v[22440]=0;c=Q(520,b|0,e|0)|0;f=v[22440];v[22440]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22440]=0;T(521,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break a}}break c}c=e+2|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22440]=0;U(192,d|0,b|0,c|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Xc(e);S(a|0);L()}b=cc(d+24|0,d);Sc(e+8|0,b);sb(b);sb(d);WR(a,e)}Xc(e);cb=d+80|0}function wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=cb-16|0;cb=b;g=v[a+16>>2];f=Zf(1,2);e=fb;h=e;Jb(a,f,e);i=v[a+24>>2];j=v[a+20>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){m=(((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&-2)+g|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=t[e+m|0]<<8;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],i);Jb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;lg(a,f,h);cb=b+16|0}function iM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=cb-16|0;cb=e;a:{if(v[a+480180>>2]!=1){break a}c=w[b+846|0];if(!c){break a}d=v[b+104>>2];if(!d){break a}if(!Sd(d)){break a}f=x[d+34>>1];if(!(f&10)){break a}c=w[b+847|0]+w[(c&15)+33344|0]|0;t[b+847|0]=c;if(c<<24>>24>=0){break a}t[b+847|0]=0;h=f&2;c=v[(h?4:12)+d>>2];g=b;b=v[b+760>>2]+1|0;b=b>>>0<v[(h?8:16)+d>>2]-c>>>0?b:0;v[g+760>>2]=b;g=v[d+20>>2];c=b+c|0;b=Ak(f);Ub(e+8|0,g+B(c,b)|0,b);b=v[e+8>>2];f=Eb(b,v[e+12>>2]);while(1){if((b|0)==(f|0)){Ai(d,a)}else{t[b|0]=w[b|0]^-1;b=b+1|0;continue}break}}cb=e+16|0}function _N(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=Zs(b);d=yd(a);v[22440]=0;R(787,a|0,2048);e=v[22440];v[22440]=0;a:{if((e|0)!=1){g=cb-16|0;cb=g;e=Oq(g,a,2048);d=v[e+4>>2];i=v[e+8>>2];while(1){if((d|0)==(i|0)){dc(e);cb=g+16|0}else{ee(d);d=d+8|0;v[e+4>>2]=d;continue}break}break a}a=P()|0;O()|0;de(d);S(a|0);L()}while(1){b:{c=1;if((f|0)!=1024){if((f|0)==2048){break b}c=+(f-1024|0);j=Zs(K(c*c*-9.5367431640625e-7+1)*b);c=c*.0372006759294457;c=j*Bi(c)/(h*c)}k=Xe(v[a>>2],f),l=c*.011841342921061943,A[k>>3]=l;f=f+1|0;continue}break}}function N$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=cb-32|0;cb=c;d=w[a+52|0];a:{if(jn(b)){if(d){break a}b=v[a+48>>2];e=a,f=jn(b)^1,t[e+52|0]=f;break a}b:{if(!d){break b}v[c+16>>2]=v[a+48>>2];c:{d:{e:{d=c+20|0;switch(xr(v[a+36>>2],v[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((ur(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}cb=c+32|0;return b|0}function DA(a,b){var c=0,d=0;a:{b:{c:{d:{e:{f:{g:{h:{d=w[a+3|0];switch(d|0){case 9:break d;case 10:break e;case 16:case 17:break g;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break h;default:break a}}if(!w[a|0]){break a}switch(d|0){case 9:break d;case 10:break e;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break f;case 16:case 17:break g;default:break c}}c=8;break c}c=w[a|0];if(!(c&7)){break c}}c=b+1>>>1|0;b=((d|0)==10)<<4;break b}c=16}c=B(c>>>3|0,b);b=((d|0)==10)<<4}c=b+B(Zp(w[a+1|0]),c)|0}return c}function zt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;WQ(c+8|0,b);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+27|0]=0;t[b+28|0]=0;t[b+29|0]=0;t[b+30|0]=0;t[b+31|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0}}function DO(a,b){var c=0,d=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+14|0]=5;u[a+12>>1]=0;v[a+8>>2]=128;v[a>>2]=256;v[a+4>>2]=64;v[a+28>>2]=0;t[a+27|0]=60;v[a+40>>2]=0;v[a+44>>2]=0;t[a+33|0]=2;t[a+34|0]=0;t[a+35|0]=0;t[a+36|0]=2;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=255;t[a+26|0]=0;t[a+32|0]=0;lz(a+48|0);lz(a+68|0);lz(a+88|0);ct(a+492|0);ct(a+524|0);Jj(a,0,0);Ij(a,0,0);v[a+40>>2]=0;v[a+44>>2]=0;Kt(a,b);c=a+108|0;b=0;while(1){if((b|0)!=128){d=Eb(c,b);b=b+1|0;t[d|0]=b;continue}break}return a}function Fja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=cb-32|0;cb=d;ed(b,0);Wh(d,1,a);e=d+16|0;xc(e,v[d>>2],v[d+4>>2],w[d+8|0]);pe(b+43|0,e);rb(e);c=a+32|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+13|0;u[b+34>>1]=x[b+34>>1]&65533|(w[c|0]|w[c+1|0]<<8)<<1&2;c=a+16|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+20|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+24|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+16|0]=w[a+15|0];t[d|0]=64;f=b,g=w[Tb(e,d)|0]<<2,u[f+30>>1]=g;cb=d+32|0}function Lja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;ed(b,0);g=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=g;c=a+4|0;e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+12>>2]=e;c=a+8|0;f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+16>>2]=f;c=a+12|0;c=w[c|0]|w[c+1|0]<<8;u[b+32>>1]=64;v[b+24>>2]=c;c=a+14|0;d=w[c|0];u[b+30>>1]=d?d+1|0:256;c=x[b+34>>1]&32767|!w[c|0]<<15;u[b+34>>1]=c;d=a+15|0;a=w[d|0];if(!(!(a&1)|e>>>0>=f>>>0)){c=c|8;u[b+34>>1]=c;a=w[d|0]}if(a&2){v[b+16>>2]=f>>>1;v[b+12>>2]=e>>>1;v[b>>2]=g>>>1;u[b+34>>1]=c|1}}function DC(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=cb-16|0;cb=f;v[f+8>>2]=e;v[f+12>>2]=d;dg(a);at(a,c);e=0;d=0;a:while(1){if(c>>>0>e>>>0){i=c-e|0;v[f+4>>2]=i;g=v[Bb(f+12|0,f+4|0)>>2];h=g+d|0;l=d>>>0>h>>>0?d:h;j=mu(nr(a,b+e|0,g),1,13);while(1)if((d|0)==(l|0)){v[f+4>>2]=i-g;d=h+1|0;e=v[Bb(f+8|0,f+4|0)>>2]+(e+g|0)|0;continue a}else{b:{c:{d:{k=t[rc(j,d)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}m=rc(j,d),n=32,t[m|0]=n}d=d+1|0;continue}}break}cb=f+16|0}function Q4(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=C(0);v[22440]=0;Z(971,a|0);d=v[22440];v[22440]=0;if((d|0)!=1){a=v[a+24>>2];a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,872);c=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125));e=C(c*c);c=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125));c=C(K(C(e+C(c*c))))}return C(c)}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,9406,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return C(C(0))}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=cb-16|0;cb=b;j=v[a+16>>2];h=Zf(1,2);e=fb;k=e;Jb(a,h,e);e=v[a+40>>2];f=v[a+36>>2];g=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=g;g=v[a+8>>2];l=v[a+12>>2];while(1){if(d){m=v[a+32>>2];i=u[(v[b+12>>2]<<1)+j>>1];f=v[a+28>>2]+f|0;v[c>>2]=v[c>>2]+B(i,f>>12);e=e+m|0;v[c+4>>2]=v[c+4>>2]+B(e>>12,i);Jb(b+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+8>>2];d=v[b+12>>2];v[a+36>>2]=f;v[a>>2]=c;v[a+4>>2]=d;v[a+40>>2]=e;v[a+20>>2]=f>>12;v[a+24>>2]=e>>12;lg(a,h,k);cb=b+16|0}function aM(a,b,c,d){var e=0;e=cb-16|0;cb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=d+c^d;if(d>>>0<224){break c}ub(e+8|0,a+1074312|0,3);if(tb(v[v[e+8>>2]>>2],v[e+12>>2])){break c}if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break a}c=B((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(t[(B(b,872)+a|0)+1075843|0]&1){ub(e+8|0,a+1074312|0,3);if(!tb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}}c=c<<2}if(!c){break a}d=B(b,872)+a|0;a=Is(a,d+1074992|0);if(!a){break a}d=v[d+1075648>>2];if(d){d=w[d+33|0]}else{d=13}gb[v[v[a>>2]+84>>2]](a,c,d<<24>>24,b)}cb=e+16|0}function w9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=yd(a);b:{c:{d=ok(v[b>>2],v[b+4>>2]);if(d){v[22440]=0;R(461,a|0,d|0);e=v[22440];v[22440]=0;if((e|0)==1){break c}Ox(a,v[b>>2],v[b+4>>2],d)}break b}a=P()|0;O()|0;Th(c);S(a|0);L()}d=a;v[a+20>>2]=v[b+20>>2];c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;v[22440]=0;c=Q(903,a+24|0,b+24|0)|0;e=v[22440];v[22440]=0;d:{e:{if((e|0)!=1){v[22440]=0;Q(55,a+36|0,b+36|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break e}v[a+48>>2]=v[b+48>>2];break a}a=P()|0;O()|0;break d}a=P()|0;O()|0;fc(c)}Th(d);S(a|0);L()}}function uda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=cb-16|0;cb=b;j=v[a+16>>2];h=Zf(1,2);e=fb;k=e;Jb(a,h,e);e=v[a+40>>2];f=v[a+36>>2];g=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=g;g=v[a+8>>2];l=v[a+12>>2];while(1){if(d){m=v[a+32>>2];i=t[v[b+12>>2]+j|0]<<8;f=v[a+28>>2]+f|0;v[c>>2]=v[c>>2]+B(i,f>>12);e=e+m|0;v[c+4>>2]=v[c+4>>2]+B(e>>12,i);Jb(b+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+8>>2];d=v[b+12>>2];v[a+36>>2]=f;v[a>>2]=c;v[a+4>>2]=d;v[a+40>>2]=e;v[a+20>>2]=f>>12;v[a+24>>2]=e>>12;lg(a,h,k);cb=b+16|0}function uaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=cb-208|0;cb=e;u[a+480212>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;SL(a+946304|0);d=e+48|0;Hb(d,0,160);d=XL(d);v[22440]=0;f=a+906300|0;U(844,f|0,f+4e4|0,d|0);f=v[22440];v[22440]=0;a:{if((f|0)!=1){up(d);d=be(e+24|0,b);v[22440]=0;f=v[d+12>>2];v[e+8>>2]=v[d+8>>2];v[e+12>>2]=f;v[e+16>>2]=v[d+16>>2];f=v[d+4>>2];v[e>>2]=v[d>>2];v[e+4>>2]=f;a=Y(845,a|0,e|0,c|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){a=P()|0;O()|0;break a}sb(b);cb=e+208|0;return a|0}a=P()|0;O()|0;up(d)}sb(b);S(a|0);L()}function maa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=cb-16|0;cb=d;e=x[a+30>>1];if(e){b=wn(b<<16>>16,e<<16>>16)}u[d+14>>1]=b;a:{if(!xd(c)){Ho(DK(a+52|0,d+14|0),c);break a}f=a+52|0;a=Hx(f,d+14|0);v[d+8>>2]=a;j=d,k=Af(f),v[j>>2]=k;if(!ih(d+8|0,d)){break a}g=cb-16|0;cb=g;a=v[ac(g,a)>>2];h=cb-16|0;cb=h;v[h+8>>2]=a;e=cb-16|0;cb=e;b=h+8|0;i=v[b>>2];c=um(ac(e+8|0,i));if((i|0)==v[f>>2]){v[f>>2]=v[c>>2]}a=xb(f);v[a>>2]=v[a>>2]-1;CK(v[bc(f)>>2],i);a=v[c>>2];cb=e+16|0;rl(od(b));zb(i);cb=h+16|0;ac(g+8|0,a);cb=g+16|0}cb=d+16|0}function ZP(a){var b=0,c=0;a:{if(Mb(a+60|0,13906,4)){break a}b=a+28|0;b=w[b|0]|w[b+1|0]<<8;if(b>>>0<64&(b|0)!=26|b>>>0>2112){break a}b=w[a+42|0];if(b>>>0>=65&(b|0)!=88){break a}b=a+48|0;if((w[b|0]|w[b+1|0]<<8)>>>0>64){break a}b=a+50|0;if((w[b|0]|w[b+1|0]<<8)>>>0>96){break a}b=a+52|0;b=w[b|0]|w[b+1|0]<<8;if(b>>>0>=130&(b|0)!=257){break a}b=a+30|0;if(w[b|0]|w[b+1|0]<<8){break a}b=a+38|0;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break a}b=a+44|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=1){break a}c=bQ(a+20|0)}return c}function jZ(){var a=0;a:{if(t[464528]&1){break a}if(!Xd(464528)){break a}a=464240;while(1){a=Db(a)+12|0;if((a|0)!=464528){continue}break}Wd(464528)}dd(464240,5037);dd(464252,5028);dd(464264,10844);dd(464276,10609);dd(464288,5264);dd(464300,11688);dd(464312,5121);dd(464324,5612);dd(464336,8915);dd(464348,8898);dd(464360,8906);dd(464372,8925);dd(464384,10092);dd(464396,13291);dd(464408,8988);dd(464420,7674);dd(464432,5264);dd(464444,9781);dd(464456,10497);dd(464468,10856);dd(464480,9278);dd(464492,6466);dd(464504,5495);dd(464516,13200)}function Kn(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0;d=x[a+24>>1];b=c+(d<<2)|0;v[a+40>>2]=((b&3)<<4)+27936;e=b>>>2|0;b=b>>>0<48;f=b?12-e|0:0;u[a+32>>1]=f;u[a+36>>1]=b?1:1<<e-12;u[a+34>>1]=-1<<f^-1;if((d|0)==15){u[a+36>>1]=4095}b=c+(x[a+26>>1]<<2)|0;v[a+52>>2]=((b&3)<<4)+27936;d=b>>>2|0;b=b>>>0<48;e=b?12-d|0:0;u[a+44>>1]=e;c=c+(x[a+30>>1]<<2)|0;v[a+64>>2]=((c&3)<<4)+27936;f=c>>>2|0;c=c>>>0<48;g=c?12-f|0:0;u[a+56>>1]=g;u[a+48>>1]=b?1:1<<d-12;u[a+60>>1]=c?1:1<<f-12;u[a+46>>1]=-1<<e^-1;u[a+58>>1]=-1<<g^-1}function Kr(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=cb-240|0;cb=h;v[h+236>>2]=d;v[h>>2]=a;v[h+232>>2]=c;a:{b:{c:{d:{if((c|0)!=1){i=a;j=1;break d}i=a;j=1;if(d){break d}c=a;break c}while(1){c=i-v[(e<<2)+g>>2]|0;if((gb[b|0](c,a)|0)<=0){c=i;break c}e:{if(!((e|0)<2|f)){d=v[((e<<2)+g|0)-8>>2];f=i-4|0;if((gb[b|0](f,c)|0)>=0){break e}if((gb[b|0](f-d|0,c)|0)>=0){break e}}v[(j<<2)+h>>2]=c;f=h+232|0;d=WG(f);Lr(f,d);j=j+1|0;e=d+e|0;f=0;i=c;if(v[h+236>>2]|v[h+232>>2]!=1){continue}break b}break}c=i;break b}if(f){break a}}VG(h,j);Gw(c,b,e,g)}cb=h+240|0}function B5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=cb-16|0;cb=e;f=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;b=cb-32|0;cb=b;v[b+24>>2]=c;c=v[bi(b+16|0,b+24|0)>>2];v[22440]=0;f=v[e+12>>2];v[b+8>>2]=v[e+8>>2];v[b+12>>2]=f;f=v[e+4>>2];v[b>>2]=v[e>>2];v[b+4>>2]=f;da(1115,a+8|0,b|0,c|0,d|0)|0;c=v[22440];v[22440]=0;a:{if((c|0)!=1){SH(a);c=RH(a+88|0);d=QH(a+92|0);v[a>>2]=58488;v[c>>2]=58600;v[d>>2]=58680;Ae(b+24|0);cb=b+32|0;break a}a=P()|0;O()|0;Ae(b+24|0);S(a|0);L()}cb=e+16|0;return a|0}function Sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=cb-16|0;cb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){e=(v[b+12>>2]<<1)+i|0;f=v[b+8>>2]>>>21&2040;e=(((B(u[e>>1],u[f+39826>>1])+B(u[e-2>>1],u[f+39824>>1])|0)+B(u[e+2>>1],u[f+39828>>1])|0)+B(u[e+4>>1],u[f+39830>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Jb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;cb=b+16|0}function kK(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=0;yx(a);c=Pd(c,C(0));a:{switch(b|0){case 0:z[a+4220>>2]=c;return;case 1:z[a+4224>>2]=c;return;case 2:z[a+4228>>2]=c;ss(a);return;case 3:t[a+4240|0]=c>=C(.5);ss(a);return;case 4:b=cb-16|0;cb=b;e=b,f=Nh(C(c*C(32))),v[e+12>>2]=f;v[b+8>>2]=0;v[b+4>>2]=5;d=v[Gj(b+12|0,b+8|0,b+4|0)>>2];cb=b+16|0;v[a+4232>>2]=d;return;case 5:t[a+4241|0]=c>=C(.5);return;case 6:t[a+4242|0]=c>=C(.5);return;case 7:t[a+4244|0]=c>=C(.5);return;case 8:if(c==C(0)){wx(a)}A[a+4256>>3]=c;break;default:break a}}}function _9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=cb-48|0;cb=d;c=d+24|0;Aj(c,b,1819307379);Sc(a+40|0,c);sb(c);Aj(c,b,1953721961);Sc(a+60|0,c);sb(c);Aj(c,b,543520099);Sc(a+120|0,c);sb(c);Aj(c,b,1414744396);v[22440]=0;c=Q(414,c|0,13851)|0;e=v[22440];v[22440]=0;a:{if((e|0)!=1){b:{if(c){v[22440]=0;U(794,d|0,d+24|0,2);c=v[22440];v[22440]=0;if((c|0)==1){break b}wt(a+140|0,d);Qd(d)}v[22440]=0;U(795,d|0,b|0,1634890872);b=v[22440];v[22440]=0;if((b|0)!=1){break a}}}a=P()|0;O()|0;sb(d+24|0);S(a|0);L()}Sc(a+80|0,d);sb(d);sb(d+24|0);cb=d+48|0}function hfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=cb-32|0;cb=d;ed(b,0);WA(d,a+1|0);c=d+16|0;xc(c,v[d>>2],v[d+4>>2],w[d+8|0]);pe(b+43|0,c);rb(c);c=a+73|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+54|0;e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b>>2]=e;c=a+58|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);if(c){v[b+8>>2]=c+1}u[b+30>>1]=(w[a+68|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;qc(b+8|0,e);qc(b+4|0,v[b+8>>2]);cb=d+32|0}function XV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=cb-16|0;cb=c;v[c+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[c+8>>2]=16384;d=v[Bb(c+12|0,c+8|0)>>2];v[a+1072>>2]=d;v[c+4>>2]=17;while(1){a:{if(!d){break a}e=v[c+4>>2];if((e|0)>17){break a}f=1<<e-1;d=Bk(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}Iq(c+4|0,Bk(a,4));break b}if(e>>>0>16){break c}e=f-8|0;if((e|0)>(d|0)|(d|0)>(f+7|0)){break d}Iq(c+4|0,d-e|0);break b}VC(a,d,f,b);break b}e=d&(f^-1);if(d&f){v[c+4>>2]=e+1;break b}VC(a,e,0,b)}d=v[a+1072>>2];continue}break}cb=c+16|0}function U4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=cb-32|0;cb=c;e=b+24|0;f=Rb(a);a=0;a:{b:{c:{d:{e:{while(1){if(x[v[e>>2]+480188>>1]<=a>>>0){break a}d=v[e>>2];v[22440]=0;R(1026,c|0,(d+(a<<5)|0)+480289|0);d=v[22440];v[22440]=0;if((d|0)!=1){v[22440]=0;U(1027,c+16|0,b|0,c|0);d=v[22440];v[22440]=0;if((d|0)==1){break e}v[22440]=0;R(185,f|0,c+16|0);d=v[22440];v[22440]=0;if((d|0)==1){break d}a=a+1|0;rb(c+16|0);rb(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;rb(c+16|0)}rb(c)}ad(f);S(a|0);L()}cb=c+32|0}function GL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=cb-16|0;cb=e;v[e+12>>2]=16777216;h=e+12|0;d=v[a>>2];c=pc(d,v[a+4>>2]);a:{if(c>>>0<b>>>0){f=cb-32|0;cb=f;b=b-c|0;c=v[xb(a)>>2];d=v[a+4>>2];b:{if(b>>>0<=c-d>>2>>>0){mC(a,b,h);break b}c=xb(a);c=$f(f+8|0,Gg(a,pc(v[a>>2],d)+b|0),pc(v[a>>2],v[a+4>>2]),c);g=cb-16|0;cb=g;b=Fl(g,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){og(d,v[h>>2]);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Gd(b);cb=g+16|0;Ad(a,c);_f(c)}cb=f+32|0;break a}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}jy(a);cb=e+16|0}function Ey(a,b,c){var d=0,e=0,f=0;d=cb+-64|0;cb=d;f=v[a>>2];e=v[f-4>>2];f=v[f-8>>2];v[d+20>>2]=0;v[d+16>>2]=b;v[d+12>>2]=a;v[d+8>>2]=c;b=0;Hb(d+24|0,0,39);a=a+f|0;a:{if(Wg(e,c,0)){v[d+56>>2]=1;gb[v[v[e>>2]+20>>2]](e,d+8|0,a,a,1,0);b=v[d+32>>2]==1?a:0;break a}gb[v[v[e>>2]+24>>2]](e,d+8|0,a,1,0);b:{switch(v[d+44>>2]){case 0:b=v[d+48>>2]==1?v[d+36>>2]==1?v[d+40>>2]==1?v[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(v[d+32>>2]!=1){if(v[d+48>>2]|v[d+36>>2]!=1|v[d+40>>2]!=1){break a}}b=v[d+24>>2]}cb=d- -64|0;return b}function WV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=cb-16|0;cb=c;v[c+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[c+8>>2]=32768;d=v[Bb(c+12|0,c+8|0)>>2];v[a+1072>>2]=d;v[c+4>>2]=9;while(1){a:{if(!d){break a}e=v[c+4>>2];if((e|0)>9){break a}f=1<<e-1;d=Bk(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}Iq(c+4|0,Bk(a,3));break b}if(e>>>0>8){break c}e=f-4|0;if((e|0)>(d|0)|(d|0)>(f+3|0)){break d}Iq(c+4|0,d-e|0);break b}UC(a,d,f,b);break b}e=d&(f^-1);if(d&f){v[c+4>>2]=e+1;break b}UC(a,e,0,b)}d=v[a+1072>>2];continue}break}cb=c+16|0}function T9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{e=cb-32|0;cb=e;a=bf(a);b:{c:{d:{e:{while(1){v[22440]=0;f=Q(158,b|0,8)|0;g=v[22440];v[22440]=0;if((g|0)==1){break c}if(f){v[22440]=0;U(891,e|0,b|0,c|0);f=v[22440];v[22440]=0;if((f|0)==1){break e}v[22440]=0;R(892,a|0,e|0);f=v[22440];v[22440]=0;if((f|0)==1){break d}Xc(e);Uh(e,LA(v[a+4>>2]));if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))!=(d|0)){continue}}break}cb=e+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;Xc(e);break b}b=P()|0;O()|0}Qd(a);S(b|0);L()}}function A_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=cb-416|0;cb=h;d=h+416|0;v[h+12>>2]=d;c=cb-144|0;cb=c;v[c+28>>2]=c+132;i=c+32|0;gF(a+8|0,i,c+28|0,e,f,g);v[c+16>>2]=0;v[c+20>>2]=0;v[c+12>>2]=i;e=h+16|0;g=pc(e,v[h+12>>2]);f=cb-16|0;cb=f;i=gi(f+8|0,v[a+8>>2]);a=KF(e,c+12|0,g,c+16|0);fi(i);cb=f+16|0;if((a|0)==-1){tr(12629);L()}v[h+12>>2]=(a<<2)+e;cb=c+144|0;c=v[h+12>>2];a=cb-16|0;cb=a;v[a+8>>2]=b;while(1){if((c|0)!=(e|0)){nG(a+8|0,v[e>>2]);e=e+4|0;continue}break}cb=a+16|0;cb=d;return v[a+8>>2]}function Tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=cb-16|0;cb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){e=v[b+12>>2]+i|0;f=v[b+8>>2]>>>21&2040;e=(((B(t[e|0],u[f+39826>>1])+B(t[e-1|0],u[f+39824>>1])|0)+B(t[e+1|0],u[f+39828>>1])|0)+B(t[e+2|0],u[f+39830>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Jb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;cb=b+16|0}function es(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;g=cb-16|0;cb=g;d=cb-16|0;cb=d;c=Kd(a);f=bc(a);e=cb-16|0;cb=e;while(1){if(c){h=Ss(c+16|0,b);f=h?f:c;c=v[(h?4:0)+c>>2];continue}break}c=v[ac(e+8|0,f)>>2];cb=e+16|0;v[d+8>>2]=c;a:{if(Qb(c,cg(a))){if(!Ss(b,od(d+8|0))){break a}}c=cg(a)}cb=d+16|0;if(!hc(c,cg(a))){c=v[ac(g+8|0,c)>>2];b=cb-16|0;cb=b;v[b+8>>2]=c;d=cb-16|0;cb=d;f=b+8|0;c=v[f>>2];e=um(ac(d+8|0,c));if((c|0)==v[a>>2]){v[a>>2]=v[e>>2]}e=xb(a);v[e>>2]=v[e>>2]-1;CK(v[bc(a)>>2],c);cb=d+16|0;jm(od(f));zb(c);cb=b+16|0}cb=g+16|0}function Paa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=cb-16|0;cb=e;f=Db(a);a=0;a:{b:{c:{d:{while(1){d=v[b>>2];if(gd(d,v[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){d=rd(d,0);break e}v[22440]=0;Q(824,f|0,c|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break b}d=rd(v[b>>2],a)}v[22440]=0;R(825,e|0,d|0);d=v[22440];v[22440]=0;if((d|0)!=1){v[22440]=0;Q(824,f|0,e|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break d}a=a+1|0;rb(e);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;rb(e);break a}cb=e+16|0;return}a=P()|0;O()|0}rb(f);S(a|0);L()}
function $i(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=cb-16|0;cb=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?E(c):E(d)+32|0;Tf(f,d,e,0,0,c+49|0);i=v[f>>2];h=v[f+4>>2];e=15372-c<<16;c=v[f+8>>2];d=e|v[f+12>>2]^65536}v[a>>2]=i;v[a+4>>2]=h;v[a+8>>2]=c;v[a+12>>2]=g&-2147483648|d;cb=f+16|0}function sba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=cb-16|0;cb=d;v[d+12>>2]=b;if(b>>>0<1073741808){h=d,i=vb(a),v[h+8>>2]=i;e=Pl(v[Pc(d+12|0,d+8|0)>>2]);if((e|0)!=(No(a)|0)){a:{f=1;c=No(a);g=vb(a);b:{if((e|0)==1){b=a;c=v[a>>2];break b}b=e+1|0;c:{if(c>>>0<e>>>0){b=Ci(b);break c}v[22440]=0;b=T(1242,b|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break c}a=V(0)|0;O()|0;_(a|0)|0;$();break a}f=Ld(a);c=Fb(a)}ki(b,c,vb(a)+1|0);if(f){zb(c)}if((e|0)!=1){cf(a,e+1|0);td(a,g);qd(a,b);break a}Yd(a,g)}}cb=d+16|0;return}Ye();L()}function dy(a,b,c){var d=0,e=0;e=cb-16|0;cb=e;ub(e+8|0,a+1074312|0,21);a:{if(tb(v[v[e+8>>2]>>2],v[e+12>>2])){c=c&255;b:{switch((b&3)-1|0){default:d=t[c+33552|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=lL(An(a))+-64|0;break a}d=t[(c>>>1&31)+32240|0];if(x[a+480182>>1]&1032){break a}a=c&63;c:{switch((b&3)-1|0){default:d=t[a+33424|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=t[a+33488|0]}a=d;cb=e+16|0;return a}function at(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=cb-16|0;cb=c;v[c+12>>2]=b;if(b>>>0<4294967280){h=c,i=vb(a),v[h+8>>2]=i;d=Kg(v[Pc(c+12|0,c+8|0)>>2]);if((d|0)!=(Dc(a)|0)){a:{f=vb(a);b:{if((d|0)==10){g=1;b=a;e=v[a>>2];break b}b=d+1|0;c:{if(Dc(a)>>>0<d>>>0){b=lc(b);break c}v[22440]=0;b=T(1241,b|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){break c}a=V(0)|0;O()|0;_(a|0)|0;$();break a}g=Ld(a);e=Fb(a)}b=Ce(b,e,vb(a)+1|0);if(g){zb(e)}if((d|0)!=10){cf(a,d+1|0);td(a,f);qd(a,b);break a}Yd(a,f)}}cb=c+16|0;return}Ye();L()}function UW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=cb-16|0;cb=e;f=Db(a);a=0;a:{b:{c:{d:{while(1){d=v[b>>2];if(gd(d,v[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){d=rd(d,0);break e}v[22440]=0;Q(100,f|0,c|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break b}d=rd(v[b>>2],a)}v[22440]=0;R(155,e|0,d|0);d=v[22440];v[22440]=0;if((d|0)!=1){v[22440]=0;Q(100,f|0,e|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break d}a=a+1|0;rb(e);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;rb(e);break a}cb=e+16|0;return}a=P()|0;O()|0}rb(f);S(a|0);L()}function $P(a,b,c,d,e,f){b=w[(b&15)+27136|0];t[a+3|0]=b;a:{b:{switch(b-11|0){case 0:b=w[a+5|0];c=b&15;if(c){t[a+5|0]=c;return}t[a+5|0]=b&240;return;case 3:b=w[a+5|0];b=B(b&240,10)|b&15;t[a+5|0]=b;d=b&255;b=x[e>>1];if(!(d|(b|0)==65535)){t[a+5|0]=b;t[a+3|0]=12;u[e>>1]=65535}qc(f,c);return;case 1:u[e>>1]=w[a+5|0];v[f>>2]=63;t[a+3|0]=0;return;case 5:b=w[a+5|0];if(d>>>0<=20){c=((b&255)>>>0)/10|0;b=c<<4|B(c,-10)+b;t[a+5|0]=b}if(b&255){break a}t[a+3|0]=0;return;case 7:break a;default:break b}}if(w[a+5|0]){break a}t[a+3|0]=0}}function g6(a){a=a|0;var b=0,c=0,d=0;b=cb-32|0;cb=b;a:{b:{if(!a){a=le(21685);break b}v[22440]=0;c=Q(56,b|0,a|0)|0;a=v[22440];v[22440]=0;c:{d:{if((a|0)!=1){v[22440]=0;R(957,b+16|0,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break d}d=b+16|0;a=le(Fb(d));rb(d);rb(c);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;rb(c)}_(a|0)|0;a=0;v[22440]=0;W(958,10984,0,0,0);c=v[22440];v[22440]=0;if((c|0)==1){break a}$()}cb=b+32|0;return a|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function bja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=cb-16|0;cb=e;g=x[Oi(v[a>>2],v[a+4>>2],b)>>1];a:{b:{if(!oq(a,b)){break b}c=v[a+24>>2]+484360|0;d=Pg(c);v[e+8>>2]=d;h=Og(c);while(1){if(!Qb(d,h)){break b}f=0;i=yl(d);c:{while(1){if((f|0)!=(i|0)){if(!(!((a|0)!=(d|0)|(b|0)!=(f|0))|x[Xb(v[d>>2],f)>>1]!=(g|0))){c=ZQ(v[a+24>>2]+484344|0,g,0);if((c|0)!=65535){break c}}f=f+1|0;continue}break}iz(e+8|0);d=v[e+8>>2];continue}break}j=Oi(v[a>>2],v[a+4>>2],b),k=c,u[j>>1]=k;break a}c=g}cb=e+16|0;return c&65535}function _d(a){var b=0,c=0,d=0;b=cb-16|0;cb=b;v[b+4>>2]=1153;v[b>>2]=a;v[b+8>>2]=0;c=cb-16|0;cb=c;if(v[a>>2]!=-1){ac(c,Sf(c+8|0,b));while(1){if(v[a>>2]==1){continue}break}a:{b:{if(!v[a>>2]){qd(a,1);v[22440]=0;Z(1154,c|0);d=v[22440];v[22440]=0;if((d|0)==1){break b}v[a>>2]=-1}break a}b=V(0)|0;O()|0;_(b|0)|0;qd(a,0);v[22440]=0;X(107);a=v[22440];v[22440]=0;c:{if((a|0)==1){a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){break c}V(0)|0;O()|0;Lb()}L()}S(a|0);L()}}cb=c+16|0;cb=b+16|0;return v[a+4>>2]-1|0}function Z4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=cb-16|0;cb=g;v[22440]=0;Z(971,a|0);h=v[22440];v[22440]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[22440]=0;ja(1022,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[22440];v[22440]=0;if((b|0)==1){break c}b=le(Fb(g));rb(g);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[22440]=0;W(958,10683,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$()}cb=g+16|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function Z3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=cb-16|0;cb=g;v[22440]=0;Z(971,a|0);h=v[22440];v[22440]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[22440]=0;ja(1048,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[22440];v[22440]=0;if((b|0)==1){break c}b=le(Fb(g));rb(g);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[22440]=0;W(958,10638,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$()}cb=g+16|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function gaa(a){a=a|0;var b=0,c=0;b=32336;a=Rb(a);a:{b:{while(1){c:{if((b|0)==32736){b=32736;break c}d:{c=v[a+4>>2];if(!hc(v[a>>2],c)){if(!jj(v[b+4>>2],v[zj(c)>>2])){break d}}v[22440]=0;R(868,a|0,b+4|0);c=v[22440];v[22440]=0;if((c|0)!=1){break d}break b}b=b+8|0;continue}break}while(1){if((b|0)==32784){break a}e:{c=v[a+4>>2];f:{if(!hc(v[a>>2],c)){if(!jj(v[b+8>>2],v[zj(c)>>2])){break f}}v[22440]=0;R(868,a|0,b+8|0);c=v[22440];v[22440]=0;if((c|0)==1){break e}}b=b+12|0;continue}break}}b=P()|0;O()|0;fc(a);S(b|0);L()}}function CV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=cb-32|0;cb=d;ed(b,0);Wh(d,1,a+33|0);c=d+16|0;xc(c,v[d>>2],v[d+4>>2],w[d+8|0]);pe(b+43|0,c);rb(c);e=a+50|0;e=w[e|0]|w[e+1|0]<<8;v[b>>2]=e;f=a+52|0;v[b+24>>2]=w[f|0]|w[f+1|0]<<8;t[d+16|0]=w[a+54|0];t[d|0]=64;g=b,h=w[Tb(c,d)|0]<<2,u[g+30>>1]=h;c=a+55|0;f=w[c|0]|w[c+1|0]<<8;v[b+4>>2]=f;c=a+57|0;c=w[c|0]|w[c+1|0]<<8;v[b+8>>2]=c;a:{if((c|0)==65535){v[b+4>>2]=0;v[b+8>>2]=0;break a}if(!w[a|0]|c>>>0<=f+2>>>0|c>>>0>e>>>0){break a}u[b+34>>1]=x[b+34>>1]|2}cb=d+32|0}function nfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=cb-32|0;cb=c;a=bf(a);b:{c:{d:{e:{while(1){v[22440]=0;d=Q(158,b|0,8)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}if(d){v[22440]=0;R(671,c|0,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break e}v[22440]=0;R(672,a|0,c|0);d=v[22440];v[22440]=0;if((d|0)==1){break d}Xc(c);Uh(c,LA(v[a+4>>2]));if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1413891155){continue}}break}cb=c+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;Xc(c);break b}b=P()|0;O()|0}Qd(a);S(b|0);L()}}function sha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[a+4>>2]!=v[xb(a)>>2]){c=cb-16|0;cb=c;a=zv(c,a);d=v[a+4>>2];v[22440]=0;R(501,d|0,b|0);b=v[22440];v[22440]=0;a:{if((b|0)!=1){v[a+4>>2]=v[a+4>>2]+12;dc(a);cb=c+16|0;break a}b=P()|0;O()|0;dc(a);S(b|0);L()}return}d=cb-32|0;cb=d;c=xb(a);c=Ll(d+8|0,Io(a,gd(v[a>>2],v[a+4>>2])+1|0),gd(v[a>>2],v[a+4>>2]),c);e=v[c+8>>2];v[22440]=0;R(501,e|0,b|0);b=v[22440];v[22440]=0;b:{if((b|0)!=1){v[c+8>>2]=v[c+8>>2]+12;yv(a,c);cr(c);cb=d+32|0;break b}a=P()|0;O()|0;cr(c);S(a|0);L()}}function O9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=cb-32|0;cb=d;Gi(d,2,a+2|0);e=d+16|0;xc(e,v[d>>2],v[d+4>>2],w[d+8|0]);uc(b+492|0,e);f=b+236|0;g=c+1|0;rb(e);c=0;while(1){if((c|0)==120){v[b>>2]=(w[a+223|0]|w[a+224|0]<<8)<<5;a=a+158|0;c=a+1|0;e=a+2|0;f=a+3|0;g=a+4|0;WK(w[a|0]&15,w[c|0]&15,w[e|0]&15,w[f|0]&15,w[g|0]&15,a+5|0,b+48|0);WK(w[a|0]>>>4|0,w[c|0]>>>4|0,w[e|0]>>>4|0,w[f|0]>>>4|0,w[g|0]>>>4|0,a+35|0,b+68|0);cb=d+32|0}else{h=Xb(f,c),i=g+w[(a+c|0)+31|0]|0,u[h>>1]=i;c=c+1|0;continue}break}}function eM(a,b,c){var d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;a:{if(b){t[c|0]=b;break a}b=w[c|0]}e=v[a+480180>>2];b=e&1048580?(b&240?-16:15)&b:b;c=b&240;f=b&255;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(w[a+480209|0]&16)){break b}b=f>>>3&30;break d}g=v[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!g){break b}b=0-(b<<1)|0;break c}if(g){break b}if(c){if(b?e&59314208:0){break b}b=f>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}a=a+1074456|0;v[d+12>>2]=v[a>>2]+(b<<!(e&59314208));oe(d+12|0,0,256);v[a>>2]=v[d+12>>2]}cb=d+16|0}function WX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Wg(a,v[b+8>>2],e)){Gv(b,c,d);return}a:{if(Wg(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}u[b+52>>1]=0;a=v[a+8>>2];gb[v[v[a>>2]+20>>2]](a,b,c,c,1,e);if(w[b+53|0]){v[b+44>>2]=3;if(!w[b+52|0]){break b}break a}v[b+44>>2]=4}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}a=v[a+8>>2];gb[v[v[a>>2]+24>>2]](a,b,c,d,e)}}function x9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=cb-16|0;cb=f;v[f+12>>2]=b;a:{if(Cs(a)>>>0>=b>>>0){d=v[a>>2];g=vk(d,v[a+4>>2]);v[f+8>>2]=g;e=v[Bb(f+12|0,f+8|0)>>2];while(1){if(e){PK(d,c);e=e-1|0;d=d+52|0;continue}break}if(b>>>0>g>>>0){Lx(a,b-g|0,c);break a}NK(a,v[a>>2]+B(b,52)|0);break a}if(v[a>>2]){Ds(a);d=v[a>>2];Cs(a);zb(d);h=xb(a),i=0,v[h>>2]=i;v[a>>2]=0;v[a+4>>2]=0}d=MK(a,b);if(LK()>>>0<d>>>0){nd();L()}e=KK(d);v[a>>2]=e;v[a+4>>2]=e;h=xb(a),i=e+B(d,52)|0,v[h>>2]=i;Lx(a,b,c)}cb=f+16|0}function S4(a){a=a|0;var b=0,c=0,d=0,e=0;c=cb-32|0;cb=c;d=Rb(a);Od(c+24|0);a=v[c+28>>2];b=v[c+24>>2];v[22440]=0;R(183,d|0,TH(b,a)|0);a=v[22440];v[22440]=0;a:{if((a|0)!=1){a=0;b:{while(1){b=v[c+24>>2];if((TH(b,v[c+28>>2])|0)<=(a|0)){cb=c+32|0;return}b=v[b+(a<<3)>>2];v[22440]=0;b=Q(56,c+8|0,b|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){v[22440]=0;R(185,d|0,b|0);e=v[22440];v[22440]=0;if((e|0)==1){break b}rb(b);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;rb(b);break a}a=P()|0;O()|0}ad(d);S(a|0);L()}function CF(a,b,c,d){var e=0,f=0,g=0;f=cb-16|0;cb=f;a:{b:{if((a|0)!=(b|0)){c:{g=v[114922];v[114922]=0;pd();d=IF(a,f+12|0,d);e=fb;d:{a=v[114922];if(a){if(v[f+12>>2]!=(b|0)){break c}if((a|0)!=68){break d}v[c>>2]=4;a=2147483647;if(!!d&(e|0)>=0|(e|0)>0){break a}break b}v[114922]=g;if(v[f+12>>2]==(b|0)){break d}break c}if((e|0)<0&d>>>0<=2147483647|(e|0)<-1){v[c>>2]=4;break b}if((e|0)>=0&d>>>0>=2147483648|(e|0)>0){v[c>>2]=4;a=2147483647;break a}a=d;break a}}v[c>>2]=4;a=0;break a}a=-2147483648}cb=f+16|0;return a}function lfa(a){a=a|0;var b=0,c=0,d=0,e=0;b=cb-16|0;cb=b;t[b+15|0]=128;d=hu(a,127,b+15|0);v[22440]=0;t[b+14|0]=64;e=Y(593,a+12|0,127,b+14|0)|0;c=v[22440];v[22440]=0;a:{b:{if((c|0)!=1){v[22440]=0;t[b+13|0]=0;Q(670,a+24|0,b+13|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break b}v[a+36>>2]=-1;v[a+40>>2]=108855296;t[a+44|0]=0;t[a+45|0]=0;t[a+46|0]=0;t[a+47|0]=0;t[a+48|0]=0;t[a+49|0]=0;t[a+50|0]=0;t[a+51|0]=0;t[a+52|0]=0;t[a+53|0]=0;cb=b+16|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;_b(e)}_b(d);S(a|0);L()}function O4(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;if((c|0)!=1){a=v[a+24>>2];a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,872);if(!(t[(b+v[a>>2]|0)+1075081|0]&1)){break a}d=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125))}return C(d)}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,6275,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return C(C(0))}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function N4(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;if((c|0)!=1){a=v[a+24>>2];a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,872);if(!(t[(b+v[a>>2]|0)+1075081|0]&1)){break a}d=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125))}return C(d)}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,6177,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return C(C(0))}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function gja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=cb-80|0;cb=c;d=of(c+48|0);v[22440]=0;e=Q(368,b|0,d|0)|0;f=v[22440];v[22440]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22440]=0;T(369,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break a}}break c}e=sB(d);v[22440]=0;U(192,c|0,b|0,e|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Xc(d);S(a|0);L()}b=cc(c+24|0,c);Sc(d+8|0,b);sb(b);sb(c);Cj(a,d)}Xc(d);cb=c+80|0}function dfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=cb-80|0;cb=c;d=of(c+48|0);v[22440]=0;e=Q(677,b|0,d|0)|0;f=v[22440];v[22440]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22440]=0;T(678,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break a}}break c}e=om(d);v[22440]=0;U(192,c|0,b|0,e|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Xc(d);S(a|0);L()}b=cc(c+24|0,c);Sc(d+8|0,b);sb(b);sb(c);Cj(a,d)}Xc(d);cb=c+80|0}function Zja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=cb-80|0;cb=c;d=of(c+48|0);v[22440]=0;e=Q(307,b|0,d|0)|0;f=v[22440];v[22440]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22440]=0;T(308,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break a}}break c}e=sB(d);v[22440]=0;U(192,c|0,b|0,e|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Xc(d);S(a|0);L()}b=cc(c+24|0,c);Sc(d+8|0,b);sb(b);sb(c);Cj(a,d)}Xc(d);cb=c+80|0}function Rt(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=cb-16|0;cb=g;v[g+12>>2]=0;v[g+8>>2]=a;h=cb-16|0;cb=h;c=$b(h+8|0,v[g+8>>2],v[g+12>>2]);f=cb-16|0;cb=f;b=117;v[f+12>>2]=117;d=v[c+4>>2];a:{if(!d){d=v[c>>2];break a}e=32-d|0;v[f+8>>2]=e;b=v[c>>2];i=v[b>>2];j=e;e=v[Bb(f+8|0,f+12|0)>>2];v[b>>2]=(-1<<d&-1>>>j-e^-1)&i;i=v[f+12>>2];d=b+4|0;v[c>>2]=d;b=i-e|0}e=d;d=b>>>5<<2;Hb(e,0,d);b=b&31;v[f+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]&(-1>>>32-b^-1)}cb=f+16|0;cb=h+16|0;cb=g+16|0;return a}function RC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=w[a+8|0];h=v[a>>2];e=v[a+4>>2];f=Fb(b);a=vb(b);b=cb-16|0;cb=b;v[b+8>>2]=a;v[b+12>>2]=e;a=h;g=v[Bb(b+12|0,b+8|0)>>2];c=g;while(1){a:{if(!c){c=0;break a}i=w[f|0];t[a|0]=i;if(!i){break a}f=f+1|0;a=a+1|0;c=c-1|0;continue}break}b:{if((d-1&255)>>>0<=1){t[b+7|0]=0;em(a,((a+e|0)-g|0)+c|0,b+7|0);break b}if((d-3&255)>>>0>1){break b}t[b+6|0]=32;em(a,((a+e|0)-g|0)+c|0,b+6|0)}c:{switch(d-1|0){case 0:case 3:t[(v[b+12>>2]+h|0)-1|0]=0;break;default:break c}}cb=b+16|0}function xH(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=cb-32|0;cb=d;A[d+24>>3]=c;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[22440]=0;d=Q(56,d+8|0,10725)|0;a=v[22440];v[22440]=0;if((a|0)==1){break c}oc(b,d);v[22440]=0;U(121,b|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;rb(d);break b}a=v[a+32>>2];v[d+8>>2]=0;v[d+12>>2]=-1074790400;v[d>>2]=0;v[d+4>>2]=1072693248;e=(a+B(b,872)|0)+1075684|0,f=tl(A[Fg(d+24|0,d+8|0,d)>>3]*128+128),v[e>>2]=f;cb=d+32|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function qha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=cb-16|0;cb=e;i=e,j=yj(b),v[i>>2]=j;g=x[b>>1];c=cb-16|0;cb=c;f=a;a=Kd(a);a:{b:{if(a){b=bc(f);while(1){c:{d=a+16|0;if(wA(g,d)){d=v[a>>2];if(!d){break b}break c}if(vA(d,g)){b=a+4|0;d=v[a+4>>2];if(d){a=b;break c}v[c+12>>2]=a;a=b;break a}v[c+12>>2]=a;a=b;break a}b=a;a=d;continue}}a=bc(f)}v[c+12>>2]=a}b=a;a=v[a>>2];if(!a){yS(c,f,e);Ig(f,v[c+12>>2],b,v[c>>2]);a=Vd(c);xS(c);h=1}b=e+8|0;Hg(b,ac(c,a),h);cb=c+16|0;a=od(b);cb=e+16|0;return a+4|0}function k9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);e=cb-16|0;cb=e;c=rf(a,c);ke(e,v[a+36>>2]);a:{if(!c){b:{Cc(e,a+32|0,5);if(!tb(v[v[e>>2]>>2],v[e+4>>2])){break b}break a}}d=cb-32|0;cb=d;h=v[a+36>>2];Fk(h,d+24|0);i=d,j=wc(v[d+24>>2],v[d+28>>2]),v[i+16>>2]=j;v[d+12>>2]=256;ak(b,v[Bb(d+16|0,d+12|0)>>2]);f=v[b>>2];while(1){if(pc(f,v[b+4>>2])>>>0<=g>>>0){cb=d+32|0}else{v[d+16>>2]=0;gp(h,d+16|0);f=v[b>>2];i=Ib(f,g),k=z[d+16>>2],z[i>>2]=k;g=g+1|0;continue}break}d=c}Se(a,d);cb=e+16|0}function cga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=cb-608|0;cb=f;b=cb-16|0;cb=b;d=f+8|0;gR(b+8|0,d);c=v[b+12>>2];cd(b,a,v[b+8>>2],c);e=v[b+4>>2];if((e|0)==(c|0)){Yc(a,v[b+12>>2])}cb=b+16|0;c=(c|0)==(e|0);if(!c){fR(d)}b=-1;a:{if(!c){break a}b=0;if(!hR(f+8|0)){break a}b=-1;if(!gg(a,1024)){break a}b=0;d=cb-1024|0;cb=d;c=cb-16|0;cb=c;Rz(c+8|0,d);e=v[c+12>>2];cd(c,a,v[c+8>>2],e);g=v[c+4>>2];if((e|0)==(g|0)){Yc(a,v[c+12>>2])}cb=c+16|0;if((e|0)==(g|0)){b=Sz(d,0)>>>0<17}cb=d+1024|0}cb=f+608|0;return b|0}function sq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){if(!Ld(a)){if(!Ld(b)){v[a+8>>2]=v[b+8>>2];c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return}d=Fb(b);b=vb(b);c=cb-16|0;cb=c;a:{if(b>>>0<=10){Yd(a,b);a=Ce(a,d,b);t[c+15|0]=0;$d(a+b|0,c+15|0);break a}f=a;a=w[a+11|0];Mo(f,10,b-10|0,a,0,a,b,d)}cb=c+16|0;return}d=Fb(b);b=vb(b);c=cb-16|0;cb=c;e=Lj(a);b:{if(e>>>0>b>>>0){e=v[a>>2];td(a,b);a=Ce(e,d,b);t[c+15|0]=0;$d(a+b|0,c+15|0);break b}f=a;a=v[a+4>>2];Mo(f,e-1|0,(b-e|0)+1|0,a,0,a,b,d)}cb=c+16|0}}function n_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;h=cb-16|0;cb=h;d=vb(a);e=No(a);g=Gt(b,c);a:{if(!g){break a}b:{f=Fb(a);if(f>>>0<=b>>>0){f=(vb(a)<<2)+f>>>0>=b>>>0}else{f=0}if(!f){if(e-d>>>0<g>>>0){ZE(a,e,(d+g|0)-e|0,d,d)}e=Fb(a)+(d<<2)|0;while(1){if((b|0)==(c|0)){break b}qd(e,v[b>>2]);b=b+4|0;e=e+4|0;continue}}b=HF(h,b,c);c=Fb(b);d=vb(b);v[22440]=0;Y(1195,a|0,c|0,d|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){Vc(b);break a}a=P()|0;O()|0;Vc(b);S(a|0);L()}qd(e,0);Bf(a,d+g|0)}cb=h+16|0;return a|0}function R4(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;if((c|0)!=1){a=v[a+24>>2];a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,872);if(t[(b+v[a>>2]|0)+1075081|0]&1){break a}d=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125))}return C(d)}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,6232,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return C(C(0))}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function M4(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;if((c|0)!=1){a=v[a+24>>2];a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,872);if(t[(b+v[a>>2]|0)+1075081|0]&1){break a}d=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125))}return C(d)}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,6133,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return C(C(0))}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function DK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=cb-16|0;cb=e;i=e,j=yj(b),v[i>>2]=j;g=x[b>>1];c=cb-16|0;cb=c;f=a;a=Kd(a);a:{b:{if(a){b=bc(f);while(1){c:{d=a+16|0;if(FK(g,d)){d=v[a>>2];if(!d){break b}break c}if(EK(d,g)){b=a+4|0;d=v[a+4>>2];if(d){a=b;break c}v[c+12>>2]=a;a=b;break a}v[c+12>>2]=a;a=b;break a}b=a;a=d;continue}}a=bc(f)}v[c+12>>2]=a}b=a;a=v[a>>2];if(!a){yS(c,f,e);Ig(f,v[c+12>>2],b,v[c>>2]);a=Vd(c);xS(c);h=1}b=e+8|0;Hg(b,ac(c,a),h);cb=c+16|0;a=od(b);cb=e+16|0;return a+4|0}function _C(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=cb-16|0;cb=e;g=v[b+16>>2];v[a+4>>2]=0;v[a>>2]=g;a:{if(!g){break a}c=b+80|0;d=v[b+84>>2];if(d>>>0<=15){c=v[c>>2]}else{v[e+12>>2]=d-16;c=v[Pc(c,e+12|0)>>2]}v[a+8>>2]=c;if(!(w[b+88|0]&2)){break a}b:{c:{if(!ZC(b)){c=v[b+104>>2];break c}c=v[b+104>>2];if(v[b+80>>2]!=v[c+12>>2]){break c}d=1;f=v[b+84>>2];if((f|0)==v[c+16>>2]){break b}}d=0;f=v[b+84>>2];if((f|0)!=v[c+8>>2]){break a}}h=a,i=B((v[c>>2]-f|0)+(d?112:48)|0,Ak(x[c+34>>1]))+g|0,v[h+4>>2]=i}cb=e+16|0}function qm(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function zl(a,b,c){var d=0;d=512;a:{if(b){break a}d=0;if(!(w[a+35|0]&2)){break a}Jz(a)}d=x[a+34>>1]&-513|d;u[a+34>>1]=d;if(b){v[a>>2]=4;u[a+34>>1]=d&65470;Lg(a);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+76|0]=b;t[a+77|0]=b>>>8;t[a+78|0]=b>>>16;t[a+79|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a+68|0]=c;t[a+69|0]=c>>>8;t[a+70|0]=c>>>16;t[a+71|0]=c>>>24;t[a+72|0]=b;t[a+73|0]=b>>>8;t[a+74|0]=b>>>16;t[a+75|0]=b>>>24}}function hha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=yb(v[b>>2]);h=yb(v[b+4>>2]);e=cb-16|0;cb=e;v[e>>2]=c;v[e+8>>2]=d;while(1){a:{b:{if(Qb(d,h)){g=cb-16|0;cb=g;c=g+8|0;f=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[c|0]=f;t[c+1|0]=f>>>8;t[c+2|0]=f>>>16;t[c+3|0]=f>>>24;d=w[d+4|0]|w[d+5|0]<<8;t[c+4|0]=d;t[c+5|0]=d>>>8;cb=g+16|0;if(v[e>>2]!=(w[c|0]|w[c+1|0]<<8)){break b}d=v[e+8>>2]}cb=e+16|0;c=d;break a}zm(e+8|0);d=v[e+8>>2];continue}break}if(hc(c,yb(v[b+4>>2]))){ai(a);return}ho(a,c)}function X4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=cb-16|0;cb=f;v[22440]=0;Z(971,a|0);g=v[22440];v[22440]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[22440]=0;ka(1023,f|0,g|0,b|0,c|0,d|0,e|0);b=v[22440];v[22440]=0;if((b|0)==1){break c}b=le(Fb(f));rb(f);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[22440]=0;W(958,12501,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$()}cb=f+16|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function X3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=cb-16|0;cb=f;v[22440]=0;Z(971,a|0);g=v[22440];v[22440]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[22440]=0;ka(1049,f|0,g|0,b|0,c|0,d|0,e|0);b=v[22440];v[22440]=0;if((b|0)==1){break c}b=le(Fb(f));rb(f);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[22440]=0;W(958,12401,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$()}cb=f+16|0;return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function bK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;b=vi(a,b,c,d);t[a+4260|0]=e;v[a>>2]=46356;c=Rb(a+4264|0);d=Rb(a+4276|0);v[a+4232>>2]=1061997773;e=a+4224|0;v[e>>2]=1061158912;v[e+4>>2]=1059082943;e=a+4216|0;v[e>>2]=1038174126;v[e+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1036831949;v[a+4328>>2]=0;e=a+4320|0;v[e>>2]=0;v[e+4>>2]=0;v[a+4312>>2]=0;v[a+4316>>2]=0;v[22440]=0;R(922,a+44|0,2);e=v[22440];v[22440]=0;if((e|0)!=1){ui(b);return a|0}a=P()|0;O()|0;fc(d);fc(c);vf(b);S(a|0);L()}function pia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=cb-48|0;cb=f;Dh(f+8|0,c);v[22440]=0;c=f+20|0;R(115,c|0,d|0);d=v[22440];v[22440]=0;b:{c:{d:{if((d|0)==1){break d}v[22440]=0;c=f+32|0;R(115,c|0,e|0);d=v[22440];v[22440]=0;if((d|0)==1){break d}_q(f,f+8|0);v[22440]=0;W(116,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[22440];v[22440]=0;if((a|0)==1){break c}Dk(f+8|0);cb=f+48|0;break a}a=P()|0;O()|0;while(1){c=rb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;O()|0;Dk(f+8|0)}S(a|0);L()}}function cea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=cb-48|0;cb=f;Dh(f+8|0,c);v[22440]=0;c=f+20|0;R(591,c|0,d|0);d=v[22440];v[22440]=0;b:{c:{d:{if((d|0)==1){break d}v[22440]=0;c=f+32|0;R(591,c|0,e|0);d=v[22440];v[22440]=0;if((d|0)==1){break d}_q(f,f+8|0);v[22440]=0;W(303,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[22440];v[22440]=0;if((a|0)==1){break c}Dk(f+8|0);cb=f+48|0;break a}a=P()|0;O()|0;while(1){c=rb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;O()|0;Dk(f+8|0)}S(a|0);L()}}function Uea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=cb-48|0;cb=f;Dh(f+8|0,c);v[22440]=0;c=f+20|0;R(141,c|0,d|0);d=v[22440];v[22440]=0;b:{c:{d:{if((d|0)==1){break d}v[22440]=0;c=f+32|0;R(115,c|0,e|0);d=v[22440];v[22440]=0;if((d|0)==1){break d}_q(f,f+8|0);v[22440]=0;W(116,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[22440];v[22440]=0;if((a|0)==1){break c}Dk(f+8|0);cb=f+48|0;break a}a=P()|0;O()|0;while(1){c=rb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;O()|0;Dk(f+8|0)}S(a|0);L()}}function P_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=cb-208|0;cb=a;u[a+204>>1]=w[79739]|w[79740]<<8;v[a+200>>2]=w[79735]|w[79736]<<8|(w[79737]<<16|w[79738]<<24);f=pd();v[a>>2]=e;g=a+176|0;i=Lf(g,20,f,a+200|0,a);e=i+g|0;g=Yg(g,e,c);f=a+8|0;Jc(f,c);v[22440]=0;f=T(1159,f|0)|0;h=v[22440];v[22440]=0;if((h|0)!=1){Pb(a+8|0);h=f;f=a+16|0;rF(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=_m(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);cb=a+208|0;return b|0}b=P()|0;O()|0;Pb(a+8|0);S(b|0);L()}function BQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=cb-16|0;cb=c;v[a>>2]=0;v[a+4>>2]=0;og(a+8|0,0);d=v[b+4>>2];if(d){Dq(a,d);kk(c+8|0,v[b>>2]);pl(c,v[b>>2],v[b+4>>2]);b=cb-16|0;cb=b;d=v[a+4>>2];h=v[c+8>>2];i=v[c+12>>2];j=v[c>>2];k=v[c+4>>2];e=AQ(h,i,j,k)+d|0;v[a+4>>2]=e;a:{b:{if(!d){f=e-1|0;break b}f=e-1|0;if((f^d-1)>>>0>31){break b}g=v[a>>2];break a}g=v[a>>2];v[g+((e>>>0<33?0:f>>>5|0)<<2)>>2]=0}to(b+8|0,g,d);zQ(b,h,i,j,k,v[b+8>>2],v[b+12>>2]);cb=b+16|0}cb=c+16|0;return a|0}function yea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=cb-4112|0;cb=d;nm(a,b);a:while(1){if(Uc(v[a>>2],v[a+4>>2])>>>12>>>0>e>>>0){f=e<<12;b=0;c=0;while(1)if((b|0)==2048){g=f|2048;b=0;while(1){if((b|0)!=2048){h=Eb(v[a>>2],b+g|0);i=Eb(d+16|0,b<<1);c=w[h|0]+c|0;t[i|0]=c;b=b+1|0;continue}break}b=d+16|0;c=HP(b);j=d,k=yb(v[a>>2]),v[j+8>>2]=k;rt(b,c,je(d+8|0,f));e=e+1|0;continue a}else{g=Eb(v[a>>2],b+f|0);h=Eb(d+16|0,b<<1|1);c=w[g|0]+c|0;t[h|0]=c;b=b+1|0;continue}}break}cb=d+4112|0}function YW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=cb-48|0;cb=f;Xm(f+8|0,c);v[22440]=0;c=f+20|0;R(141,c|0,d|0);d=v[22440];v[22440]=0;b:{c:{d:{if((d|0)==1){break d}v[22440]=0;c=f+32|0;R(141,c|0,e|0);d=v[22440];v[22440]=0;if((d|0)==1){break d}_q(f,f+8|0);v[22440]=0;W(116,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[22440];v[22440]=0;if((a|0)==1){break c}Dk(f+8|0);cb=f+48|0;break a}a=P()|0;O()|0;while(1){c=rb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;O()|0;Dk(f+8|0)}S(a|0);L()}}function Jha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=cb-32|0;cb=c;e=c+8|0;f=Rb(e+8|0);v[22440]=0;d=T(204,b|0)|0;g=v[22440];v[22440]=0;a:{b:{if((g|0)==1){break b}v[22440]=0;U(250,e|0,b|0,d|0);d=v[22440];v[22440]=0;if((d|0)==1){break b}d=v[e>>2];v[22440]=0;Q(190,b|0,d|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;_b(f);S(a|0);L()}Au(c,e);v[22440]=0;U(476,a|0,v[c>>2],v[c+4>>2]);a=v[22440];v[22440]=0;if((a|0)!=1){vc(c+8|0);cb=c+32|0;return}a=P()|0;O()|0;vc(c+8|0);S(a|0);L()}function zO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;j=b?33:32;c=v[a+8>>2]-1|0;e=v[a+12>>2];f=v[a>>2]+B(e,31)|0;g=b?1:-1;d=g;a:while(1){b:{b=0;if((h|0)==(j|0)){break b}while(1)if((b|0)>=(e|0)){b=B(e,g);i=v[a+8>>2]-1|0;c:{if(!((i|0)!=(c|0)|(d|0)<=0)){if(!w[a+16|0]){d=1;c=0;break c}d=-1;c=c-(w[a+17|0]!=0&(c|0)!=0)|0;break c}if(!((d|0)>=0|c)){c=w[a+16|0];d=c?1:-1;c=c?0:i;break c}c=c+d|0}f=b+f|0;h=h+1|0;continue a}else{t[b+f|0]=w[v[a+4>>2]+(B(c,e)+b|0)|0];b=b+1|0;e=v[a+12>>2];continue}}break}}function xk(a){var b=0,c=0;a:{b=v[a+4>>2];b=v[v[b>>2]-12>>2]+b|0;b:{if(!v[b+24>>2]){break b}if(!Gh(b)|!(v[b+4>>2]&8192)){break b}if((bb()|0)>0){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[22440]=0;b=T(22,b|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[22440]=0;R(16,a+b|0,1);a=v[22440];v[22440]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;_(a|0)|0;v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Lb();L()}function X_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=cb-160|0;cb=a;u[a+156>>1]=w[79733]|w[79734]<<8;v[a+152>>2]=w[79729]|w[79730]<<8|(w[79731]<<16|w[79732]<<24);f=a+152|0;Nk(f|1,10773,1,v[c+4>>2]);g=pd();v[a>>2]=e;e=a+139|0;f=Lf(e,13,g,f,a)+e|0;g=Yg(e,f,c);h=a+16|0;Jc(h,c);v[22440]=0;ja(1176,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[22440];v[22440]=0;if((e|0)!=1){Pb(a+16|0);b=_m(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);cb=a+160|0;return b|0}b=P()|0;O()|0;Pb(a+16|0);S(b|0);L()}function U_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=cb-160|0;cb=a;u[a+156>>1]=w[79733]|w[79734]<<8;v[a+152>>2]=w[79729]|w[79730]<<8|(w[79731]<<16|w[79732]<<24);f=a+152|0;Nk(f|1,10773,0,v[c+4>>2]);g=pd();v[a>>2]=e;e=a+139|0;f=Lf(e,13,g,f,a)+e|0;g=Yg(e,f,c);h=a+16|0;Jc(h,c);v[22440]=0;ja(1176,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[22440];v[22440]=0;if((e|0)!=1){Pb(a+16|0);b=_m(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);cb=a+160|0;return b|0}b=P()|0;O()|0;Pb(a+16|0);S(b|0);L()}function XM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=cb-16|0;cb=e;k=e,l=yj(b),v[k>>2]=l;c=cb-16|0;cb=c;h=zy(a,c+12|0,w[b|0],v[b+4>>2]);b=v[h>>2];if(!b){g=cb-16|0;cb=g;b=bc(a);i=kh(c,lc(28),lh(g+8|0,b));b=v[i>>2];d=cb-16|0;cb=d;v[d+8>>2]=v[e>>2];f=v[d+8>>2];j=v[f+4>>2];f=v[f>>2];v[b+24>>2]=0;v[b+16>>2]=f;v[b+20>>2]=j;cb=d+16|0;k=bc(i),l=1,t[k+4|0]=l;cb=g+16|0;Ig(a,v[c+12>>2],h,v[c>>2]);b=Vd(c);pk(c);d=1}a=e+8|0;Hg(a,ac(c,b),d);cb=c+16|0;a=od(a);cb=e+16|0;return a+8|0}function gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=cb-32|0;cb=d;ed(b,0);WA(d,a+1|0);c=d+16|0;xc(c,v[d>>2],v[d+4>>2],w[d+8|0]);pe(b+43|0,c);rb(c);c=a+78|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;c=a+58|0;e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b>>2]=e;c=a+62|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+66|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);u[b+30>>1]=(w[a+73|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;qc(b+8|0,e);qc(b+4|0,v[b+8>>2]);cb=d+32|0}function yO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=b?33:32;e=v[a+12>>2];j=(e|0)>0?e:0;g=v[a>>2]+B(e,62)|0;d=b?1:-1;k=B(e,d)<<1;f=v[a+8>>2]-1|0;c=f;a:while(1){if((h|0)!=(i|0)){l=B(c,e);b=0;while(1)if((b|0)==(j|0)){b:{if(!((c|0)!=(f|0)|(d|0)<=0)){if(!w[a+16|0]){d=1;c=0;break b}d=-1;c=f-(w[a+17|0]!=0&(f|0)!=0)|0;break b}if(!((d|0)>=0|c)){b=w[a+16|0];d=b?1:-1;c=b?0:f;break b}c=d+c|0}g=g+k|0;h=h+1|0;continue a}else{u[(b<<1)+g>>1]=x[v[a+4>>2]+(b+l<<1)>>1];b=b+1|0;continue}}break}}function nba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=cb-48|0;cb=d;YN(a,1<<b-1);v[a+12>>2]=b;b=1<<b;h=-6.283185307179586/+(b>>>0);f=1;g=b>>>2|0;b=g;while(1){if(b){e=v[10493];c=d+16|0;v[c+8>>2]=v[10492];v[c+12>>2]=e;e=v[10491];v[c>>2]=v[10490];v[c+4>>2]=e;Yy(c,h*+(b>>>0));TN(d+32|0,c);c=sd(v[a>>2],f);e=v[d+44>>2];v[c+8>>2]=v[d+40>>2];v[c+12>>2]=e;e=v[d+36>>2];v[c>>2]=v[d+32>>2];v[c+4>>2]=e;b=b>>>1|0;f=f<<1;continue}break}b=lm(d,1,0);Sx(a,0,g,A[b>>3],A[b+8>>3]);cb=d+48|0;return a|0}function tv(a){var b=0,c=0,d=0;if(y[a+4>>2]<y[xb(a)>>2]){b=cb-16|0;cb=b;a=sD(b,a);c=v[a+4>>2];v[22440]=0;Z(172,c|0);c=v[22440];v[22440]=0;a:{if((c|0)!=1){v[a+4>>2]=v[a+4>>2]+36;dc(a);cb=b+16|0;break a}b=P()|0;O()|0;dc(a);S(b|0);L()}return}c=cb-32|0;cb=c;b=xb(a);b=qD(c+8|0,rD(a,Nq(v[a>>2],v[a+4>>2])+1|0),Nq(v[a>>2],v[a+4>>2]),b);d=v[b+8>>2];v[22440]=0;Z(172,d|0);d=v[22440];v[22440]=0;b:{if((d|0)!=1){v[b+8>>2]=v[b+8>>2]+36;pD(a,b);kv(b);cb=c+32|0;break b}a=P()|0;O()|0;kv(b);S(a|0);L()}}function f4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22440]=0;Z(971,a|0);d=v[22440];v[22440]=0;a:{if((d|0)==1){break a}v[22440]=0;Z(1042,c|0);d=v[22440];v[22440]=0;if((d|0)==1){break a}d=v[a+24>>2];v[22440]=0;b=Q(1043,d|0,b|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}v[c>>2]=b;return 1}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,10372,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function f$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=cb-80|0;cb=a;u[a+76>>1]=w[79733]|w[79734]<<8;v[a+72>>2]=w[79729]|w[79730]<<8|(w[79731]<<16|w[79732]<<24);f=a+72|0;Nk(f|1,10773,1,v[c+4>>2]);g=pd();v[a>>2]=e;e=a+59|0;f=Lf(e,13,g,f,a)+e|0;g=Yg(e,f,c);h=a+16|0;Jc(h,c);v[22440]=0;ja(1173,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[22440];v[22440]=0;if((e|0)!=1){Pb(a+16|0);b=Fm(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);cb=a+80|0;return b|0}b=P()|0;O()|0;Pb(a+16|0);S(b|0);L()}function c$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=cb-80|0;cb=a;u[a+76>>1]=w[79733]|w[79734]<<8;v[a+72>>2]=w[79729]|w[79730]<<8|(w[79731]<<16|w[79732]<<24);f=a+72|0;Nk(f|1,10773,0,v[c+4>>2]);g=pd();v[a>>2]=e;e=a+59|0;f=Lf(e,13,g,f,a)+e|0;g=Yg(e,f,c);h=a+16|0;Jc(h,c);v[22440]=0;ja(1173,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[22440];v[22440]=0;if((e|0)!=1){Pb(a+16|0);b=Fm(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);cb=a+80|0;return b|0}b=P()|0;O()|0;Pb(a+16|0);S(b|0);L()}function L1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=cb-48|0;cb=e;a:{if(w[b+8|0]){f=v[b+12>>2];j=e,k=Uc(f,v[b+16>>2])-c|0,v[j+40>>2]=k;v[e+32>>2]=v[d+4>>2];h=e+40|0;i=e+32|0;g=v[Bb(h,i)>>2];j=e,k=yb(f),v[j+40>>2]=k;f=je(h,c);j=e,k=yb(v[b+12>>2]),v[j+24>>2]=k;j=e,k=je(e+24|0,c),v[j+32>>2]=k;c=je(i,g);b=v[d>>2];zk(f,c,b);Ub(a,b,g);break a}g=v[d+4>>2];d=v[d>>2];v[e+16>>2]=d;v[e+20>>2]=g;f=v[v[b>>2]+40>>2];v[e+8>>2]=d;v[e+12>>2]=g;gb[f|0](a,b,c,e+8|0)}cb=e+48|0}function xI(a){var b=0,c=0,d=0,e=0,f=0;while(1){d=v[a+16>>2];if(d>>>0<=e>>>0){while(1){if(!(y[a+12>>2]<=d>>>0)){while(1){e=my(v[a>>2]);c=fb;f=v[a+36>>2];if((c|0)==(f|0)&y[a+32>>2]<=e>>>0|c>>>0>f>>>0){continue}break}c=b;b=v[a+8>>2];b=(e&v[a+48>>2])+(b>>>0<31?c<<b+1:0)|0;d=d+1|0;continue}break}}else{while(1){d=my(v[a>>2]);c=fb;f=v[a+28>>2];if((c|0)==(f|0)&y[a+24>>2]<=d>>>0|c>>>0>f>>>0){continue}break}c=b;b=v[a+8>>2];b=(d&v[a+40>>2])+(b>>>0<32?c<<b:0)|0;e=e+1|0;continue}break}return b}function J4(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){a=v[a+24>>2]+24|0;b=x[v[a>>2]+1074448>>1];a:{if(rj(Nb(v[a>>2]+484360|0))>>>0<=b>>>0){a=x[v[a>>2]+1074446>>1];break a}b=x[Xb(v[Nb(v[a>>2]+484360|0)>>2],b)>>1];a=Dm(v[a>>2]+484344|0,b)?b:-1}return a|0}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,9785,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function Z_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=cb-96|0;cb=a;u[a+92>>1]=w[79739]|w[79740]<<8;v[a+88>>2]=w[79735]|w[79736]<<8|(w[79737]<<16|w[79738]<<24);f=pd();v[a>>2]=e;g=a- -64|0;i=Lf(g,20,f,a+88|0,a);e=i+g|0;g=Yg(g,e,c);f=a+8|0;Jc(f,c);v[22440]=0;f=T(19,f|0)|0;h=v[22440];v[22440]=0;if((h|0)!=1){Pb(a+8|0);h=f;f=a+16|0;vF(h,a- -64|0,e,f);h=b;b=f+i|0;b=Fm(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);cb=a+96|0;return b|0}b=P()|0;O()|0;Pb(a+8|0);S(b|0);L()}function Xga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[xb(a)>>2]){c=cb-16|0;cb=c;a=zU(c,a);jA(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;dc(a);cb=c+16|0;return}e=cb-32|0;cb=e;c=xb(a);c=xU(e+8|0,yU(a,qq(v[a>>2],v[a+4>>2])+1|0),qq(v[a>>2],v[a+4>>2]),c);jA(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-28|0;jA(v[b>>2]-28|0,d);v[b>>2]=v[b>>2]-28;continue}break}ec(a,b);ec(a+4|0,c+8|0);ec(xb(a),mc(c));v[c>>2]=v[c+4>>2];wU(c);cb=e+32|0}function Dj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[xb(a)>>2]){c=cb-16|0;cb=c;a=zU(c,a);rB(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;dc(a);cb=c+16|0;return}e=cb-32|0;cb=e;c=xb(a);c=xU(e+8|0,yU(a,qq(v[a>>2],v[a+4>>2])+1|0),qq(v[a>>2],v[a+4>>2]),c);rB(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-28|0;rB(v[b>>2]-28|0,d);v[b>>2]=v[b>>2]-28;continue}break}ec(a,b);ec(a+4|0,c+8|0);ec(xb(a),mc(c));v[c>>2]=v[c+4>>2];wU(c);cb=e+32|0}function C8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;b=vi(a,b,c,d);v[a>>2]=44184;c=Rb(a+4208|0);v[a+4236>>2]=2147483647;v[a+4240>>2]=0;v[a+4228>>2]=1049926264;v[a+4232>>2]=0;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;t[a+4244|0]=0;Hb(a+4248|0,0,48);v[22440]=0;X(834);d=v[22440];v[22440]=0;a:{if((d|0)==1){break a}e=a,f=TL(),v[e+4296>>2]=f;ss(a);rs(a);v[22440]=0;R(922,a+44|0,2);d=v[22440];v[22440]=0;if((d|0)==1){break a}ui(b);return a|0}a=P()|0;O()|0;_b(c);vf(b);S(a|0);L()}function bJ(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;if((e|0)==10){Nx(a,b,c,d);return}g=d;i=B(e,e);k=B(i,e);j=B(i,i);a:{while(1){h=f|1;if(e>>>0>g>>>0){break a}h=f|2;if(g>>>0<i>>>0){break a}h=f|3;if(g>>>0<k>>>0){break a}if(g>>>0<j>>>0){h=f+4|0}else{f=f+4|0;g=(g>>>0)/(j>>>0)|0;continue}break}}f=h;if((f|0)>(c-b|0)){v[a+4>>2]=61;v[a>>2]=c;return}f=b+f|0;b=f;while(1){b=b-1|0;c=(d>>>0)/(e>>>0)|0;t[b|0]=w[(d-B(c,e)|0)+4898|0];g=d>>>0>=e>>>0;d=c;if(g){continue}break}v[a+4>>2]=0;v[a>>2]=f}function PK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a|0)!=(b|0)){c=cb-16|0;cb=c;d=v[b>>2];f=v[b+4>>2];e=ok(d,f);a:{if(e>>>0<=du(a)>>>0){g=f;h=v[a>>2];i=ok(h,v[a+4>>2]);j=i>>>0>=e>>>0;if(!j){v[c+12>>2]=d;v[c+12>>2]=v[c+12>>2]+B(i,6);h=v[a>>2];g=v[c+12>>2]}d=RK(d,g,h);if(!j){Ox(a,g,f,e-ok(v[a>>2],v[a+4>>2])|0);break a}Nd(a,d);break a}QK(a);DS(a,tA(a,e));Ox(a,d,f,e)}cb=c+16|0}v[a+12>>2]=v[b+12>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=v[b+20>>2];OK(a+24|0,b+24|0);sq(a+36|0,b+36|0)}function Mfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,26);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0}}function Afa(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;b=-1;a:{if(!gg(a,8)){break a}b=cb-32|0;cb=b;v[b+24>>2]=0;v[b+28>>2]=0;d=$b(b+8|0,b+24|0,8);cd(b+16|0,a,v[d>>2],v[d+4>>2]);d=0;b:{if(v[b+20>>2]!=8){break b}if(Mb(b+24|0,14222,8)){break b}Yc(a,8);d=1}cb=b+32|0;b=0;if(!d){break a}b=-1;if(!Pj(a,c+8|0)){break a}a=c+8|4;b=0;if(!Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}b=!(Wb(w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24))&-2139062144)}cb=c+16|0;return b|0}function v4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=cb-32|0;cb=e;d=Me(e+16|0,1,0);a:{b:{while(1){f=Fb(d);jx(e+8|0,f,vb(d)+f|0,v[b>>2],c);if(!v[e+12>>2]){break b}f=Yf(vb(d));v[22440]=0;R(60,d|0,f|0);f=v[22440];v[22440]=0;if((f|0)!=1){continue}break}break a}b=v[e+8>>2];c=Fb(d);v[22440]=0;R(61,d|0,b-c|0);b=v[22440];v[22440]=0;c:{if((b|0)!=1){v[22440]=0;R(62,a|0,d|0);a=v[22440];v[22440]=0;if((a|0)!=1){break c}break a}break a}rb(d);cb=e+32|0;return}a=P()|0;O()|0;rb(d);S(a|0);L()}function m4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=cb-32|0;cb=e;d=Me(e+16|0,1,0);a:{b:{while(1){f=Fb(d);$I(e+8|0,f,vb(d)+f|0,v[b>>2],c);if(!v[e+12>>2]){break b}f=Yf(vb(d));v[22440]=0;R(60,d|0,f|0);f=v[22440];v[22440]=0;if((f|0)!=1){continue}break}break a}b=v[e+8>>2];c=Fb(d);v[22440]=0;R(61,d|0,b-c|0);b=v[22440];v[22440]=0;c:{if((b|0)!=1){v[22440]=0;R(62,a|0,d|0);a=v[22440];v[22440]=0;if((a|0)!=1){break c}break a}break a}rb(d);cb=e+32|0;return}a=P()|0;O()|0;rb(d);S(a|0);L()}function Tf(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function N2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=cb-32|0;cb=e;d=Me(e+16|0,1,0);a:{b:{while(1){f=Fb(d);jx(e+8|0,f,vb(d)+f|0,v[b>>2],c);if(!v[e+12>>2]){break b}f=Yf(vb(d));v[22440]=0;R(60,d|0,f|0);f=v[22440];v[22440]=0;if((f|0)!=1){continue}break}break a}b=v[e+8>>2];c=Fb(d);v[22440]=0;R(61,d|0,b-c|0);b=v[22440];v[22440]=0;c:{if((b|0)!=1){v[22440]=0;R(74,a|0,d|0);a=v[22440];v[22440]=0;if((a|0)!=1){break c}break a}break a}rb(d);cb=e+32|0;return}a=P()|0;O()|0;rb(d);S(a|0);L()}function K2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=cb-32|0;cb=e;d=Me(e+16|0,1,0);a:{b:{while(1){f=Fb(d);$I(e+8|0,f,vb(d)+f|0,v[b>>2],c);if(!v[e+12>>2]){break b}f=Yf(vb(d));v[22440]=0;R(60,d|0,f|0);f=v[22440];v[22440]=0;if((f|0)!=1){continue}break}break a}b=v[e+8>>2];c=Fb(d);v[22440]=0;R(61,d|0,b-c|0);b=v[22440];v[22440]=0;c:{if((b|0)!=1){v[22440]=0;R(74,a|0,d|0);a=v[22440];v[22440]=0;if((a|0)!=1){break c}break a}break a}rb(d);cb=e+32|0;return}a=P()|0;O()|0;rb(d);S(a|0);L()}function q6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=cb-32|0;cb=e;d=Me(e+16|0,1,0);a:{b:{while(1){f=Fb(d);jx(e+8|0,f,vb(d)+f|0,w[b|0],c);if(!v[e+12>>2]){break b}f=Yf(vb(d));v[22440]=0;R(60,d|0,f|0);f=v[22440];v[22440]=0;if((f|0)!=1){continue}break}break a}b=v[e+8>>2];c=Fb(d);v[22440]=0;R(61,d|0,b-c|0);b=v[22440];v[22440]=0;c:{if((b|0)!=1){v[22440]=0;R(62,a|0,d|0);a=v[22440];v[22440]=0;if((a|0)!=1){break c}break a}break a}rb(d);cb=e+32|0;return}a=P()|0;O()|0;rb(d);S(a|0);L()}function _t(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=cb-16|0;cb=g;h=Eb(b,0);f=(w[h|0]&15)<<8|w[Eb(b,1)|0];d=0;a:{if(!f){break a}d=0;if((f|0)==4095){break a}while(1){d=108;if((e|0)==84){break a}b:{d=x[(e<<1)+32784>>1];if(d>>>0<=f>>>0){if(!e|(f|0)==(d|0)|(x[(e<<1)+32782>>1]-f|0)>=(f-d|0)){break b}d=e+24|0;break a}e=e+1|0;continue}break}d=e+25|0}t[c|0]=d;e=Eb(b,2);d=w[e|0];f=w[h|0];t[c+3|0]=0;t[c+1|0]=f&16|d>>>4;c=w[e|0];i=g,j=w[Eb(b,3)|0],t[i+15|0]=j;ae(a,c&15,g+15|0);cb=g+16|0}function _m(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=cb-16|0;cb=i;a:{b:{if(!a){break b}h=v[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>2;if((Cm(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if(b){f=oF(i,b,f);h=Fb(f);v[22440]=0;h=Y(1178,a|0,h|0,b|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break a}Vc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>2;if((Cm(a,c,b)|0)!=(b|0)){break b}}lo(e);j=a}cb=i+16|0;return j|0}a=P()|0;O()|0;Vc(f);S(a|0);L()}function Q1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;Co(a);v[a>>2]=57260;e=mc(a);c=cb-16|0;cb=c;d=b;b=v[b+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=b;b=c;c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;c=cb-16|0;cb=c;d=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=d;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;d=$H(c);Sm(e);t[e+8|0]=0;v[e+4>>2]=d;v[e>>2]=57660;Rb(e+12|0);v[e>>2]=57424;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;d=v[b+12>>2];v[e+32>>2]=v[b+8>>2];v[e+36>>2]=d;cb=c+16|0;cb=b+16|0;return a|0}function P4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=cb-32|0;cb=e;d=Me(e+16|0,1,0);a:{b:{while(1){f=Fb(d);aJ(e+8|0,f,vb(d)+f|0,w[b|0],c);if(!v[e+12>>2]){break b}f=Yf(vb(d));v[22440]=0;R(60,d|0,f|0);f=v[22440];v[22440]=0;if((f|0)!=1){continue}break}break a}b=v[e+8>>2];c=Fb(d);v[22440]=0;R(61,d|0,b-c|0);b=v[22440];v[22440]=0;c:{if((b|0)!=1){v[22440]=0;R(62,a|0,d|0);a=v[22440];v[22440]=0;if((a|0)!=1){break c}break a}break a}rb(d);cb=e+32|0;return}a=P()|0;O()|0;rb(d);S(a|0);L()}function Oja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=yd(a);a:{b:{if(b){v[22440]=0;R(325,a|0,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break b}d=cb-16|0;cb=d;c=nq(d,a,b);b=v[c+4>>2];e=v[c+8>>2];while(1){if((b|0)==(e|0)){dc(c);cb=d+16|0}else{t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+4|0]=6;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=8;t[b+3|0]=4;b=b+6|0;v[c+4>>2]=b;continue}break}}break a}a=P()|0;O()|0;Th(c);S(a|0);L()}t[a+16|0]=6;v[a+12>>2]=2015363072;return a|0}function K3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=cb-32|0;cb=e;d=Me(e+16|0,1,0);a:{b:{while(1){f=Fb(d);aJ(e+8|0,f,vb(d)+f|0,w[b|0],c);if(!v[e+12>>2]){break b}f=Yf(vb(d));v[22440]=0;R(60,d|0,f|0);f=v[22440];v[22440]=0;if((f|0)!=1){continue}break}break a}b=v[e+8>>2];c=Fb(d);v[22440]=0;R(61,d|0,b-c|0);b=v[22440];v[22440]=0;c:{if((b|0)!=1){v[22440]=0;R(74,a|0,d|0);a=v[22440];v[22440]=0;if((a|0)!=1){break c}break a}break a}rb(d);cb=e+32|0;return}a=P()|0;O()|0;rb(d);S(a|0);L()}function D4(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=cb-32|0;cb=b;a:{b:{if(fj(a)){If(b+24|0);break b}c=b+8|0;sn(c,a);v[22440]=0;c=T(1030,c|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break a}v[b+24>>2]=c;Rf(b+8|0)}if(fj(a)){c=a+36|0}else{c=v[b+24>>2]}a=v[a+8>>2];c:{if((a|0)==-1){f=b,g=yb(v[c>>2]),v[f+8>>2]=g;a=yb(v[c+4>>2]);while(1){c=v[b+8>>2];if(!Qb(c,a)){break c}d=d+A[c>>3];Fx(b+8|0);continue}}d=A[jf(v[c>>2],a)>>3]}Xk(b+24|0);cb=b+32|0;return+d}a=P()|0;O()|0;Rf(b+8|0);S(a|0);L()}function q2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=cb-16|0;cb=c;a:{d=Nh(C(z[a+24>>2]*C(65536)));if((d|0)==65536){break a}i=v[b+4>>2];j=v[b+8>>2];k=d>>31;b:while(1){if((f|0)==(j|0)){break a}l=v[b+4>>2];m=v[b>>2];e=0;while(1)if((e|0)==(i|0)){f=f+1|0;continue b}else{g=Kh(m,l,e,f);h=v[g>>2];n=g,o=yc(lka(kka(h,h>>31,d,k),fb,65536,0),fb),v[n>>2]=o;e=e+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;nI(a,c);cb=c+16|0}function ML(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=v[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=v[c>>2];c=v[c+4>>2];h=v[a+96>>2];i=v[a+100>>2];a:{if(!(h|i)){b=v[e+4>>2];d=v[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=v[e+4>>2];d=v[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;v[e>>2]=f-d;v[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;v[a+104>>2]=(g+1>>>0)%12;v[a+96>>2]=j;v[a+100>>2]=0;fb=v[e+4>>2];return v[e>>2]}function B2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=cb-16|0;cb=c;a:{d=Nh(C(z[a+24>>2]*C(65536)));if((d|0)==65536){break a}i=v[b+4>>2];j=v[b+8>>2];k=d>>31;b:while(1){if((f|0)==(j|0)){break a}l=v[b+4>>2];m=v[b>>2];e=0;while(1)if((e|0)==(i|0)){f=f+1|0;continue b}else{g=Kh(m,l,e,f);h=v[g>>2];n=g,o=yc(lka(kka(h,h>>31,d,k),fb,65536,0),fb),v[n>>2]=o;e=e+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;uI(a,c);cb=c+16|0}function zN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=cb-16|0;cb=e;k=e,l=yj(b),v[k>>2]=l;c=cb-16|0;cb=c;g=Vy(a,c+12|0,x[b>>1],v[b+4>>2]);b=v[g>>2];if(!b){f=cb-16|0;cb=f;b=bc(a);h=kh(c,lc(36),lh(f+8|0,b));b=v[h>>2]+16|0;d=cb-16|0;cb=d;v[d+8>>2]=v[e>>2];i=v[d+8>>2];j=v[i+4>>2];v[b>>2]=v[i>>2];v[b+4>>2]=j;Rb(b+8|0);cb=d+16|0;k=bc(h),l=1,t[k+4|0]=l;cb=f+16|0;Ig(a,v[c+12>>2],g,v[c>>2]);b=Vd(c);EN(c);d=1}a=e+8|0;Hg(a,ac(c,b),d);cb=c+16|0;a=od(a);cb=e+16|0;return a+8|0}function Qia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=cb-32|0;cb=c;a=bf(a);b:{c:{d:{e:{while(1){v[22440]=0;d=Q(158,b|0,8)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}if(d){v[22440]=0;R(410,c|0,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break e}v[22440]=0;R(411,a|0,c|0);d=v[22440];v[22440]=0;if((d|0)==1){break d}Xc(c);Uh(c,LA(v[a+4>>2]));if((tB(c)|0)!=1162757187){continue}}break}cb=c+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;Xc(c);break b}b=P()|0;O()|0}Qd(a);S(b|0);L()}}function $8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=cb-48|0;cb=f;d=v[a+36>>2];Ml(v[v[d>>2]-12>>2]+d|0,0);e=v[b>>2];d=v[e+12>>2];g=v[e+8>>2];if(d|g){h=v[a+36>>2];d=v[a+20>>2]+d|0;e=v[a+16>>2];g=g+e|0;e=Xg(f+32|0,g,e>>>0>g>>>0?d+1|0:d);d=v[e+12>>2];v[f+8>>2]=v[e+8>>2];v[f+12>>2]=d;d=v[e+4>>2];v[f>>2]=v[e>>2];v[f+4>>2]=d;Uj(h,f)}d=f+16|0;ke(d,v[a+36>>2]);ez(v[a+36>>2],c,v[v[b>>2]+16>>2]);c=v[b>>2];b=Lk(d,Eb(v[a+40>>2],v[c>>2]),x[c+20>>1]);Se(a,c);Ab(b);cb=f+48|0}function $1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=cb-16|0;cb=e;v[e+4>>2]=1;g=e,h=lc(56),v[g+8>>2]=h;c=v[e+8>>2];Co(c);v[c>>2]=57760;d=mc(c);c=cb-16|0;cb=c;f=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=f;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;Sm(d);v[d>>2]=58124;Rb(d+4|0);t[d+20|0]=0;v[d+16>>2]=0;v[d>>2]=57924;b=v[c+4>>2];v[d+24>>2]=v[c>>2];v[d+28>>2]=b;b=v[c+12>>2];v[d+32>>2]=v[c+8>>2];v[d+36>>2]=b;t[d+40|0]=0;cb=c+16|0;b=a;a=Eo(e);Do(b,mc(a),a);Tm(e);cb=e+16|0}function xf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;h=kka(b,c,h,i);i=fb;j=h;h=kka(d,e,f,g);e=j+h|0;d=fb+i|0;i=e;h=i>>>0<h>>>0?d+1|0:d;j=i;k=g;e=0;l=c;d=0;i=kka(g,e,c,d);g=j+i|0;c=fb+h|0;j=g;g=g>>>0<i>>>0?c+1|0:c;h=f;i=b;f=kka(h,0,i,0);b=fb;c=0;d=kka(h,c,l,d);b=b+d|0;c=fb+c|0;c=b>>>0<d>>>0?c+1|0:c;h=c;c=c+j|0;d=g;d=c>>>0<h>>>0?d+1|0:d;h=c;c=d;d=kka(i,m,k,e)+b|0;e=fb;e=b>>>0>d>>>0?e+1|0:e;g=a;i=e;h=i+h|0;v[g+8>>2]=h;v[g+12>>2]=h>>>0<i>>>0?c+1|0:c;v[g>>2]=f;v[g+4>>2]=d}function ry(a,b,c){var d=0,e=0;d=cb-16|0;cb=d;e=v[a+480180>>2];a:{if((e|0)!=1048576){if((e|0)!=4){break a}e=w[b+813|0];if(c){t[b+813|0]=e&240|c&15;break a}c=e&15;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}ck(a,b,b+700|0,0-(c<<2)|0,0);if(v[b+700>>2]<65536){break b}ub(d+8|0,a+1074312|0,7);if(tb(v[v[d+8>>2]>>2],v[d+12>>2])|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}cb=d+16|0}function AF(a,b,c,d){var e=0,f=0,g=0,h=0;e=cb-16|0;cb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[114922];v[114922]=0;pd();a=fw(a,e+12|0,d);d=fb;g=v[114922];e:{if(g){if(v[e+12>>2]!=(b|0)){break c}if(!d&a>>>0>65535|d|(g|0)==68){break e}break b}v[114922]=h;if((b|0)!=v[e+12>>2]){break c}if(!d&a>>>0<65536){break b}}v[c>>2]=4;a=65535;break a}}v[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}cb=e+16|0;return a&65535}function zR(a,b,c,d){var e=0,f=0;f=cb-16|0;cb=f;e=x[c>>1];while(1){a:{e=e<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!mf(a,f+15|0)){break a}e=w[f+15|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;u[c>>1]=w[c|0]}t[d|0]=w[b|0]+(w[d|0]<<1);e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!mf(a,f+14|0)){break a}e=w[f+14|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;e=w[c|0];u[c>>1]=e;if(w[b|0]){continue}break a}if(w[b|0]){continue}}break}cb=f+16|0}function $da(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=cb+-64|0;cb=d;j=a;f=d+16|0;a=0;g=cb-16|0;cb=g;h=_O(g+8|0);while(1){if((a|0)==12){cb=g+16|0}else{e=cb-48|0;cb=e;b=v[h>>2];c=v[h+4>>2]-b|0;a:{if(!c){break a}b=c+1|0;if(!b){b=VO(YO(e+8|0,32));break a}c=E(b);c=YO(e+8|0,(b<<c+1?32:31)-c|0);while(1){i=VO(c);if(i>>>0>=b>>>0){continue}break}b=i+v[h>>2]|0}cb=e+48|0;k=Ib(f,a),l=b,v[k>>2]=l;a=a+1|0;continue}break}a=eP(d,f,jP(f));cP(j,a);fc(a);cb=d- -64|0}function ys(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==w[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}if(w[a|0]==(b&255)|c>>>0<4){break b}d=B(b&255,16843009);while(1){e=d^v[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}b=b&255;while(1){if((b|0)==w[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function mz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=cb-16|0;cb=c;a:{d=v[a>>2];if(hc(d,v[a+4>>2])){break a}u[d>>1]=0;yf(d+2|0,b);h=c,i=yb(v[a>>2]),v[h>>2]=i;h=c,i=nl(c,1),v[h+8>>2]=i;while(1){d=yb(v[a+4>>2]);e=v[c+8>>2];if(!Qb(e,d)){break a}d=c+8|0;g=nl(d,-1);f=v[c+8>>2];h=f,i=x[ie(e,g)>>1],u[h>>1]=i;yf(f+2|0,b);IP(d);continue}}yf(a+14|0,Dd(a)-1&255);yf(a+13|0,w[a+14|0]);yf(a+16|0,Dd(a)-1&255);yf(a+15|0,w[a+16|0]);if(w[a+17|0]!=255){yf(a+17|0,Dd(a)-1&255)}cb=c+16|0}function gN(a,b,c,d){var e=0,f=0,g=C(0),h=0,i=0,j=0;f=cb-16|0;cb=f;v[f+12>>2]=c>>>2;v[f+8>>2]=v[a>>2];a=v[a+20>>2];h=v[Bb(f+12|0,f+8|0)>>2];c=h;while(1){if(c){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);g=Qf((l(2,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)),q()));g=zf(C(Pd(C((ng(g)?g>=C(0)?C(1):C(-1):g)*d),C(-1))*C(32768)));a:{if(C(D(g))<C(2147483648)){e=~~g;break a}e=-2147483648}i=a,j=Wc(e),u[i>>1]=j;a=a+2|0;b=b+4|0;c=c-1|0;continue}break}cb=f+16|0;return h<<2}function a9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=cb-48|0;cb=g;e=v[a+36>>2];Ml(v[v[e>>2]-12>>2]+e|0,0);f=v[b>>2];e=v[f+12>>2];h=v[f+8>>2];if(e|h){i=v[a+36>>2];e=v[a+20>>2]+e|0;f=v[a+16>>2];h=h+f|0;f=Xg(g+32|0,h,f>>>0>h>>>0?e+1|0:e);e=v[f+12>>2];v[g+8>>2]=v[f+8>>2];v[g+12>>2]=e;e=v[f+4>>2];v[g>>2]=v[f>>2];v[g+4>>2]=e;Uj(i,g)}e=g+16|0;ke(e,v[a+36>>2]);yK(d,v[a+36>>2],c);c=v[b>>2];b=Lk(e,Eb(v[a+40>>2],v[c>>2]),x[c+20>>1]);Se(a,c);Ab(b);cb=g+48|0}function _8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=cb-48|0;cb=g;e=v[a+36>>2];Ml(v[v[e>>2]-12>>2]+e|0,0);f=v[b>>2];e=v[f+12>>2];h=v[f+8>>2];if(e|h){i=v[a+36>>2];e=v[a+20>>2]+e|0;f=v[a+16>>2];h=h+f|0;f=Xg(g+32|0,h,f>>>0>h>>>0?e+1|0:e);e=v[f+12>>2];v[g+8>>2]=v[f+8>>2];v[g+12>>2]=e;e=v[f+4>>2];v[g>>2]=v[f>>2];v[g+4>>2]=e;Uj(i,g)}e=g+16|0;ke(e,v[a+36>>2]);vK(c,v[a+36>>2],d);c=v[b>>2];b=Lk(e,Eb(v[a+40>>2],v[c>>2]),x[c+20>>1]);Se(a,c);Ab(b);cb=g+48|0}function T3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[22440]=0;Z(971,a|0);h=v[22440];v[22440]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[22440]=0;b=qa(1051,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,12945,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function E3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[22440]=0;Z(971,a|0);h=v[22440];v[22440]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[22440]=0;b=qa(1058,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,13013,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function cM(a,b,c){var d=0,e=0;d=cb-16|0;cb=d;e=v[a+480180>>2];a:{if((e|0)!=1048576){if((e|0)!=4){break a}e=w[b+814|0];if(c){t[b+814|0]=e&240|c&15;break a}c=e&15;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}ck(a,b,b+700|0,0-c|0,0);if(v[b+700>>2]<65536){break b}ub(d+8|0,a+1074312|0,7);if(tb(v[v[d+8>>2]>>2],v[d+12>>2])|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}cb=d+16|0}function eJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=cb-32|0;cb=e;v[e+24>>2]=b;k=e,l=fd(a),v[k+16>>2]=l;b=xn(e+24|0,e+16|0);h=cb-16|0;cb=h;a:{g=vb(a);if(b>>>0<=g>>>0){if(c){f=Dc(a);b:{if(f-g>>>0>=c>>>0){f=Fb(a);i=g-b|0;if(!i){break b}j=b+f|0;Rh(j+c|0,j,i);break b}fm(a,f,(c+g|0)-f|0,g,b,0,c);f=v[a>>2]}vB(b+f|0,c,d);c=c+g|0;Bf(a,c);t[h+15|0]=0;$d(c+f|0,h+15|0)}cb=h+16|0;break a}tk();L()}k=e,l=fd(a),v[k+8>>2]=l;je(e+8|0,b);cb=e+32|0}function Fm(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=cb-16|0;cb=i;a:{b:{if(!a){break b}g=v[e+12>>2];h=c-b|0;if((h|0)>0){if((Cm(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if(b){f=Me(i,b,f);g=Fb(f);v[22440]=0;g=Y(23,a|0,g|0,b|0)|0;h=v[22440];v[22440]=0;if((h|0)==1){break a}rb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((Cm(a,c,b)|0)!=(b|0)){break b}}lo(e);j=a}cb=i+16|0;return j|0}a=P()|0;O()|0;rb(f);S(a|0);L()}function vL(a,b){var c=0,d=0,e=0,f=0,g=0;c=cb-32|0;cb=c;a:{if((b-4e3&65535)>>>0<61537){break a}f=1;e=(B(b,104)+a|0)+484380|0;if(!Sd(e)){break a}g=a+1298224|0;d=a+1074992|0;while(1){if((d|0)==(g|0)){pm(e);v[e>>2]=0;a=(B(b,104)+a|0)+484414|0;u[a>>1]=x[a>>1]&65470;v[c+24>>2]=0;v[c+8>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c>>2]=0;v[c+4>>2]=0;zl(e,0,c);break a}if(v[d+104>>2]==(e|0)){v[d+76>>2]=0;v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0}d=d+872|0;continue}}cb=c+32|0;return f}function HX(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;v[22440]=0;m=a;a=b;b=0;a=Ma(1066,m|b,a|0,c|0,d|0,b|e,f|0)|0;b=v[22440];v[22440]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[22440]=0;ja(954,8872,g|0,h|0,i|0,j|0,k|0,l|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}return a|0}function t5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;v[22440]=0;Z(996,a|0);f=v[22440];v[22440]=0;a:{b:{if((f|0)!=1){f=v[a+28>>2];g=v[v[f>>2]+72>>2];v[22440]=0;b=Ra(g|0,f|0,b|0,c|0,+d,+e)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,11334,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function OO(a,b){var c=0,d=0,e=0,f=0;c=cb-16|0;cb=c;a=Db(a);d=vb(b);v[22440]=0;R(47,a|0,d|0);d=v[22440];v[22440]=0;if((d|0)!=1){a:{e=c,f=fd(b),v[e+8>>2]=f;e=c,f=gf(b),v[e>>2]=f;while(1){if(!oj(c+8|0,c)){cb=c+16|0;return}b:{b=w[v[c+8>>2]];if((b|0)!=13){v[22440]=0;R(48,a|0,b<<24>>24);b=v[22440];v[22440]=0;if((b|0)==1){break a}break b}v[22440]=0;R(48,a|0,10);b=v[22440];v[22440]=0;if((b|0)!=1){break b}break a}Fe(c+8|0);continue}}}b=P()|0;O()|0;rb(a);S(b|0);L()}function IK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=v[a>>2];c=pc(d,v[a+4>>2]);if(c>>>0<=127){f=cb-32|0;cb=f;c=128-c|0;e=v[xb(a)>>2];d=v[a+4>>2];a:{if(c>>>0<=e-d>>2>>>0){Jx(a,c,b);break a}e=xb(a);d=$f(f+8|0,Gg(a,pc(v[a>>2],d)+c|0),pc(v[a>>2],v[a+4>>2]),e);g=cb-16|0;cb=g;c=Fl(g,d+8|0,c);e=v[c>>2];while(1){if(v[c+4>>2]!=(e|0)){bk(e,z[b>>2]);e=v[c>>2]+4|0;v[c>>2]=e;continue}break}Gd(c);cb=g+16|0;Ad(a,d);_f(d)}cb=f+32|0;return}if((c|0)!=128){Nd(a,d+512|0)}}function xF(a,b,c,d){var e=0,f=0,g=0,h=0;e=cb-16|0;cb=e;a:{if((a|0)!=(b|0)){b:{c:{f=w[a|0];if((f|0)!=45){break c}a=a+1|0;if((b|0)!=(a|0)){break c}break b}h=v[114922];v[114922]=0;pd();a=fw(a,e+12|0,d);d=fb;d:{g=v[114922];if(g){if(v[e+12>>2]!=(b|0)){break b}if((g|0)!=68){break d}v[c>>2]=4;b=-1;a=-1;break a}v[114922]=h;if(v[e+12>>2]==(b|0)){break d}break b}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d;break a}}v[c>>2]=4;b=0;a=0}cb=e+16|0;fb=a;return b}function X1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=cb-16|0;cb=e;g=v[d+4>>2];Xw(b,c,g);f=v[b+16>>2];a:{if(f>>>0<=c>>>0){Ub(a,v[d>>2],0);break a}v[e+12>>2]=f-c;v[e+8>>2]=g;f=v[d>>2];h=v[Bb(e+12|0,e+8|0)>>2];jq(e,f,g,0,h);i=v[e>>2];j=v[e+4>>2];d=cb-32|0;cb=d;l=d,m=yb(v[b+4>>2]),v[l+24>>2]=m;k=je(d+24|0,c);l=d,m=yb(v[b+4>>2]),v[l+8>>2]=m;l=d,m=je(d+8|0,c),v[l+16>>2]=m;zk(k,je(d+16|0,j),i);cb=d+32|0;jq(a,f,g,0,h)}cb=e+16|0}function t_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=cb-16|0;cb=f;d=vb(a);e=Dc(a);g=Oh(b,c);a:{if(!g){break a}b:{if(!Js(a,b)){if(e-d>>>0<g>>>0){fm(a,e,(d+g|0)-e|0,d,d,0,0)}e=Fb(a)+d|0;while(1){if((b|0)==(c|0)){break b}$d(e,b);b=b+1|0;e=e+1|0;continue}}b=Ph(f,b,c);c=Fb(b);d=vb(b);v[22440]=0;Y(1087,a|0,c|0,d|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){rb(b);break a}a=P()|0;O()|0;rb(b);S(a|0);L()}t[f+15|0]=0;$d(e,f+15|0);Bf(a,d+g|0)}cb=f+16|0;return a|0}function QL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=cb-32|0;cb=d;v[d+16>>2]=c;v[d+24>>2]=b;k=d,l=fd(a),v[k+8>>2]=l;b=d+24|0;g=d+8|0;c=xn(b,g);e=xn(d+16|0,b);a:{if(vb(a)>>>0>=c>>>0){if((e|0)==-1){HL(a,c);break a}b=cb-16|0;cb=b;v[b+12>>2]=e;if(e){h=vb(a);i=Fb(a);f=h-c|0;v[b+8>>2]=f;e=v[Bb(b+12|0,b+8|0)>>2];v[b+12>>2]=e;f=f-e|0;if(f){j=c+i|0;Rh(j,e+j|0,f)}f=a;a=h-e|0;Bf(f,a);t[b+7|0]=0;$d(a+i|0,b+7|0)}cb=b+16|0;break a}tk();L()}je(g,c);cb=d+32|0}function xea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb+-64|0;cb=c;nm(c+48|0,b);qe(c+16|0,v[c+48>>2],v[c+52>>2]);b=ee(c+8|0);d=v[b+4>>2];b=v[b>>2];v[22440]=0;b=ea(168,c+24|0,v[c+16>>2],v[c+20>>2],b|0,d|0)|0;d=v[22440];v[22440]=0;a:{if((d|0)!=1){d=Rb(a);a=v[c+52>>2];e=v[c+48>>2];v[22440]=0;U(723,b|0,d|0,Uc(e,a)>>>2|0);a=v[22440];v[22440]=0;if((a|0)==1){a=P()|0;O()|0;fc(d);sb(b);break a}sb(b);_b(c+48|0);cb=c- -64|0;return}a=P()|0;O()|0}_b(c+48|0);S(a|0);L()}function wea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb+-64|0;cb=c;nm(c+48|0,b);qe(c+16|0,v[c+48>>2],v[c+52>>2]);b=ee(c+8|0);d=v[b+4>>2];b=v[b>>2];v[22440]=0;b=ea(168,c+24|0,v[c+16>>2],v[c+20>>2],b|0,d|0)|0;d=v[22440];v[22440]=0;a:{if((d|0)!=1){d=Rb(a);a=v[c+52>>2];e=v[c+48>>2];v[22440]=0;U(724,b|0,d|0,Uc(e,a)>>>8|0);a=v[22440];v[22440]=0;if((a|0)==1){a=P()|0;O()|0;qt(d);sb(b);break a}sb(b);_b(c+48|0);cb=c- -64|0;return}a=P()|0;O()|0}_b(c+48|0);S(a|0);L()}function vea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb+-64|0;cb=c;nm(c+48|0,b);qe(c+16|0,v[c+48>>2],v[c+52>>2]);b=ee(c+8|0);d=v[b+4>>2];b=v[b>>2];v[22440]=0;b=ea(168,c+24|0,v[c+16>>2],v[c+20>>2],b|0,d|0)|0;d=v[22440];v[22440]=0;a:{if((d|0)!=1){d=Rb(a);a=v[c+52>>2];e=v[c+48>>2];v[22440]=0;U(725,b|0,d|0,Uc(e,a)>>>4|0);a=v[22440];v[22440]=0;if((a|0)==1){a=P()|0;O()|0;ml(d);sb(b);break a}sb(b);_b(c+48|0);cb=c- -64|0;return}a=P()|0;O()|0}_b(c+48|0);S(a|0);L()}function Aea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb+-64|0;cb=c;nm(c+48|0,b);qe(c+16|0,v[c+48>>2],v[c+52>>2]);b=ee(c+8|0);d=v[b+4>>2];b=v[b>>2];v[22440]=0;b=ea(168,c+24|0,v[c+16>>2],v[c+20>>2],b|0,d|0)|0;d=v[22440];v[22440]=0;a:{if((d|0)!=1){d=Rb(a);a=v[c+52>>2];e=v[c+48>>2];v[22440]=0;U(722,b|0,d|0,Uc(e,a)>>>5|0);a=v[22440];v[22440]=0;if((a|0)==1){a=P()|0;O()|0;Di(d);sb(b);break a}sb(b);_b(c+48|0);cb=c- -64|0;return}a=P()|0;O()|0}_b(c+48|0);S(a|0);L()}function _K(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;j=cb-16|0;cb=j;v[j+12>>2]=d;i=a+12|0;a:{if(!(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))){break a}k=a+8|0;v[j+8>>2]=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);k=b;b=v[Bb(j+8|0,j+12|0)>>2];v[k>>2]=b;b=wd(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24),b,d);v[c>>2]=((h^1)&b>>>0<d>>>0)+b;b=x[e>>1]|f;u[e>>1]=b;a=a+4|0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1){break a}u[e>>1]=b|g}cb=j+16|0}function w5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22440]=0;Z(996,a|0);e=v[22440];v[22440]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+12>>2];v[22440]=0;b=da(f|0,e|0,b|0,c|0,d|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,11479,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function hda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=cb-16|0;cb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+12>>2]+i|0;e=t[f|0];e=((B(t[f+1|0]-e|0,v[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Jb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;cb=b+16|0}function aD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{d=cb-16|0;cb=d;b:{c:{if(!b){b=Fb(c);e=b;f=vb(c)+b|0;c=Oh(b,f);if(c>>>0<4294967280){d:{if(c>>>0<=10){Yd(a,c);b=a;break d}g=Kg(c)+1|0;b=lc(g);qd(a,b);cf(a,g);td(a,c)}while(1){if((e|0)!=(f|0)){kd(b,w[e|0]);b=b+1|0;e=e+1|0;continue}break}kd(b,0);break c}Ye();L()}LO(d,b,c);v[22440]=0;R(51,a|0,d|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}Vc(d)}cb=d+16|0;break a}a=P()|0;O()|0;Vc(d);S(a|0);L()}}function v5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22440]=0;Z(996,a|0);e=v[22440];v[22440]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+8>>2];v[22440]=0;b=da(f|0,e|0,b|0,c|0,d|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,11515,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function G0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=cb-32|0;cb=d;v[d+16>>2]=b;e=v[a+48>>2];v[d+20>>2]=c-((e|0)!=0);g=v[a+44>>2];v[d+28>>2]=e;v[d+24>>2]=g;a:{b:{if(Ew(ab(v[a+60>>2],d+16|0,2,d+12|0)|0)){b=32}else{e=v[d+12>>2];if((e|0)>0){break b}b=e?32:16}v[a>>2]=b|v[a>>2];break a}g=v[d+20>>2];if(g>>>0>=e>>>0){f=e;break a}f=v[a+44>>2];v[a+4>>2]=f;v[a+8>>2]=f+(e-g|0);if(v[a+48>>2]){v[a+4>>2]=f+1;t[(b+c|0)-1|0]=w[f|0]}f=c}cb=d+32|0;return f|0}function $x(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{if((c|0)<2){break a}j=c-2>>>1|0;g=d-a|0;if((j|0)<g>>1){break a}h=g+1|0;e=(h<<1)+a|0;g=g+2|0;if((g|0)<(c|0)){f=np(b,x[e>>1],x[e+2>>1]);e=f?e+2|0:e;h=f?g:h}f=x[e>>1];i=x[d>>1];if(np(b,f,i)){break a}while(1){b:{g=e;u[d>>1]=f;if((h|0)>(j|0)){break b}d=h<<1;h=d|1;e=(h<<1)+a|0;d=d+2|0;if((d|0)<(c|0)){f=np(b,x[e>>1],x[e+2>>1]);e=f?e+2|0:e;h=f?d:h}d=g;f=x[e>>1];if(!np(b,f,i)){continue}}break}u[g>>1]=i}}function r5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[22440]=0;Z(996,a|0);d=v[22440];v[22440]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+64>>2];v[22440]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,6663,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function p5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[22440]=0;Z(996,a|0);d=v[22440];v[22440]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+56>>2];v[22440]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,6717,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function gda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=cb-16|0;cb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=(v[b+12>>2]<<1)+i|0;e=u[f>>1];e=e+((B(u[f+2>>1]-e|0,v[b+8>>2]>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Jb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;cb=b+16|0}function oC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=Fc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=cb-32|0;cb=e;b=b-c|0;c=v[xb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>1>>>0){fC(a,b);break a}c=xb(a);c=Mj(e+8|0,Nj(a,Fc(v[a>>2],d)+b|0),Fc(v[a>>2],v[a+4>>2]),c);f=cb-16|0;cb=f;b=uo(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){eC(d);d=v[b>>2]+2|0;v[b>>2]=d;continue}break}Gd(b);cb=f+16|0;Ad(a,c);Pi(c)}cb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<1)|0)}}function ak(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=pc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=cb-32|0;cb=e;b=b-c|0;c=v[xb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){WO(a,b);break a}c=xb(a);c=$f(e+8|0,Gg(a,pc(v[a>>2],d)+b|0),pc(v[a>>2],v[a+4>>2]),c);f=cb-16|0;cb=f;b=Fl(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){TO(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Gd(b);cb=f+16|0;Ad(a,c);_f(c)}cb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}function Y5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=cb-16|0;cb=d;a:{g=v[c+12>>2];if(!g){break a}e=qf(d,c+16|0);f=vb(b);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){rb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(w[rc(b,0)|0]==43){break c}if(w[rc(b,0)|0]==45){break c}}v[22440]=0;Y(79,b|0,f-c|0,e|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=P()|0;O()|0;rb(e);S(a|0);L()}zc(a,b);cb=d+16|0}function GI(a,b,c){var d=0,e=0,f=0;e=yd(a);a:{b:{if(c){v[22440]=0;R(1090,a|0,c|0);d=v[22440];v[22440]=0;if((d|0)==1){break b}d=cb-16|0;cb=d;e=uh(d,a,c);c=v[e+4>>2];f=v[e+8>>2];while(1){if((c|0)==(f|0)){dc(e);cb=d+16|0}else{v[c>>2]=0;hh(c);c=c+4|0;v[e+4>>2]=c;continue}break}}break a}a=P()|0;O()|0;fc(e);S(a|0);L()}e=a;a=0;c=0;d=cb-16|0;cb=d;f=d+8|0;while(1){if(a>>>0<32){a=a+48|0;c=NL(b);continue}break}v[f>>2]=c;yn(f);cb=d+16|0;v[e+12>>2]=v[f>>2]}function wM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=cb-16|0;cb=e;d=Dc(a);a:{b:{c:{f=Oh(b,c);if(d>>>0<f>>>0){if(Js(a,b)){break c}g=d;h=f-d|0;d=vb(a);fm(a,g,h,d,0,d,0)}d=Fb(a);while(1){if((b|0)==(c|0)){break b}$d(d,b);d=d+1|0;b=b+1|0;continue}}b=Ph(e,b,c);c=Fb(b);d=vb(b);v[22440]=0;Y(58,a|0,c|0,d|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){rb(b);break a}a=P()|0;O()|0;rb(b);S(a|0);L()}t[e+15|0]=0;$d(d,e+15|0);Bf(a,f)}cb=e+16|0;return a|0}function l4(a,b){a=a|0;b=b|0;var c=0;v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;if((c|0)!=1){c=v[a+24>>2];a=-1;a:{if((b|0)<0){break a}c=c+24|0;if(rj(Nb(v[c>>2]+484360|0))>>>0<=b>>>0){break a}a=x[Xb(v[Nb(v[c>>2]+484360|0)>>2],b)>>1]}return a|0}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,9820,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function kc(a,b){var c=0,d=0,e=0;c=v[a+1396>>2];if((c|0)>=0){a:{b:{if((b|0)<=(c|0)){break b}if((b|0)>24){return kc(a,24)+(kc(a,b-24|0)<<24)|0}if(!c){v[a+1392>>2]=0}while(1){if((b|0)<=(c|0)){break b}c=-1;e=Nr(a);d=0;if((e|0)==-1){break a}d=v[a+1396>>2];c=d+8|0;v[a+1396>>2]=c;v[a+1392>>2]=v[a+1392>>2]+(e<<d);continue}}if((b|0)>(c|0)){ca(10096,13226,1632,6833);L()}d=v[a+1392>>2];v[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}v[a+1396>>2]=c}return d}function fs(a){var b=0,c=0,d=0,e=0;a:{while(1){if(!a){b=0;if(v[22434]){b=fs(v[22434])}if(!v[22358]){break a}c=b|c;a=v[22358];continue}break}d=v[a+76>>2]>=0;b:{c:{if(v[a+20>>2]==v[a+28>>2]){break c}gb[v[a+36>>2]](a,0,0)|0;if(v[a+20>>2]){break c}b=-1;if(d){break b}break a}b=v[a+8>>2];e=v[a+4>>2];if((b|0)!=(e|0)){b=e-b|0;gb[v[a+40>>2]](a,b,b>>31,1)|0}b=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;if(!d){break a}}}return b|c}function V_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=cb-256|0;cb=a;v[a+248>>2]=37;v[a+252>>2]=0;g=a+248|0;Nk(g|1,10606,1,v[c+4>>2]);h=pd();v[a>>2]=e;v[a+4>>2]=f;e=a+224|0;f=Lf(e,24,h,g,a)+e|0;g=Yg(e,f,c);h=a+16|0;Jc(h,c);v[22440]=0;ja(1176,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[22440];v[22440]=0;if((e|0)!=1){Pb(a+16|0);b=_m(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);cb=a+256|0;return b|0}b=P()|0;O()|0;Pb(a+16|0);S(b|0);L()}function T_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=cb-256|0;cb=a;v[a+248>>2]=37;v[a+252>>2]=0;g=a+248|0;Nk(g|1,10606,0,v[c+4>>2]);h=pd();v[a>>2]=e;v[a+4>>2]=f;e=a+224|0;f=Lf(e,24,h,g,a)+e|0;g=Yg(e,f,c);h=a+16|0;Jc(h,c);v[22440]=0;ja(1176,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[22440];v[22440]=0;if((e|0)!=1){Pb(a+16|0);b=_m(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);cb=a+256|0;return b|0}b=P()|0;O()|0;Pb(a+16|0);S(b|0);L()}function Fk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=cb-16|0;cb=e;v[b>>2]=0;v[b+4>>2]=0;t[e+15|0]=0;Jh(a,e+15|0);c=w[e+15|0];f=(c&252)>>>2|0;i=-1<<(c&3)^-1;while(1){v[b>>2]=f;v[b+4>>2]=d;if(!g&(h|0)==(i|0)){cb=e+16|0}else{t[e+15|0]=0;Jh(a,e+15|0);c=v[b>>2];j=v[b+4>>2];f=w[e+15|0];d=g;g=h+1|0;d=g?d:d+1|0;h=g;g=d;k=c;d=(h<<3)-2|0;c=d&31;if((d&63)>>>0>=32){d=f<<c;c=0}else{d=(1<<c)-1&f>>>32-c;c=f<<c}f=k|c;d=d|j;continue}break}}function i3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=cb-16|0;cb=d;a:{g=v[c+12>>2];if(!g){break a}e=qf(d,c+16|0);f=vb(b);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){rb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(w[Fb(b)|0]==43){break c}if(w[Fb(b)|0]==45){break c}}v[22440]=0;Y(86,b|0,f-c|0,e|0)|0;i=v[22440];v[22440]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=P()|0;O()|0;rb(e);S(a|0);L()}zc(a,b);cb=d+16|0}function d$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=cb-112|0;cb=a;v[a+104>>2]=37;v[a+108>>2]=0;g=a+104|0;Nk(g|1,10606,1,v[c+4>>2]);h=pd();v[a>>2]=e;v[a+4>>2]=f;e=a+80|0;f=Lf(e,24,h,g,a)+e|0;g=Yg(e,f,c);h=a+16|0;Jc(h,c);v[22440]=0;ja(1173,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[22440];v[22440]=0;if((e|0)!=1){Pb(a+16|0);b=Fm(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);cb=a+112|0;return b|0}b=P()|0;O()|0;Pb(a+16|0);S(b|0);L()}function b$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=cb-112|0;cb=a;v[a+104>>2]=37;v[a+108>>2]=0;g=a+104|0;Nk(g|1,10606,0,v[c+4>>2]);h=pd();v[a>>2]=e;v[a+4>>2]=f;e=a+80|0;f=Lf(e,24,h,g,a)+e|0;g=Yg(e,f,c);h=a+16|0;Jc(h,c);v[22440]=0;ja(1173,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=v[22440];v[22440]=0;if((e|0)!=1){Pb(a+16|0);b=Fm(b,a+32|0,v[a+28>>2],v[a+24>>2],c,d);cb=a+112|0;return b|0}b=P()|0;O()|0;Pb(a+16|0);S(b|0);L()}function Cw(a,b){a:{if(a){if(b>>>0<=127){break a}b:{if(!v[v[114924]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){t[a+1|0]=b&63|128;t[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){t[a+2|0]=b&63|128;t[a|0]=b>>>12|224;t[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){t[a+3|0]=b&63|128;t[a|0]=b>>>18|240;t[a+2|0]=b>>>6&63|128;t[a+1|0]=b>>>12&63|128;return 4}}v[114922]=25;a=-1}else{a=1}return a}t[a|0]=b;return 1}function n5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[22440]=0;Z(996,a|0);d=v[22440];v[22440]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+48>>2];v[22440]=0;wa(f|0,d|0,b|0,+c);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,11714,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function d5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[22440]=0;Z(996,a|0);d=v[22440];v[22440]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+96>>2];v[22440]=0;wa(f|0,d|0,b|0,+c);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,11652,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function b5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[22440]=0;Z(996,a|0);d=v[22440];v[22440]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+88>>2];v[22440]=0;wa(f|0,d|0,b|0,+c);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,11035,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function Waa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=cb-32|0;cb=d;e=bf(a);b:{c:{d:{e:{while(1){v[22440]=0;a=Q(158,b|0,8)|0;f=v[22440];v[22440]=0;if((f|0)==1){break c}if(!a){break d}v[22440]=0;U(819,d|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;R(820,e|0,d|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}Xc(d);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Xc(d);break b}cb=d+32|0;break a}a=P()|0;O()|0}Qd(e);S(a|0);L()}}function Eea(a,b){a=a|0;b=b|0;var c=0,d=0;d=yd(a);a:{if(b){v[22440]=0;R(700,a|0,b|0);c=v[22440];v[22440]=0;if((c|0)==1){break a}c=cb-16|0;cb=c;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+B(b,9);b=v[c+4>>2];d=v[c+8>>2];while(1){if((b|0)==(d|0)){dc(c);cb=c+16|0}else{t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;b=b+9|0;v[c+4>>2]=b;continue}break}}return a|0}a=P()|0;O()|0;Tp(d);S(a|0);L()}function wba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=ag(e,v[a+4>>2]);if(d>>>0<b>>>0){e=cb-32|0;cb=e;a:{b:{d=b-d|0;b=v[xb(a)>>2];f=v[a+4>>2];c:{if(d>>>0<=b-f>>5>>>0){hz(a,d,c);break c}b=xb(a);b=gt(e+8|0,Qp(a,ag(v[a>>2],f)+d|0),ag(v[a>>2],v[a+4>>2]),b);v[22440]=0;U(779,b|0,d|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}lO(a,b);fz(b)}cb=e+32|0;break a}a=P()|0;O()|0;fz(b);S(a|0);L()}return}if(b>>>0<d>>>0){nO(a,e+(b<<5)|0)}}function rV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;v[d+12>>2]=-1;if(yg(a,d+8|0)){v[d+4>>2]=w[d+8|0];f=v[Bb(d+4|0,d+12|0)>>2];c=cb+-64|0;cb=c;e=c+40|0;Ze(e,a,f);g=v[c+40>>2];ef(c+8|0,3,ce(e),g);v[22440]=0;W(225,c+24|0,v[c+8>>2],v[c+12>>2],w[c+16|0]);a=v[22440];v[22440]=0;a:{if((a|0)!=1){$b(c,b,11);a=c+24|0;Kj(c,a);rb(a);vc(c+40|0);cb=c- -64|0;e=!f|(g|0)!=0;break a}a=P()|0;O()|0;vc(c+40|0);S(a|0);L()}}cb=d+16|0;return e|0}function S9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=cb-32|0;cb=d;e=bf(a);b:{c:{d:{e:{while(1){v[22440]=0;a=Q(158,b|0,8)|0;f=v[22440];v[22440]=0;if((f|0)==1){break c}if(!a){break d}v[22440]=0;U(891,d|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;R(892,e|0,d|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}Xc(d);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Xc(d);break b}cb=d+32|0;break a}a=P()|0;O()|0}Qd(e);S(a|0);L()}}function R3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22440]=0;Z(971,a|0);f=v[22440];v[22440]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22440]=0;b=ea(1052,f|0,b|0,c|0,d|0,e|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,9645,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function C3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22440]=0;Z(971,a|0);f=v[22440];v[22440]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22440]=0;b=ea(1059,f|0,b|0,c|0,d|0,e|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,9717,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function Si(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=Uc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=cb-32|0;cb=e;b=b-c|0;c=v[xb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>>0){Lv(a,b);break a}c=xb(a);c=Sl(e+8|0,Ol(a,Uc(v[a>>2],d)+b|0),Uc(v[a>>2],v[a+4>>2]),c);f=cb-16|0;cb=f;b=Iv(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){BE(d);d=v[b>>2]+1|0;v[b>>2]=d;continue}break}Gd(b);cb=f+16|0;Ad(a,c);Rl(c)}cb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,b+d|0)}}function le(a){var b=0,c=0,d=0;d=ap(Rg(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){break b}if(a&3){while(1){b=w[a|0];t[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=v[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){v[c>>2]=b;b=v[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}b=w[a|0];t[c|0]=b;if(!b){break a}while(1){b=w[a+1|0];t[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function hD(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=cb-16|0;cb=f;d=fd(a);v[f+8>>2]=d;d=$n(b,d);c=$n(c,b);a:{if(vb(a)>>>0>=d>>>0){if((c|0)==-1){if(Ld(a)){kd(d+v[a>>2]|0,0);td(a,d);break a}kd(a+d|0,0);Yd(a,d);break a}b=cb-16|0;cb=b;v[b+12>>2]=c;if(c){g=vb(a);h=Fb(a);e=g-d|0;v[b+8>>2]=e;c=v[Bb(b+12|0,b+8|0)>>2];v[b+12>>2]=c;e=e-c|0;if(e){i=d+h|0;Rh(i,c+i|0,e)}e=a;a=g-c|0;Bf(e,a);kd(a+h|0,0)}cb=b+16|0;break a}tk();L()}je(f+8|0,d);cb=f+16|0}function jea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=cb-16|0;cb=c;d=Nc(c+8|0,16,1,1,0);v[c+4>>2]=0;ed(a,0);sc(b);a:{b:{if(yq(b,13843)){Tc(b,12);if(!Am(b)){so(d,2)}Tc(b,24);break b}if(Ah(b,13715)){sc(b);v[c+4>>2]=4;e=1;break a}kd(d,8)}e=0}f=a,g=(_e(b)>>>0)/(B(w[c+8|0],Zp(w[d+1|0]))>>>3>>>0)|0,v[f>>2]=g;b=vg(d,a,b);if(!(!b|!e)){d=v[a+20>>2];f=c,g=Fj(v[a>>2],x[a+34>>1]),v[f>>2]=g;Hb(d,0,v[Bb(c+4|0,c)>>2])}cb=c+16|0;return(b|0)!=0|0}function hS(a,b){var c=0,d=0,e=0,f=0;d=v[a>>2];c=pc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=cb-32|0;cb=e;b=b-c|0;c=v[xb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){nA(a,b);break a}c=xb(a);c=$f(e+8|0,Gg(a,pc(v[a>>2],d)+b|0),pc(v[a>>2],v[a+4>>2]),c);f=cb-16|0;cb=f;b=Fl(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){Bm(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Gd(b);cb=f+16|0;Ad(a,c);_f(c)}cb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}function S3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=cb-16|0;cb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=aa(8)|0;v[22440]=0;b=Q(56,h|0,8229)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}oc(a,b);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}e=P()|0;O()|0;rb(b);break b}hj(a,b,4);c=ax(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);cb=h+16|0;return c|0}e=P()|0;O()|0;ba(a|0)}S(e|0)}L()}function D3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=cb-16|0;cb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=aa(8)|0;v[22440]=0;b=Q(56,h|0,8229)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}oc(a,b);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}e=P()|0;O()|0;rb(b);break b}hj(a,b,4);c=bx(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);cb=h+16|0;return c|0}e=P()|0;O()|0;ba(a|0)}S(e|0)}L()}function yF(a,b,c,d){var e=0,f=0,g=0,h=0;e=cb-16|0;cb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[114922];v[114922]=0;pd();a=fw(a,e+12|0,d);d=fb;g=v[114922];e:{if(g){if(v[e+12>>2]!=(b|0)){break c}if((g|0)==68|d){break e}break b}v[114922]=h;if((b|0)!=v[e+12>>2]){break c}if(!d){break b}}v[c>>2]=4;a=-1;break a}}v[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}cb=e+16|0;return a}function r6(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;t[a+4202|0]=1;b=tj(C(C(y[v[a+16>>2]+24620>>2])*C(.04500000178813934)));c=tj(C(C(b>>>0)*C(1.1892070770263672)));d=tj(C(C(c>>>0)*C(1.1892070770263672)));g=tj(C(C(d>>>0)*C(1.1892070770263672)));e=tj(C(C(b+d>>>0)*C(.11546666920185089)));f=tj(C(C(c+g>>>0)*C(.11546666920185089)));v[a+4292>>2]=f;v[a+4288>>2]=e;v[a+4276>>2]=d-e;v[a+4272>>2]=b-e;v[a+4284>>2]=g-f;v[a+4280>>2]=c-f;AJ(a);zJ(a)}function aX(a,b){a=a|0;b=b|0;var c=0;a=Db(a);a:{if(w[b+16|0]){v[22440]=0;Q(135,a|0,4948)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}}if(w[b+17|0]){v[22440]=0;Q(135,a|0,12576)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}}if(xd(a)){v[22440]=0;Q(135,a|0,10086)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}}if(w[b+18|0]){v[22440]=0;Q(135,a|0,11101)|0;b=v[22440];v[22440]=0;if((b|0)==1){break a}}return}b=P()|0;O()|0;rb(a);S(b|0);L()}function MU(){var a=0,b=0,c=0;a=cb-16|0;cb=a;a:{if($a(a+12|0,a+8|0)|0){break a}b=Hd((v[a+12>>2]<<2)+4|0);v[115830]=b;if(!b){break a}b=Hd(v[a+8>>2]);if(b){c=v[115830];v[c+(v[a+12>>2]<<2)>>2]=0;if(!(_a(c|0,b|0)|0)){break a}}v[115830]=0}cb=a+16|0;b:{if(t[463312]&1){break b}if(!Xd(463312)){break b}v[22440]=0;X(1137);a=v[22440];v[22440]=0;if((a|0)!=1){Wd(463312);break b}a=P()|0;O()|0;nf(463312);S(a|0);L()}t[459692]=1;v[114924]=463412}function nga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb-80|0;cb=d;Dt(b);e=d+56|0;Ze(e,a,c);a=v[d+56>>2];ef(d+8|0,3,ce(e),a);v[22440]=0;W(225,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);a=v[22440];v[22440]=0;b:{c:{if((a|0)!=1){v[22440]=0;U(11,d+40|0,5,d+24|0);a=v[22440];v[22440]=0;if((a|0)==1){break c}a=d+40|0;Cb(b,a);rb(a);rb(d+24|0);vc(d+56|0);cb=d+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;rb(d+24|0)}vc(d+56|0);S(a|0);L()}}function cha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=v[a>>2];c=Df(d,v[a+4>>2]);if(c>>>0<b>>>0){d=cb-32|0;cb=d;a:{b:{c=b-c|0;b=v[xb(a)>>2];e=v[a+4>>2];c:{if(c>>>0<=(b-e|0)/20>>>0){lC(a,c);break c}b=xb(a);b=ZA(d+8|0,_A(a,Df(v[a>>2],e)+c|0),Df(v[a>>2],v[a+4>>2]),b);v[22440]=0;R(519,b|0,c|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}YA(a,b);Zt(b)}cb=d+32|0;break a}a=P()|0;O()|0;Zt(b);S(a|0);L()}return}if(b>>>0<c>>>0){jC(a,d+B(b,20)|0)}}function YT(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=v[a+1064>>2];a:{while(1){if((b|0)>255){break a}f=(B(b,6)+a|0)+1072|0,g=Bk(a,7),t[f|0]=g;d=Bk(a,1);e=Bk(a,1);c=v[a+1060>>2];if((c|0)>255){break a}b=v[a+1064>>2]+1|0;v[a+1060>>2]=b;v[a+1064>>2]=b;b:{if(d){u[(B(c,6)+a|0)+1068>>1]=b;YT(a);b=v[a+1064>>2];break b}u[(B(c,6)+a|0)+1068>>1]=65535}v[a+1060>>2]=b;if(e){u[(B(c,6)+a|0)+1070>>1]=b;continue}break}u[(B(c,6)+a|0)+1070>>1]=65535}}function Xfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb-80|0;cb=d;Dt(b);e=d+56|0;Ze(e,a,c);a=v[d+56>>2];ef(d+8|0,2,ce(e),a);v[22440]=0;W(225,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);a=v[22440];v[22440]=0;b:{c:{if((a|0)!=1){v[22440]=0;U(11,d+40|0,2,d+24|0);a=v[22440];v[22440]=0;if((a|0)==1){break c}a=d+40|0;Cb(b,a);rb(a);rb(d+24|0);vc(d+56|0);cb=d+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;rb(d+24|0)}vc(d+56|0);S(a|0);L()}}function u5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22440]=0;Z(996,a|0);c=v[22440];v[22440]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+76>>2];v[22440]=0;R(e|0,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,11344,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function iV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=cb-16|0;cb=e;a:{b:{if(!gg(a,7)){break b}c=0;if(!bC(a,17858)){break a}if(!gg(a,1)){break b}c=-1;if(!Yc(a,tq(a))){break a}c=cb-16|0;cb=c;f=e+8|0;mo(c+8|0,f);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;d=(d|0)==(g|0);if(!d){yu(f)}c=-1;if(!d){break a}c=0;if(!QB(e+8|0)){break a}c=ye(a,b,PB(e+8|0),fb);break a}c=-1}cb=e+16|0;return c|0}function f5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22440]=0;Z(996,a|0);c=v[22440];v[22440]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+16>>2];v[22440]=0;R(e|0,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,12815,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function a5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22440]=0;Z(996,a|0);c=v[22440];v[22440]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+84>>2];v[22440]=0;R(e|0,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,12298,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function Cda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;a:{c=v[b+4>>2];if(!c){break a}f=a+480190|0;u[d>>1]=x[f>>1];u[d+14>>1]=c-1;c=x[Kc(d,d+14|0)>>1];while(1){if(!c){break a}ub(d,v[b>>2],c);b:{if(tb(v[v[d>>2]>>2],v[d+4>>2])){break b}if(vL(a,c&65535)){e=Bc(d,21685);uc(((c<<5)+a|0)+946304|0,e);rb(e);g=g+1|0}if(c>>>0<2){break b}e=x[f>>1];if((e|0)!=(c|0)){break b}u[f>>1]=e-1}c=c-1|0;continue}}cb=d+16|0;return g&65535}function $4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22440]=0;Z(996,a|0);c=v[22440];v[22440]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+80>>2];v[22440]=0;R(e|0,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,11125,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function rja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=cb-32|0;cb=c;d=bf(a);b:{c:{d:{e:{while(1){v[22440]=0;a=Q(158,b|0,8)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}if(!a){break d}v[22440]=0;R(364,c|0,b|0);a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;R(365,d|0,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}Xc(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Xc(c);break b}cb=c+32|0;break a}a=P()|0;O()|0}Qd(d);S(a|0);L()}}function mfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=cb-32|0;cb=c;d=bf(a);b:{c:{d:{e:{while(1){v[22440]=0;a=Q(158,b|0,8)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}if(!a){break d}v[22440]=0;R(671,c|0,b|0);a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;R(672,d|0,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}Xc(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Xc(c);break b}cb=c+32|0;break a}a=P()|0;O()|0}Qd(d);S(a|0);L()}}function l5(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22440]=0;Z(996,a|0);c=v[22440];v[22440]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+40>>2];v[22440]=0;sa(e|0,c|0,+b);c=v[22440];v[22440]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[22440]=0;W(958,11752,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22440]=0;X(18);d=v[22440];v[22440]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function iha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=cb-32|0;cb=c;d=bf(a);b:{c:{d:{e:{while(1){v[22440]=0;a=Q(158,b|0,6)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}if(!a){break d}v[22440]=0;R(517,c|0,b|0);a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;R(518,d|0,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}Xc(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Xc(c);break b}cb=c+32|0;break a}a=P()|0;O()|0}Qd(d);S(a|0);L()}}function g5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22440]=0;Z(996,a|0);c=v[22440];v[22440]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+20>>2];v[22440]=0;R(e|0,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,9341,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function e5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22440]=0;Z(996,a|0);c=v[22440];v[22440]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+100>>2];v[22440]=0;d=+va(e|0,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,11670,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function P3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22440]=0;Z(971,a|0);e=v[22440];v[22440]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22440]=0;b=da(1053,e|0,b|0,c|0,d|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,12902,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function L3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22440]=0;Z(971,a|0);e=v[22440];v[22440]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22440]=0;b=da(1055,e|0,b|0,c|0,d|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,12976,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function Efa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=cb-32|0;cb=c;d=bf(a);b:{c:{d:{e:{while(1){v[22440]=0;a=Q(158,b|0,8)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}if(!a){break d}v[22440]=0;R(639,c|0,b|0);a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;R(640,d|0,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}Xc(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Xc(c);break b}cb=c+32|0;break a}a=P()|0;O()|0}Qd(d);S(a|0);L()}}function E0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=cb-16|0;cb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=v[a+16>>2];d=v[a+12>>2];b:{if(g>>>0>d>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=g-d;v[e+4>>2]=c-f;g=d;d=v[ld(e+12|0,ld(e+8|0,e+4|0))>>2];b=Ce(b,g,d);v[a+12>>2]=v[a+12>>2]+d;b=b+d|0;break b}d=gb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=Vo(d),t[h|0]=i;d=1;b=b+1|0}f=d+f|0;continue}break}cb=e+16|0;return f|0}function zia(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=cb-32|0;cb=g;a:{if(x[a+480192>>1]<b>>>0){break a}h=v[((b<<2)+a|0)+900380>>2];if(!h){break a}b=g+16|0;eT(b,h);i=g,j=bq(b),v[i+8>>2]=j;h=cg(b);while(1){if(Qb(v[g+8>>2],h)){b=x[Xn(g+8|0)>>1];if(b>>>0<=x[a+480190>>1]){b=B(b,104)+a|0;t[b+484421|0]=f;t[b+484418|0]=c;t[b+484420|0]=e;t[b+484419|0]=d}um(g+8|0);continue}else{Ut(g+16|0)}break}}cb=g+32|0}function o5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22440]=0;Z(996,a|0);c=v[22440];v[22440]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+52>>2];v[22440]=0;d=+va(e|0,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,11733,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function lX(a){a=a|0;var b=0,c=0,d=0,e=0;c=cb-32|0;cb=c;b=jc(c,16802);v[22440]=0;U(122,c+16|0,a|0,b|0);a=v[22440];v[22440]=0;a:{if((a|0)!=1){rb(b);a=0;b=0;while(1){d=v[c+16>>2];if(!(b>>>0<=3&gd(d,v[c+20>>2])>>>0>b>>>0)){ad(c+16|0);cb=c+32|0;return a|0}v[22440]=0;d=T(123,rd(d,b)|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){a=(d&255)<<24-(b<<3)|a;b=b+1|0;continue}break}a=P()|0;O()|0;ad(c+16|0);break a}a=P()|0;O()|0;rb(b)}S(a|0);L()}function j5(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22440]=0;Z(996,a|0);c=v[22440];v[22440]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+32>>2];v[22440]=0;sa(e|0,c|0,+b);c=v[22440];v[22440]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[22440]=0;W(958,7737,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22440]=0;X(18);d=v[22440];v[22440]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function h5(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22440]=0;Z(996,a|0);c=v[22440];v[22440]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+24>>2];v[22440]=0;sa(e|0,c|0,+b);c=v[22440];v[22440]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[22440]=0;W(958,7685,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22440]=0;X(18);d=v[22440];v[22440]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function c5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22440]=0;Z(996,a|0);c=v[22440];v[22440]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+92>>2];v[22440]=0;d=+va(e|0,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,11055,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function WU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=cb-32|0;cb=c;d=bf(a);b:{c:{d:{e:{while(1){v[22440]=0;a=Q(158,b|0,8)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}if(!a){break d}v[22440]=0;R(301,c|0,b|0);a=v[22440];v[22440]=0;if((a|0)!=1){v[22440]=0;R(302,d|0,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break e}Xc(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Xc(c);break b}cb=c+32|0;break a}a=P()|0;O()|0}Qd(d);S(a|0);L()}}function V3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22440]=0;Z(971,a|0);e=v[22440];v[22440]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22440]=0;b=da(1050,e|0,b|0,c|0,d|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,9449,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function N3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22440]=0;Z(971,a|0);e=v[22440];v[22440]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22440]=0;b=da(1054,e|0,b|0,c|0,d|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,9600,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function I3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22440]=0;Z(971,a|0);e=v[22440];v[22440]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22440]=0;b=da(1056,e|0,b|0,c|0,d|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,9678,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function G3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22440]=0;Z(971,a|0);e=v[22440];v[22440]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22440]=0;b=da(1057,e|0,b|0,c|0,d|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,9480,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function xda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=cb-16|0;cb=b;i=v[a+16>>2];f=Zf(1,2);g=fb;Jb(a,f,g);j=v[a+24>>2];k=v[a+20>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;e=v[a+8>>2];l=v[a+12>>2];while(1){if(d){h=u[(v[b+12>>2]<<1)+i>>1];v[c>>2]=v[c>>2]+B(h,k);v[c+4>>2]=v[c+4>>2]+B(j,h);Jb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;lg(a,f,g);cb=b+16|0}function wW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=cb-16|0;cb=f;v[f+4>>2]=1;j=f,k=lc(32),v[j+8>>2]=k;e=v[f+8>>2];Co(e);v[e>>2]=43080;e=mc(e);h=cb-16|0;cb=h;g=Jl(h+8|0,v[b>>2],v[b+4>>2]);i=v[g>>2];c=v[c>>2];d=v[d>>2];b=cb-16|0;cb=b;g=v[g+4>>2];v[b+12>>2]=g;v[b+8>>2]=i;Sm(e);v[e>>2]=43216;Jl(e+4|0,i,g);v[e+16>>2]=d;v[e+12>>2]=c;Md(b+8|0);cb=b+16|0;cb=h+16|0;b=a;a=Eo(f);Do(b,mc(a),a);Tm(f);cb=f+16|0}function YP(a){var b=0,c=0,d=0;b=cb-16|0;cb=b;v[b+4>>2]=((w[a+48|0]|w[a+49|0]<<8)<<1)+((w[a+32|0]|w[a+33|0]<<8)<<4);v[b+8>>2]=((w[a+50|0]|w[a+51|0]<<8)<<1)+((w[a+34|0]|w[a+35|0]<<8)<<4);v[b+12>>2]=(B(w[a+52|0]|w[a+53|0]<<8,5)+((w[a+36|0]|w[a+37|0]<<8)<<4)|0)+32;a=b+4|0;d=Ib(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=So(v[a>>2],v[c>>2])?c:a;continue}}cb=b+16|0;a=v[a>>2];fb=a>>31;return a}function L9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=cb-32|0;cb=d;Ie(d,2,a+6|0);e=d+16|0;xc(e,v[d>>2],v[d+4>>2],w[d+8|0]);uc(b+492|0,e);f=b+236|0;g=c+1|0;rb(e);c=0;while(1){if((c|0)==128){v[b>>2]=(w[a+226|0]|w[a+227|0]<<8)<<5;Px(a+180|0,b+48|0,0);Px(a+228|0,b+88|0,2);Px(a+276|0,b+68|0,1);if(!(w[a+324|0]|w[a+325|0]<<8)){Hb(f,0,256)}cb=d+32|0}else{h=Xb(f,c),i=w[(a+c|0)+38|0]+g|0,u[h>>1]=i;c=c+1|0;continue}break}}function s5(a,b){a=a|0;b=b|0;var c=0,d=0;v[22440]=0;Z(996,a|0);c=v[22440];v[22440]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+68>>2];v[22440]=0;b=Q(d|0,c|0,b|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,6690,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function q5(a,b){a=a|0;b=b|0;var c=0,d=0;v[22440]=0;Z(996,a|0);c=v[22440];v[22440]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+60>>2];v[22440]=0;b=Q(d|0,c|0,b|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,6741,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function a6(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=cb-16|0;cb=d;if(a){c=nc(d+8|0,a);f=v[c>>2];b=cb-16|0;cb=b;e=v[c+4>>2];a=0;a:{if(!e){break a}a=32336;while(1){if((a|0)==32736){c=32736;while(1){a=c;if((a|0)!=32784){nc(b,v[a+8>>2]);c=a+12|0;if(!gL(f,e,v[b>>2],v[b+4>>2])){continue}}break}a=(a|0)!=32784;break a}nc(b+8|0,v[a+4>>2]);a=a+8|0;if(!gL(f,e,v[b+8>>2],v[b+12>>2])){continue}break}a=1}cb=b+16|0}else{a=0}cb=d+16|0;return a|0}function yda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=cb-16|0;cb=b;i=v[a+16>>2];f=Zf(1,2);g=fb;Jb(a,f,g);j=v[a+24>>2];k=v[a+20>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;e=v[a+8>>2];l=v[a+12>>2];while(1){if(d){h=t[v[b+12>>2]+i|0]<<8;v[c>>2]=v[c>>2]+B(h,k);v[c+4>>2]=v[c+4>>2]+B(j,h);Jb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;lg(a,f,g);cb=b+16|0}function hN(a,b,c,d){var e=0,f=C(0),g=0,h=0,i=0,j=0;e=cb-16|0;cb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];c=v[a+20>>2];g=v[Bb(e+12|0,e+8|0)>>2];a=g;while(1){if(a){f=Qf((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()));f=zf(C(Pd(C((ng(f)?f>=C(0)?C(1):C(-1):f)*d),C(-1))*C(32768)));a:{if(C(D(f))<C(2147483648)){h=~~f;break a}h=-2147483648}i=c,j=Wc(h),u[i>>1]=j;c=c+2|0;b=b+4|0;a=a-1|0;continue}break}cb=e+16|0;return g<<2}function OA(a,b,c,d,e){var f=0,g=0,h=0,i=0;h=-1;f=d&2147483647;i=f;g=(f|0)==2147418112;a:{if(g&!c?a|b:g&(c|0)!=0|f>>>0>2147418112){break a}f=e&2147483647;g=(f|0)==2147418112;if(g?0:g&0|f>>>0>2147418112){break a}if(!(a|c|(f|i|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(!c&(d|0)==(e|0)?0:(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function Ff(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;u[d+12>>1]=65535;u[d+14>>1]=b;f=d+12|0;b=x[Kc(43068,d+14|0)>>1];e=v[a>>2];c=Fc(e,v[a+4>>2]);a:{if(b>>>0>c>>>0){e=cb-32|0;cb=e;b=b-c|0;c=v[xb(a)>>2];g=v[a+4>>2];b:{if(b>>>0<=c-g>>1>>>0){oo(a,b,f);break b}c=xb(a);c=Mj(e+8|0,Nj(a,Fc(v[a>>2],g)+b|0),Fc(v[a>>2],v[a+4>>2]),c);zC(c,b,f);Ad(a,c);Pi(c)}cb=e+32|0;break a}if(b>>>0<c>>>0){Nd(a,e+(b<<1)|0)}}cb=d+16|0}function CA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Kb(a,b)){break a}if(b>>>0<=3){c=cb-16|0;cb=c;if(Kb(a,b)){while(1){if((d|0)==4){v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}else{t[c+11|0]=0;b:{if(b>>>0>d>>>0){yg(a,c+11|0);e=t[c+11|0];g=e>>>31|0;break b}e=0-g|0}t[(c+12|0)+d|0]=e;d=d+1|0;continue}break}}cb=c+16|0;c=d;break a}c=Ag(a);Ob(a,b-4|0)}t[f|0]=c}function jG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=cb-48|0;cb=e;v[e+44>>2]=c;v[e+40>>2]=b;b=Bc(e+8|0,d);v[22440]=0;U(1133,e+24|0,e+40|0,b|0);c=v[22440];v[22440]=0;a:{b:{if((c|0)!=1){v[22440]=0;Q(1134,a|0,e+24|0)|0;c=v[22440];v[22440]=0;if((c|0)==1){break b}rb(e+24|0);rb(b);v[a>>2]=87676;b=v[e+44>>2];v[a+8>>2]=v[e+40>>2];v[a+12>>2]=b;cb=e+48|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;rb(e+24|0)}rb(b);S(a|0);L()}function dH(a){var b=0,c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=C(0),p=0;c=z[a>>2];i=a-16|0;d=z[i>>2];e=C(c+d);b=a-8|0;f=z[b>>2];j=a-24|0;g=z[j>>2];h=C(f+g);z[a>>2]=e+h;z[b>>2]=e-h;b=a-12|0;h=z[b>>2];k=a-28|0;l=z[k>>2];e=C(h+l);p=b;b=a-4|0;m=z[b>>2];a=a-20|0;n=z[a>>2];o=C(m+n);z[p>>2]=o-e;f=C(f-g);g=C(m-n);z[k>>2]=f+g;c=C(c-d);d=C(h-l);z[i>>2]=c+d;z[j>>2]=c-d;z[b>>2]=e+o;z[a>>2]=g-f}function t3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[22440]=0;Z(971,a|0);d=v[22440];v[22440]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[22440]=0;U(1065,d|0,b|0,c|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,10340,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function ye(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=cb-16|0;cb=e;g=sp(a);a:{b:{if(!b){i=e,j=sp(a),v[i+8>>2]=j;v[e+12>>2]=0;break b}f=v[b+4>>2];h=v[b>>2];v[e+8>>2]=h;v[e+12>>2]=f;a=v[a+12>>2];v[e>>2]=2048;v[e+4>>2]=0;b=a+c|0;d=a>>>0>b>>>0?d+1|0:d;a=Dl(e+8|0,e);c=v[a>>2];a=v[a+4>>2];if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break b}break a}a=0;if((d|0)==(f|0)&b>>>0>h>>>0|d>>>0>f>>>0){break a}}a=1}cb=e+16|0;return a}function Gha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=cb-16|0;cb=e;c=rf(a,c);ke(e,v[a+36>>2]);a:{b:{if(!c){Cc(e,a+32|0,5);d=-1;if(!tb(v[v[e>>2]>>2],v[e+4>>2])){break b}break a}d=v[c+16>>2]}f=v[a+36>>2];c:{d:{switch(d+1|0){case 0:case 2:d=cb-32|0;cb=d;t[d+24|0]=0;bj(d+8|0,d+24|0);kn(d+16|0,f,v[d+8>>2],v[d+12>>2]);t[d+16|0]=w[d+24|0];t[b|0]=w[d+16|0];cb=d+32|0;break c;default:break d}}wS(f,b,d)}f=c}Se(a,f);cb=e+16|0}function GX(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;v[22440]=0;a=Ka(1068,a|0,b|0,c|0,d|0)|0;b=v[22440];v[22440]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[22440]=0;ja(954,11148,e|0,f|0,g|0,h|0,i|0,j|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}return a|0}function A0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=cb-16|0;cb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=v[a+12>>2];f=v[a+16>>2];b:{if(d>>>0<f>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=f-d>>2;v[e+4>>2]=c-g;f=d;d=v[ld(e+12|0,ld(e+8|0,e+4|0))>>2];ki(b,f,d);f=d<<2;v[a+12>>2]=f+v[a+12>>2];b=b+f|0;break b}d=gb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}cb=e+16|0;return g|0}function x3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[22440]=0;Z(971,a|0);d=v[22440];v[22440]=0;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[22440]=0;e=+ra(1061,d|0,b|0,c|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,5353,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function Sha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=ok(e,v[a+4>>2]);if(d>>>0<b>>>0){e=cb-32|0;cb=e;d=b-d|0;b=v[xb(a)>>2];f=v[a+4>>2];a:{if(d>>>0<=(b-f|0)/6>>>0){zA(a,d,c);break a}b=xb(a);b=tS(e+8|0,tA(a,ok(v[a>>2],f)+d|0),ok(v[a>>2],v[a+4>>2]),b);sS(b,d,c);c=b+4|0;qS(v[a>>2],v[a+4>>2],c);ec(a,c);ec(a+4|0,b+8|0);ec(xb(a),mc(b));v[b>>2]=v[b+4>>2];rS(b)}cb=e+32|0;return}if(b>>>0<d>>>0){Nd(a,e+B(b,6)|0)}}function MN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=cb-32|0;cb=d;v[a+4>>2]=0;a:{if(b){b:{if(ft(a)>>>0>=b>>>0){v[a+4>>2]=b;break b}e=Nn(d+16|0);v[22440]=0;f=Q(750,a|0,b|0)|0;g=v[22440];v[22440]=0;if((g|0)==1){break a}v[22440]=0;R(751,e|0,f|0);f=v[22440];v[22440]=0;if((f|0)==1){break a}v[e+4>>2]=b;pt(a,e);Re(e)}kk(d+8|0,v[a>>2]);Yu(v[d+8>>2],v[d+12>>2],b,w[c|0])}cb=d+32|0;return}a=P()|0;O()|0;Re(e);S(a|0);L()}function m5(a){a=a|0;var b=0,c=0,d=0;v[22440]=0;Z(996,a|0);b=v[22440];v[22440]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+44>>2];v[22440]=0;c=+ma(d|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,11770,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function k5(a){a=a|0;var b=0,c=0,d=0;v[22440]=0;Z(996,a|0);b=v[22440];v[22440]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+36>>2];v[22440]=0;c=+ma(d|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,7754,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function i5(a){a=a|0;var b=0,c=0,d=0;v[22440]=0;Z(996,a|0);b=v[22440];v[22440]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+28>>2];v[22440]=0;c=+ma(d|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,7702,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function i4(a,b){a=a|0;b=b|0;var c=0;v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;if((c|0)!=1){c=v[a+24>>2];a=0;a:{if(!Qr(b)){break a}c=v[c+24>>2]+484344|0;if(!ve(c,b&65535)){break a}a=v[Sb(c,b)+12>>2]}return a|0}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,6627,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function Lw(a){var b=0,c=0,d=0;a:{b:{if(!v[a+1384>>2]){b=v[a+1380>>2];if((b|0)==-1){v[a+1388>>2]=v[a+1116>>2]-1;if(!Mr(a)){v[a+1384>>2]=1;return 0}if(!(t[a+1375|0]&1)){break b}b=v[a+1380>>2]}d=b+1|0;v[a+1380>>2]=d;c=w[(a+b|0)+1120|0];if((c|0)!=255){v[a+1388>>2]=b;v[a+1384>>2]=1}if(v[a+1116>>2]<=(d|0)){v[a+1380>>2]=-1}if(w[a+1376|0]){break a}t[a+1376|0]=c}return c}Zb(a,32);return 0}ca(15787,13226,1564,6039);L()}function yq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-32|0;cb=c;a:{if(!w[b+7|0]){while(1){if((d|0)==7){d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=$b(c+8|0,c+24|0,7);Yb(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=7){break b}if(Mb(c+24|0,b,7)){break b}Ob(a,7);d=1}cb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}ca(17496,9108,413,13190);L()}ca(17475,9108,411,13190);L()}return d|0}function Q3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=cb-16|0;cb=f;a:{b:{c:{if(!(e?d:0)){a=aa(8)|0;v[22440]=0;b=Q(56,f|0,8229)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}oc(a,b);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}e=P()|0;O()|0;rb(b);break b}hj(a,b,2);c=ax(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);cb=f+16|0;return c|0}e=P()|0;O()|0;ba(a|0)}S(e|0)}L()}function DE(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=cb-16|0;cb=i;if(1073741806-b>>>0>=c>>>0){j=Fb(a);k=1073741807;if(b>>>0<=536870886){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=Pl(v[Pc(i+12|0,i+8|0)>>2])+1|0}c=Ci(k);if(e){ki(c,j,e)}if(g){ki(c+(e<<2)|0,h,g)}d=d-(e+f|0)|0;if(d){h=e<<2;ki((h+c|0)+(g<<2)|0,(h+j|0)+(f<<2)|0,d)}if((b|0)!=1){zb(j)}qd(a,c);cf(a,k);b=a;a=d+(e+g|0)|0;td(b,a);qd(c+(a<<2)|0,0);cb=i+16|0;return}Ye();L()}function B3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=cb-16|0;cb=f;a:{b:{c:{if(!(e?d:0)){a=aa(8)|0;v[22440]=0;b=Q(56,f|0,8229)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}oc(a,b);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}e=P()|0;O()|0;rb(b);break b}hj(a,b,2);c=bx(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);cb=f+16|0;return c|0}e=P()|0;O()|0;ba(a|0)}S(e|0)}L()}function Tt(a,b){var c=0;c=cb-16|0;cb=c;v[c+12>>2]=b;a:{b:{switch(a|0){case 0:a=b;b=a>>31<<6|a>>>26;a=a<<6;a=yc(lka(a- -8192|0,b-((a>>>0<4294959104)-1|0)|0,16384,0),fb);break a;case 1:a=b>>31;a=a<<6|b>>>26;b=(b<<6)+2048|0;a=b>>>0<2048?a+1|0:a;a=yc(lka(b,a,4096,0),fb);break a;default:break b}}v[c+8>>2]=1;a=tl(lK(8192/+v[Ke(c+12|0,c+8|0)>>2])*24+8)}v[c+12>>2]=a;cb=c+16|0;a=(a|0)<64?a:64;return((a|0)>0?a:0)&255}function VR(a){var b=0,c=0;a:{if(Mb(a,14363,3)|(w[a+3|0]-52&255)>>>0<252){break a}b=a+8|0;if(Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+788>>>0<840){break a}b=a+16|0;if(Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}b=a+24|0;if(Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-1>>>0<51){break a}a=a+32|0;c=Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<4294967216}return c}function Qaa(a){a=a|0;var b=0;a=Db(a);v[22440]=0;R(47,a|0,4);b=v[22440];v[22440]=0;a:{b:{if((b|0)==1){break b}v[22440]=0;R(48,a|0,32);b=v[22440];v[22440]=0;if((b|0)==1){break b}v[22440]=0;R(48,a|0,10);b=v[22440];v[22440]=0;if((b|0)==1){break b}v[22440]=0;R(48,a|0,13);b=v[22440];v[22440]=0;if((b|0)==1){break b}v[22440]=0;R(48,a|0,9);b=v[22440];v[22440]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;rb(a);S(b|0);L()}}function Ho(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!Ld(a)){if(!Ld(b)){v[a+8>>2]=v[b+8>>2];c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return}c=Fb(b);b=vb(b);a:{if(b>>>0<=10){Yd(a,b);kd(Ce(a,c,b)+b|0,0);break a}e=a;a=w[a+11|0];cq(e,10,b-10|0,a,0,a,b,c)}return}c=Fb(b);b=vb(b);d=Lj(a);b:{if(b>>>0<d>>>0){d=v[a>>2];td(a,b);kd(Ce(d,c,b)+b|0,0);break b}e=a;a=v[a+4>>2];cq(e,d-1|0,(b-d|0)+1|0,a,0,a,b,c)}}}function lt(a,b){var c=0,d=0;c=cb-32|0;cb=c;d=c+16|0;zP(d,a,a+1|0,a+2|0,a+3|0);zP(c,b,b+1|0,b+2|0,b+3|0);cb=c+32|0;a=1;a:{if(w[v[d>>2]]<w[v[c>>2]]){break a}a=0;if(w[v[c>>2]]<w[v[d>>2]]){break a}a=1;b:{if(t[v[d+4>>2]]<t[v[c+4>>2]]){break b}a=0;if(t[v[c+4>>2]]<t[v[d+4>>2]]){break b}a=1;c:{if(w[v[d+8>>2]]<w[v[c+8>>2]]){break c}a=0;if(w[v[c+8>>2]]<w[v[d+8>>2]]){break c}a=w[v[d+12>>2]]<w[v[c+12>>2]]}}}return a}function TW(a){a=a|0;var b=0;a=Db(a);v[22440]=0;R(75,a|0,4);b=v[22440];v[22440]=0;a:{b:{if((b|0)==1){break b}v[22440]=0;R(52,a|0,32);b=v[22440];v[22440]=0;if((b|0)==1){break b}v[22440]=0;R(52,a|0,10);b=v[22440];v[22440]=0;if((b|0)==1){break b}v[22440]=0;R(52,a|0,13);b=v[22440];v[22440]=0;if((b|0)==1){break b}v[22440]=0;R(52,a|0,9);b=v[22440];v[22440]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;rb(a);S(b|0);L()}}function IU(a){a=a|0;var b=0,c=0,d=0;b=v[a>>2];if(b){gb[v[v[b>>2]+8>>2]](b);v[a>>2]=0}a=a+4|0;Ac(a);b=cb-32|0;cb=b;a:{b:{d=Qo(a);c=Uc(v[a>>2],v[a+4>>2]);c:{if(d>>>0<=c>>>0){break c}v[22440]=0;c=da(931,b+8|0,c|0,c|0,xb(a)|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){Ad(a,c);Rl(c);break c}a=V(0)|0;O()|0;_(a|0)|0;v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)==1){break b}}cb=b+32|0;break a}V(0)|0;O()|0;Lb();L()}}function A3(a,b){a=a|0;b=b|0;var c=0,d=0;v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22440]=0;R(1060,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,10869,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function Av(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=Fb(a);d=vb(a);e=Fb(b);f=vb(b);a:{if(c>>>0<=d>>>0){if(!f){break a}a=c+g|0;h=d+g|0;b=h;d=cb-16|0;cb=d;c=(e+f|0)-e|0;b:{if(!c){b=a;break b}if((c|0)>(b-a|0)){break b}t[d+15|0]=w[e|0];f=1-c|0;while(1){i=b-a|0;if((c|0)>(i|0)){break b}a=Yt(a,f+i|0,d+15|0);if(!a){break b}if(xv(a,e,c)){a=a+1|0;continue}break}b=a}cb=d+16|0;c=(b|0)==(h|0)?-1:b-g|0}else{c=-1}}return c}function y5(a){a=a|0;var b=0;v[22440]=0;Z(996,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){v[a+24>>2]=0;b=v[a+28>>2];if(b){gb[v[v[b>>2]+4>>2]](b)}v[a+28>>2]=0;b=v[a+20>>2];if(b){zb(b);v[a+20>>2]=0}zb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,5054,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function ly(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=0;t[a+1074368|0]=b;IL(a+1074332|0,b);f=a+946300|0;a=a+906300|0;while(1){if((a|0)!=(f|0)){b=v[a>>2];if(b){c=C(1);d=v[b+20>>2];if(d){c=C(C(w[d+26|0])*C(.10000000149011612))}c=c<C(.10000000149011612)?C(1):c;if(gb[v[v[b>>2]+136>>2]](b)|0){d=v[b+16>>2];e=d+1074332|0;c=C(C(c/z[e+8>>2])*C(C(y[d+480232>>2])/z[e+20>>2]))}z[b+4196>>2]=c}a=a+160|0;continue}break}}function GH(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{b:{c:{d:{if((b|0)>=0){if(($o(a+8|0)|0)>(b|0)){break d}}a=aa(8)|0;v[22440]=0;b=Q(56,c|0,10725)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}oc(a,b);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}c=P()|0;O()|0;rb(b);break b}cb=c+16|0;return+(+v[(v[a+32>>2]+B(b,872)|0)+1075740>>2]*.015625)}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}function C0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=cb-16|0;cb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=v[a+28>>2];d=v[a+24>>2];if(g>>>0<=d>>>0){if(((i=a,j=sg(t[b|0]),h=v[v[a>>2]+52>>2],gb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{v[e+12>>2]=g-d;v[e+8>>2]=c-f;g=d;d=v[ld(e+12|0,e+8|0)>>2];Ce(g,b,d);v[a+24>>2]=d+v[a+24>>2];f=f+d|0;b=b+d|0}continue}break}cb=e+16|0;return f|0}function cH(a,b){var c=0,d=0,e=0;if(!w[b+21|0]){Zb(a,21);return-1}if(v[a+1396>>2]<=9){Vk(a)}c=v[a+1392>>2];e=u[(((c&1023)<<1)+b|0)+36>>1];a:{if((e|0)>=0){d=c;c=w[e+v[b+8>>2]|0];v[a+1392>>2]=d>>>c;c=v[a+1396>>2]-c|0;d=(c|0)<0;v[a+1396>>2]=d?0:c;c=d?-1:e;break a}c=Xl(a,b)}if(!((c|0)>=v[b+2092>>2]?w[b+23|0]:0)){if(!(!(v[a+1384>>2]?w[a+1376|0]:1)|(c|0)>=0)){Zb(a,21)}return c}ca(7526,13226,1793,5753);L()}function _s(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=cb-16|0;cb=e;v[b+40>>2]=0;v[b+44>>2]=0;f=b- -64|0;v[f>>2]=0;v[f+4>>2]=0;v[b+56>>2]=0;v[b+60>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;while(1){if((d|0)==1e4){a:{d=yb(v[c>>2]);v[e+8>>2]=d;f=yb(v[c+4>>2]);while(1){if(!Qb(d,f)){break a}g=d,h=QN(b,A[d>>3]),A[g>>3]=h;Ys(e+8|0);d=v[e+8>>2];continue}}}else{QN(b,A[Xe(v[c>>2],0)>>3]);d=d+1|0;continue}break}lk(a,c);cb=e+16|0}function We(a){var b=0,c=0,d=0;b=cb-16|0;cb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=Ko(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(wE(a,b)&3){case 0:c=Ko(A[b>>3],A[b+8>>3]);break a;case 1:c=-Lo(A[b>>3],A[b+8>>3],1);break a;case 2:c=-Ko(A[b>>3],A[b+8>>3]);break a;default:break b}}c=Lo(A[b>>3],A[b+8>>3],1)}a=c;cb=b+16|0;return a}function pV(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=cb-16|0;cb=f;v[f+12>>2]=c;a:{g=Kb(b,c<<1);if(!g){break a}qc(f+12|0,65535);Ff(a,x[f+12>>1]);c=yb(v[a>>2]);v[f>>2]=c;i=yb(v[a+4>>2]);while(1){if(!Qb(c,i)){break a}a=f+8|0;Du(b,a);a=w[a|0]|w[a+1|0]<<8;u[c>>1]=a;h=65535;b:{if((a|0)!=(d|0)){h=65534;if((a|0)!=(e|0)){break b}}u[c>>1]=h}Ne(f);c=v[f>>2];continue}}cb=f+16|0;return g|0}function Zn(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=cb-16|0;cb=f;v[f+12>>2]=c;a:{g=Kb(b,c);if(!g){break a}qc(f+12|0,65535);Ff(a,x[f+12>>1]);c=yb(v[a>>2]);v[f>>2]=c;i=yb(v[a+4>>2]);while(1){if(!Qb(c,i)){break a}a=f+11|0;if(!yg(b,a)){ug(a)}a=w[f+11|0];u[c>>1]=a;h=65535;b:{if((a|0)!=(d|0)){h=65534;if((a|0)!=(e|0)){break b}}u[c>>1]=h}Ne(f);c=v[f>>2];continue}}cb=f+16|0;return g|0}function Pda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;u[d+12>>1]=c;u[d+14>>1]=b;Kf(d+14|0,x[v[v[a+24>>2]+8>>2]+12>>1]);e=d+12|0;c=cb-16|0;cb=c;b=x[d+14>>1];v[c+12>>2]=b;a:{if(Lm(a)>>>0>=b>>>0){g=v[a>>2];f=Fc(g,v[a+4>>2]);v[c+8>>2]=f;Ft(g,v[Bb(c+12|0,c+8|0)>>2],e);if(b>>>0>f>>>0){oo(a,b-f|0,e);break a}Nd(a,v[a>>2]+(b<<1)|0);break a}wO(a);Lz(a,Nj(a,b));oo(a,b,e)}cb=c+16|0;cb=d+16|0}function EH(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{b:{c:{d:{if((b|0)>=0){if(($o(a+8|0)|0)>(b|0)){break d}}a=aa(8)|0;v[22440]=0;b=Q(56,c|0,10725)|0;c=v[22440];v[22440]=0;if((c|0)==1){break c}oc(a,b);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}c=P()|0;O()|0;rb(b);break b}cb=c+16|0;return(w[(v[a+32>>2]+B(b,872)|0)+1075081|0]&4)>>>2|0}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}function v3(a,b){a=a|0;b=+b;var c=0;v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22440]=0;b=+Ua(1062,c|0,+b);c=v[22440];v[22440]=0;if((c|0)!=1){break b}}c=V(0)|0;O()|0;_(c|0)|0;v[22440]=0;W(958,7566,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;O()|0;v[22440]=0;X(18);c=v[22440];v[22440]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function ts(a){var b=0,c=0,d=0;b=w[a+4266|0];z[a+4236>>2]=C(b>>>0)*C(.00390625);v[a+4228>>2]=(B(v[a+4232>>2],w[a+4264|0])+250>>>0)/500;z[a+4240>>2]=C(256-b|0)*C(.00390625);c=w[a+4267|0];b=w[a+4265|0];z[a+4244>>2]=C(B(c,b)|0)*C(152587890625e-16);d=c|-256;z[a+4256>>2]=C(B(d,b|-256)|0)*C(152587890625e-16);z[a+4252>>2]=C(B(b,d)|0)*C(152587890625e-16);z[a+4248>>2]=C(B(256-b|0,c)|0)*C(152587890625e-16)}function n7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=vi(a,b,c,d);v[a>>2]=45856;d=Rb(a+4208|0);v[a+4240>>2]=0;v[a+4244>>2]=0;c=v[c+24620>>2];v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;e=a+4228|0;v[e>>2]=1048576e3;v[e+4>>2]=1048576e3;v[a+4236>>2]=0;v[a+4260>>2]=0;v[a+4256>>2]=c;v[22440]=0;R(922,a+44|0,2);c=v[22440];v[22440]=0;if((c|0)!=1){ui(b);return a|0}a=P()|0;O()|0;fc(d);vf(b);S(a|0);L()}function DP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=cb-16|0;cb=d;v[d+12>>2]=6553600;e=b+4|0;i=d,j=Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24)),v[i+8>>2]=j;f=+(c>>>0)/6553600;g=d+12|0;e=d+8|0;h=hq(f*+y[Bb(g,e)>>2]);v[d+8>>2]=6553600;b=b+8|0;i=d,j=Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),v[i+4>>2]=j;i=d,j=hq(f*+y[Bb(e,d+4|0)>>2]),v[i+12>>2]=j;v[d+8>>2]=c-h;On(a,h,Bb(e,g));cb=d+16|0}function ix(a,b,c,d,e){var f=0,g=0;a:{if(!Qr(b)){break a}f=a+24|0;a=v[f>>2]+484344|0;if(!ve(a,b&65535)){break a}a=Sb(a,b);if((c|d)<0|v[a+12>>2]<=(c|0)|(x[v[f>>2]+480188>>1]<=d>>>0|e>>>0>5)){break a}b=Zc(a,c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}g=w[b|0]}return g}function ffa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Gz(a,b);v[22440]=0;e=Q(675,a+12|0,b+12|0)|0;d=v[22440];v[22440]=0;b:{c:{if((d|0)!=1){v[22440]=0;Q(676,a+24|0,b+24|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}c=v[b+40>>2];v[a+36>>2]=v[b+36>>2];v[a+40>>2]=c;u[a+52>>1]=x[b+52>>1];c=v[b+48>>2];v[a+44>>2]=v[b+44>>2];v[a+48>>2]=c;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;_b(e)}_b(c);S(a|0);L()}}function bC(a,b){var c=0,d=0,e=0;c=cb-32|0;cb=c;a:{if(!w[b+7|0]){while(1){if((d|0)==7){d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=$b(c+8|0,c+24|0,7);cd(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=7){break b}if(Mb(c+24|0,b,7)){break b}Yc(a,7);d=1}cb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}ca(17496,9108,413,13190);L()}ca(17475,9108,411,13190);L()}return d}function U3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=cb-16|0;cb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[22440]=0;c=Q(56,e|0,8229)|0;b=v[22440];v[22440]=0;if((b|0)==1){break c}oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}b=P()|0;O()|0;rb(c);break b}hj(a,b,1);c=ax(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);cb=e+16|0;return c|0}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function RL(a,b){var c=0,d=0,e=0,f=0;d=v[a>>2];v[a>>2]=b;if(d){if(d){a=cb-16|0;cb=a;b=yb(v[d>>2]);v[a+8>>2]=b;f=yb(v[d+4>>2]);while(1){if(Qb(b,f)){a:{while(1){c=v[b>>2];e=v[c>>2];if(!e){break a}c=v[v[e>>2]+8>>2];v[22440]=0;Z(c|0,e|0);c=v[22440];v[22440]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;fc(d);Lb();L()}Ab(c+20|0);Ab(c+8|0);zb(c);Ge(a+8|0);b=v[a+8>>2];continue}break}fc(d);cb=a+16|0}zb(d)}}function F3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=cb-16|0;cb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[22440]=0;c=Q(56,e|0,8229)|0;b=v[22440];v[22440]=0;if((b|0)==1){break c}oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}b=P()|0;O()|0;rb(c);break b}hj(a,b,1);c=bx(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);cb=e+16|0;return c|0}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function j2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=cb-16|0;cb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;iI(a,c);a:{if(z[a+24>>2]==C(1)){break a}d=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=e+g|0;b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=Kh(v[a+12>>2],v[a+16>>2],b,i);z[f>>2]=z[a+24>>2]*z[f>>2];b=b+1|0;continue}}}cb=c+16|0}function ar(a){var b=0,c=0;Wm(a,1,13647);v[22440]=0;b=ha(128)|0;c=v[22440];v[22440]=0;a:{if((c|0)==1){break a}v[a+12>>2]=b;v[22440]=0;b=ha(129)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}t[a+16|0]=b;v[22440]=0;b=ha(130)|0;c=v[22440];v[22440]=0;if((c|0)==1){break a}t[a+18|0]=0;t[a+17|0]=b;v[22440]=0;Z(131,a+20|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}return}b=P()|0;O()|0;rb(a);S(b|0);L()}function uH(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=cb-16|0;cb=d;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[22440]=0;d=Q(56,d|0,10725)|0;a=v[22440];v[22440]=0;if((a|0)==1){break c}oc(b,d);v[22440]=0;U(121,b|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;rb(d);break b}e=(v[a+32>>2]+B(b,872)|0)+1075766|0,f=zz(c*32768),u[e>>1]=f;cb=d+16|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function q4(a){a=a|0;var b=0,c=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22440]=0;b=T(1038,b|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,7238,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function O3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=cb-16|0;cb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[22440]=0;c=Q(56,e|0,8229)|0;b=v[22440];v[22440]=0;if((b|0)==1){break c}oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}b=P()|0;O()|0;rb(c);break b}hj(a,b,4);c=jI(a,c,4,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);cb=e+16|0;return c|0}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function M3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=cb-16|0;cb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[22440]=0;c=Q(56,e|0,8229)|0;b=v[22440];v[22440]=0;if((b|0)==1){break c}oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}b=P()|0;O()|0;rb(c);break b}hj(a,b,2);c=jI(a,c,2,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);cb=e+16|0;return c|0}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function J3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=cb-16|0;cb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[22440]=0;c=Q(56,e|0,8229)|0;b=v[22440];v[22440]=0;if((b|0)==1){break c}oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}b=P()|0;O()|0;rb(c);break b}hj(a,b,4);c=oI(a,c,4,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);cb=e+16|0;return c|0}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function H3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=cb-16|0;cb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[22440]=0;c=Q(56,e|0,8229)|0;b=v[22440];v[22440]=0;if((b|0)==1){break c}oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}b=P()|0;O()|0;rb(c);break b}hj(a,b,2);c=oI(a,c,2,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);cb=e+16|0;return c|0}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function hd(a,b){var c=0,d=0,e=0,f=0,g=0;a:{e=NF(b);c=No(a);if(e>>>0<=c>>>0){f=Fb(a);d=f;c=e;if(c){b:{if((b|0)==(d|0)){break b}if(d-b>>>0>=c<<2>>>0){if(!c){break b}while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}break b}if(!c){break b}while(1){c=c-1|0;g=c<<2;v[g+d>>2]=v[b+g>>2];if(c){continue}break}}}qd((e<<2)+f|0,0);Bf(a,e);break a}d=a;a=vb(a);DE(d,c,e-c|0,a,0,a,e,b)}}function YL(a,b){a=a|0;b=b|0;VL(a);VL(a+368680|0);if(b){UL(a,1);return a|0}a:{if(t[458632]&1){break a}if(!Xd(458632)){break a}v[22440]=0;Q(871,89928,1)|0;b=v[22440];v[22440]=0;if((b|0)!=1){Wd(458632);break a}a=P()|0;O()|0;nf(458632);S(a|0);L()}Hn(221040,286576,a+131112|0);Hn(286576,352112,a+196648|0);Hn(352112,417648,a+262184|0);Hn(89952,221040,a+24|0);ic(a+327720|0,417648,40960);return a|0}function E4(a){a=a|0;var b=0,c=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22440]=0;c=+ma(1029,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,7638,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function Bi(a){var b=0,c=0;b=cb-16|0;cb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=Lo(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(wE(a,b)&3){case 0:a=Lo(A[b>>3],A[b+8>>3],1);break a;case 1:a=Ko(A[b>>3],A[b+8>>3]);break a;case 2:a=-Lo(A[b>>3],A[b+8>>3],1);break a;default:break b}}a=-Ko(A[b>>3],A[b+8>>3])}cb=b+16|0;return a}function mT(a){var b=0,c=0;a:{if(Mb(a,15259,3)){break a}c=w[a+3|0];if(c>>>0>9){break a}b=a+202|0;if((wb(w[b|0]|w[b+1|0]<<8)-1e4&65535)>>>0<57516){break a}b=1;b:{if(c>>>0>5){break b}b=a+228|0;if(!wb(w[b|0]|w[b+1|0]<<8)){break a}b=a+230|0;if(!wb(w[b|0]|w[b+1|0]<<8)){break a}c=a+232|0;b=0;if(wb(w[c|0]|w[c+1|0]<<8)>>>0>4095){break b}a=a+234|0;b=wb(w[a|0]|w[a+1|0]<<8)>>>0<100}return b}return 0}function wF(a,b,c){var d=0,e=0,f=C(0),g=0,h=C(0);e=cb-16|0;cb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[114922];v[114922]=0;pd();d=cb-16|0;cb=d;ew(d,a,e+12|0,0);f=kF(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);cb=d+16|0;a=v[114922];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[114922]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}cb=e+16|0;return f}function Xw(a,b,c){var d=0,e=0;d=cb-32|0;cb=d;a:{if(w[a+20|0]){break a}b=b+c|0;b=b>>>0<c>>>0?-1:b;c=v[a+16>>2];if(b>>>0<=c>>>0){break a}b=cI(b,4096);bI(a,b-c|0);c=v[a+16>>2];b=$b(d+16|0,Eb(v[a+4>>2],c),b-c|0);c=v[v[a>>2]+44>>2];e=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=e;gb[c|0](d+24|0,a,d+8|0);v[a+16>>2]=v[a+16>>2]+v[d+28>>2];if(!(gb[v[v[a>>2]+40>>2]](a)|0)){break a}t[a+20|0]=1}cb=d+32|0}function Mo(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=cb-16|0;cb=i;if(-18-b>>>0>=c>>>0){j=Fb(a);k=-17;if(b>>>0<=2147483622){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=Kg(v[Pc(i+12|0,i+8|0)>>2])+1|0}c=lc(k);if(e){Ce(c,j,e)}if(g){Ce(c+e|0,h,g)}d=d-(e+f|0)|0;if(d){Ce((c+e|0)+g|0,(e+j|0)+f|0,d)}if((b|0)!=10){zb(j)}qd(a,c);cf(a,k);b=a;a=d+(e+g|0)|0;td(b,a);t[i+7|0]=0;$d(a+c|0,i+7|0);cb=i+16|0;return}Ye();L()}function Fu(a,b,c){var d=0,e=0,f=0;d=v[c+16>>2];a:{if(!d){if(BC(c)){break a}d=v[c+16>>2]}f=v[c+20>>2];if(d-f>>>0<b>>>0){return gb[v[c+36>>2]](c,a,b)|0}b:{if(v[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(w[e+a|0]!=10){continue}break}e=gb[v[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=v[c+20>>2]}ic(f,a,b);v[c+20>>2]=v[c+20>>2]+b;e=b+d|0}return e}function z2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0;c=cb-16|0;cb=c;a:{f=z[a+24>>2];if(f==C(1)){break a}h=v[b+4>>2];i=v[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=v[b+4>>2];k=v[b>>2];d=0;while(1)if((d|0)==(h|0)){e=e+1|0;continue b}else{g=ah(k,j,d,e);A[g>>3]=A[g>>3]*+f;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;tI(a,c);cb=c+16|0}function s2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0;c=cb-16|0;cb=c;a:{f=z[a+24>>2];if(f==C(1)){break a}h=v[b+4>>2];i=v[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=v[b+4>>2];k=v[b>>2];d=0;while(1)if((d|0)==(h|0)){e=e+1|0;continue b}else{g=ah(k,j,d,e);A[g>>3]=A[g>>3]*+f;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;pI(a,c);cb=c+16|0}function p2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0;c=cb-16|0;cb=c;a:{f=z[a+24>>2];if(f==C(1)){break a}h=v[b+4>>2];i=v[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=v[b+4>>2];k=v[b>>2];d=0;while(1)if((d|0)==(h|0)){e=e+1|0;continue b}else{g=ah(k,j,d,e);A[g>>3]=A[g>>3]*+f;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;mI(a,c);cb=c+16|0}function is(a,b){var c=0,d=0,e=0;c=cb-32|0;cb=c;e=Db(a+16|0);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=v[b+12>>2];v[22440]=0;b=Q(55,c|0,b+16|0)|0;d=v[22440];v[22440]=0;a:{b:{if((d|0)!=1){v[22440]=0;R(59,c+16|0,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break b}a=c+16|0;tc(e,a);rb(a);rb(b);cb=c+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;rb(b)}Qc(a);S(c|0);L()}function i2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=0;c=cb-16|0;cb=c;a:{f=z[a+24>>2];if(f==C(1)){break a}h=v[b+4>>2];i=v[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=v[b+4>>2];k=v[b>>2];d=0;while(1)if((d|0)==(h|0)){e=e+1|0;continue b}else{g=ah(k,j,d,e);A[g>>3]=A[g>>3]*+f;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;hI(a,c);cb=c+16|0}function sR(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function lP(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+30|0]=0;t[a+31|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function as(a,b){var c=0,d=0,e=0;c=cb-32|0;cb=c;e=Db(a+16|0);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=v[b+12>>2];v[22440]=0;b=Q(3,c|0,b+16|0)|0;d=v[22440];v[22440]=0;a:{b:{if((d|0)!=1){v[22440]=0;R(73,c+16|0,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break b}a=c+16|0;Cb(e,a);rb(a);rb(b);cb=c+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;rb(b)}Qc(a);S(c|0);L()}function vZ(){var a=0;a:{if(t[464232]&1){break a}if(!Xd(464232)){break a}a=464064;while(1){a=Db(a)+12|0;if((a|0)!=464232){continue}break}Wd(464232)}hd(464064,84356);hd(464076,84384);hd(464088,84412);hd(464100,84444);hd(464112,84484);hd(464124,84520);hd(464136,84548);hd(464148,84584);hd(464160,84600);hd(464172,84616);hd(464184,84632);hd(464196,84648);hd(464208,84664);hd(464220,84680)}function t2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=cb-16|0;cb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;qI(a,c);a:{if(z[a+24>>2]==C(1)){break a}d=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=e+g|0;b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=Wp(v[a+12>>2],b,i);z[f>>2]=z[a+24>>2]*z[f>>2];b=b+1|0;continue}}}cb=c+16|0}function uF(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=cb-16|0;cb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[114922];v[114922]=0;pd();d=cb-16|0;cb=d;ew(d,a,e+12|0,1);f=Sw(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);cb=d+16|0;a=v[114922];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[114922]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}cb=e+16|0;return f}function P8(a){a=a|0;var b=0,c=0;b=v[a+20>>2];v[b+148>>2]=-1;v[22440]=0;R(292,b+4|0,8);b=v[22440];v[22440]=0;if((b|0)!=1){b=v[a+4264>>2];c=v[v[a+20>>2]+4>>2];a=v[a+4260>>2];t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;t[c+4|0]=b;t[c+5|0]=b>>>8;t[c+6|0]=b>>>16;t[c+7|0]=b>>>24;return}b=V(88360)|0;if((O()|0)==(fa(88360)|0)){_(b|0)|0;Ac(v[a+20>>2]+4|0);$();return}S(b|0);L()}function Kz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=cb-32|0;cb=d;e=Rb(a);a=yb(v[b>>2]);v[d+24>>2]=a;b=yb(v[b+4>>2]);a:{while(1){if(Qb(a,b)){Uh(d,a);if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==(c|0)){ho(d,a);v[22440]=0;R(363,e|0,d|0);a=v[22440];v[22440]=0;if((a|0)==1){break a}sb(d)}zm(d+24|0);a=v[d+24>>2];continue}break}cb=d+32|0;return}a=P()|0;O()|0;sb(d);Ic(e);S(a|0);L()}function Dba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=yd(a);b:{c:{c=Fc(v[b>>2],v[b+4>>2]);if(c){v[22440]=0;R(634,a|0,c|0);e=v[22440];v[22440]=0;if((e|0)==1){break c}mO(a,v[b>>2],v[b+4>>2],c)}break b}a=P()|0;O()|0;_c(d);S(a|0);L()}c=a;v[22440]=0;Q(3,a+12|0,b+12|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){v[a+24>>2]=v[b+24>>2];u[a+28>>1]=x[b+28>>1];break a}a=P()|0;O()|0;_c(c);S(a|0);L()}}function l2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a+32|0;sq(c,b);v[a+44>>2]=0;b=v[a+48>>2];if(b&8){b=Fb(c)+vb(c)|0;v[a+44>>2]=b;d=Fb(c);fn(a,d,d,b);b=v[a+48>>2]}a:{if(!(b&16)){break a}b=vb(c);e=a,f=b+Fb(c)|0,v[e+44>>2]=f;Qx(c,Dc(c));d=Fb(c);rw(a,d,vb(c)+d|0);if(!(w[a+48|0]&3)){break a}while(1){if((b|0)<0){zr(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}zr(a,b)}}function H5(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){b=v[a+24>>2];if(b){ds(b)}zb(b);v[a+24>>2]=0;b=v[a+20>>2];if(b){zb(b);v[a+20>>2]=0}zb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,5081,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function AH(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[22440]=0;c=Q(56,c|0,10725)|0;a=v[22440];v[22440]=0;if((a|0)==1){break c}oc(b,c);v[22440]=0;U(121,b|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;rb(c);break b}a=v[a+32>>2]+B(b,872)|0;v[a+1075008>>2]=0;v[a+1075068>>2]=0;cb=c+16|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function y0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=cb-16|0;cb=f;while(1){a:{if((c|0)<=(g|0)){break a}d=v[a+24>>2];e=v[a+28>>2];if(d>>>0>=e>>>0){if((gb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){break a}g=g+1|0;b=b+4|0}else{v[f+12>>2]=e-d>>2;v[f+8>>2]=c-g;e=d;d=v[ld(f+12|0,f+8|0)>>2];ki(e,b,d);e=d<<2;v[a+24>>2]=e+v[a+24>>2];g=g+d|0;b=b+e|0}continue}break}cb=f+16|0;return g|0}function vH(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[22440]=0;c=Q(56,c|0,10725)|0;a=v[22440];v[22440]=0;if((a|0)==1){break c}oc(b,c);v[22440]=0;U(121,b|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;rb(c);break b}cb=c+16|0;return+(+(v[(v[a+32>>2]+B(b,872)|0)+1075684>>2]-128|0)*.0078125)}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function mha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=cb-16|0;cb=d;e=-1;a:{if(!Pj(a,d+8|0)){break a}c=d+8|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))==(Hm(9007)|0)){c=c+4|0;c=((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))&-4)==256}else{c=0}e=0;if(!c){break a}c=a;a=d+12|0;e=ye(c,b,(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<259?80:76,0)}c=e;cb=d+16|0;return c|0}function jha(a){a=a|0;var b=0,c=0,d=0,e=0;e=cb-16|0;cb=e;b=lc(2500);c=cb-2496|0;cb=c;kR(a,c,c+2496|0);a=0;while(1){if((a|0)==624){v[b+2496>>2]=0;a:{if(v[b>>2]<0){break a}a=1;while(1){if((a|0)!=624){d=a<<2;a=a+1|0;if(!v[b+d>>2]){continue}break a}break}v[b>>2]=-2147483648}cb=c+2496|0}else{d=a<<2;v[d+b>>2]=v[c+d>>2];a=a+1|0;continue}break}a=v[Sf(e+8|0,b)>>2];cb=e+16|0;return a|0}function NH(a,b){a=a|0;b=+b;var c=0,d=0;c=cb-16|0;cb=c;a:{b:{c:{if(b<=0|b>4){a=aa(8)|0;v[22440]=0;c=Q(56,c|0,7814)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}d=P()|0;O()|0;rb(c);break b}d=Le(65536/b);a=a+32|0;v[v[a>>2]+480244>>2]=d;rp(v[a>>2]);cb=c+16|0;return}d=P()|0;O()|0;ba(a|0)}S(d|0)}L()}function LH(a,b){a=a|0;b=+b;var c=0,d=0;c=cb-16|0;cb=c;a:{b:{c:{if(b<=0|b>4){a=aa(8)|0;v[22440]=0;c=Q(56,c|0,7835)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}d=P()|0;O()|0;rb(c);break b}d=Le(b*65536);a=a+32|0;v[v[a>>2]+480240>>2]=d;rp(v[a>>2]);cb=c+16|0;return}d=P()|0;O()|0;ba(a|0)}S(d|0)}L()}function zH(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[22440]=0;c=Q(56,c|0,10725)|0;a=v[22440];v[22440]=0;if((a|0)==1){break c}oc(b,c);v[22440]=0;U(121,b|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;rb(c);break b}a=(v[a+32>>2]+B(b,872)|0)+1075080|0;v[a>>2]=v[a>>2]|2048;cb=c+16|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function yH(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[22440]=0;c=Q(56,c|0,10725)|0;a=v[22440];v[22440]=0;if((a|0)==1){break c}oc(b,c);v[22440]=0;U(121,b|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;rb(c);break b}a=(v[a+32>>2]+B(b,872)|0)+1075080|0;v[a>>2]=v[a>>2]|4096;cb=c+16|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function tH(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[22440]=0;c=Q(56,c|0,10725)|0;a=v[22440];v[22440]=0;if((a|0)==1){break c}oc(b,c);v[22440]=0;U(121,b|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;rb(c);break b}cb=c+16|0;return+(+u[(v[a+32>>2]+B(b,872)|0)+1075766>>1]*30517578125e-15)}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function OQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-32|0;cb=c;a:{if(!w[b+8|0]){while(1){if((d|0)==8){v[c+24>>2]=0;v[c+28>>2]=0;d=$b(c+8|0,c+24|0,8);Yb(c+16|0,a,v[d>>2],v[d+4>>2]);d=0;b:{if(v[c+20>>2]!=8){break b}if(Mb(c+24|0,b,8)){break b}Ob(a,8);d=1}cb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}ca(17496,9108,413,13190);L()}ca(17475,9108,411,13190);L()}return d|0}function MB(a,b){var c=0,d=0;b=!v[a+24>>2]|b;v[a+16>>2]=b;if(b&v[a+20>>2]){c=cb-16|0;cb=c;b=aa(16)|0;a=cb-16|0;cb=a;a:{if(t[460196]&1){break a}if(!Xd(460196)){break a}Wd(460196)}$b(a+8|0,1,89440);d=v[a+12>>2];c=c+8|0;v[c>>2]=v[a+8>>2];v[c+4>>2]=d;cb=a+16|0;v[22440]=0;Q(1135,b|0,c|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){ia(b|0,74324,1136);L()}a=P()|0;O()|0;ba(b|0);S(a|0);L()}}function uQ(a){var b=0,c=0;a:{if(Mb(a+44|0,14245,4)|w[a+28|0]!=26|w[a+30|0]>2){break a}b=a+40|0;if(w[b|0]|w[b+1|0]<<8){break a}b=a+38|0;if(((w[b|0]|w[b+1|0]<<8)-33&65535)>>>0<65504){break a}b=a+32|0;if(((w[b|0]|w[b+1|0]<<8)-257&65535)>>>0<65280){break a}b=a+34|0;if(((w[b|0]|w[b+1|0]<<8)-256&65535)>>>0<65281){break a}a=a+36|0;c=((w[a|0]|w[a+1|0]<<8)-1&65535)>>>0<128}return c}function lZ(){var a=0;a:{if(t[464056]&1){break a}if(!Xd(464056)){break a}a=463888;while(1){a=Db(a)+12|0;if((a|0)!=464056){continue}break}Wd(464056)}dd(463888,5243);dd(463900,5250);dd(463912,5216);dd(463924,5224);dd(463936,5207);dd(463948,5257);dd(463960,5234);dd(463972,9777);dd(463984,9983);dd(463996,11330);dd(464008,12898);dd(464020,5506);dd(464032,10787);dd(464044,6590)}function Z8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=cb-16|0;cb=d;c=lc(64);v[22440]=0;e=T(859,c|0)|0;f=v[22440];v[22440]=0;a:{if((f|0)!=1){c=Sf(d,e);e=v[c>>2];v[22440]=0;a=Y(920,e|0,a|0,b|0)|0;b=v[22440];v[22440]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}If(d+8|0);break b}a=P()|0;O()|0;qg(c);break a}bi(d+8|0,c)}qg(c);cb=d+16|0;return v[d+8>>2]}a=P()|0;O()|0;zb(c)}S(a|0);L()}function D5(a,b){a=a|0;b=b|0;var c=0;v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;a:{b:{if((c|0)!=1){v[a+16>>2]=b;b=v[a+20>>2];if(!b){break b}zb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,5663,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function x8(a,b){a=a|0;b=b|0;var c=C(0);a:{switch(b|0){case 0:return C(z[a+4220>>2]);case 1:return C(z[a+4224>>2]);case 2:return C(z[a+4228>>2]);case 3:return C(w[a+4240|0]?C(1):C(0));case 4:return C(C(C(v[a+4232>>2])*C(.03125)));case 5:return C(w[a+4241|0]?C(1):C(0));case 6:return C(w[a+4242|0]?C(1):C(0));case 7:c=w[a+4244|0]?C(1):C(0);break;default:break a}}return C(c)}function cq(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=cb-16|0;cb=i;if(-18-b>>>0>=c>>>0){j=Fb(a);k=-17;if(b>>>0<=2147483622){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=Kg(v[Pc(i+12|0,i+8|0)>>2])+1|0}c=lc(k);if(e){Ce(c,j,e)}if(g){Ce(c+e|0,h,g)}d=d-(e+f|0)|0;if(d){Ce((c+e|0)+g|0,(e+j|0)+f|0,d)}if((b|0)!=10){zb(j)}qd(a,c);cf(a,k);b=a;a=d+(e+g|0)|0;td(b,a);kd(a+c|0,0);cb=i+16|0;return}Ye();L()}function Bg(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=Fb(a);c=vb(a);d=Rg(b);a=0;a:{if(!d){break a}a=f;g=c+a|0;c=g;e=cb-16|0;cb=e;d=(b+d|0)-b|0;b:{if(!d){c=a;break b}if((d|0)>(c-a|0)){break b}t[e+15|0]=w[b|0];i=1-d|0;while(1){h=c-a|0;if((d|0)>(h|0)){break b}a=qp(a,i+h|0,e+15|0);if(!a){break b}if(zp(a,b,d)){a=a+1|0;continue}break}c=a}cb=e+16|0;a=(c|0)==(g|0)?-1:c-f|0}return a}function vy(a,b,c,d){a:{if(v[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=B(b,872)+a|0;v[c+1075688>>2]=0;d=c+1075e3|0;v[d>>2]=0;v[d+4>>2]=0;d=c+1075080|0;c=v[d>>2]|4096;v[d>>2]=c;break b}c=B(b,872)+a|0;v[c+1075680>>2]=0;c=v[c+1075080>>2]}d=B(b,872)+a|0;v[d+1075080>>2]=c|2097152;gm(a,b,255,0);if(!(w[d+1075081|0]&2)){break a}a=a+1298300|0;if(!Bd(a)){break a}pj(v[a>>2],b,0)}}function SS(a){var b=0,c=0,d=0;a:{if(Mb(a+60|0,15573,4)){break a}b=a+32|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+36|0;if(w[a+49|0]<32|(w[b|0]|w[b+1|0]<<8)>>>0>255|(t[a+51|0]<4|w[a+50|0]>64)){break a}b=a+576|0;a=a- -64|0;while(1){if((a|0)==(b|0)){d=c;break a}b:{switch(w[a+15|0]){case 0:case 1:c=1;break;case 2:break b;default:break a}}a=a+16|0;continue}}return d&1}function sx(a){var b=C(0),c=C(0),d=0,e=C(0),f=0;b=C(y[v[a+16>>2]+24620>>2]);c=C(C(C(gb[v[v[a>>2]+204>>2]](a))*b)/C(1e3));d=a,e=C(C(c*C(gb[v[v[a>>2]+196>>2]](a)))*C(2048)),z[d+4248>>2]=e;d=a,f=Nh(C(C(c+C(2))*C(4096))),v[d+4256>>2]=f;c=C(gb[v[v[a>>2]+208>>2]](a));z[a+4252>>2]=c;b=C(c/b);if(!(gb[v[v[a>>2]+192>>2]](a)|0)){b=WJ(C(b*C(3.1415927410125732)))}z[a+4244>>2]=b+b}function Wi(a,b,c,d,e){var f=0,g=0,h=0;f=cb-16|0;cb=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if(Xj(a,f+8|0)){break b}g=4;h=Tk(v[a>>2]);if(!qh(d,2048,h)){break b}b=Zm(d,h);while(1){c:{b=b-48|0;h=Ul(a);if(!To(h,f+8|0)|(e|0)<2){break c}g=Tk(v[a>>2]);if(!qh(d,2048,g)){break a}e=e-1|0;b=Zm(d,g)+B(b,10)|0;continue}break}g=2;if(!Xj(h,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}cb=f+16|0;return b}function Vi(a,b,c,d,e){var f=0,g=0,h=0;f=cb-16|0;cb=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if(Qk(a,f+8|0)){break b}g=4;h=Sk(v[a>>2]);if(!Rk(d,2048,h)){break b}b=Ym(d,h);while(1){c:{b=b-48|0;h=gn(a);if(!Cr(h,f+8|0)|(e|0)<2){break c}g=Sk(v[a>>2]);if(!Rk(d,2048,g)){break a}e=e-1|0;b=Ym(d,g)+B(b,10)|0;continue}break}g=2;if(!Qk(h,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}cb=f+16|0;return b}function sT(a){var b=0,c=0;a:{if(Mb(a,13964,3)|(w[a+3|0]-1&255)>>>0>3){break a}b=a+196|0;if(wb(w[b|0]|w[b+1|0]<<8)>>>0>255){break a}b=a+198|0;if((wb(w[b|0]|w[b+1|0]<<8)-1&65535)>>>0>255){break a}b=a+200|0;if((wb(w[b|0]|w[b+1|0]<<8)-1&65535)>>>0>31){break a}b=a+202|0;b=wb(w[b|0]|w[b+1|0]<<8);if(b>>>0>256){break a}a=a+204|0;c=wb(w[a|0]|w[a+1|0]<<8)>>>0<b>>>0}return c}function Yl(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return t[a+68640|0]}if(a>>>0<=511){return t[(a>>>5|0)+68640|0]+5|0}return t[(a>>>10|0)+68640|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return t[(a>>>15|0)+68640|0]+15|0}return t[(a>>>20|0)+68640|0]+20|0}if(a>>>0<=536870911){return t[(a>>>25|0)+68640|0]+25|0}a=t[(a>>>30|0)+68640|0]+30|0}else{a=0}return a}function JC(a,b){var c=0,d=0,e=0,f=0;c=cb-16|0;cb=c;a:{if(b>>>0<5){if(!b){break a}if(!Kb(a,b)){break a}while(1)if((d|0)==4){v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);break a}else{t[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){yg(a,c+11|0);e=w[c+11|0]}else{e=0}t[f|0]=e;d=d+1|0;continue}}ca(11259,9108,136,14288);L()}cb=c+16|0;return d}function G5(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;a:{b:{if((b|0)!=1){v[a+16>>2]=0;b=v[a+20>>2];if(!b){break b}zb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,8945,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function mr(a,b,c){var d=0,e=0;if(c&2048){t[a|0]=43;a=a+1|0}if(c&1024){t[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){t[a|0]=46;t[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}t[a|0]=b;return(d|0)!=260}function Fha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=cb-16|0;cb=f;c=rf(a,c);ke(f,v[a+36>>2]);a:{if(!c){Cc(f,a+32|0,5);e=0;if(tb(v[v[f>>2]>>2],v[f+4>>2])){break a}}h=v[a+36>>2];g=cb-16|0;cb=g;e=Db(g);v[22440]=0;da(470,b|0,h|0,e|0,d|0)|0;b=v[22440];v[22440]=0;b:{if((b|0)!=1){rb(e);cb=g+16|0;break b}a=P()|0;O()|0;rb(e);S(a|0);L()}e=c}Se(a,e);cb=f+16|0}function Cja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-16|0;cb=d;a:{e=He(a);b:{if(e>>>0>1){break b}c:{if(e){v[22440]=0;U(338,d|0,a|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){xm(b,d);_b(d);break c}a=V(30592)|0;if((O()|0)!=(fa(30592)|0)){break a}_(a|0)|0;$();break b}if(!Kb(a,c)){break b}Gu(a,b,c)}f=Uc(v[b>>2],v[b+4>>2])>>>0>=c>>>0}cb=d+16|0;return f|0}S(a|0);L()}function oL(a,b){var c=0,d=0,e=0,f=0;a:{if(x[a+480188>>1]<=b>>>0){break a}b:{c:{c=B(b,872)+a|0;d=w[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(w[a+480209|0]&16)){break a}}e=a+1074376|0;f=(d|0)==32;c=t[c+1075785|0];d:{if((c|0)>=0){d=we(a+901692|0,w[(B(b,872)+a|0)+1075836|0]);break d}d=we(a+902204|0,c&127)}JM(a,e,b,f,d,c&255,0)}}function OH(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{b:{c:{if(b-513>>>0<=4294966814){b=aa(8)|0;v[22440]=0;c=Q(56,c|0,9392)|0;a=v[22440];v[22440]=0;if((a|0)==1){break c}oc(b,c);v[22440]=0;U(121,b|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;rb(c);break b}v[v[a+32>>2]+1074420>>2]=B(b,1e4);cb=c+16|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function E5(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;a:{b:{if((b|0)!=1){a=v[a+20>>2];if(!a){break b}return le(a)|0}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,12211,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();return 0}return le(21685)|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function Ah(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-32|0;cb=c;a:{if(!w[b+4|0]){while(1){if((d|0)==4){d=0;v[c+28>>2]=0;e=$b(c+8|0,c+28|0,4);Yb(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=4){break b}if(Mb(c+28|0,b,4)){break b}Ob(a,4);d=1}cb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}ca(17496,9108,413,13190);L()}ca(17475,9108,411,13190);L()}return d|0}function oR(a,b){var c=0,d=0,e=0;c=cb-32|0;cb=c;a:{if(!w[b+5|0]){while(1){if((d|0)==5){d=0;t[c+28|0]=0;v[c+24>>2]=0;e=$b(c+8|0,c+24|0,5);Yb(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=5){break b}if(Mb(c+24|0,b,5)){break b}Ob(a,5);d=1}cb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}ca(17496,9108,413,13190);L()}ca(17475,9108,411,13190);L()}return d}function Uja(a,b){a=a|0;b=b|0;var c=0,d=0;d=cb-16|0;cb=d;c=d+8|0;lu(c,a,b);Ef(b,w[c|0],w[Ec(c)|0]);a=w[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=w[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48){break a}t[b+3|0]=45;t[b+5|0]=a&15;break a}if((a|0)!=64){break a}t[b+3|0]=0;t[b|0]=254;break a}t[b+3|0]=20;t[b+5|0]=a&15|160;break a}t[b+3|0]=0}cb=d+16|0}function nja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,15);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0}}function Maa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[a>>2]=b;c=cb-16|0;cb=c;d=lc(223888);v[22440]=0;b=Q(826,d|0,b+1074376|0)|0;e=v[22440];v[22440]=0;a:{if((e|0)!=1){b=v[Sf(c+8|0,b)>>2];cb=c+16|0;break a}a=P()|0;O()|0;zb(d);S(a|0);L()}v[a+4>>2]=b;b=Rb(a+8|0);v[22440]=0;Z(601,a|0);c=v[22440];v[22440]=0;if((c|0)!=1){return a|0}c=P()|0;O()|0;de(b);AM(a+4|0);S(c|0);L()}function eha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,14);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0}}function En(a,b,c,d){a:{if(v[a+480180>>2]==4){if(c){t[b+810|0]=w[b+810|0]&15|c<<4;break a}c=w[b+810|0]>>>4|0;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]+((c&255)<<2)|0;v[b+688>>2]=(c|0)<256?c:256;if(!(t[a+480180|0]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function jV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-16|0;cb=d;v[a>>2]=0;v[a+4>>2]=0;if(!Kb(b,c)){c=_e(b)}v[a>>2]=c;c=v[b>>2];a:{if(gb[v[v[c>>2]+16>>2]](c)|0){c=a;a=v[b>>2];e=c,f=(gb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0,v[e+4>>2]=f;break a}Si(a+8|0,v[a>>2]);c=v[a+8>>2];a=v[a+12>>2];if(hc(c,a)){break a}qe(d+8|0,c,a);Yb(d,b,v[d+8>>2],v[d+12>>2])}cb=d+16|0}function PH(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){b=aa(8)|0;v[22440]=0;c=Q(56,c|0,5851)|0;a=v[22440];v[22440]=0;if((a|0)==1){break c}oc(b,c);v[22440]=0;U(121,b|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;rb(c);break b}v[v[a+32>>2]+1074416>>2]=b;cb=c+16|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function JH(a,b){a=a|0;b=+b;var c=0,d=0;c=cb-16|0;cb=c;a:{b:{c:{if(b<0|b>1){a=aa(8)|0;v[22440]=0;c=Q(56,c|0,11788)|0;d=v[22440];v[22440]=0;if((d|0)==1){break c}oc(a,c);v[22440]=0;U(121,a|0,58712,975);a=v[22440];v[22440]=0;if((a|0)!=1){break a}d=P()|0;O()|0;rb(c);break b}d=Le(b*256);v[v[a+32>>2]+1074456>>2]=d;cb=c+16|0;return}d=P()|0;O()|0;ba(a|0)}S(d|0)}L()}function HC(a){var b=0,c=0,d=0,e=0;a:{b:{if(Mb(a,11122,2)){if(Mb(a,13860,2)){break a}if(w[a+110|0]<=64){break b}break a}if(w[a+110|0]>64){break a}}if(t[a+112|0]<0|w[a+111|0]>128){break a}while(1){if((b|0)==128){return 1}c=a+b|0;d=t[c+113|0];if((d|0)<-2){break a}e=w[c+241|0];if(!e&(d|0)>=0|e>>>0>15){break a}b=b+1|0;if(w[c+369|0]<64){continue}break}}return 0}function BF(a,b,c,d){var e=0,f=0,g=0;e=cb-16|0;cb=e;a:{if((a|0)!=(b|0)){g=v[114922];v[114922]=0;pd();d=IF(a,e+12|0,d);a=fb;f=v[114922];b:{if(f){if(v[e+12>>2]!=(b|0)){break b}if((f|0)!=68){break a}v[c>>2]=4;a=!!d&(a|0)>=0|(a|0)>0;d=a?-1:0;a=a?2147483647:-2147483648;break a}v[114922]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;d=0;a=0}cb=e+16|0;fb=a;return d}function _M(a,b,c,d){var e=0,f=0,g=0;e=cb-16|0;cb=e;f=!d|y[c+20>>2]<2?f:v[b+480180>>2]==1;g=v[c+52>>2];d=!g|d;t[e+15|0]=d;a:{if(!d|v[b+480180>>2]!=2){break a}b=x[b+480188>>1];d=0;while(1){if((b|0)==(d|0)){break a}v[(B(d,872)+c|0)+1380>>2]=0;d=d+1|0;continue}}v[c+24>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+48>>2]=g;u[c+72>>1]=x[c+74>>1];ae(a,f,e+15|0);cb=e+16|0}function nt(a,b){var c=0,d=0;if(a-268435457>>>0>=4026531840){a=a+208|0;kka(b,0,a,0);a=fb?0:B(a,b)}else{a=0}a:{if(!a){break a}v[22440]=0;b=T(773,a|0)|0;c=v[22440];v[22440]=0;b:{c:{if((c|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;X(18);c=v[22440];v[22440]=0;b=0;if((c|0)==1){break c}}break b}V(0)|0;O()|0;Lb();L()}if(!b){break a}d=Hb(b,0,a)- -64|0}return d}function E7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=vi(a,b,c,d);v[a>>2]=45248;c=Rb(a+4256|0);d=a+4224|0;v[d>>2]=1017370378;v[d+4>>2]=1065353216;d=a+4216|0;v[d>>2]=1028670828;v[d+4>>2]=1059760811;v[a+4208>>2]=1056964608;v[a+4212>>2]=1017370378;v[22440]=0;R(922,a+44|0,2);d=v[22440];v[22440]=0;if((d|0)!=1){ui(b);return a|0}a=P()|0;O()|0;fc(c);vf(b);S(a|0);L()}function h4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22440]=0;Z(971,a|0);f=v[22440];v[22440]=0;if((f|0)!=1){return ix(v[a+24>>2],b,c,d,e)|0}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,12454,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function $B(a){var b=0,c=0,d=0,e=0,f=0;b=a+9|0;d=w[b|0]|w[b+1|0]<<8;c=kka(w[a+3|0],0,18,0);d=d+c|0;b=fb;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;b=a+6|0;c=w[b|0]|w[b+1|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=a+4|0;a=w[a|0]|w[a+1|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;a=b>>>0<3?a+1|0:a;fb=a;return b}function kQ(a,b){var c=0,d=0,e=0;c=cb-32|0;cb=c;a:{if(!w[b+4|0]){while(1){if((d|0)==4){d=0;v[c+28>>2]=0;e=$b(c+8|0,c+28|0,4);cd(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=4){break b}if(Mb(c+28|0,b,4)){break b}Yc(a,4);d=1}cb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}ca(17496,9108,413,13190);L()}ca(17475,9108,411,13190);L()}return d}function Oo(a,b,c){var d=0,e=0,f=0;e=cb-16|0;cb=e;d=e+8|0;Jc(d,b);v[22440]=0;b=T(1160,d|0)|0;d=v[22440];v[22440]=0;a:{if((d|0)==1){break a}v[22440]=0;d=T(1169,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break a}v[c>>2]=d;v[22440]=0;R(1170,a|0,b|0);a=v[22440];v[22440]=0;if((a|0)==1){break a}Pb(e+8|0);cb=e+16|0;return}a=P()|0;O()|0;Pb(e+8|0);S(a|0);L()}function H$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=v[a+84>>2];f=v[e>>2];d=v[e+4>>2];h=v[a+28>>2];g=v[a+20>>2]-h|0;g=d>>>0<g>>>0?d:g;if(g){ic(f,h,g);f=g+v[e>>2]|0;v[e>>2]=f;d=v[e+4>>2]-g|0;v[e+4>>2]=d}d=c>>>0>d>>>0?d:c;if(d){ic(f,b,d);f=d+v[e>>2]|0;v[e>>2]=f;v[e+4>>2]=v[e+4>>2]-d}t[f|0]=0;b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;return c|0}function xK(a,b){var c=0,d=0,e=0,f=0,g=0,h=C(0);c=cb-16|0;cb=c;d=0;a:{if(!Gh(v[v[a>>2]-12>>2]+a|0)){break a}v[c+12>>2]=0;nk(a,c+12|0);e=v[c+12>>2];d=0;if(e>>>0>65535){break a}ak(b,e);while(1){if((f|0)==(e|0)){d=Gh(v[v[a>>2]-12>>2]+a|0)}else{v[c+8>>2]=0;gp(a,c+8|0);g=Ib(v[b>>2],f),h=z[c+8>>2],z[g>>2]=h;f=f+1|0;continue}break}}a=d;cb=c+16|0;return a}function laa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=cb-16|0;cb=b;u[a>>1]=0;c=Rb(a+4|0);d=Rb(a+16|0);v[a+36>>2]=0;e=Db(a+40|0);f=Jg(a+52|0);Ac(c);u[a+28>>1]=65472;v[22440]=0;v[b+12>>2]=1065353216;R(863,c|0,b+12|0);g=v[22440];v[22440]=0;if((g|0)!=1){v[a+32>>2]=0;u[a+30>>1]=0;Ac(d);cb=b+16|0;return a|0}a=P()|0;O()|0;zS(f);rb(e);fc(d);fc(c);S(a|0);L()}function hia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-16|0;cb=d;v[d+12>>2]=c;a:{e=Kb(b,c<<2);if(!e){break a}qc(d+12|0,65535);Ff(a,x[d+12>>1]);c=yb(v[a>>2]);v[d>>2]=c;a=yb(v[a+4>>2]);while(1){if(!Qb(c,a)){break a}f=d+8|0;if(!zo(b,f)){Bm(f)}u[c>>1]=w[d+8|0]|w[d+9|0]<<8|(w[d+10|0]<<16|w[d+11|0]<<24);Ne(d);c=v[d>>2];continue}}cb=d+16|0;return e|0}function Ro(a,b,c){var d=0,e=0,f=0;e=cb-16|0;cb=e;d=e+8|0;Jc(d,b);v[22440]=0;b=T(1142,d|0)|0;d=v[22440];v[22440]=0;a:{if((d|0)==1){break a}v[22440]=0;d=T(1155,b|0)|0;f=v[22440];v[22440]=0;if((f|0)==1){break a}t[c|0]=d;v[22440]=0;R(1156,a|0,b|0);a=v[22440];v[22440]=0;if((a|0)==1){break a}Pb(e+8|0);cb=e+16|0;return}a=P()|0;O()|0;Pb(e+8|0);S(a|0);L()}function H2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;a:{b:{if((cx(a)|0)!=1){break b}if((KI(a)|0)!=(b|0)){break b}d=a+120|0;oi(d);b=cb-16|0;cb=b;v[b+8>>2]=c+8;a=cb-16|0;cb=a;e=v[13455];v[a+8>>2]=v[13454];v[a+12>>2]=e;e=v[13453];v[a>>2]=v[13452];v[a+4>>2]=e;gb[v[Lh(a,bh(w[d+20|0]))>>2]](b+8|0,d);cb=a+16|0;cb=b+16|0;break a}JI(a,1,b)}cb=c+16|0}function wV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=cb-16|0;cb=d;c=-1;a:{if(!gg(a,7)){break a}c=0;if(!bC(a,11810)){break a}c=cb-16|0;cb=c;_B(c+8|0,d);e=v[c+12>>2];cd(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Yc(a,v[c+12>>2])}cb=c+16|0;e=(e|0)==(f|0);if(!e){ZB(d)}c=-1;if(!e){break a}c=0;if(!aC(d)){break a}c=ye(a,b,$B(d),fb)}cb=d+16|0;return c|0}function jja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=cb-32|0;cb=e;bB(e+8|0,c);v[22440]=0;R(366,e+20|0,d|0);c=v[22440];v[22440]=0;b:{c:{if((c|0)!=1){ci(e,e+8|0);v[22440]=0;W(116,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[22440];v[22440]=0;if((a|0)==1){break c}hf(e+8|0);cb=e+32|0;break a}a=P()|0;O()|0;rb(e+8|0);break b}a=P()|0;O()|0;hf(e+8|0)}S(a|0);L()}}function iy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=cb-16|0;cb=d;e=Oh(b,c);a:{if(e>>>0<=Qo(a)>>>0){f=c;g=v[a>>2];h=Uc(g,v[a+4>>2]);i=h>>>0>=e>>>0;if(!i){v[d+12>>2]=b;v[d+12>>2]=v[d+12>>2]+h;g=v[a>>2];f=v[d+12>>2]}b=Qi(b,f,g);if(!i){Qt(a,f,c,e-Uc(v[a>>2],v[a+4>>2])|0);break a}Nd(a,b);break a}eB(a);Gl(a,Ol(a,e));Qt(a,b,c,e)}cb=d+16|0}function c6(a){a=a|0;var b=0,c=0,d=0,e=0;b=cb-32|0;cb=b;a=Rb(a);v[22440]=0;Z(961,b+16|0);c=v[22440];v[22440]=0;a:{b:{if((c|0)!=1){c=yb(v[b+16>>2]);d=yb(v[b+20>>2]);e=v[ac(b+8|0,a)>>2];v[22440]=0;U(962,c|0,d|0,e|0);c=v[22440];v[22440]=0;if((c|0)==1){break b}fc(b+16|0);cb=b+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;fc(b+16|0)}ad(a);S(c|0);L()}function Zha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=cb-32|0;cb=e;bB(e+8|0,c);v[22440]=0;R(475,e+20|0,d|0);c=v[22440];v[22440]=0;b:{c:{if((c|0)!=1){ci(e,e+8|0);v[22440]=0;W(116,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[22440];v[22440]=0;if((a|0)==1){break c}hf(e+8|0);cb=e+32|0;break a}a=P()|0;O()|0;rb(e+8|0);break b}a=P()|0;O()|0;hf(e+8|0)}S(a|0);L()}}function Wja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=cb-32|0;cb=e;Xm(e+8|0,c);v[22440]=0;R(141,e+20|0,d|0);c=v[22440];v[22440]=0;b:{c:{if((c|0)!=1){ci(e,e+8|0);v[22440]=0;W(116,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[22440];v[22440]=0;if((a|0)==1){break c}hf(e+8|0);cb=e+32|0;break a}a=P()|0;O()|0;rb(e+8|0);break b}a=P()|0;O()|0;hf(e+8|0)}S(a|0);L()}}function Lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=cb-32|0;cb=e;US(e+8|0,c);v[22440]=0;R(115,e+20|0,d|0);c=v[22440];v[22440]=0;b:{c:{if((c|0)!=1){ci(e,e+8|0);v[22440]=0;W(116,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[22440];v[22440]=0;if((a|0)==1){break c}hf(e+8|0);cb=e+32|0;break a}a=P()|0;O()|0;rb(e+8|0);break b}a=P()|0;O()|0;hf(e+8|0)}S(a|0);L()}}function Kaa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[xb(a)>>2]){c=cb-16|0;cb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+32;mM(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;dc(c);cb=c+16|0;return}d=cb-32|0;cb=d;c=xb(a);c=gt(d+8|0,Qp(a,ag(v[a>>2],v[a+4>>2])+1|0),ag(v[a>>2],v[a+4>>2]),c);mM(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;Ad(a,c);oP(c);cb=d+32|0}function Fga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=cb-32|0;cb=e;Dh(e+8|0,c);v[22440]=0;R(591,e+20|0,d|0);c=v[22440];v[22440]=0;b:{c:{if((c|0)!=1){ci(e,e+8|0);v[22440]=0;W(303,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[22440];v[22440]=0;if((a|0)==1){break c}hf(e+8|0);cb=e+32|0;break a}a=P()|0;O()|0;rb(e+8|0);break b}a=P()|0;O()|0;hf(e+8|0)}S(a|0);L()}}function $ha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=cb-32|0;cb=e;Xm(e+8|0,c);v[22440]=0;R(115,e+20|0,d|0);c=v[22440];v[22440]=0;b:{c:{if((c|0)!=1){ci(e,e+8|0);v[22440]=0;W(116,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[22440];v[22440]=0;if((a|0)==1){break c}hf(e+8|0);cb=e+32|0;break a}a=P()|0;O()|0;rb(e+8|0);break b}a=P()|0;O()|0;hf(e+8|0)}S(a|0);L()}}function z3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22440]=0;Z(971,a|0);d=v[22440];v[22440]=0;if((d|0)!=1){v[a+16>>2]=0;v[a+12>>2]=c;v[a+8>>2]=b;return}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,13075,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function xu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=cb-32|0;cb=e;IB(e+8|0,c);v[22440]=0;R(115,e+20|0,d|0);c=v[22440];v[22440]=0;b:{c:{if((c|0)!=1){ci(e,e+8|0);v[22440]=0;W(116,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[22440];v[22440]=0;if((a|0)==1){break c}hf(e+8|0);cb=e+32|0;break a}a=P()|0;O()|0;rb(e+8|0);break b}a=P()|0;O()|0;hf(e+8|0)}S(a|0);L()}}function tV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=cb-32|0;cb=e;Iu(e+8|0,c);v[22440]=0;R(249,e+20|0,d|0);c=v[22440];v[22440]=0;b:{c:{if((c|0)!=1){ci(e,e+8|0);v[22440]=0;W(116,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[22440];v[22440]=0;if((a|0)==1){break c}hf(e+8|0);cb=e+32|0;break a}a=P()|0;O()|0;rb(e+8|0);break b}a=P()|0;O()|0;hf(e+8|0)}S(a|0);L()}}function rX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=cb-32|0;cb=e;Dh(e+8|0,c);v[22440]=0;R(115,e+20|0,d|0);c=v[22440];v[22440]=0;b:{c:{if((c|0)!=1){ci(e,e+8|0);v[22440]=0;W(116,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[22440];v[22440]=0;if((a|0)==1){break c}hf(e+8|0);cb=e+32|0;break a}a=P()|0;O()|0;rb(e+8|0);break b}a=P()|0;O()|0;hf(e+8|0)}S(a|0);L()}}function U2(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[xb(a)>>2]){c=cb-16|0;cb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+24;VI(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+24;dc(c);cb=c+16|0;return}d=cb-32|0;cb=d;c=xb(a);c=sE(d+8|0,vE(a,Ri(v[a>>2],v[a+4>>2])+1|0),Ri(v[a>>2],v[a+4>>2]),c);VI(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+24;rE(a,c);nE(c);cb=d+32|0}function Tj(a,b){a:{if((b|0)>=1024){a=a*8.98846567431158e307;if(b>>>0<2047){b=b-1023|0;break a}a=a*8.98846567431158e307;b=(b>>>0<3069?b:3069)-2046|0;break a}if((b|0)>-1023){break a}a=a*2.004168360008973e-292;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2.004168360008973e-292;b=(b>>>0>4294964336?b:-2960)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function IC(a,b){var c=0,d=0,e=0,f=0;c=cb-16|0;cb=c;a:{if(b>>>0<3){if(!b){break a}if(!Kb(a,b)){break a}while(1)if((d|0)==2){u[c+10>>1]=x[c+14>>1];a=c+10|0;d=w[a|0]|w[a+1|0]<<8;break a}else{t[c+13|0]=0;f=(c+14|0)+d|0;if(b>>>0>d>>>0){yg(a,c+13|0);e=w[c+13|0]}else{e=0}t[f|0]=e;d=d+1|0;continue}}ca(11259,9108,136,14288);L()}cb=c+16|0;return d&65535}function Hs(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=cb-16|0;cb=e;a:{if(!b){break a}ub(e+8|0,a+1074312|0,73);j=tb(v[v[e+8>>2]>>2],v[e+12>>2])?c- -64|0:c;c=120;h=lj(a);k=h^-1;f=1;while(1){if(!c){break a}l=c;c=c>>>1|0;i=f+c|0;g=ch(a,i,j,d);if(!(g>>>0>b>>>0&k)&(!(!g|h)|b>>>0<=g>>>0)){continue}f=i+1|0;c=(c^-1)+l|0;continue}}cb=e+16|0;return f}function Dn(a,b,c,d){a:{if(v[a+480180>>2]==4){d=w[b+810|0];if(c){t[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]-((c&255)<<2)|0;v[b+688>>2]=(c|0)>0?c:0;if(!(t[a+480180|0]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function Hv(a,b,c,d){t[a+53|0]=1;a:{if(v[a+4>>2]!=(c|0)){break a}t[a+52|0]=1;c=v[a+16>>2];b:{if(!c){v[a+36>>2]=1;v[a+24>>2]=d;v[a+16>>2]=b;if((d|0)!=1){break a}if(v[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=v[a+24>>2];if((c|0)==2){v[a+24>>2]=d;c=d}if(v[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}v[a+36>>2]=v[a+36>>2]+1}t[a+54|0]=1}}function Bu(a,b,c,d){var e=0,f=0;a:{e=w[a|0];f=w[c|0];b:{if(!(w[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){t[a|0]=(f|0)==5?7:6;break b}if(!(w[b|0]|((f|0)!=11|(e-5&255)>>>0>1))){t[a|0]=(e|0)==5?7:6;t[b|0]=w[d|0];break b}if(!((e|0)!=10|(f|0)!=20|w[d|0]!=159)){t[a|0]=42;break b}if(w[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}t[a|0]=42;t[b|0]=w[d|0]}t[c|0]=0}}function Hx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=cb-16|0;cb=e;d=cb-16|0;cb=d;i=x[b>>1];c=Kd(a);f=bc(a);g=cb-16|0;cb=g;while(1){if(c){h=EK(c+16|0,i);f=h?f:c;c=v[(h?4:0)+c>>2];continue}break}c=v[ac(g+8|0,f)>>2];cb=g+16|0;v[d+8>>2]=c;a:{if(Qb(c,cg(a))){if(!FK(x[b>>1],od(d+8|0))){break a}}c=cg(a)}cb=d+16|0;a=v[ac(e+8|0,c)>>2];cb=e+16|0;return a}function $H(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=gb[a|0](b)|0;d=fb;if((d|0)<0){break b}if((gb[c|0](b,0,0,0)|0)<0){break a}if((gb[c|0](b,0,0,2)|0)<0){break a}f=gb[a|0](b)|0;a=fb;gb[c|0](b,e,d,0)|0;if((a|0)<0){break b}g=Oy(f,a)}return g}gb[c|0](b,e,d,0)|0;return 0}function ifa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=cb-16|0;cb=d;c=d+11|0;FQ(a,c);if(Mb(c,13615,4)){a=1}else{FQ(a,d+11|0);t[b|0]=1;a=0}c=cb-16|0;cb=c;a:{b:{a=(d+11|0)+a|0;c:{if(!a){a=0;break c}b=Bc(c,a);v[22440]=0;a=T(673,b|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break b}rb(b)}cb=c+16|0;break a}a=P()|0;O()|0;rb(b);S(a|0);L()}cb=d+16|0;return a|0}function cJ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=cb-16|0;cb=g;f=vb(a);if(f>>>0>=b>>>0){e=Dc(a);a:{if(e-f>>>0>=d>>>0){if(!d){break a}e=Fb(a);i=e+b|0;h=f-b|0;if(h){b=b+e|0;Rh(b+d|0,b,h);c=(b>>>0<=c>>>0?f+e>>>0>c>>>0?d:0:0)+c|0}Rh(i,c,d);b=d+f|0;Bf(a,b);t[g+15|0]=0;$d(b+e|0,g+15|0);break a}Mo(a,e,(d+f|0)-e|0,f,b,0,d,c)}cb=g+16|0;return a}tk();L()}function Y2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Fb(c);c=vb(c);a:{e=vb(a);if(e>>>0>=b>>>0){d=Dc(a);if(c>>>0<=d-e>>>0){if(!c){break a}d=Fb(a);h=d+b|0;g=e-b|0;if(g){b=b+d|0;Rh(b+c|0,b,g);f=(b>>>0<=f>>>0?e+d>>>0>f>>>0?c:0:0)+f|0}Rh(h,f,c);b=c+e|0;Bf(a,b);kd(b+d|0,0);break a}cq(a,d,(c+e|0)-d|0,e,b,0,c,f);break a}tk();L()}return a|0}function JT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=cb-32|0;cb=d;e=Rb(a);a=yb(v[b>>2]);v[d+24>>2]=a;b=yb(v[b+4>>2]);a:{while(1){if(Qb(a,b)){Uh(d,a);if((tB(d)|0)==(c|0)){ho(d,a);v[22440]=0;R(363,e|0,d|0);a=v[22440];v[22440]=0;if((a|0)==1){break a}sb(d)}zm(d+24|0);a=v[d+24>>2];continue}break}cb=d+32|0;return}a=P()|0;O()|0;sb(d);Ic(e);S(a|0);L()}function xia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(y[a+4>>2]<y[xb(a)>>2]){d=cb-16|0;cb=d;a=uh(d,a,1);ZS(v[a+4>>2],x[b>>1],w[c|0]);v[a+4>>2]=v[a+4>>2]+4;dc(a);cb=d+16|0;return}e=cb-32|0;cb=e;d=xb(a);d=$f(e+8|0,Gg(a,pc(v[a>>2],v[a+4>>2])+1|0),pc(v[a>>2],v[a+4>>2]),d);ZS(v[d+8>>2],x[b>>1],w[c|0]);v[d+8>>2]=v[d+8>>2]+4;Ad(a,d);_f(d);cb=e+32|0}function jo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=yb(v[b>>2]);g=yb(v[b+4>>2]);e=cb-16|0;cb=e;v[e>>2]=c;v[e+8>>2]=d;while(1){a:{b:{if(Qb(d,g)){c=cb-16|0;cb=c;f=c+8|0;Uh(f,d);d=tB(f);cb=c+16|0;if(v[e>>2]!=(d|0)){break b}d=v[e+8>>2]}cb=e+16|0;c=d;break a}zm(e+8|0);d=v[e+8>>2];continue}break}if(hc(c,yb(v[b+4>>2]))){ai(a);return}ho(a,c)}function Bba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=cb-32|0;cb=d;sA(d+8|0,c);v[22440]=0;R(475,d+20|0,43324);c=v[22440];v[22440]=0;b:{c:{if((c|0)!=1){ci(d,d+8|0);v[22440]=0;W(116,a|0,b|0,v[d>>2],v[d+4>>2]);a=v[22440];v[22440]=0;if((a|0)==1){break c}hf(d+8|0);cb=d+32|0;break a}a=P()|0;O()|0;rb(d+8|0);break b}a=P()|0;O()|0;hf(d+8|0)}S(a|0);L()}}function rj(a){var b=0,c=0,d=0,e=0;b=v[a+4>>2];if(hc(v[a>>2],b)){a=0}else{b=uO(b);d=uO(v[a>>2]);c=cb-16|0;cb=c;v[c+8>>2]=b;while(1){a:{b:{if(Qb(b,d)){b=cb-16|0;cb=b;v[b+8>>2]=v[c+8>>2];e=tO(b+8|0);cb=b+16|0;if(x[v[e>>2]>>1]==65535){break b}b=v[c+8>>2]}cb=c+16|0;break a}tO(c+8|0);b=v[c+8>>2];continue}break}a=uB(yb(v[a>>2]),b)}return a&65535}function UQ(a){var b=0,c=0,d=0,e=0,f=0;b=a+28|0;e=w[b|0]|w[b+1|0]<<8;b=kka(w[a+30|0],0,37,0);c=fb;d=b;b=a+24|0;b=kka(w[b|0]|w[b+1|0]<<8,0,192,0);d=d+b|0;c=fb+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;a=w[a+26|0];c=a>>>26|0;e=d;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;a=b>>>0<192?a+1|0:a;fb=a;return b}function uI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;v[d+8>>2]=a;v[d+12>>2]=b;f=Wk(v[a+8>>2]);oi(f);e=cb-16|0;cb=e;v[e+8>>2]=d+8;c=cb-16|0;cb=c;g=v[13689];v[c+8>>2]=v[13688];v[c+12>>2]=g;g=v[13687];v[c>>2]=v[13686];v[c+4>>2]=g;gb[v[Lh(c,bh(w[f+20|0]))>>2]](e+8|0,f);cb=c+16|0;cb=e+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];cb=d+16|0}function tI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;v[d+8>>2]=a;v[d+12>>2]=b;f=Wk(v[a+8>>2]);oi(f);e=cb-16|0;cb=e;v[e+8>>2]=d+8;c=cb-16|0;cb=c;g=v[13693];v[c+8>>2]=v[13692];v[c+12>>2]=g;g=v[13691];v[c>>2]=v[13690];v[c+4>>2]=g;gb[v[Lh(c,bh(w[f+20|0]))>>2]](e+8|0,f);cb=c+16|0;cb=e+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];cb=d+16|0}function qI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;v[d+8>>2]=a;v[d+12>>2]=b;f=Wk(v[a+8>>2]);oi(f);e=cb-16|0;cb=e;v[e+8>>2]=d+8;c=cb-16|0;cb=c;g=v[13894];v[c+8>>2]=v[13893];v[c+12>>2]=g;g=v[13892];v[c>>2]=v[13891];v[c+4>>2]=g;gb[v[Lh(c,bh(w[f+20|0]))>>2]](e+8|0,f);cb=c+16|0;cb=e+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];cb=d+16|0}function pI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;v[d+8>>2]=a;v[d+12>>2]=b;f=Wk(v[a+8>>2]);oi(f);e=cb-16|0;cb=e;v[e+8>>2]=d+8;c=cb-16|0;cb=c;g=v[13898];v[c+8>>2]=v[13897];v[c+12>>2]=g;g=v[13896];v[c>>2]=v[13895];v[c+4>>2]=g;gb[v[Lh(c,bh(w[f+20|0]))>>2]](e+8|0,f);cb=c+16|0;cb=e+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];cb=d+16|0}function nI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;v[d+8>>2]=a;v[d+12>>2]=b;f=Wk(v[a+8>>2]);oi(f);e=cb-16|0;cb=e;v[e+8>>2]=d+8;c=cb-16|0;cb=c;g=v[14101];v[c+8>>2]=v[14100];v[c+12>>2]=g;g=v[14099];v[c>>2]=v[14098];v[c+4>>2]=g;gb[v[Lh(c,bh(w[f+20|0]))>>2]](e+8|0,f);cb=c+16|0;cb=e+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];cb=d+16|0}function mI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;v[d+8>>2]=a;v[d+12>>2]=b;f=Wk(v[a+8>>2]);oi(f);e=cb-16|0;cb=e;v[e+8>>2]=d+8;c=cb-16|0;cb=c;g=v[14105];v[c+8>>2]=v[14104];v[c+12>>2]=g;g=v[14103];v[c>>2]=v[14102];v[c+4>>2]=g;gb[v[Lh(c,bh(w[f+20|0]))>>2]](e+8|0,f);cb=c+16|0;cb=e+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];cb=d+16|0}function iI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;v[d+8>>2]=a;v[d+12>>2]=b;f=Wk(v[a+8>>2]);oi(f);e=cb-16|0;cb=e;v[e+8>>2]=d+8;c=cb-16|0;cb=c;g=v[14308];v[c+8>>2]=v[14307];v[c+12>>2]=g;g=v[14306];v[c>>2]=v[14305];v[c+4>>2]=g;gb[v[Lh(c,bh(w[f+20|0]))>>2]](e+8|0,f);cb=c+16|0;cb=e+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];cb=d+16|0}function hI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;v[d+8>>2]=a;v[d+12>>2]=b;f=Wk(v[a+8>>2]);oi(f);e=cb-16|0;cb=e;v[e+8>>2]=d+8;c=cb-16|0;cb=c;g=v[14312];v[c+8>>2]=v[14311];v[c+12>>2]=g;g=v[14310];v[c>>2]=v[14309];v[c+4>>2]=g;gb[v[Lh(c,bh(w[f+20|0]))>>2]](e+8|0,f);cb=c+16|0;cb=e+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];cb=d+16|0}function Z7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;c=vi(a,b,c,d);v[a>>2]=44992;d=Rb(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=1056964608;b=a+4228|0;t[b+4|0]=0;t[b+5|0]=4;t[b|0]=69;t[b+1|0]=99;t[b+2|0]=104;t[b+3|0]=111;t[b+6|0]=1;v[22440]=0;R(922,a+44|0,2);b=v[22440];v[22440]=0;if((b|0)!=1){ui(c);ps(a);return a|0}a=P()|0;O()|0;fc(d);vf(c);S(a|0);L()}function wja(a){a=a|0;var b=0,c=0,d=0;c=yd(a);v[22440]=0;Z(347,a|0);b=v[22440];v[22440]=0;if((b|0)==1){a=P()|0;O()|0;fc(c);S(a|0);L()}b=cb-16|0;cb=b;v[b>>2]=a;c=v[a+4>>2];v[b+4>>2]=c;v[b+8>>2]=c+32768;d=v[b+4>>2];c=v[b+8>>2];while(1){if((c|0)==(d|0)){dc(b);cb=b+16|0}else{u[d>>1]=0;u[d+2>>1]=0;d=d+4|0;v[b+4>>2]=d;continue}break}return a|0}function s3(a,b){a=a|0;b=b|0;var c=0;v[22440]=0;Z(971,a|0);c=v[22440];v[22440]=0;if((c|0)!=1){v[v[v[a+24>>2]+24>>2]+480272>>2]=b;return 1}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,5787,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function YX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=cb+-64|0;cb=e;d=1;a:{if(Wg(a,b,0)){break a}d=0;if(!b){break a}b=Ey(b,88012,88060);d=0;if(!b){break a}d=e+8|0;Hb(d|4,0,52);v[e+56>>2]=1;v[e+20>>2]=-1;v[e+16>>2]=a;v[e+8>>2]=b;gb[v[v[b>>2]+28>>2]](b,d,v[c>>2],1);a=v[e+32>>2];if((a|0)==1){v[c>>2]=v[e+24>>2]}d=(a|0)==1}cb=e- -64|0;return d|0}function Zy(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function y3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22440]=0;Z(971,a|0);d=v[22440];v[22440]=0;if((d|0)!=1){v[a+4>>2]=c;v[a>>2]=b?b:952;return}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,13105,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function pW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=cb-32|0;cb=e;f=v[b+16>>2];a:{if(f>>>0<=c>>>0){Ub(a,v[d>>2],0);break a}g=v[b+12>>2];b=v[b+4>>2];v[e+20>>2]=v[d+4>>2];v[e+16>>2]=f-c;Ub(e+24|0,v[d>>2],v[Bb(e+20|0,e+16|0)>>2]);d=v[v[b>>2]+28>>2];f=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=f;gb[d|0](a,b,c+g|0,e+8|0)}cb=e+32|0}function bG(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=cb-16|0;cb=b;e=b+16|0;a:{while(1){d=v[a+36>>2];c=b+8|0;f=gb[v[v[d>>2]+20>>2]](d,v[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=v[b+4>>2]-c|0;if((uk(g,1,c,v[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=fs(v[a+32>>2])?-1:0}cb=b+16|0;return d|0}function Kp(a,b){a=a|0;b=b|0;var c=0,d=0;d=cb-16|0;cb=d;t[d+15|0]=b;a:{b:{c:{d:{if(Ld(a)){c=Lj(a);b=v[a+4>>2];c=c-1|0;if((b|0)==(c|0)){break d}break b}c=10;b=w[a+11|0];if((b|0)!=10){break c}}fm(a,c,1,c,c,0,0);b=c;if(Ld(a)){break b}}c=a;Yd(a,b+1|0);break a}c=v[a>>2];td(a,b+1|0)}a=b+c|0;$d(a,d+15|0);t[d+14|0]=0;$d(a+1|0,d+14|0);cb=d+16|0}function KY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}f=1;g=cb-16|0;cb=g;k=gi(g+8|0,v[a+8>>2]);i=sr(0,c,d-c|0,b?b:463436);fi(k);cb=g+16|0;b:{switch(i+2|0){default:f=i;break;case 0:case 1:break a;case 2:break b}}h=h+1|0;j=f+j|0;c=c+f|0;continue}break}return j|0}function Hp(a){var b=0,c=0,d=0,e=0,f=0;c=cb-16|0;cb=c;d=yb(v[a>>2]);e=a;f=yb(v[a+4>>2]);a=cb-16|0;cb=a;v[a+8>>2]=d;while(1){if(Qb(d,f)){b=b+A[d>>3];Ys(a+8|0);d=v[a+8>>2];continue}break}cb=a+16|0;a=yb(v[e>>2]);v[c+8>>2]=a;b=-b;e=yb(v[e+4>>2]);while(1){if(Qb(a,e)){b=b+A[a>>3];A[a>>3]=b;Ys(c+8|0);a=v[c+8>>2];continue}else{cb=c+16|0}break}}function dF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=cb-16|0;cb=e;d=bc(a);i=v[b>>2];h=v[a>>2];d=v[d>>2]==1181;f=v[c>>2]-v[a>>2]|0;g=f<<1;f=f>>>0<2147483647?g?g:4:-1;g=Ir(d?0:h,f);if(g){if(!d){Vd(a)}v[e+4>>2]=1146;d=re(e+8|0,g,e+4|0);a=aF(a,d);Lc(d);v[b>>2]=v[a>>2]+(i-h|0);v[c>>2]=v[a>>2]+(f&-4);cb=e+16|0;return}cw();L()}function JR(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=cb-16|0;cb=d;e=Gt(b,c);a:{if(e>>>0<=vh(a)>>>0){f=c;g=v[a>>2];h=pc(g,v[a+4>>2]);i=h>>>0>=e>>>0;if(!i){v[d+12>>2]=b;v[d+12>>2]=v[d+12>>2]+(h<<2);g=v[a>>2];f=v[d+12>>2]}b=Qi(b,f,g);if(!i){bA(a,f,c,e-pc(v[a>>2],v[a+4>>2])|0);break a}Nd(a,b);break a}St(a);Em(a,Gg(a,e));bA(a,b,c,e)}cb=d+16|0}function tK(a){var b=0,c=0,d=0;c=cb-32|0;cb=c;a:{d=Dx(a);b=Oj(v[a>>2],v[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}v[22440]=0;b=da(926,c+8|0,b|0,b|0,xb(a)|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){Ad(a,b);qK(b);break b}a=V(0)|0;O()|0;_(a|0)|0;v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)==1){break a}}cb=c+32|0;return}V(0)|0;O()|0;Lb();L()}function sK(a){var b=0,c=0,d=0;c=cb-32|0;cb=c;a:{d=vh(a);b=pc(v[a>>2],v[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}v[22440]=0;b=da(927,c+8|0,b|0,b|0,xb(a)|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){Ad(a,b);_f(b);break b}a=V(0)|0;O()|0;_(a|0)|0;v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)==1){break a}}cb=c+32|0;return}V(0)|0;O()|0;Lb();L()}function ega(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=cb+-64|0;cb=c;b=-1;a:{if(!(gb[v[v[a>>2]+32>>2]](a,0,1084)|0)){break a}ql(a,1080);d=c+60|0;wR(a,d);e=d;d=vR(c+40|0);b=0;if(!uR(e,d)){break a}ql(a,20);b=1;while(1){if((b&65535)>>>0>=32){b=y[d+4>>2]>=f>>>0}else{e=c+8|0;tR(a,e);b=b+1|0;f=Xz(e)+f|0;continue}break}}cb=c- -64|0;return b|0}function bR(a){var b=0,c=0;a:{if(Mb(a,15543,4)){break a}b=a+8|0;if(((w[b|0]|w[b+1|0]<<8)-768&65535)>>>0<65280){break a}b=a+112|0;if(((w[b|0]|w[b+1|0]<<8)-65&65535)>>>0<65472){break a}b=a+106|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+122|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+124|0;c=(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return c}function F4(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){return y[v[v[a+24>>2]+24>>2]+1074420>>2]/1e4|0}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,9359,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function t4(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){return rj(Nb(v[v[a+24>>2]+24>>2]+484360|0))|0}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,6888,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function T1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{if(w[b+40|0]){break a}d=v[b+28>>2];if(!d){t[b+40|0]=1;break a}b:{e=v[c+4>>2];if(!e){break b}f=v[c>>2];while(1){d=gb[d|0](v[b+24>>2],f,e)|0;if(!d){t[b+40|0]=1;break b}g=d+g|0;h=g>>>0<d>>>0?h+1|0:h;e=e-d|0;if(!e){break b}f=d+f|0;d=v[b+28>>2];continue}}e=g}Ub(a,v[c>>2],e)}function PV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=cb-512|0;cb=d;c=cb-16|0;cb=c;f=d+8|0;FC(c+8|0,f);e=v[c+12>>2];cd(c,a,v[c+8>>2],e);g=v[c+4>>2];if((g|0)==(e|0)){Yc(a,v[c+12>>2])}cb=c+16|0;e=(e|0)==(g|0);if(!e){EC(f)}c=-1;a:{if(!e){break a}c=0;if(!HC(d+8|0)){break a}c=ye(a,b,GC(w[d+118|0],w[d+119|0]),fb)}cb=d+512|0;return c|0}function yia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=cb-16|0;cb=c;v[c+12>>2]=1;a:{if(vh(a)){d=v[a>>2];e=pc(d,v[a+4>>2]);v[c+8>>2]=e;f=v[Bb(c+12|0,c+8|0)>>2];while(1){if(f){u[d>>1]=x[b>>1];t[d+2|0]=w[b+2|0];f=f-1|0;d=d+4|0;continue}break}if(!e){aT(a,1-e|0,b);break a}Nd(a,v[a>>2]+4|0);break a}St(a);Em(a,Gg(a,1));aT(a,1,b)}cb=c+16|0}function v_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=cb-16|0;cb=e;d=bc(a);i=v[b>>2];h=v[a>>2];d=v[d>>2]==1181;f=v[c>>2]-v[a>>2]|0;g=f<<1;f=f>>>0<2147483647?g?g:1:-1;g=Ir(d?0:h,f);if(g){if(!d){Vd(a)}v[e+4>>2]=1146;d=re(e+8|0,g,e+4|0);a=aF(a,d);Lc(d);v[b>>2]=v[a>>2]+(i-h|0);v[c>>2]=f+v[a>>2];cb=e+16|0;return}cw();L()}function s4(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){return Xs(v[v[a+24>>2]+24>>2]+484344|0)|0}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,6956,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function SJ(a){a=a|0;var b=0,c=0;c=cb-16|0;cb=c;b=v[v[a+16>>2]+24620>>2]/5|0;b=yc(b,b>>31);v[a+4272>>2]=b;v[22440]=0;v[c+12>>2]=0;U(928,a+4256|0,b<<1,c+12|0);b=v[22440];v[22440]=0;a:{if((b|0)==1){b=V(88360)|0;if((O()|0)!=(fa(88360)|0)){break a}_(b|0)|0;v[a+4272>>2]=0;$()}v[a+4276>>2]=0;v[a+4268>>2]=0;cb=c+16|0;return}S(b|0);L()}function K1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;a:{if(!v[b+28>>2]){break a}if((gb[v[b+32>>2]](v[b+24>>2],c,0,0)|0)<0){break a}c=v[d+4>>2];if(!c){break a}e=v[d>>2];while(1){b:{f=gb[v[b+28>>2]](v[b+24>>2],e,c)|0;g=f+g|0;h=g>>>0<f>>>0?h+1|0:h;if(!f){break b}e=e+f|0;c=c-f|0;if(c){continue}}break}e=g}Ub(a,v[d>>2],e)}function G4(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){return v[v[v[a+24>>2]+24>>2]+1074416>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,12833,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function ed(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;pm(a);v[a+16>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0;v[a+4>>2]=0;u[a+32>>1]=64;v[a+24>>2]=8363;v[a+28>>2]=16777344;v[a+36>>2]=0;t[a+39|0]=0;t[a+40|0]=0;t[a+41|0]=0;t[a+42|0]=0;d=x[a+34>>1]&-25151;u[a+34>>1]=(b|0)==4?d|32:d;b=Bc(c,21685);pe(a+43|0,b);rb(b);Jz(a);cb=c+16|0}function K4(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){return x[v[v[a+24>>2]+24>>2]+1074448>>1]}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,8825,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function H4(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){return v[v[v[a+24>>2]+24>>2]+1074424>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,5322,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function gI(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=v[a>>2];a:{if(!b){break a}c=v[a+8>>2];if(!c){break a}d=v[a+12>>2];if(!d){break a}e=gb[d|0](b)|0;a=fb;f=a;if((a|0)<0){break a}a=0;b:{if((gb[c|0](b,0,0,0)|0)<0){break b}a=0;if((gb[c|0](b,0,0,2)|0)<0){break b}gb[d|0](b)|0;a=fb;a=(a|0)>0|(a|0)>=0}g=a;gb[c|0](b,e,f,0)|0}return g|0}function d4(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){return v[v[v[a+24>>2]+24>>2]+480272>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,5819,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function cN(a,b,c,d){var e=0,f=0,g=0,h=0;e=cb-16|0;cb=e;a:{b:{while(1){v[e+12>>2]=b;v[e+8>>2]=d;if(y[Bb(e+12|0,e+8|0)>>2]<=f>>>0){break b}g=Dp(t[Eb(a,f)|0]);h=Dp(t[Eb(c,f)|0]);if((g|0)!=(h|0)){a=g>>>0<h>>>0?-1:1;break a}f=f+1|0;if(g){continue}break}a=0;break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}cb=e+16|0;return a}function I4(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){return x[v[v[a+24>>2]+24>>2]+480214>>1]}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,7113,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function yba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=cb-32|0;cb=e;v[e+24>>2]=d;c=rf(a,c);ke(e+8|0,v[a+36>>2]);f=a;a:{if(!c){Cc(e+8|0,a+32|0,5);d=0;if(tb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}}d=v[a+36>>2];a=0;oC(b,v[e+24>>2]);while(1){if(y[e+24>>2]>a>>>0){kO(d,Xb(v[b>>2],a));a=a+1|0;continue}break}d=c}Se(f,d);cb=e+32|0}function s9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=cb-16|0;cb=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,52)+e;a=v[d>>2];a:{while(1){if(v[d+4>>2]==(a|0)){break a}v[22440]=0;R(902,a|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){a=v[d>>2]+52|0;v[d>>2]=a;continue}break}a=P()|0;O()|0;Gd(d);S(a|0);L()}Gd(d);cb=d+16|0}function Gw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=cb-240|0;cb=g;v[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-v[(i<<2)+d>>2]|0;if((gb[b|0](a,f)|0)>=0){if((gb[b|0](a,e)|0)>=0){break a}}j=f;f=(gb[b|0](f,e)|0)>=0;e=f?j:e;v[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}VG(g,h);cb=g+240|0}function z5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=cb-16|0;cb=f;v[f+8>>2]=d;d=v[bi(f,f+8|0)>>2];v[22440]=0;ea(966,a+8|0,b|0,c|0,d|0,e|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){SH(a);b=RH(a+88|0);c=QH(a+92|0);v[a>>2]=58488;v[b>>2]=58600;v[c>>2]=58680;Ae(f+8|0);cb=f+16|0;return a|0}a=P()|0;O()|0;Ae(f+8|0);S(a|0);L()}function pfa(a,b){a=a|0;b=b|0;var c=0;b=cb-32|0;cb=b;c=-1;a:{if(!hB(a,b+16|0)){break a}c=0;if(!HQ(b+16|0)){break a}c=-1;if(!Pj(a,b+8|0)){break a}a=b+8|4;c=0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}a=b+8|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=(a&2139062143)==(a|0)}a=c;cb=b+32|0;return a|0}function Tha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=Uc(e,v[a+4>>2]);if(d>>>0<b>>>0){e=cb-32|0;cb=e;b=b-d|0;d=v[xb(a)>>2];f=v[a+4>>2];a:{if(b>>>0<=d-f>>>0){Jm(a,b,c);break a}d=xb(a);d=Sl(e+8|0,Ol(a,Uc(v[a>>2],f)+b|0),Uc(v[a>>2],v[a+4>>2]),d);oS(d,b,c);Ad(a,d);Rl(d)}cb=e+32|0;return}if(b>>>0<d>>>0){Nd(a,b+e|0)}}function Lb(){var a=0;a=v[22437];v[22440]=0;X(a|0);a=v[22440];v[22440]=0;a:{if((a|0)!=1){v[22440]=0;X(1243);a=v[22440];v[22440]=0;if((a|0)!=1){break a}}a=V(0)|0;O()|0;_(a|0)|0;v[22440]=0;X(1243);a=v[22440];v[22440]=0;if((a|0)!=1){break a}V(0)|0;O()|0;v[22440]=0;X(18);a=v[22440];v[22440]=0;if((a|0)==1){V(0)|0;O()|0}Lb()}L()}function p4(a){a=a|0;var b=0,c=0,d=0;b=cb-32|0;cb=b;a:{b:{if(fj(a)){If(b+24|0);break b}c=b+8|0;sn(c,a);v[22440]=0;c=T(1030,c|0)|0;d=v[22440];v[22440]=0;if((d|0)==1){break a}v[b+24>>2]=c;Rf(b+8|0)}if(fj(a)){a=a+36|0}else{a=v[b+24>>2]}a=Ri(v[a>>2],v[a+4>>2]);Xk(b+24|0);cb=b+32|0;return a|0}a=P()|0;O()|0;Rf(b+8|0);S(a|0);L()}function l0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=v[a+44>>2];c=v[a+24>>2];if(e>>>0<c>>>0){v[a+44>>2]=c;e=c}f=v[a+8>>2];c=v[a+12>>2];d=-1;a:{if(f>>>0>=c>>>0){break a}if(hc(b,-1)){fn(a,f,c-1|0,e);return qw(b)|0}g=Vo(b);if(!(v[a+48>>2]&16)){d=-1;if(!hc(g,t[c-1|0])){break a}}fn(a,f,c-1|0,e);t[v[a+12>>2]]=g;d=b}return d|0}function Wia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=yd(a);a:{if(b){v[22440]=0;R(377,a|0,b|0);e=v[22440];v[22440]=0;if((e|0)==1){break a}e=cb-16|0;cb=e;d=Xh(e,a,b);b=v[d+4>>2];f=v[d+8>>2];while(1){if((b|0)==(f|0)){dc(d);cb=e+16|0}else{fo(b,c);b=b+2|0;v[d+4>>2]=b;continue}break}}return a|0}a=P()|0;O()|0;_c(d);S(a|0);L()}function xW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=cb-32|0;cb=f;v[f+28>>2]=c;v[f+24>>2]=b;v[f+20>>2]=d;v[f+16>>2]=e;v[22440]=0;W(175,f|0,f+24|0,f+20|0,f+16|0);b=v[22440];v[22440]=0;if((b|0)!=1){b=f+8|0;lv(b,v[f>>2],v[f+4>>2]);Wf(a,b);Md(b);Md(f);Md(f+24|0);cb=f+32|0;return}a=P()|0;O()|0;Md(f+24|0);S(a|0);L()}function Saa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=cb-32|0;cb=d;b=qf(d,b);v[22440]=0;U(823,d+16|0,b|0,c|0);e=v[22440];v[22440]=0;a:{b:{if((e|0)!=1){v[22440]=0;U(57,a|0,d+16|0,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}rb(d+16|0);rb(b);cb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;rb(d+16|0)}rb(b);S(c|0);L()}function f9(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[xb(a)>>2]){c=cb-16|0;cb=c;a=uh(c,a,1);bk(v[a+4>>2],z[b>>2]);v[a+4>>2]=v[a+4>>2]+4;dc(a);cb=c+16|0;return}d=cb-32|0;cb=d;c=xb(a);c=$f(d+8|0,Gg(a,pc(v[a>>2],v[a+4>>2])+1|0),pc(v[a>>2],v[a+4>>2]),c);bk(v[c+8>>2],z[b>>2]);v[c+8>>2]=v[c+8>>2]+4;Ad(a,c);_f(c);cb=d+32|0}function W7(a){a=a|0;var b=0,c=0,d=0,e=0;c=cb-16|0;cb=c;v[v[a+20>>2]+148>>2]=-1;mo(c+8|0,a+4228|0);d=v[a+20>>2];e=v[c+12>>2];b=v[c+8>>2];v[22440]=0;U(940,d+4|0,b|0,Eb(b,e)|0);b=v[22440];v[22440]=0;a:{if((b|0)==1){b=V(88360)|0;if((O()|0)!=(fa(88360)|0)){break a}_(b|0)|0;Ac(v[a+20>>2]+4|0);$()}cb=c+16|0;return}S(b|0);L()}function MJ(a){var b=C(0),c=0,d=C(0);b=z[a+4224>>2];z[a+4260>>2]=K(C(C(1)-C(b*b)));t[a+4264|0]=z[a+4236>>2]>C(.5);d=C(v[a+4256>>2]<<1>>>0);b=C(z[a+4228>>2]*d);a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}v[a+4248>>2]=c;c=a+4252|0;b=C(z[a+4232>>2]*d);b:{if(b<C(4294967296)&b>=C(0)){a=~~b>>>0;break b}a=0}v[c>>2]=a}function LB(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[xb(a)>>2]){c=cb-16|0;cb=c;a=Xh(c,a,1);Mi(v[a+4>>2],x[b>>1]);v[a+4>>2]=v[a+4>>2]+2;dc(a);cb=c+16|0;return}d=cb-32|0;cb=d;c=xb(a);c=Mj(d+8|0,Nj(a,Fc(v[a>>2],v[a+4>>2])+1|0),Fc(v[a>>2],v[a+4>>2]),c);Mi(v[c+8>>2],x[b>>1]);v[c+8>>2]=v[c+8>>2]+2;Ad(a,c);Pi(c);cb=d+32|0}function fe(a,b){var c=0,d=0,e=0,f=0;c=cb-16|0;cb=c;Rm(a);d=Sf(c+8|0,a);a:{a=v[116308];if(pc(a,v[116309])>>>0<=b>>>0){v[22440]=0;Z(1232,b+1|0);a=v[22440];v[22440]=0;if((a|0)==1){break a}a=v[116308]}a=v[Ib(a,b)>>2];if(a){Um(a)}a=Vd(d);e=Ib(v[116308],b),f=a,v[e>>2]=f;RE(d);cb=c+16|0;return}a=P()|0;O()|0;RE(d);S(a|0);L()}function SW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=cb-32|0;cb=d;b=qf(d,b);v[22440]=0;U(156,d+16|0,b|0,c|0);e=v[22440];v[22440]=0;a:{b:{if((e|0)!=1){v[22440]=0;U(4,a|0,d+16|0,c|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}rb(d+16|0);rb(b);cb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;rb(d+16|0)}rb(b);S(c|0);L()}function L4(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){return+BL(v[v[a+24>>2]+24>>2])}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,10168,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function dI(a){var b=0,c=0,d=0,e=0;b=cb-32|0;cb=b;if(!w[a+20|0]){while(1){if(!(gb[v[v[a>>2]+40>>2]](a)|0)){bI(a,65536);c=$b(b+16|0,Eb(v[a+4>>2],v[a+16>>2]),65536);d=v[v[a>>2]+44>>2];e=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=e;gb[d|0](b+24|0,a,b+8|0);v[a+16>>2]=v[a+16>>2]+v[b+28>>2];continue}break}t[a+20|0]=1}cb=b+32|0}function RX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Wg(a,v[b+8>>2],e)){Gv(b,c,d);return}a:{if(!Wg(a,v[b>>2],e)){break a}if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+20>>2]=c;v[b+32>>2]=d;v[b+40>>2]=v[b+40>>2]+1;if(!(v[b+36>>2]!=1|v[b+24>>2]!=2)){t[b+54|0]=1}v[b+44>>2]=4}}function Wga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=cb+-64|0;cb=e;c=cb-16|0;cb=c;f=e+8|0;TR(c+8|0,f);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;d=(d|0)==(g|0);if(!d){SR(f)}c=-1;a:{if(!d){break a}c=0;if(!VR(e+8|0)){break a}c=ye(a,b,UR(e+8|0),fb)}cb=e- -64|0;return c|0}function LV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=cb-48|0;cb=e;c=cb-16|0;cb=c;f=e+8|0;wC(c+8|0,f);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;d=(d|0)==(g|0);if(!d){vC(f)}c=-1;a:{if(!d){break a}c=0;if(!yC(e+8|0)){break a}c=ye(a,b,xC(w[e+43|0]),fb)}cb=e+48|0;return c|0}function uP(){var a=0,b=0;a=cb-240|0;cb=a;a:{b:{if(t[89920]&1){break b}if(!Xd(89920)){break b}v[22440]=0;X(41);b=v[22440];v[22440]=0;if((b|0)==1){break a}v[22440]=0;Z(42,a+120|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}ic(89800,ic(a,a+120|0,120),116);Wd(89920)}cb=a+240|0;return}a=P()|0;O()|0;nf(89920);S(a|0);L()}function fja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=cb-112|0;cb=e;c=cb-16|0;cb=c;f=e+8|0;GT(c+8|0,f);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;d=(d|0)==(g|0);if(!d){FT(f)}c=-1;a:{if(!d){break a}c=0;if(!IT(e+8|0)){break a}c=ye(a,b,HT(e+8|0),fb)}cb=e+112|0;return c|0}function Y9(a){a=a|0;var b=0,c=0;b=cb-32|0;cb=b;t[b+23|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+27|0]=0;t[b+28|0]=0;t[b+29|0]=0;t[b+30|0]=0;v[b+16>>2]=0;v[b+20>>2]=0;c=$b(b,b+16|0,15);Yb(b+8|0,a,v[c>>2],v[c+4>>2]);c=0;a:{if(v[b+12>>2]!=15){break a}if(Mb(b+16|0,8554,15)){break a}Ob(a,15);c=1}cb=b+32|0;return c|0}function Zga(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;v[c>>2]=v[a+8>>2];d=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,20)+d;a=v[c>>2];a:{while(1){if(v[c+4>>2]==(a|0)){break a}v[22440]=0;Z(234,a|0);a=v[22440];v[22440]=0;if((a|0)!=1){a=v[c>>2]+20|0;v[c>>2]=a;continue}break}a=P()|0;O()|0;Gd(c);S(a|0);L()}Gd(c);cb=c+16|0}function FM(a,b,c,d){var e=0,f=0;e=cb-16|0;cb=e;f=-2147483648;f=!c|!(t[c+15|0]&1)?f:v[c+8>>2];a:{b:{if(!(!d|!(w[d+34|0]&32))){f=x[d+28>>1];break b}if((f|0)==-2147483648){break a}}Mp(b,f,a);ub(e+8|0,a+1074312|0,10);if(!tb(v[v[e+8>>2]>>2],v[e+12>>2])|v[a+480208>>2]&16384){break a}v[b+88>>2]=v[b+88>>2]&-257}cb=e+16|0}function g4(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){return+A[v[a+24>>2]+16>>3]}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,7602,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function a4(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){return v[v[a+24>>2]+8>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,10899,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function Tx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=F(c,.999);h=c*3.141592653589793;i=Zs(b);while(1){if((e|0)!=32768){f=((e<<12^-1)&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=Bi(g)*Zs(K(d*d*-.0625+1)*b)/(i*g)}else{d=1}j=a,k=zz(c*d*32768),u[j>>1]=k;e=e+1|0;a=a+2|0;continue}break}}function Ph(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=cb-16|0;cb=f;a:{e=Oh(b,c);if(e>>>0<4294967280){b:{if(e>>>0<=10){Yd(a,e);d=a;break b}g=Kg(e)+1|0;d=lc(g);qd(a,d);cf(a,g);td(a,e)}while(1){if((b|0)!=(c|0)){$d(d,b);d=d+1|0;b=b+1|0;continue}break}t[f+15|0]=0;$d(d,f+15|0);cb=f+16|0;break a}Ye();L()}return a|0}function vr(a){var b=0;b=v[a+76>>2];a:{if(!((b|0)>=0&(!b|(b&-1073741825)!=((w[459692]?42:0)|0)))){b=v[a+4>>2];if((b|0)!=v[a+8>>2]){v[a+4>>2]=b+1;b=w[b|0];break a}b=lw(a);break a}b=v[a+76>>2];v[a+76>>2]=b?b:1073741823;b=v[a+4>>2];b:{if((b|0)!=v[a+8>>2]){v[a+4>>2]=b+1;b=w[b|0];break b}b=lw(a)}v[a+76>>2]=0}return b}function fm(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=cb-16|0;cb=h;i=-17;if(-17-b>>>0>=c>>>0){j=Fb(a);if(b>>>0<=2147483622){v[h+8>>2]=b<<1;v[h+12>>2]=b+c;i=Kg(v[Pc(h+12|0,h+8|0)>>2])+1|0}c=lc(i);if(e){Ce(c,j,e)}d=d-(e+f|0)|0;if(d){Ce((c+e|0)+g|0,(e+j|0)+f|0,d)}if((b|0)!=10){zb(j)}qd(a,c);cf(a,i);cb=h+16|0;return}Ye();L()}function c_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a:{if(!Ld(f)){v[a+8>>2]=v[f+8>>2];b=v[f+4>>2];v[a>>2]=v[f>>2];v[a+4>>2]=b;break a}d=v[f>>2];b:{c:{c=v[f+4>>2];d:{if(c>>>0<=1){b=a;Yd(a,c);break d}if(c>>>0>=1073741808){break c}e=Pl(c)+1|0;b=Ci(e);qd(a,b);cf(a,e);td(a,c)}ki(b,d,c+1|0);break b}Ye();L()}}}function VK(a){var b=0,c=0;a:{if(Mb(a,14279,4)){break a}b=a+4|0;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b|0)!=-1095062050&(b|0)!=-1346458146){break a}b=a+16|0;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!b){break a}a=a+8|0;c=(b+24|0)==(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}return c}function T6(a,b){a=a|0;b=b|0;var c=0,d=0;a=Db(a);c=vb(b);v[22440]=0;R(75,a|0,c|0);c=v[22440];v[22440]=0;if((c|0)!=1){a:{b:{while(1){if(vb(b)>>>0<=d>>>0){break b}c=t[rc(b,d)|0];v[22440]=0;R(52,a|0,sg(sg(c))|0);c=v[22440];v[22440]=0;if((c|0)!=1){d=d+1|0;continue}break}break a}return}}b=P()|0;O()|0;rb(a);S(b|0);L()}function Il(a,b,c,d,e){var f=0;a:{if(c>>>0>255){break a}b:{switch(d|0){case 1:return Dy((B(c,872)+b|0)+616|0,e);case 2:f=Dy((B(c,872)+b|0)+616|0,e);if((f+5&255)>>>0>5){break a}case 0:return qM(a,b,c,e);case 3:break b;default:break a}}f=qM(a,b,c,e);if((f+5&255)>>>0>5){break a}f=Dy((B(c,872)+b|0)+616|0,e)}return f}function wfa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[xb(a)>>2]){c=cb-16|0;cb=c;a=Lu(c,a,1);NQ(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+20;dc(a);cb=c+16|0;return}d=cb-32|0;cb=d;c=xb(a);c=ZA(d+8|0,_A(a,Df(v[a>>2],v[a+4>>2])+1|0),Df(v[a>>2],v[a+4>>2]),c);NQ(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+20;YA(a,c);Zt(c);cb=d+32|0}function w4(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){return $o(v[a+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,7081,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function u4(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){return cs(v[a+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,6790,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function r4(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){return bs(v[a+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,7440,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function naa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=cb-16|0;cb=b;d=a+1298300|0;if(!Bd(d)){a=v[a+24620>>2];c=cb-16|0;cb=c;e=lc(536);v[22440]=0;f=Q(858,e|0,a|0)|0;a=v[22440];v[22440]=0;a:{if((a|0)!=1){a=v[Sf(c+8|0,f)>>2];cb=c+16|0;break a}a=P()|0;O()|0;zb(e);S(a|0);L()}v[b+8>>2]=a;a=b+8|0;PL(d,Vd(a));Es(a)}cb=b+16|0}function _U(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=cb-1968|0;cb=e;c=cb-16|0;cb=c;f=e+8|0;FB(c+8|0,f);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;d=(d|0)==(g|0);if(!d){EB(f)}c=-1;a:{if(!d){break a}c=0;if(!GB(e+8|0)){break a}c=ye(a,b,1024,0)}cb=e+1968|0;return c|0}function I1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=cb-32|0;cb=f;v[f+28>>2]=e;v[f+24>>2]=d;_g(f+16|0,b,c);b=Wf(f+8|0,f+24|0);c=v[b+4>>2];b=v[b>>2];v[22440]=0;ea(171,a|0,v[f+16>>2],v[f+20>>2],b|0,c|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){Md(f+24|0);cb=f+32|0;return}a=P()|0;O()|0;Md(f+24|0);S(a|0);L()}function pB(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[xb(a)>>2]){c=cb-16|0;cb=c;a=eU(c,a,1);dU(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+48;dc(a);cb=c+16|0;return}d=cb-32|0;cb=d;c=xb(a);c=bU(d+8|0,cU(a,mq(v[a>>2],v[a+4>>2])+1|0),mq(v[a>>2],v[a+4>>2]),c);dU(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+48;aU(a,c);$T(c);cb=d+32|0}function ija(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[xb(a)>>2]){c=cb-16|0;cb=c;a=Lu(c,a,1);$A(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+20;dc(a);cb=c+16|0;return}d=cb-32|0;cb=d;c=xb(a);c=ZA(d+8|0,_A(a,Df(v[a>>2],v[a+4>>2])+1|0),Df(v[a>>2],v[a+4>>2]),c);$A(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+20;YA(a,c);Zt(c);cb=d+32|0}function by(a,b,c){var d=0,e=0,f=0;d=cb-16|0;cb=d;f=v[b+656>>2];e=0;a:{if(!f){break a}f=Qu(f,c);e=a+1074312|0;ub(d+8|0,e,31);a=0;if(!tb(v[v[d+8>>2]>>2],v[d+12>>2])){ub(d,e,93);a=tb(v[v[d>>2]>>2],v[d+4>>2])^1}if(!(t[kL(b,c)+6|0]&1)){e=0;if(!(t[f+12|0]&1)|a){break a}}e=hc(v[f>>2],v[f+4>>2])^1}cb=d+16|0;return e}function ZE(a,b,c,d,e){var f=0,g=0,h=0;f=cb-16|0;cb=f;g=1073741807;if(1073741807-b>>>0>=c>>>0){h=Fb(a);if(b>>>0<=536870886){v[f+8>>2]=b<<1;v[f+12>>2]=b+c;g=Pl(v[Pc(f+12|0,f+8|0)>>2])+1|0}c=Ci(g);if(e){ki(c,h,e)}d=d-e|0;if(d){e=e<<2;ki(e+c|0,e+h|0,d)}if((b|0)!=1){zb(h)}qd(a,c);cf(a,g);cb=f+16|0;return}Ye();L()}function Cba(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[xb(a)>>2]){c=cb-16|0;cb=c;a=sz(c,a,1);gz(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+32;dc(a);cb=c+16|0;return}d=cb-32|0;cb=d;c=xb(a);c=gt(d+8|0,Qp(a,ag(v[a>>2],v[a+4>>2])+1|0),ag(v[a>>2],v[a+4>>2]),c);gz(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;lO(a,c);fz(c);cb=d+32|0}function H_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=cb-32|0;cb=g;h=v[19983];v[g+24>>2]=v[19982];v[g+28>>2]=h;h=v[19981];v[g+16>>2]=v[19980];v[g+20>>2]=h;h=v[19979];v[g+8>>2]=v[19978];v[g+12>>2]=h;h=v[19977];v[g>>2]=v[19976];v[g+4>>2]=h;h=a;a=g+32|0;b=Vj(h,b,c,d,e,f,g,a);cb=a;return b|0}function Fea(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[xb(a)>>2]){c=cb-16|0;cb=c;a=zv(c,a);Dz(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;dc(a);cb=c+16|0;return}d=cb-32|0;cb=d;c=xb(a);c=Ll(d+8|0,Io(a,gd(v[a>>2],v[a+4>>2])+1|0),gd(v[a>>2],v[a+4>>2]),c);Dz(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;TP(a,c);SP(c);cb=d+32|0}function Mf(a,b,c,d){var e=0,f=0,g=0;a:{if(!vb(a)|(c-b|0)<5){break a}pr(b,c);e=c-4|0;c=Fb(a);g=c+vb(a)|0;b:{while(1){c:{a=t[c|0];f=a-127|0;if(b>>>0>=e>>>0){break c}if((a|0)!=v[b>>2]&(f&255)>>>0>=130){break b}b=b+4|0;c=((g-c|0)>1)+c|0;continue}break}if((f&255)>>>0<130|a>>>0>v[e>>2]-1>>>0){break a}}v[d>>2]=4}}function qf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(!Ld(b)){v[a+8>>2]=v[b+8>>2];c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a|0}e=v[b>>2];a:{b:{c=v[b+4>>2];c:{if(c>>>0<=10){b=a;Yd(a,c);break c}if(c>>>0>=4294967280){break b}d=Kg(c)+1|0;b=lc(d);qd(a,b);cf(a,d);td(a,c)}Ce(b,e,c+1|0);break a}Ye();L()}return a|0}function cW(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[xb(a)>>2]){c=cb-16|0;cb=c;a=sD(c,a);jv(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+36;dc(a);cb=c+16|0;return}d=cb-32|0;cb=d;c=xb(a);c=qD(d+8|0,rD(a,Nq(v[a>>2],v[a+4>>2])+1|0),Nq(v[a>>2],v[a+4>>2]),c);jv(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+36;pD(a,c);kv(c);cb=d+32|0}function Z9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb+-64|0;cb=d;dg(b);e=d+40|0;Ze(e,a,c);a=v[d+40>>2];ef(d+8|0,1,ce(e),a);v[22440]=0;W(225,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);a=v[22440];v[22440]=0;if((a|0)!=1){a=d+24|0;tc(b,a);rb(a);vc(d+40|0);cb=d- -64|0;break a}a=P()|0;O()|0;vc(d+40|0);S(a|0);L()}}function mK(a){a=a|0;var b=0,c=0;c=cb-16|0;cb=c;b=v[a+4232>>2];b=(b>>>1)+(b>>>6)|0;v[a+4220>>2]=b;v[22440]=0;v[c+12>>2]=0;U(928,a+4208|0,b<<1,c+12|0);b=v[22440];v[22440]=0;a:{if((b|0)==1){b=V(88360)|0;if((O()|0)!=(fa(88360)|0)){break a}_(b|0)|0;v[a+4220>>2]=0;$()}v[a+4224>>2]=0;cb=c+16|0;return}S(b|0);L()}function QU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;v[d+12>>2]=c;a:{if(!Kb(b,c<<1)){break a}qc(d+12|0,65535);Ff(a,x[d+12>>1]);c=yb(v[a>>2]);v[d>>2]=c;e=yb(v[a+4>>2]);while(1){if(!Qb(c,e)){break a}a=d+8|0;Du(b,a);f=c,g=wb(w[a|0]|w[a+1|0]<<8),u[f>>1]=g;Ne(d);c=v[d>>2];continue}}cb=d+16|0}function Hda(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[xb(a)>>2]){c=cb-16|0;cb=c;a=pz(c,a);UO(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+4;dc(a);cb=c+16|0;return}d=cb-32|0;cb=d;c=xb(a);c=$f(d+8|0,Gg(a,pc(v[a>>2],v[a+4>>2])+1|0),pc(v[a>>2],v[a+4>>2]),c);UO(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;Ad(a,c);_f(c);cb=d+32|0}function Eja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=cb-32|0;cb=e;c=cb-16|0;cb=c;f=e+8|0;SB(c+8|0,f);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;d=(d|0)==(g|0);if(!d){zu(f)}c=-1;a:{if(!d){break a}c=0;if(!RT(e+8|0)){break a}c=ye(a,b,72,0)}cb=e+32|0;return c|0}function Dia(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=cb+-64|0;cb=c;d=c+40|0;Ze(d,a,16);a=v[c+40>>2];ef(c+8|0,3,ce(d),a);v[22440]=0;W(225,c+24|0,v[c+8>>2],v[c+12>>2],w[c+16|0]);a=v[22440];v[22440]=0;if((a|0)!=1){$b(c,b,17);a=c+24|0;Kj(c,a);rb(a);vc(c+40|0);cb=c- -64|0;break a}a=P()|0;O()|0;vc(c+40|0);S(a|0);L()}}function u7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=vi(a,b,c,d);v[a+4224>>2]=1049951732;c=a+4216|0;v[c>>2]=1065353216;v[c+4>>2]=1049951732;v[a+4208>>2]=1060320051;v[a+4212>>2]=1041865114;v[a>>2]=45484;v[22440]=0;R(922,a+44|0,2);c=v[22440];v[22440]=0;if((c|0)!=1){ui(b);return a|0}a=P()|0;O()|0;vf(b);S(a|0);L()}function ss(a){var b=0,c=0,d=0;b=ni(+z[a+4228>>2]*8)*.25+-.25;A[a+4248>>3]=b;if(w[a+4240|0]){if(b>45e-5){c=jp(b)/.6931471805599453;b=c-H(c);d=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=ni(d+c)*.5}else{b=0}A[a+4248>>3]=b}rs(a)}function oB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=cb-32|0;cb=f;v[f+8>>2]=c;g=f,h=_e(b),v[g+28>>2]=h;c=f+8|0;Ze(c,b,v[Bb(c,f+28|0)>>2]);b=ce(c);v[22440]=0;ga(242,a|0,b|0,v[f+8>>2],d|0,e|0);a=v[22440];v[22440]=0;if((a|0)!=1){vc(f+8|0);cb=f+32|0;return}a=P()|0;O()|0;vc(f+8|0);S(a|0);L()}function _4(a){a=a|0;var b=0;v[22440]=0;Z(996,a|0);b=v[22440];v[22440]=0;a:{if((b|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,12010,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function TU(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=cb+-64|0;cb=c;d=c+40|0;Ze(d,a,44);a=v[c+40>>2];ef(c+8|0,2,ce(d),a);v[22440]=0;W(225,c+24|0,v[c+8>>2],v[c+12>>2],w[c+16|0]);a=v[22440];v[22440]=0;if((a|0)!=1){$b(c,b,44);a=c+24|0;Kj(c,a);rb(a);vc(c+40|0);cb=c- -64|0;break a}a=P()|0;O()|0;vc(c+40|0);S(a|0);L()}}function F5(a){a=a|0;var b=0;v[22440]=0;Z(971,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){return v[a+16>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[22440]=0;W(958,5693,a|0,0,0);a=v[22440];v[22440]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Lb();L()}function VU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,10);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0}return a|0}function Om(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{if(v[c>>2]|v[d>>2]){while(1){if((b|0)==(f|0)){break a}e=v[d>>2];g=v[c>>2];h=c,i=g-bd((bd(0-g|0,31)&255)+g|0,8)|0,v[h>>2]=i;h=d,i=v[d>>2]-bd(e+(bd(0-e|0,31)&255)|0,8)|0,v[h>>2]=i;e=(f<<3)+a|0;v[e>>2]=v[c>>2];v[e+4>>2]=v[d>>2];f=f+1|0;continue}}Hb(a,0,b<<3)}}function Lx(a,b,c){var d=0,e=0;d=cb-16|0;cb=d;v[d>>2]=a;a=v[a+4>>2];v[d+4>>2]=a;v[d+8>>2]=a+B(b,52);a=v[d+4>>2];b=v[d+8>>2];a:{while(1){if((a|0)==(b|0)){break a}v[22440]=0;R(902,a|0,c|0);e=v[22440];v[22440]=0;if((e|0)!=1){a=a+52|0;v[d+4>>2]=a;continue}break}a=P()|0;O()|0;dc(d);S(a|0);L()}dc(d);cb=d+16|0}function _k(a,b){a=a|0;b=b|0;var c=0;c=cb-32|0;cb=c;Cg(c,b);v[22440]=0;R(1075,c+16|0,c|0);b=v[22440];v[22440]=0;a:{b:{if((b|0)!=1){v[22440]=0;U(1076,a|0,0,c+16|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}Vc(c+16|0);rb(c);cb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Vc(c+16|0)}rb(c);S(b|0);L()}function YN(a,b){var c=0,d=0,e=0;c=yd(a);a:{if(b){v[22440]=0;R(788,a|0,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break a}d=cb-16|0;cb=d;c=ht(d,a,b);b=v[c+4>>2];e=v[c+8>>2];while(1){if((b|0)==(e|0)){dc(c);cb=d+16|0}else{lm(b,0,0);b=b+16|0;v[c+4>>2]=b;continue}break}}return a}a=P()|0;O()|0;ml(c);S(a|0);L()}function TN(a,b){var c=0,d=0,e=0,f=0;c=A[b+8>>3];a:{d=A[b>>3];if(kf(d)){if(d<0){c=ON(c)?c:1;break a}if(c!=0){if(ON(c)){break a}}lm(a,d,kf(c)?M:c);return}if(!Qh(d)|c!=0){break a}e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;return}d=qx(d);f=Bi(c);lm(a,d*We(c),f*d)}function T8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=cb-16|0;cb=d;Jc(a,b);v[22440]=0;U(68,d+8|0,b|0,c|0);e=v[22440];v[22440]=0;a:{if((e|0)==1){break a}Pb(d+8|0);b=v[b+24>>2];if(b){v[22440]=0;U(69,d|0,b|0,c|0);b=v[22440];v[22440]=0;if((b|0)==1){break a}Pb(d)}cb=d+16|0;return}b=P()|0;O()|0;Pb(a);S(b|0);L()}function Nk(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}t[a|0]=43;a=a+1|0}if(d&512){t[a|0]=35;a=a+1|0}while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}t[a|0]=b}function MY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;b=cb-16|0;cb=b;v[e>>2]=c;a=Nv(b+12|0,0,v[a+8>>2]);c=2;a:{if(a+1>>>0<2){break a}a=a-1|0;c=1;if(a>>>0>d-v[e>>2]>>>0){break a}c=b+12|0;while(1){if(a){d=w[c|0];f=v[e>>2];v[e>>2]=f+1;t[f|0]=d;a=a-1|0;c=c+1|0;continue}break}c=0}cb=b+16|0;return c|0}function Jy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=cb-16|0;cb=e;f=w[c+4|0];g=v[b+480180>>2];a:{if(g&64671904){b=w[(f&15)+43856|0];t[a+2|0]=0;u[a>>1]=b;break a}c=w[c+3|0];ub(e+8|0,b+1074312|0,66);h=a;a=(c|0)==4&(g|0)==4;b=f<<a<<4;ul(h,(i=tb(v[v[e+8>>2]>>2],v[e+12>>2])?0:b,j=b,k=d,k?i:j),a)}cb=e+16|0}function xba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-16|0;cb=d;c=rf(a,c);ke(d,v[a+36>>2]);a:{b:{if(!c){Cc(d,a+32|0,5);e=-1;if(!tb(v[v[d>>2]>>2],v[d+4>>2])){break b}break a}e=v[c+16>>2]}f=v[a+36>>2];c:{d:{switch(e+1|0){case 0:case 2:li(f,b);break c;default:break d}}wS(f,b,e)}f=c}Se(a,f);cb=d+16|0}function dia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb+-64|0;cb=d;e=d+40|0;Ze(e,a,c);a=v[d+40>>2];ef(d+8|0,2,ce(e),a);v[22440]=0;W(225,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);a=v[22440];v[22440]=0;if((a|0)!=1){a=d+24|0;Al(b,a);rb(a);vc(d+40|0);cb=d- -64|0;break a}a=P()|0;O()|0;vc(d+40|0);S(a|0);L()}}function W8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=vi(a,b,c,d);v[a>>2]=43948;d=Rb(a+4208|0);v[a+4228>>2]=0;v[a+4220>>2]=0;v[a+4224>>2]=0;v[a+4232>>2]=v[c+24620>>2];GU(a+4260|0,80,150,80,255);v[22440]=0;R(922,a+44|0,2);c=v[22440];v[22440]=0;if((c|0)!=1){ui(b);return a|0}a=P()|0;O()|0;fc(d);vf(b);S(a|0);L()}function FS(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=cb+-64|0;cb=c;d=c+40|0;Ze(d,a,32);a=v[c+40>>2];ef(c+8|0,2,ce(d),a);v[22440]=0;W(225,c+24|0,v[c+8>>2],v[c+12>>2],w[c+16|0]);a=v[22440];v[22440]=0;if((a|0)!=1){Im(c,b);a=c+24|0;Kj(c,a);rb(a);vc(c+40|0);cb=c- -64|0;break a}a=P()|0;O()|0;vc(c+40|0);S(a|0);L()}}function sU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb+-64|0;cb=d;e=d+40|0;Ze(e,a,c);a=v[d+40>>2];ef(d+8|0,2,ce(e),a);v[22440]=0;W(225,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);a=v[22440];v[22440]=0;if((a|0)!=1){a=d+24|0;uc(b,a);rb(a);vc(d+40|0);cb=d- -64|0;break a}a=P()|0;O()|0;vc(d+40|0);S(a|0);L()}}function W9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb+-64|0;cb=d;e=d+40|0;Ze(e,a,c);a=v[d+40>>2];ef(d+8|0,1,ce(e),a);v[22440]=0;W(225,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);a=v[22440];v[22440]=0;if((a|0)!=1){a=d+24|0;pe(b,a);rb(a);vc(d+40|0);cb=d- -64|0;break a}a=P()|0;O()|0;vc(d+40|0);S(a|0);L()}}function b6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=cb-16|0;cb=e;a:{if(!(c&1024)){break a}f=e,g=fd(b),v[f+8>>2]=g;b:{if(!vb(b)){break b}if(w[rc(b,0)|0]!=43){if(w[rc(b,0)|0]!=45){break b}}d=d+1|0;iJ(e+8|0)}if(vb(b)>>>0>=d>>>0){break a}eJ(b,v[kj(e,e+8|0)>>2],d-vb(b)|0,48)}zc(a,b);cb=e+16|0}function _p(a){var b=0,c=0;b=cb-32|0;cb=b;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[b>>2]=0;v[b+4>>2]=0;c=a+288|0;nz(c,c+512|0,b);v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[b>>2]=0;v[b+4>>2]=0;a=a+800|0;nz(a,HP(a),b);cb=b+32|0}function Sy(a,b,c,d,e,f){var g=0,h=0,i=0;g=cb-16|0;cb=g;h=-17;if(-17-b>>>0>=c>>>0){i=Fb(a);if(b>>>0<=2147483622){v[g+8>>2]=b<<1;v[g+12>>2]=b+c;h=Kg(v[Pc(g+12|0,g+8|0)>>2])+1|0}c=lc(h);if(e){Ce(c,i,e)}d=d-e|0;if(d){Ce((c+e|0)+f|0,e+i|0,d)}if((b|0)!=10){zb(i)}qd(a,c);cf(a,h);cb=g+16|0;return}Ye();L()}function RB(a,b,c){var d=0,e=0;d=cb+-64|0;cb=d;dg(b);e=d+40|0;Ze(e,a,c);a=v[d+40>>2];ef(d+8|0,3,ce(e),a);v[22440]=0;W(225,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);e=v[22440];v[22440]=0;if((e|0)!=1){e=b;b=d+24|0;tc(e,b);rb(b);vc(d+40|0);cb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;vc(d+40|0);S(a|0);L()}function KW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(d>>>0>=c>>>0){break a}a=a+4|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);if(a>>>0>c>>>0|a>>>0>c-d>>>0|!a){break a}e=1;a=a+d|0;if(Uc(v[b>>2],v[b+4>>2])>>>0>=a>>>0){break a}Si(b,a)}return e|0}function Hca(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:jl(a,0,c);return;case 1:jl(a,1,c);return;case 2:jl(a,2,c);return;case 3:jl(a,3,c);return;case 4:jl(a,4,c);return;case 5:jl(a,5,c);return;case 6:JO(a,23808,c);return;case 7:JO(a,24832,c);return;case 8:jl(a,6,c);return;default:break a}}Db(a)}function dja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=cb-224|0;cb=d;c=cb-16|0;cb=c;yT(c+8|0,d);e=v[c+12>>2];cd(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Yc(a,v[c+12>>2])}cb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!AT(d)){break a}c=ye(a,b,zT(w[d+216|0],w[d+217|0]),fb)}cb=d+224|0;return c|0}function vf(a){a=a|0;var b=0,c=0;v[a>>2]=44416;b=v[a+12>>2];if(v[b>>2]==(a|0)){v[b>>2]=v[a+4>>2]}b=v[a+20>>2];if(b){v[b>>2]=0;v[a+20>>2]=0}b=v[a+4>>2];if(b){v[b+8>>2]=v[a+8>>2]}c=v[a+8>>2];if(c){v[c+4>>2]=b}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+16>>2];v[b+946300>>2]=v[b+946300>>2]-1;gK(a+44|0);return a|0}function Nea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=cb+-64|0;cb=d;c=cb-16|0;cb=c;ku(c+8|0,d);e=v[c+12>>2];cd(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Yc(a,v[c+12>>2])}cb=c+16|0;e=(e|0)==(f|0);if(!e){bu(d)}c=-1;a:{if(!e){break a}c=0;if(!ZP(d)){break a}c=ye(a,b,YP(d),fb)}cb=d- -64|0;return c|0}function tia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=cb-576|0;cb=d;c=cb-16|0;cb=c;QS(c+8|0,d);e=v[c+12>>2];cd(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Yc(a,v[c+12>>2])}cb=c+16|0;e=(e|0)==(f|0);if(!e){PS(d)}c=-1;a:{if(!e){break a}c=0;if(!SS(d)){break a}c=ye(a,b,RS(d),fb)}cb=d+576|0;return c|0}function mia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=cb-192|0;cb=d;c=cb-16|0;cb=c;rq(c+8|0,d);e=v[c+12>>2];cd(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Yc(a,v[c+12>>2])}cb=c+16|0;e=(e|0)==(f|0);if(!e){KS(d)}c=-1;a:{if(!e){break a}c=0;if(!MS(d)){break a}c=ye(a,b,LS(d),fb)}cb=d+192|0;return c|0}function hK(a){a=a|0;var b=0,c=0,d=0;b=A[a+4264>>3]*+y[v[a+16>>2]+1074376>>2];a:{if(D(b)<0x8000000000000000){d=~~b>>>0;c=D(b)>=1?~~(b>0?F(H(b*2.3283064365386963e-10),4294967295):I((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break a}c=-2147483648}A[a+4256>>3]=b-(+(d>>>0)+ +(c|0)*4294967296)}function Zia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=cb-208|0;cb=d;c=cb-16|0;cb=c;qT(c+8|0,d);e=v[c+12>>2];cd(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Yc(a,v[c+12>>2])}cb=c+16|0;e=(e|0)==(f|0);if(!e){pT(d)}c=-1;a:{if(!e){break a}c=0;if(!sT(d)){break a}c=ye(a,b,rT(d),fb)}cb=d+208|0;return c|0}function Sia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=cb-240|0;cb=d;c=cb-16|0;cb=c;kT(c+8|0,d);e=v[c+12>>2];cd(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Yc(a,v[c+12>>2])}cb=c+16|0;e=(e|0)==(f|0);if(!e){jT(d)}c=-1;a:{if(!e){break a}c=0;if(!mT(d)){break a}c=ye(a,b,lT(d),fb)}cb=d+240|0;return c|0}function Jp(a,b,c){var d=0,e=0;a=Db(a);d=vb(b);v[22440]=0;R(49,a|0,d|0);d=v[22440];v[22440]=0;if((d|0)!=1){a:{while(1){if(vb(b)>>>0>e>>>0){d=v[(w[rc(b,e)|0]<<2)+c>>2];v[22440]=0;R(50,a|0,d|0);d=v[22440];v[22440]=0;if((d|0)==1){break a}e=e+1|0;continue}break}return}}b=P()|0;O()|0;Vc(a);S(b|0);L()}function Faa(a,b){a=a|0;b=b|0;var c=0,d=0;c=ic(a,b,614);a=0;while(1){d=B(a,872);wp((d+c|0)+616|0,(b+d|0)+616|0);a=a+1|0;if((a|0)!=256){continue}break}a=Gz(c+223848|0,b+223848|0);v[22440]=0;Q(827,c+223860|0,b+223860|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){return c|0}b=P()|0;O()|0;_b(a);S(b|0);L()}function $ea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=cb-608|0;cb=d;c=cb-16|0;cb=c;sQ(c+8|0,d);e=v[c+12>>2];cd(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Yc(a,v[c+12>>2])}cb=c+16|0;e=(e|0)==(f|0);if(!e){rQ(d)}c=-1;a:{if(!e){break a}c=0;if(!uQ(d)){break a}c=ye(a,b,tQ(d),fb)}cb=d+608|0;return c|0}function Uaa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=cb+-64|0;cb=c;d=c+40|0;Ze(d,a,32);a=v[c+40>>2];ef(c+8|0,1,ce(d),a);v[22440]=0;W(225,c+24|0,v[c+8>>2],v[c+12>>2],w[c+16|0]);a=v[22440];v[22440]=0;if((a|0)!=1){a=c+24|0;uc(b,a);rb(a);vc(c+40|0);cb=c- -64|0;break a}a=P()|0;O()|0;vc(c+40|0);S(a|0);L()}}function Iea(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=cb+-64|0;cb=c;d=c+40|0;Ze(d,a,31);a=v[c+40>>2];ef(c+8|0,2,ce(d),a);v[22440]=0;W(225,c+24|0,v[c+8>>2],v[c+12>>2],w[c+16|0]);a=v[22440];v[22440]=0;if((a|0)!=1){a=c+24|0;pe(b,a);rb(a);vc(c+40|0);cb=c- -64|0;break a}a=P()|0;O()|0;vc(c+40|0);S(a|0);L()}}function Rda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=cb-80|0;cb=d;c=cb-16|0;cb=c;lS(c+8|0,d);e=v[c+12>>2];cd(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Yc(a,v[c+12>>2])}cb=c+16|0;e=(e|0)==(f|0);if(!e){qA(d)}c=-1;a:{if(!e){break a}c=0;if(!$O(d)){break a}c=ye(a,b,ZO(d),fb)}cb=d+80|0;return c|0}function Kja(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=cb+-64|0;cb=c;d=c+40|0;Ze(d,a,8);a=v[c+40>>2];ef(c+8|0,3,ce(d),a);v[22440]=0;W(225,c+24|0,v[c+8>>2],v[c+12>>2],w[c+16|0]);a=v[22440];v[22440]=0;if((a|0)!=1){a=c+24|0;pe(b,a);rb(a);vc(c+40|0);cb=c- -64|0;break a}a=P()|0;O()|0;vc(c+40|0);S(a|0);L()}}function Daa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{if(Ed(w[b+24|0])){d=lM(a);c=qk(b);e=Af(b);v[22440]=0;U(830,a|0,c|0,e|0);c=v[22440];v[22440]=0;if((c|0)==1){break a}d=a;v[22440]=0;Q(829,a+12|0,b+12|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break a}t[a+24|0]=1}return}a=P()|0;O()|0;yM(d);S(a|0);L()}function tha(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;v[c+8>>2]=b;b=0;a:{if(pc(v[a>>2],v[a+4>>2])>>>0>511){break a}if(!Bd(c+8|0)){break a}d=c+8|0;b=v[d>>2];v[22440]=0;R(500,a|0,d|0);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;qg(c+8|0);S(a|0);L()}qg(c+8|0);cb=c+16|0;return b|0}function b3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=yd(a);a:{c=vj(v[b+4>>2],v[b+8>>2]);if(!c){break a}v[22440]=0;R(1077,a|0,c|0);d=v[22440];v[22440]=0;if((d|0)!=1){d=v[b+8>>2];b=v[b+4>>2];v[22440]=0;W(1078,a|0,b|0,d|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;_r(e);S(a|0);L()}}function _ia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;v[d+8>>2]=c;v[d+12>>2]=-1;if((c|0)!=-1){f=d,g=vb(a),v[f>>2]=g;e=v[Bb(d+12|0,d)>>2];v[d+4>>2]=e;a=zp(Fb(a),b,v[Bb(d+4|0,d+8|0)>>2]);a:{if(a){break a}a=-1;if(c>>>0>e>>>0){break a}a=c>>>0<e>>>0}cb=d+16|0;return a|0}tk();L()}function ZM(a,b,c){var d=0,e=0;d=cb-16|0;cb=d;e=v[b+48>>2]+1|0;v[b+52>>2]=e;a:{if(y[Sb(a+484344|0,x[b+70>>1])+12>>2]>e>>>0){break a}if(!c){u[b+74>>1]=x[b+72>>1]+1}v[b+52>>2]=0;ub(d+8|0,a+1074312|0,63);if(!tb(v[v[d+8>>2]>>2],v[d+12>>2])){break a}a=v[b+56>>2];v[b+56>>2]=0;v[b+52>>2]=a}cb=d+16|0}function Wfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=cb-128|0;cb=e;c=cb-16|0;cb=c;aR(c+8|0,e);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);f=v[c+4>>2];if((f|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;d=(d|0)==(f|0);if(!d){$Q(e)}c=-1;a:{if(!d){break a}c=0;if(!bR(e)){break a}c=ye(a,b,256,0)}cb=e+128|0;return c|0}function UB(a,b,c){var d=0,e=0;d=cb+-64|0;cb=d;e=d+40|0;Ze(e,a,c);a=v[d+40>>2];ef(d+8|0,3,ce(e),a);v[22440]=0;W(225,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);e=v[22440];v[22440]=0;if((e|0)!=1){e=b;b=d+24|0;uc(e,b);rb(b);vc(d+40|0);cb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;vc(d+40|0);S(a|0);L()}function gB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=cb-32|0;cb=e;v[e+8>>2]=c;f=e,g=_e(b),v[f+28>>2]=g;c=e+8|0;Ze(c,b,v[Bb(c,e+28|0)>>2]);b=ce(c);v[22440]=0;W(346,a|0,b|0,v[e+8>>2],d|0);a=v[22440];v[22440]=0;if((a|0)!=1){vc(e+8|0);cb=e+32|0;return}a=P()|0;O()|0;vc(e+8|0);S(a|0);L()}function aY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=cb-16|0;cb=d;a:{e=v[b>>2];if(OC(e)){if(!xd(c)){pJ(c,17800);e=v[b>>2]}b=v[b+4>>2];gb[v[v[b>>2]+24>>2]](d,b,e);v[22440]=0;Q(824,c|0,d|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break a}rb(d)}zc(a,c);cb=d+16|0;return}a=P()|0;O()|0;rb(d);S(a|0);L()}function VD(a){var b=0,c=0;a:{if(Mb(a,13386,8)){break a}b=a+8|0;if((w[b|0]|w[b+1|0]<<8)!=14){break a}b=a+12|0;if(!(w[b|0]|w[b+1|0]<<8)){break a}b=a+14|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))<=0){break a}a=a+18|0;c=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>23}return c}function Gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=cb-1120|0;cb=d;c=cb-16|0;cb=c;RQ(c+8|0,d+8|0);e=v[c+12>>2];cd(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Yc(a,v[c+12>>2])}cb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!TQ(d+8|0)){break a}c=ye(a,b,SQ(d+8|0),fb)}cb=d+1120|0;return c|0}function wK(a,b){var c=0,d=0,e=0,f=0,g=C(0);c=cb-16|0;cb=c;if(Gh(v[v[a>>2]-12>>2]+a|0)){u[c+14>>1]=0;bg(a,c+14|0);e=x[c+14>>1];ak(b,e);while(1){if((d|0)!=(e|0)){v[c+8>>2]=0;gp(a,c+8|0);f=Ib(v[b>>2],d),g=z[c+8>>2],z[f>>2]=g;d=d+1|0;continue}break}d=Gh(v[v[a>>2]-12>>2]+a|0)}cb=c+16|0;return d}function eT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;e=Jg(a);a=b+236|0;b=et(a);a:{while(1){if((a|0)!=(b|0)){d=x[a>>1];u[c+14>>1]=d;if(d){v[22440]=0;U(404,c|0,e|0,c+14|0);d=v[22440];v[22440]=0;if((d|0)==1){break a}}a=a+2|0;continue}break}cb=c+16|0;return}a=P()|0;O()|0;Ut(e);S(a|0);L()}function WI(a,b){var c=0;c=cb-32|0;cb=c;Cg(c,b);v[22440]=0;U(1081,c+16|0,0,c|0);b=v[22440];v[22440]=0;a:{b:{if((b|0)!=1){v[22440]=0;R(1082,a|0,c+16|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}Vc(c+16|0);rb(c);cb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Vc(c+16|0)}rb(c);S(b|0);L()}function FQ(a,b){var c=0,d=0;a:{c=cb+-64|0;cb=c;d=c+40|0;Ze(d,a,4);a=v[c+40>>2];ef(c+8|0,3,ce(d),a);v[22440]=0;W(225,c+24|0,v[c+8>>2],v[c+12>>2],w[c+16|0]);a=v[22440];v[22440]=0;if((a|0)!=1){$b(c,b,5);a=c+24|0;Kj(c,a);rb(a);vc(c+40|0);cb=c- -64|0;break a}a=P()|0;O()|0;vc(c+40|0);S(a|0);L()}}function uv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function mB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=v[a>>2];g=vk(e,v[a+4>>2]);while(1){a:{f=d&65535;if(f>>>0>=g>>>0){break a}if(!Vh(fg(e,f))){break a}d=d+1|0;continue}break}b:{if(c){c=65535;if(x[v[v[a+12>>2]+8>>2]+10>>1]<=(d&65535)>>>0){break b}}c=nh(a,d&65535,b)?d:-1}return c&65535}function ew(a,b,c,d){var e=0,f=0,g=0,h=0;e=cb-160|0;cb=e;v[e+60>>2]=b;v[e+20>>2]=b;v[e+24>>2]=-1;f=e+16|0;hi(f,0,0);WF(e,f,d,1);d=v[e+8>>2];f=v[e+12>>2];g=v[e>>2];h=v[e+4>>2];if(c){v[c>>2]=((v[e+20>>2]+v[e+136>>2]|0)-v[e+60>>2]|0)+b}v[a+8>>2]=d;v[a+12>>2]=f;v[a>>2]=g;v[a+4>>2]=h;cb=e+160|0}function KT(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function sy(a,b,c){var d=0;d=v[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=w[b+813|0];if(c){t[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}ck(a,b,b+700|0,c<<2,0)}}function Po(a,b){var c=0,d=0;c=cb-16|0;cb=c;d=c+8|0;Jc(d,a);v[22440]=0;a=T(1159,d|0)|0;d=v[22440];v[22440]=0;a:{b:{if((d|0)==1){break b}v[22440]=0;W(1171,a|0,79696,79722,b|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}Pb(c+8|0);cb=c+16|0;break a}a=P()|0;O()|0;Pb(c+8|0);S(a|0);L()}return b}function LJ(a){a=a|0;var b=0,c=0;c=cb-16|0;cb=c;b=v[a+4256>>2];v[a+4240>>2]=b<<1;v[22440]=0;v[c+12>>2]=0;U(928,a+4208|0,b<<2,c+12|0);b=v[22440];v[22440]=0;a:{if((b|0)==1){b=V(88360)|0;if((O()|0)!=(fa(88360)|0)){break a}_(b|0)|0;v[a+4240>>2]=0;$()}v[a+4244>>2]=0;cb=c+16|0;return}S(b|0);L()}function $g(a,b){var c=0,d=0,e=0,f=0;d=cb-16|0;cb=d;a:{if(!b){b=0;break a}c=b>>31;e=c+b^c;c=E(e);Tf(d,e,0,0,0,c+81|0);e=0+v[d+8>>2]|0;c=(v[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=v[d+4>>2];b=v[d>>2]}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=e;v[a+12>>2]=f;cb=d+16|0}function $C(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=v[a+92>>2];e=v[a+96>>2];if(d|e){while(1){if((c|0)==(g|0)){v[a+96>>2]=e;v[a+92>>2]=d}else{f=(g<<3)+b|0;h=v[f>>2];d=d-bd((bd(0-d|0,31)&255)+d|0,8)|0;v[f>>2]=h+d;h=v[f+4>>2];e=e-bd((bd(0-e|0,31)&255)+e|0,8)|0;v[f+4>>2]=h+e;g=g+1|0;continue}break}}}function rha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-16|0;cb=d;dg(b);v[d+12>>2]=0;a:{if(!nk(a,d+12|0)){break a}f=c;c=v[d+12>>2];if(f>>>0<c>>>0){break a}while(1){if((c|0)==(e|0)){e=1;break a}t[d+11|0]=0;if(Jh(a,d+11|0)){Kp(b,t[d+11|0]);e=e+1|0;continue}break}e=0}cb=d+16|0;return e|0}function hG(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=cb-16|0;cb=d;e=js(a);v[a+32>>2]=b;v[a>>2]=74812;b=d+8|0;yr(b,e);v[22440]=0;b=T(1138,b|0)|0;f=v[22440];v[22440]=0;if((f|0)!=1){Pb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=en(b),t[g+44|0]=h;cb=d+16|0;return}a=P()|0;O()|0;Pb(d+8|0);am(e);S(a|0);L()}function gG(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=cb-16|0;cb=d;e=AG(a);v[a+32>>2]=b;v[a>>2]=74980;b=d+8|0;yr(b,e);v[22440]=0;b=T(1139,b|0)|0;f=v[22440];v[22440]=0;if((f|0)!=1){Pb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=en(b),t[g+44|0]=h;cb=d+16|0;return}a=P()|0;O()|0;Pb(d+8|0);Uo(e);S(a|0);L()}function xQ(a){var b=0,c=0;a:{if(Mb(a,3868,4)|w[a+63|0]!=26){break a}b=w[a+65|0];if(w[a- -64|0]&3|(w[a+66|0]|(b|0)!=16&(b|0)!=1)){break a}b=a+78|0;if((w[b|0]|w[b+1|0]<<8)>>>0>127){break a}a=a+80|0;if((w[a|0]|w[a+1|0]<<8)>>>0>127){break a}a=gC(b,a)?a:b;c=(w[a|0]|w[a+1|0]<<8)!=0}return c}function eO(a){a=a|0;var b=0,c=0,d=0;b=cb-16|0;cb=b;if(w[a+534|0]){while(1){d=c&65535;if(d>>>0>=256){t[a+534|0]=0}else{pj(a,d,1);c=c+1|0;continue}break}}t[b+15|0]=0;_h(a+8|0,18,b+15|0);Ft(a+26|0,18,29306);t[b+14|0]=255;_h(a+62|0,256,b+14|0);fh(a,65535,261,1);fh(a,65535,260,0);cb=b+16|0}function bM(a,b,c){var d=0;d=v[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=w[b+814|0];if(c){t[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}ck(a,b,b+700|0,c,0)}}function Ez(a,b,c,d,e){var f=0;a:{if(!Sd(a)){break a}f=v[a>>2];if(f>>>0<=c>>>0|f-c>>>0<d>>>0){break a}pm(b);b=Sn(b,a);v[b+20>>2]=0;v[b>>2]=d;if(!Lg(b)){break a}if(v[a>>2]!=(d|0)){Kq(b+68|0)}ic(v[b+20>>2],v[a+20>>2]+c|0,d);v[b+8>>2]=e?d:0;v[b+4>>2]=0;u[b+34>>1]=x[b+34>>1]&65533|(e?2:0)}}function gm(a,b,c,d){var e=0,f=0;a:{f=v[(B(b,872)+a|0)+1075648>>2];if(!f){break a}if(!sj(w[f+31|0])){break a}e=w[f+34|0];if((e-1&255)>>>0>249){break a}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break a}gb[v[v[e>>2]+92>>2]](e,f,c,d,b);if(c>>>0>250){break a}u[(B(b,872)+a|0)+1075834>>1]=65535}}function c7(a,b,c){a=a|0;b=b|0;c=C(c);var d=C(0);if((b|0)<=6){c=Pd(c,C(0));a:{b:{switch(b-1|0){case 0:d=z[a+4212>>2];c=zf(c);if(d==c){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 3:break b;default:break a}}c=C(zf(C(c*C(4)))*C(.25))}z[((b<<2)+a|0)+4208>>2]=c;sx(a)}}function N7(a,b,c){a=a|0;b=b|0;c=C(c);var d=C(0);if((b|0)<=6){c=Pd(c,C(0));a:{b:{switch(b-3|0){case 0:d=z[a+4220>>2];c=zf(c);if(d==c){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 1:break b;default:break a}}c=C(zf(C(c*C(4)))*C(.25))}z[((b<<2)+a|0)+4208>>2]=c;sx(a)}}function aJ(a,b,c,d,e){var f=0;a:{if((e|0)==10){HJ(a,b,c,d);break a}f=d>>>0<e>>>0?1:B(e,e)>>>0>d>>>0?2:3;if((f|0)>(c-b|0)){v[a+4>>2]=61;v[a>>2]=c;break a}c=b+f|0;b=c;while(1){f=d&255;d=(f|0)/(e|0)|0;b=b-1|0;t[b|0]=w[(f-B(d,e)|0)+4898|0];if(d&255){continue}break}v[a+4>>2]=0;v[a>>2]=c}}function VC(a,b,c,d){var e=0,f=0,g=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;e=d;d=v[a+1068>>2];u[e+(d<<1)>>1]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;f=a,g=zd(x[v[a+1060>>2]+34>>1])+d|0,v[f+1068>>2]=g;v[a+1072>>2]=v[a+1072>>2]-1}function FU(a,b,c){var d=0,e=0;d=cb+-64|0;cb=d;dg(b);e=d+40|0;Ze(e,a,c);a=v[d+40>>2];ef(d+8|0,2,ce(e),a);v[22440]=0;W(225,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);a=v[22440];v[22440]=0;if((a|0)!=1){a=d+24|0;tc(b,a);rb(a);vc(d+40|0);cb=d- -64|0;return}a=P()|0;O()|0;vc(d+40|0);S(a|0);L()}function BK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-16|0;cb=d;v[d+12>>2]=b;a:{if(vh(a)>>>0>=b>>>0){f=v[a>>2];e=pc(f,v[a+4>>2]);v[d+8>>2]=e;AK(f,v[Bb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Jx(a,b-e|0,c);break a}Nd(a,v[a>>2]+(b<<2)|0);break a}St(a);Em(a,Gg(a,b));Jx(a,b,c)}cb=d+16|0}function B_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=cb-128|0;cb=c;v[c+12>>2]=c+116;d=a+8|0;a=c+16|0;gF(d,a,c+12|0,e,f,g);e=v[c+12>>2];d=cb-16|0;cb=d;v[d+8>>2]=b;while(1){if((a|0)!=(e|0)){oG(d+8|0,t[a|0]);a=a+1|0;continue}break}cb=d+16|0;cb=c+128|0;return v[d+8>>2]}function Aj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=yb(v[b>>2]);f=yb(v[b+4>>2]);d=cb-16|0;cb=d;v[d>>2]=c;v[d+8>>2]=e;while(1){a:{b:{if(Qb(e,f)){if(!fU(d,e)){break b}e=v[d+8>>2]}cb=d+16|0;c=e;break a}zm(d+8|0);e=v[d+8>>2];continue}break}if(hc(c,yb(v[b+4>>2]))){ai(a);return}ho(a,c)}function rr(a,b,c,d){var e=0,f=0;e=cb-160|0;cb=e;f=-1;v[e+148>>2]=b?b-1|0:0;a=b?a:e+158|0;v[e+144>>2]=a;e=Hb(e,0,144);v[e+76>>2]=-1;v[e+36>>2]=1141;v[e+80>>2]=-1;v[e+44>>2]=e+159;v[e+84>>2]=e+144;a:{if((b|0)<0){v[114922]=61;break a}t[a|0]=0;f=PG(e,c,d,1120,1121)}cb=e+160|0;return f}function Rg(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!w[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=v[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}if(!(d&255)){return c-a|0}while(1){d=w[c+1|0];b=c+1|0;c=b;if(d){continue}break}}return b-a|0}function xJ(a,b,c){t[a+12|0]=0;v[c>>2]=0;v[b>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;u[a+24>>1]=0;v[a+36>>2]=0;v[a+40>>2]=0;v[a+44>>2]=0;v[a+48>>2]=0;wJ(a+60|0);wJ(a+52|0);tp(a+49956|0);tp(a+58148|0);tp(a+66340|0);tp(a+74532|0);Hb(a+228|0,0,32768);Hb(a+32996|0,0,512);Hb(a+33508|0,0,16384)}function LS(a){var b=0,c=0,d=0,e=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+38|0;e=w[b|0]|w[b+1|0]<<8;b=a+36|0;a=a+34|0;c=w[a|0]|w[a+1|0]<<8;b=(w[b|0]|w[b+1|0]<<8)+c|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;fb=a;return b}function F2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+60|0;d=qs(c);v[a>>2]=74072;v[d>>2]=74092;v[a>>2]=74112;v[a+4>>2]=0;v[c>>2]=74132;e=c;c=a+8|0;un(e,c);v[a>>2]=74072;v[d>>2]=74092;v[22440]=0;Q(93,c|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;$k(d);S(a|0);L()}function ov(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=cb-16|0;cb=f;v[f+12>>2]=e;v[f+8>>2]=d;_g(f,b,c);v[22440]=0;U(173,a|0,v[f>>2],v[f+4>>2]);b=v[22440];v[22440]=0;if((b|0)!=1){v[a+8>>2]=0;b=f+8|0;Wf(a+12|0,b);Md(b);cb=f+16|0;return a|0}a=P()|0;O()|0;Md(f+8|0);S(a|0);L()}function lba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=yd(a);a:{d=Vg(v[b>>2],v[b+4>>2]);if(d){v[22440]=0;R(787,a|0,d|0);e=v[22440];v[22440]=0;if((e|0)==1){break a}c=cb-16|0;cb=c;e=v[b>>2];f=v[b+4>>2];b=Oq(c,a,d);Pt(e,f,b+4|0);dc(b);cb=c+16|0}return a|0}a=P()|0;O()|0;de(c);S(a|0);L()}function gba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-16|0;cb=d;v[d+12>>2]=b;a:{if(Qo(a)>>>0>=b>>>0){f=v[a>>2];e=Uc(f,v[a+4>>2]);v[d+8>>2]=e;_h(f,v[Bb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Jm(a,b-e|0,c);break a}Nd(a,v[a>>2]+b|0);break a}eB(a);Gl(a,Ol(a,b));Jm(a,b,c)}cb=d+16|0}function Xi(a,b,c,d){var e=0,f=0,g=0,h=0;e=cb-16|0;cb=e;v[e+12>>2]=d;g=gi(e+8|0,b);b=cb-16|0;cb=b;d=v[e+12>>2];v[b+12>>2]=d;v[b+8>>2]=d;f=-1;d=rr(0,0,c,d);a:{if((d|0)<0){break a}h=a;d=d+1|0;a=Hd(d);v[h>>2]=a;if(!a){break a}f=rr(a,d,c,v[b+12>>2])}cb=b+16|0;fi(g);cb=e+16|0;return f}function LO(a,b,c){a:{switch(b|0){case 0:kl(a,0,c);return;case 1:kl(a,1,c);return;case 2:kl(a,2,c);return;case 3:kl(a,3,c);return;case 4:kl(a,4,c);return;case 5:kl(a,5,c);return;case 6:KO(a,23808,c);return;case 7:KO(a,24832,c);return;case 8:kl(a,6,c);return;default:break a}}Db(a)}function zf(a){var b=C(0),c=0,d=0;c=(p(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return C(a*C(0))}a=(c|0)>=0?a:C(-a);b=C(C(C(a+C(8388608))+C(-8388608))-a);a:{if(b>C(.5)){a=C(C(a+b)+C(-1));break a}a=C(a+b);if(!(b<=C(-.5))){break a}a=C(a+C(1))}a=(c|0)>=0?a:C(-a)}return a}function i8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-32|0;cb=d;v[d+28>>2]=c;v[d+8>>2]=33;c=v[Bb(d+28|0,d+8|0)>>2];if(!Kb(a,c)){c=_e(a)}e=d+8|0;kA(e,b);f=$b(d+16|0,v[d+8>>2],c);Yb(d,a,v[f>>2],v[f+4>>2]);kA(e,b);Hb(v[d+8>>2]+c|0,0,33-c|0);Ob(a,v[d+28>>2]);cb=d+32|0;return c|0}function O8(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{d=v[a+20>>2];c=v[d+4>>2];if((Uc(c,v[d+8>>2])|0)!=8){break b}if(Mb(c,9585,4)){break b}b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);v[a+4260>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[a+4264>>2]=b;break a}Ax(a,b)}ts(a)}function Iga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=cb-16|0;cb=f;v[f+12>>2]=e;v[f+8>>2]=d;d=Wf(f,f+8|0);e=v[d+4>>2];d=v[d>>2];v[22440]=0;ea(584,a|0,b|0,c|0,d|0,e|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){Md(f+8|0);cb=f+16|0;return a|0}a=P()|0;O()|0;Md(f+8|0);S(a|0);L()}function A9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-16|0;cb=d;c=rf(a,c);ke(d,v[a+36>>2]);a:{b:{if(!c){Cc(d,a+32|0,5);e=-1;if(!tb(v[v[d>>2]>>2],v[d+4>>2])){break b}break a}e=v[c+16>>2]}f=v[a+36>>2];c:{if(!((e|0)!=4&(e|0)!=-1)){nk(f,b);break c}jH(f,b,e)}f=c}Se(a,f);cb=d+16|0}function zq(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=cb-16|0;cb=f;v[f+12>>2]=c;c=f+12|0;qc(c,256);qc(c,65535);h=x[f+12>>1];Ff(a,h);c=0;while(1){if((c|0)==(h|0)){cb=f+16|0}else{g=w[b+c|0];i=Oi(v[a>>2],v[a+4>>2],c),j=(d|0)==(g|0)?-1:(e|0)==(g|0)?-2:g,u[i>>1]=j;c=c+1|0;continue}break}}function cP(a,b){var c=0,d=0,e=0,f=0;c=cb-96|0;cb=c;kR(b,c,c+96|0);b=0;while(1){if((b|0)==12){v[a+104>>2]=0;v[a+96>>2]=!(v[a+88>>2]|v[a+92>>2]);v[a+100>>2]=0;cb=c+96|0}else{d=b<<3;e=d+a|0;f=c+d|0;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d&65535;b=b+1|0;continue}break}v[a+112>>2]=0}function WB(a,b,c){var d=0,e=0;d=cb+-64|0;cb=d;e=d+40|0;Ze(e,a,c);a=v[d+40>>2];ef(d+8|0,3,ce(e),a);v[22440]=0;W(225,d+24|0,v[d+8>>2],v[d+12>>2],w[d+16|0]);a=v[22440];v[22440]=0;if((a|0)!=1){a=d+24|0;Al(b,a);rb(a);vc(d+40|0);cb=d- -64|0;return}a=P()|0;O()|0;vc(d+40|0);S(a|0);L()}function Uq(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=cb-16|0;cb=f;v[f+12>>2]=e;v[f+8>>2]=d;d=Wf(f,f+8|0);e=v[d+4>>2];d=v[d>>2];v[22440]=0;ea(171,a|0,b|0,c|0,d|0,e|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){Md(f+8|0);cb=f+16|0;return a|0}a=P()|0;O()|0;Md(f+8|0);S(a|0);L()}function QT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=cb-16|0;cb=f;v[f+12>>2]=e;v[f+8>>2]=d;d=Wf(f,f+8|0);e=v[d+4>>2];d=v[d>>2];v[22440]=0;ea(342,a|0,b|0,c|0,d|0,e|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){Md(f+8|0);cb=f+16|0;return a|0}a=P()|0;O()|0;Md(f+8|0);S(a|0);L()}function D6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=vi(a,b,c,d);v[a+4272>>2]=1065353216;v[a>>2]=47104;v[a+4216>>2]=1056964608;v[a+4208>>2]=1056880300;v[a+4212>>2]=1050733080;v[22440]=0;R(922,a+44|0,2);c=v[22440];v[22440]=0;if((c|0)!=1){ui(b);return a|0}a=P()|0;O()|0;vf(b);S(a|0);L()}function eL(a,b){var c=0,d=0,e=0,f=0,g=0;c=cb-16|0;cb=c;se(c+8|0,b);b=cb-16|0;cb=b;f=v[c+8>>2];d=v[c+12>>2];e=vb(a);v[b+12>>2]=e;v[b+8>>2]=d;g=Bb(b+12|0,b+8|0);a=xv(Fb(a),f,v[g>>2]);a:{if(a){break a}a=-1;if(d>>>0>e>>>0){break a}a=d>>>0<e>>>0}cb=b+16|0;cb=c+16|0;return a>>>31|0}function UC(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;t[v[a+1068>>2]+d|0]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=v[a+1068>>2]+zd(x[v[a+1060>>2]+34>>1])|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function Ss(a,b){var c=0,d=0,e=0,f=0,g=0;c=cb-16|0;cb=c;se(c+8|0,b);b=cb-16|0;cb=b;f=v[c+8>>2];d=v[c+12>>2];e=vb(a);v[b+12>>2]=e;v[b+8>>2]=d;g=Bb(b+12|0,b+8|0);a=zp(Fb(a),f,v[g>>2]);a:{if(a){break a}a=-1;if(d>>>0>e>>>0){break a}a=d>>>0<e>>>0}cb=b+16|0;cb=c+16|0;return a>>>31|0}function NI(a,b,c){var d=0,e=0;while(1){a:{if((a|0)!=(b|0)){e=v[a>>2];d=Rg(e);b:{c:{if((vb(c)|0)==(d|0)){v[22440]=0;d=Y(372,c|0,e|0,d|0)|0;e=v[22440];v[22440]=0;if((e|0)==1){break c}d=!d}else{d=0}break b}V(0)|0;O()|0;Lb();L()}if(!d){break a}}else{a=b}return a}a=a+8|0;continue}}function LR(a,b,c,d){var e=0,f=0;e=cb-16|0;cb=e;v[e+12>>2]=a;a:{if(!(!c|b)){a=Le(+(B(a,d)>>>0)*.25*1e4);break a}if(!(!a|!b)){qc(e+12|0,10);a=B(w[v[e+12>>2]+26912|0],1e4);break a}f=+(a>>>0);if(a-1>>>0<=9){a=Le(733.8401379310345/f*1e4);break a}a=Le(f/.264*1e4)}cb=e+16|0;return a}function $e(a){var b=0,c=0;b=cb-32|0;cb=b;t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;AC(b+9|0);v[a>>2]=v[b>>2];c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;c=v[b+24>>2];v[a+20>>2]=v[b+20>>2];v[a+24>>2]=c;t[a+28|0]=w[b+28|0];cb=b+32|0}function tba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-16|0;cb=d;b=mP(d,a+8|0,b);a=v[b>>2];a:{while(1){if(v[b+4>>2]==(a|0)){break a}v[22440]=0;R(776,a|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){a=v[b>>2]+32|0;v[b>>2]=a;continue}break}a=P()|0;O()|0;Gd(b);S(a|0);L()}Gd(b);cb=d+16|0}function qba(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c:{d:{if(Ld(a)){c=Lj(a)-1|0;d=v[a+4>>2];if((c|0)==(d|0)){break d}break b}c=1;d=w[a+11|0];if((d|0)!=1){break c}}ZE(a,c,1,c,c);d=c;if(Ld(a)){break b}}c=a;Yd(a,d+1|0);break a}c=v[a>>2];td(a,d+1|0)}a=(d<<2)+c|0;qd(a,b);qd(a+4|0,0)}function cK(a){a=a|0;var b=0,c=0;c=cb-16|0;cb=c;b=v[v[a+16>>2]+1074404>>2];v[22440]=0;v[c+12>>2]=0;U(928,a+4208|0,B(b,254)|0,c+12|0);b=v[22440];v[22440]=0;a:{if((b|0)==1){b=V(88360)|0;if((O()|0)!=(fa(88360)|0)){break a}_(b|0)|0;$()}v[a+4220>>2]=0;cb=c+16|0;return}S(b|0);L()}function KI(a){var b=0,c=0,d=0,e=0;d=cb-16|0;cb=d;b=a+120|0;oi(b);c=cb-16|0;cb=c;v[c+8>>2]=d+8;a=cb-16|0;cb=a;e=v[13451];v[a+8>>2]=v[13450];v[a+12>>2]=e;e=v[13449];v[a>>2]=v[13448];v[a+4>>2]=e;b=gb[v[Lh(a,bh(w[b+20|0]))>>2]](c+8|0,b)|0;cb=a+16|0;cb=c+16|0;cb=d+16|0;return b}function yU(a,b){var c=0,d=0,e=0;d=cb-16|0;cb=d;v[d+12>>2]=b;c=cb-16|0;cb=c;v[c+12>>2]=153391689;v[c+8>>2]=2147483647;e=Bb(c+12|0,c+8|0);cb=c+16|0;c=b;b=v[e>>2];if(c>>>0<=b>>>0){a=wB(a);if(a>>>0<b>>>1>>>0){v[d+8>>2]=a<<1;b=v[Pc(d+8|0,d+12|0)>>2]}cb=d+16|0;return b}nd();L()}function gga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;b=mE(c,a,b);a=v[b+4>>2];d=v[b+8>>2];a:{while(1){if((a|0)==(d|0)){break a}v[22440]=0;Z(592,a|0);e=v[22440];v[22440]=0;if((e|0)!=1){a=a+24|0;v[b+4>>2]=a;continue}break}a=P()|0;O()|0;dc(b);S(a|0);L()}dc(b);cb=c+16|0}function fba(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c:{d:{if(Ld(a)){c=Lj(a)-1|0;d=v[a+4>>2];if((c|0)==(d|0)){break d}break b}c=10;d=w[a+11|0];if((d|0)!=10){break c}}Sy(a,c,1,c,c,0);d=c;if(Ld(a)){break b}}c=a;Yd(a,d+1|0);break a}c=v[a>>2];td(a,d+1|0)}a=c+d|0;kd(a,b);kd(a+1|0,0)}function Fda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-32|0;cb=d;v[d+28>>2]=c;v[d+8>>2]=4896;c=v[Bb(d+28|0,d+8|0)>>2];if(!Kb(a,c)){c=_e(a)}e=d+8|0;oA(e,b);f=$b(d+16|0,v[d+8>>2],c);Yb(d,a,v[f>>2],v[f+4>>2]);oA(e,b);Hb(v[d+8>>2]+c|0,0,4896-c|0);Ob(a,v[d+28>>2]);cb=d+32|0}function w6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=vi(a,b,c,d);c=a+4216|0;v[c>>2]=1051372203;v[c+4>>2]=0;v[a+4208>>2]=1065353216;v[a+4212>>2]=1065353216;v[a>>2]=47336;v[22440]=0;R(922,a+44|0,2);c=v[22440];v[22440]=0;if((c|0)!=1){ui(b);return a|0}a=P()|0;O()|0;vf(b);S(a|0);L()}function ln(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=nka(a,b,10,0);f=fb;e=kka(d,f,-10,-1)+a|0;c=c-1|0;t[c|0]=e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;t[c|0]=B(a,-10)+d|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function lC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;b=Lu(c,a,b);a=v[b+4>>2];d=v[b+8>>2];a:{while(1){if((a|0)==(d|0)){break a}v[22440]=0;Z(234,a|0);e=v[22440];v[22440]=0;if((e|0)!=1){a=a+20|0;v[b+4>>2]=a;continue}break}a=P()|0;O()|0;dc(b);S(a|0);L()}dc(b);cb=c+16|0}function cU(a,b){var c=0,d=0,e=0;d=cb-16|0;cb=d;v[d+12>>2]=b;c=cb-16|0;cb=c;v[c+12>>2]=89478485;v[c+8>>2]=2147483647;e=Bb(c+12|0,c+8|0);cb=c+16|0;c=b;b=v[e>>2];if(c>>>0<=b>>>0){a=_T(a);if(a>>>0<b>>>1>>>0){v[d+8>>2]=a<<1;b=v[Pc(d+8|0,d+12|0)>>2]}cb=d+16|0;return b}nd();L()}function RD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=cb-32|0;cb=e;f=v[b>>2];g=v[b+8>>2];_g(e+16|0,c,d);c=v[v[f>>2]+28>>2];d=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=d;gb[c|0](e+24|0,f,g,e+8|0);_g(a,v[e+24>>2],v[e+28>>2]);v[b+8>>2]=v[b+8>>2]+v[a+4>>2];cb=e+32|0}function KU(a,b){var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c}function aQ(a){var b=0,c=0,d=0,e=0;b=cb-16|0;cb=b;c=yb(v[a>>2]);v[b+8>>2]=c;e=yb(v[a+4>>2]);while(1){a:{d=Qb(c,e);if(!d){break a}a=x[c>>1];b:{if(!((a|0)!=255&(a|0)!=99)){u[c>>1]=65535;break b}if(a>>>0>63){break a}}Ne(b+8|0);c=v[b+8>>2];continue}break}cb=b+16|0;return d^1}function T2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;sn(c,a);if(v[b>>2]){Ac(b);a=v[b>>2];fr(b);zb(a);d=xb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];a=xb(c);d=xb(b),e=v[a>>2],v[d>>2]=e;v[a>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Rf(c);cb=c+16|0}function Nda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-32|0;cb=d;v[d+28>>2]=c;v[d+8>>2]=263;c=v[Bb(d+28|0,d+8|0)>>2];if(!Kb(a,c)){c=_e(a)}e=d+8|0;RO(e,b);f=$b(d+16|0,v[d+8>>2],c);Yb(d,a,v[f>>2],v[f+4>>2]);RO(e,b);Hb(v[d+8>>2]+c|0,0,263-c|0);Ob(a,v[d+28>>2]);cb=d+32|0}function G$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=t[b|0];g=t[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function Fia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-32|0;cb=d;v[d+28>>2]=c;v[d+8>>2]=102;c=v[Bb(d+28|0,d+8|0)>>2];if(!Kb(a,c)){c=_e(a)}e=d+8|0;bT(e,b);f=$b(d+16|0,v[d+8>>2],c);Yb(d,a,v[f>>2],v[f+4>>2]);bT(e,b);Hb(v[d+8>>2]+c|0,0,102-c|0);Ob(a,v[d+28>>2]);cb=d+32|0}function ne(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function f2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=cb-32|0;cb=d;v[d+24>>2]=c;a:{while(1){if((a|0)==(b|0)){break a}c=Bc(d+8|0,v[a>>2]);v[22440]=0;Q(1100,d+24|0,c|0)|0;e=v[22440];v[22440]=0;if((e|0)!=1){rb(c);a=a+4|0;continue}break}a=P()|0;O()|0;rb(c);S(a|0);L()}cb=d+32|0}function c1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a=Db(a);d=vb(b);e=vb(c);b=Fb(b);v[22440]=0;W(104,a|0,b|0,d|0,d+e|0);b=v[22440];v[22440]=0;a:{if((b|0)!=1){b=Fb(c);v[22440]=0;Y(105,a|0,b|0,e|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;rb(a);S(b|0);L()}}function DT(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=cb-16|0;cb=d;v[d+12>>2]=c;c=d+12|0;qc(c,256);qc(c,65535);f=x[d+12>>1];Ff(a,f);c=0;while(1){if((c|0)==(f|0)){cb=d+16|0}else{e=w[b+c|0];g=Oi(v[a>>2],v[a+4>>2],c),h=(e|0)==255?-1:(e|0)==254?-2:e,u[g>>1]=h;c=c+1|0;continue}break}}function CC(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=cb-16|0;cb=d;v[d+12>>2]=c;c=d+12|0;qc(c,128);qc(c,65535);f=x[d+12>>1];Ff(a,f);c=0;while(1){if((c|0)==(f|0)){cb=d+16|0}else{e=w[b+c|0];g=Oi(v[a>>2],v[a+4>>2],c),h=(e|0)==255?-1:(e|0)==254?-2:e,u[g>>1]=h;c=c+1|0;continue}break}}function h8(a){a=a|0;var b=0,c=0,d=0,e=0;b=cb-16|0;cb=b;v[b+12>>2]=a;v[b+8>>2]=4104;a=0;d=v[b+8>>2];a:{if(d>>>0<4096){break a}c=v[b+12>>2];e=c+7&-8;c=e-c|0;if(c>>>0>d-4096>>>0){break a}v[b+12>>2]=e;v[b+8>>2]=d-c;a=e}if(!a){ca(6056,9043,88,7360);L()}cb=b+16|0;return a|0}function bn(a,b){var c=0,d=0,e=0,f=0;c=cb-16|0;cb=c;a:{if(!b){b=0;break a}d=b;b=E(b);Tf(c,d,0,0,0,b+81|0);e=16414-b<<16;b=0;d=b+v[c+8>>2]|0;e=e+(v[c+12>>2]^65536)|0;e=b>>>0>d>>>0?e+1|0:e;f=d;d=v[c>>2];b=v[c+4>>2]}v[a>>2]=d;v[a+4>>2]=b;v[a+8>>2]=f;v[a+12>>2]=e;cb=c+16|0}function XP(a){var b=0,c=0;a:{if(Mb(a,15083,4)){break a}b=a+4|0;if(wb(w[b|0]|w[b+1|0]<<8)>>>0>2|w[a+6|0]>128){break a}b=a+200|0;if(wb(w[b|0]|w[b+1|0]<<8)>>>0>3999){break a}b=a+140|0;if(!wb(w[b|0]|w[b+1|0]<<8)){break a}a=a+148|0;c=(wb(w[a|0]|w[a+1|0]<<8)|0)==50}return c}function Sga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-32|0;cb=d;v[d+28>>2]=c;v[d+8>>2]=22;c=v[Bb(d+28|0,d+8|0)>>2];if(!Kb(a,c)){c=_e(a)}e=d+8|0;$t(e,b);f=$b(d+16|0,v[d+8>>2],c);Yb(d,a,v[f>>2],v[f+4>>2]);$t(e,b);Hb(v[d+8>>2]+c|0,0,22-c|0);Ob(a,v[d+28>>2]);cb=d+32|0}function Qga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-32|0;cb=d;v[d+28>>2]=c;v[d+8>>2]=40;c=v[Bb(d+28|0,d+8|0)>>2];if(!Kb(a,c)){c=_e(a)}e=d+8|0;cA(e,b);f=$b(d+16|0,v[d+8>>2],c);Yb(d,a,v[f>>2],v[f+4>>2]);cA(e,b);Hb(v[d+8>>2]+c|0,0,40-c|0);Ob(a,v[d+28>>2]);cb=d+32|0}function MO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=cb-16|0;cb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Fb(d);Ph(b,a,vb(d)+a|0);break c}LO(e,c,d);v[22440]=0;U(45,a|0,b|0,e|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}Vc(e)}cb=e+16|0;break a}a=P()|0;O()|0;Vc(e);S(a|0);L()}}function FW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-16|0;cb=d;v[d+12>>2]=c;v[d+8>>2]=b;b=cb-16|0;cb=b;v[b+4>>2]=1;e=b,f=lc(24),v[e+8>>2]=f;c=v[b+8>>2];Co(c);v[c>>2]=58180;MD(mc(c),v[d+8>>2],v[d+12>>2]);c=Eo(b);Do(d,mc(c),c);Tm(b);cb=b+16|0;Wf(a,d);Md(d);cb=d+16|0}function ps(a){var b=0,c=0,d=C(0);b=a+4232|0;c=w[b|0];if(c>>>0>=5){t[b|0]=0;c=0}if(t[a+4233|0]<0){t[a+4233|0]=127}b=t[a+4234|0];if((b|0)<0){t[a+4234|0]=127;b=127}a:{if((c|0)==3){d=C(C(1)-te(C(2),C(-C((b&255)+1|0))));break a}d=te(C(2),C(-C((b&255)>>>0)))}z[a+4224>>2]=d}function EU(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=cb-16|0;cb=b;f=Eb(a,31),g=0,t[f|0]=g;t[b+15|0]=0;c=yi(a,Pp(a),b+15|0);t[b+14|0]=0;c=Oh(a,c);em(c+a|0,Pp(a),b+14|0);while(1){if((c|0)!=(d|0)){e=Eb(a,d);if((w[e|0]-127&255)>>>0<=160){t[e|0]=32}d=d+1|0;continue}break}cb=b+16|0}function BV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-32|0;cb=d;v[d+28>>2]=c;v[d+8>>2]=65;c=v[Bb(d+28|0,d+8|0)>>2];if(!Kb(a,c)){c=_e(a)}e=d+8|0;Ku(e,b);f=$b(d+16|0,v[d+8>>2],c);Yb(d,a,v[f>>2],v[f+4>>2]);Ku(e,b);Hb(v[d+8>>2]+c|0,0,65-c|0);Ob(a,v[d+28>>2]);cb=d+32|0}function g7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;bK(a,b,c,d,e^1);v[a+4232>>2]=1056964608;b=a+4224|0;v[b>>2]=1056964608;v[b+4>>2]=1048406533;b=a+4216|0;v[b>>2]=1020054733;v[b+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1065353216;v[a>>2]=46084;return a|0}function Via(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-32|0;cb=d;v[d+28>>2]=c;v[d+8>>2]=5;c=v[Bb(d+28|0,d+8|0)>>2];if(!Kb(a,c)){c=_e(a)}e=d+8|0;ko(e,b);f=$b(d+16|0,v[d+8>>2],c);Yb(d,a,v[f>>2],v[f+4>>2]);ko(e,b);Hb(v[d+8>>2]+c|0,0,5-c|0);Ob(a,v[d+28>>2]);cb=d+32|0}function mh(a,b){var c=0,d=0,e=0;a:{if(!(b?1:t[a+480180|0]&1)){break a}e=v[a+24616>>2]&524288;b=0;while(1){if((b|0)==127){break a}c=(b<<5)+a|0;u[c+480286>>1]=64;d=c+480280|0;v[d>>2]=v[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;u[d>>1]=e?c<<8:c?192:64;b=b+1|0;continue}}}function jU(a,b,c){var d=0,e=0;d=cb-16|0;cb=d;t[d+15|0]=1;t[d+14|0]=a>>>2;a=w[ff(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){t[d+13|0]=1;t[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=w[ff(d+13|0,d+12|0)|0]}cb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function hz(a,b,c){var d=0,e=0,f=0;d=cb-16|0;cb=d;b=sz(d,a,b);a=v[b+4>>2];e=v[b+8>>2];a:{while(1){if((a|0)==(e|0)){break a}v[22440]=0;R(776,a|0,c|0);f=v[22440];v[22440]=0;if((f|0)!=1){a=a+32|0;v[b+4>>2]=a;continue}break}a=P()|0;O()|0;dc(b);S(a|0);L()}dc(b);cb=d+16|0}function gA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;RR(a,b);e=b+8|0;Tc(a,Wb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))+504|0);QR(a,d);a:{b=b+32|0;b=Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));if(!b){break a}if(!Tc(a,b)){break a}iA(a,c);return}Hb(c,0,80)}function cfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=cb-160|0;cb=b;e=-1;c=cb-16|0;cb=c;f=b+8|0;wQ(c+8|0,f);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(g|0);if(!a){vQ(f)}if(a){e=xQ(b+8|0)}cb=b+160|0;return e|0}function Yja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=cb-624|0;cb=b;e=-1;c=cb-16|0;cb=c;f=b+8|0;uU(c+8|0,f);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(g|0);if(!a){tU(f)}if(a){e=vU(b+8|0)}cb=b+624|0;return e|0}function SC(a,b){var c=0,d=0;c=cb-16|0;cb=c;d=c+8|0;Jc(d,a);v[22440]=0;a=T(19,d|0)|0;d=v[22440];v[22440]=0;a:{if((d|0)==1){break a}v[22440]=0;a=Q(20,a|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break a}Pb(c+8|0);cb=c+16|0;return a}a=P()|0;O()|0;Pb(c+8|0);S(a|0);L()}function S$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=sg(t[b|0]),e=v[v[a>>2]+52>>2],gb[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=uk(b,1,c,v[a+32>>2])}return c|0}function QC(a,b,c){var d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;e=v[a+4>>2];f=e+b|0;v[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0>31){break b}a=v[a>>2];break a}a=v[a>>2];v[a+((f>>>0<33?0:g>>>5|0)<<2)>>2]=0}to(d+8|0,a,e);Yu(v[d+8>>2],v[d+12>>2],b,c);cb=d+16|0}function Lo(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function $7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;v[a+4>>2]=b;v[a>>2]=0;b=tx(a+8|0,d);v[22440]=0;Q(938,a+20|0,c|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){v[a+32>>2]=0;v[a+36>>2]=0;t[a+42|0]=0;t[a+40|0]=0;t[a+41|0]=w[a+41|0]&224|25;return a|0}a=P()|0;O()|0;Ab(b);S(a|0);L()}function tja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=cb-32|0;cb=b;e=-1;c=cb-16|0;cb=c;f=b+8|0;$t(c+8|0,f);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(g|0);if(!a){KT(f)}if(a){e=LT(b+8|0)}cb=b+32|0;return e|0}function lha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=cb-16|0;cb=b;e=-1;c=cb-16|0;cb=c;f=b+8|0;ko(c+8|0,f);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(g|0);if(!a){dS(f)}if(a){e=eS(b+8|0)}cb=b+16|0;return e|0}function MI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a=Db(a);d=Rg(b);e=vb(c);v[22440]=0;W(1086,a|0,b|0,d|0,d+e|0);b=v[22440];v[22440]=0;a:{if((b|0)!=1){b=Fb(c);v[22440]=0;Y(1087,a|0,b|0,e|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;rb(a);S(b|0);L()}}function ur(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=v[b+76>>2]>=0;b:{c=v[b+4>>2];c:{if(!c){yw(b);c=v[b+4>>2];if(!c){break c}}if(v[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;v[b+4>>2]=c;t[c|0]=a;v[b>>2]=v[b>>2]&-17;d=a&255}return d}function m0(a){a=a|0;var b=0,c=0,d=0;c=v[a+44>>2];b=v[a+24>>2];if(c>>>0<b>>>0){v[a+44>>2]=b;c=b}d=-1;a:{if(!(w[a+48|0]&8)){break a}b=v[a+16>>2];if(b>>>0<c>>>0){fn(a,v[a+8>>2],v[a+12>>2],c);b=v[a+16>>2]}a=v[a+12>>2];if(a>>>0>=b>>>0){break a}d=sg(t[a|0])}return d|0}function H1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=yd(a);a:{if(!c){break a}v[22440]=0;R(1108,a|0,c|0);e=v[22440];v[22440]=0;if((e|0)!=1){v[22440]=0;W(1109,a|0,b|0,rd(b,c)|0,c|0);b=v[22440];v[22440]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;ad(d);S(a|0);L()}return a|0}function Tz(a,b,c){var d=0;d=cb-16|0;cb=d;u[d+14>>1]=b;u[d+12>>1]=c;if((b|0)!=(c|0)){b=yb(v[a>>2]);c=yb(v[a+4>>2]);a=cb-16|0;cb=a;v[a+8>>2]=b;while(1){if(Qb(b,c)){if(x[b>>1]==x[d+14>>1]){u[b>>1]=x[d+12>>1]}Ne(a+8|0);b=v[a+8>>2];continue}break}cb=a+16|0}cb=d+16|0}function ED(a){var b=0,c=0,d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;c=cb-16|0;cb=c;v[c+4>>2]=1;f=c,g=lc(16),v[f+8>>2]=g;b=v[c+8>>2];Co(b);v[b>>2]=42840;b=mc(b);Sm(b);v[b>>2]=42972;b=d+8|0;e=Eo(c);Do(b,mc(e),e);Tm(c);cb=c+16|0;Wf(a,b);Md(b);cb=d+16|0;v[a+8>>2]=0;ee(a+12|0)}function C9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=cb-16|0;cb=e;c=rf(a,c);ke(e,v[a+36>>2]);a:{b:{if(!c){Cc(e,a+32|0,5);f=-1;if(!tb(v[v[e>>2]>>2],v[e+4>>2])){break b}break a}f=v[c+16>>2]}gb[d|0](v[a+36>>2],b,f);g=1;h=c}Se(a,h);cb=e+16|0;return g|0}function a2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=cb-16|0;cb=c;v[c+4>>2]=1;e=c,f=lc(52),v[e+8>>2]=f;d=v[c+8>>2];v[22440]=0;Q(1107,d|0,b|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){b=a;a=Eo(c);Do(b,mc(a),a);Tm(c);cb=c+16|0;break a}a=P()|0;O()|0;Tm(c);S(a|0);L()}}function Pga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=cb-16|0;cb=d;v[d+12>>2]=c;c=d+12|0;qc(c,256);qc(c,65535);e=x[d+12>>1];Ff(a,e);c=0;while(1){if((c|0)==(e|0)){cb=d+16|0}else{f=w[b+c|0];g=Oi(v[a>>2],v[a+4>>2],c),h=f,u[g>>1]=h;c=c+1|0;continue}break}}function Kj(a,b){var c=0,d=0,e=0,f=0;c=cb-16|0;cb=c;d=Fb(b);e=c,f=vb(b),v[e+12>>2]=f;v[c+8>>2]=v[a+4>>2]-1;zk(d,d+v[Bb(c+12|0,c+8|0)>>2]|0,v[a>>2]);d=v[a>>2];e=c,f=vb(b),v[e+12>>2]=f;a=v[a+4>>2];v[c+8>>2]=a-1;em(d+v[Bb(c+12|0,c+8|0)>>2]|0,a+d|0,58412);cb=c+16|0}function zy(a,b,c,d){var e=0,f=0;e=Kd(a);a:{if(e){f=bc(a);while(1){b:{a=e+16|0;if(yy(c,d,a)){a=v[e>>2];if(!a){break a}break b}if(xy(a,c,d)){f=e+4|0;a=v[e+4>>2];if(a){e=f;break b}v[b>>2]=e;return f}v[b>>2]=e;return f}f=e;e=a;continue}}e=bc(a)}v[b>>2]=e;return e}function bW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-48|0;cb=c;d=-1;a:{if(!cD(a,c+8|0)){break a}d=0;if(!bD(c+8|0)){break a}if(b){a=v[b>>2];e=!v[b+4>>2];b=c+12|0;if(e&a>>>0<Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-8>>>0){break a}}d=1}cb=c+48|0;return d|0}function aea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=cb-16|0;cb=c;v[c+12>>2]=4925421;v[c+8>>2]=2147483647;d=Bb(c+12|0,c+8|0);cb=c+16|0;if(y[d>>2]<b>>>0){nd();L()}if(b>>>0>=4925422){af(11191);L()}c=B(b,872);b=lc(c);v[a>>2]=b;v[a+4>>2]=b;e=xb(a),f=b+c|0,v[e>>2]=f}function Vy(a,b,c,d){var e=0,f=0;e=Kd(a);a:{if(e){f=bc(a);while(1){b:{a=e+16|0;if(Ws(c,d,a)){a=v[e>>2];if(!a){break a}break b}if(Vs(a,c,d)){f=e+4|0;a=v[e+4>>2];if(a){e=f;break b}v[b>>2]=e;return f}v[b>>2]=e;return f}f=e;e=a;continue}}e=bc(a)}v[b>>2]=e;return e}function Vk(a){var b=0,c=0;a:{b=v[a+1396>>2];if((b|0)>24){break a}if(!b){v[a+1392>>2]=0}while(1){if(w[a+1376|0]?0:v[a+1384>>2]){break a}c=Nr(a);if((c|0)==-1){break a}b=v[a+1396>>2];v[a+1396>>2]=b+8;v[a+1392>>2]=v[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function YO(a,b){var c=0,d=0;v[a+4>>2]=b;v[a>>2]=89768;v[a+20>>2]=0;v[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;v[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;v[a+8>>2]=d;v[a+32>>2]=d>>>0<31?-1>>>31-d|0:-1;v[a+28>>2]=b>>>0<c>>>0?0:-1>>>32-d|0;v[a+16>>2]=(B(c,d)-b|0)+c;return a}function TX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(Wg(a,v[b+8>>2],0)){Fv(b,c,d);return}e=v[a+12>>2];f=a+16|0;yE(f,b,c,d);a:{if((e|0)<2){break a}e=(e<<3)+f|0;a=a+24|0;while(1){yE(a,b,c,d);if(w[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function K8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0),f=0,g=C(0);d=cb-16|0;cb=d;f=d,g=C(C(gb[v[v[a>>2]+48>>2]](a,b))+c),z[f+12>>2]=g;c=C(0);e=z[d+12>>2];a:{if(!(e<C(0))){c=C(1);if(!(e>C(1))){break a}}z[d+12>>2]=c}gb[v[v[a>>2]+44>>2]](a,b,z[d+12>>2]);cb=d+16|0}function oia(a,b){a=a|0;b=b|0;var c=0;c=cb-32|0;cb=c;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=0;Db(c+16|0);v[c+4>>2]=2;v[22440]=0;v[c>>2]=v[c>>2]&-1332|1042;U(417,a|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){Qc(c);cb=c+32|0;return}a=P()|0;O()|0;Qc(c);S(a|0);L()}function fka(a,b){a=a|0;b=b|0;var c=0;c=cb-32|0;cb=c;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=0;Db(c+16|0);v[c+4>>2]=2;v[22440]=0;v[c>>2]=v[c>>2]&-1332|1058;U(300,a|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){Qc(c);cb=c+32|0;return}a=P()|0;O()|0;Qc(c);S(a|0);L()}function Zea(a,b){a=a|0;b=b|0;var c=0;c=cb-32|0;cb=c;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=0;Db(c+16|0);v[c+4>>2]=2;v[22440]=0;v[c>>2]=v[c>>2]&-1332|1042;U(265,a|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){Qc(c);cb=c+32|0;return}a=P()|0;O()|0;Qc(c);S(a|0);L()}function Yk(a,b,c){var d=0,e=0,f=0,g=0;e=cb-16|0;cb=e;v[e+8>>2]=c;while(1){a:{if((a|0)!=(b|0)){c=cb-16|0;cb=c;d=nc(c+8|0,v[a>>2]);f=v[d>>2];g=v[d+4>>2];d=v[e+8>>2];d=Hc(f,g,v[d>>2],v[d+4>>2]);cb=c+16|0;if(!d){break a}b=a}cb=e+16|0;return b}a=a+8|0;continue}}function Qha(a,b){a=a|0;b=b|0;var c=0;c=cb-32|0;cb=c;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=0;Db(c+16|0);v[c+4>>2]=2;v[22440]=0;v[c>>2]=v[c>>2]&-1332|1042;U(103,a|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){Qc(c);cb=c+32|0;return}a=P()|0;O()|0;Qc(c);S(a|0);L()}function DW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=cb-16|0;cb=e;f=v[b+8>>2];a:{if(f>>>0<=c>>>0){c=v[d>>2];b=0;break a}v[e+12>>2]=f-c;v[e+8>>2]=v[d+4>>2];c=v[b+4>>2]+c|0;f=c;b=v[Bb(e+12|0,e+8|0)>>2];g=c+b|0;c=v[d>>2];Qi(f,g,c)}Ub(a,c,b);cb=e+16|0}function Bda(a,b){a=a|0;b=b|0;var c=0;c=cb-32|0;cb=c;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=0;Db(c+16|0);v[c+4>>2]=3;v[22440]=0;v[c>>2]=v[c>>2]&-1332|1058;U(585,a|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){Qc(c);cb=c+32|0;return}a=P()|0;O()|0;Qc(c);S(a|0);L()}function $L(a,b,c,d){var e=0,f=0,g=0;t[c+851|0]=w[c+851|0]|64;e=a?w[c+813|0]:0;g=(d|0)>=0?0-e|0:e;f=(+(a>>>0)+1)*+(d|0)/+(b>>>0);a:{if(D(f)<2147483648){e=~~f;break a}e=-2147483648}v[c+852>>2]=g+(e+v[c+852>>2]|0);b=(a+1|0)==(b|0)?d:e;a=b>>31;t[c+813|0]=a^a+b}function v1(a,b){a=a|0;b=b|0;var c=0;c=cb-32|0;cb=c;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=0;Db(c+16|0);v[c+4>>2]=4;v[22440]=0;v[c>>2]=v[c>>2]&-1284|1025;U(103,a|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){Qc(c);cb=c+32|0;return}a=P()|0;O()|0;Qc(c);S(a|0);L()}function pha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=cb-16|0;cb=c;dg(b);t[c+15|0]=0;a:{if(!Jh(a,c+15|0)){break a}f=w[c+15|0];d=1;while(1){if((e&255)==(f|0)){break a}t[c+14|0]=0;if(Jh(a,c+14|0)){Kp(b,t[c+14|0]);e=e+1|0;continue}break}d=0}cb=c+16|0;return d|0}function o9(a,b){a=a|0;b=b|0;var c=0;c=cb-32|0;cb=c;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=0;Db(c+16|0);v[22440]=0;v[c>>2]=v[c>>2]&-1332|1058;v[c+4>>2]=1;U(103,a|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){Qc(c);cb=c+32|0;return}a=P()|0;O()|0;Qc(c);S(a|0);L()}function n1(a,b){a=a|0;b=b|0;var c=0;c=cb-32|0;cb=c;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=0;Db(c+16|0);v[c+4>>2]=2;v[22440]=0;v[c>>2]=v[c>>2]&-1284|1025;U(103,a|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){Qc(c);cb=c+32|0;return}a=P()|0;O()|0;Qc(c);S(a|0);L()}function fV(a,b){a=a|0;b=b|0;var c=0;c=cb-32|0;cb=c;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=0;Db(c+16|0);v[c+4>>2]=2;v[22440]=0;v[c>>2]=v[c>>2]&-1284|1025;U(265,a|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){Qc(c);cb=c+32|0;return}a=P()|0;O()|0;Qc(c);S(a|0);L()}function aA(a,b){a=a|0;b=b|0;var c=0;c=cb-32|0;cb=c;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=0;Db(c+16|0);v[c+4>>2]=2;v[22440]=0;v[c>>2]=v[c>>2]&-1332|1058;U(585,a|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){Qc(c);cb=c+32|0;return}a=P()|0;O()|0;Qc(c);S(a|0);L()}function SU(a){a=a|0;var b=0,c=0,d=0;c=cb-32|0;cb=c;b=255;a:{if(qj(a)>>>0<=49){b=jz(c,v[a+12>>2]);v[22440]=0;R(296,a|0,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break a}il(b);Hi(a,qj(a)-1&255);b=qj(a)-1|0}cb=c+32|0;return b&255}a=P()|0;O()|0;il(b);S(a|0);L()}function PB(a){var b=0,c=0,d=0,e=0;b=a+5|0;c=w[b|0]|w[b+1|0]<<8;b=w[a+2|0];c=c+b|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;a=a+3|0;a=w[a|0]|w[a+1|0]<<8;d=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;a=b>>>0<47?a+1|0:a;fb=a;return b}function Et(a,b){a=a|0;b=b|0;var c=0;c=cb-32|0;cb=c;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=0;Db(c+16|0);v[c+4>>2]=2;v[22440]=0;v[c>>2]=v[c>>2]&-1332|1058;U(586,a|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){Qc(c);cb=c+32|0;return}a=P()|0;O()|0;Qc(c);S(a|0);L()}function sX(a,b){a=a|0;b=b|0;var c=0;c=cb-32|0;cb=c;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=0;Db(c+16|0);v[c+4>>2]=2;v[22440]=0;v[c>>2]=v[c>>2]&-1332|1058;U(12,a|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){Qc(c);cb=c+32|0;return}a=P()|0;O()|0;Qc(c);S(a|0);L()}function UU(a,b){a=a|0;b=b|0;var c=0;c=cb-32|0;cb=c;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Db(c+16|0);v[22440]=0;v[c>>2]=v[c>>2]&-1332|274;U(265,a|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){Qc(c);cb=c+32|0;return}a=P()|0;O()|0;Qc(c);S(a|0);L()}function D$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b>>2];g=v[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function zba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=b;d=cb-16|0;cb=d;b=rf(a,c);ke(d,v[a+36>>2]);a:{b:{if(!b){Cc(d,a+32|0,5);c=-1;if(!tb(v[v[d>>2]>>2],v[d+4>>2])){break b}break a}c=v[b+16>>2]}ez(v[a+36>>2],e,c);f=1;g=b}Se(a,g);cb=d+16|0;return f|0}function tX(a,b){a=a|0;b=b|0;var c=0;c=cb-32|0;cb=c;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Db(c+16|0);v[22440]=0;v[c>>2]=v[c>>2]&-1332|290;U(12,a|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){Qc(c);cb=c+32|0;return}a=P()|0;O()|0;Qc(c);S(a|0);L()}function PW(a,b){a=a|0;b=b|0;var c=0;c=cb-32|0;cb=c;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Db(c+16|0);v[22440]=0;v[c>>2]=v[c>>2]&-1284|257;U(12,a|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){Qc(c);cb=c+32|0;return}a=P()|0;O()|0;Qc(c);S(a|0);L()}function F_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=cb-16|0;cb=g;v[g+8>>2]=b;Jc(g,d);v[22440]=0;b=T(1159,g|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){Pb(g);jF(a,f+24|0,g+8|0,c,e,b);cb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Pb(g);S(a|0);L()}function E_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=cb-16|0;cb=g;v[g+8>>2]=b;Jc(g,d);v[22440]=0;b=T(1159,g|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){Pb(g);iF(a,f+16|0,g+8|0,c,e,b);cb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Pb(g);S(a|0);L()}function Cy(a,b,c){var d=0,e=0;d=Kd(a);a:{if(d){e=bc(a);while(1){b:{a=d+16|0;if(By(c,a)){a=v[d>>2];if(!a){break a}break b}if(Ay(a,c)){e=d+4|0;a=v[d+4>>2];if(a){d=e;break b}v[b>>2]=d;return e}v[b>>2]=d;return e}e=d;d=a;continue}}d=bc(a)}v[b>>2]=d;return d}function yw(a){var b=0,c=0;b=v[a+72>>2];v[a+72>>2]=b-1|b;if(v[a+20>>2]!=v[a+28>>2]){gb[v[a+36>>2]](a,0,0)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;b=v[a>>2];if(b&4){v[a>>2]=b|32;return-1}c=v[a+44>>2]+v[a+48>>2]|0;v[a+8>>2]=c;v[a+4>>2]=c;return b<<27>>31}function HF(a,b,c){var d=0,e=0,f=0;a:{e=Gt(b,c);if(e>>>0<1073741808){b:{if(e>>>0<=1){Yd(a,e);d=a;break b}f=Pl(e)+1|0;d=Ci(f);qd(a,d);cf(a,f);td(a,e)}while(1){if((b|0)!=(c|0)){qd(d,v[b>>2]);d=d+4|0;b=b+4|0;continue}break}qd(d,0);break a}Ye();L()}return a}function lU(a,b,c){var d=0,e=0;d=cb-16|0;cb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}t[d+15|0]=1;t[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=w[ff(d+15|0,d+14|0)|0]}a=e;cb=d+16|0;return a&255}function V7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=cb-16|0;cb=d;a:{b:{e=v[a+20>>2];c=v[e+4>>2];if((Uc(c,v[e+8>>2])|0)!=7){break b}if(Mb(c,9585,4)){break b}b=yb(c);c=yb(v[v[a+20>>2]+8>>2]);mo(d+8|0,a+4228|0);zk(b,c,v[d+8>>2]);break a}Ax(a,b)}ps(a);cb=d+16|0}function M_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=cb-16|0;cb=g;v[g+8>>2]=b;Jc(g,d);v[22440]=0;b=T(19,g|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){Pb(g);nF(a,f+24|0,g+8|0,c,e,b);cb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Pb(g);S(a|0);L()}function L_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=cb-16|0;cb=g;v[g+8>>2]=b;Jc(g,d);v[22440]=0;b=T(19,g|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){Pb(g);mF(a,f+16|0,g+8|0,c,e,b);cb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Pb(g);S(a|0);L()}function JB(a,b,c){var d=0,e=0,f=0;d=cb-32|0;cb=d;v[d+28>>2]=c;v[d+8>>2]=192;c=v[Bb(d+28|0,d+8|0)>>2];if(!Kb(a,c)){c=_e(a)}e=d+8|0;rq(e,b);f=$b(d+16|0,v[d+8>>2],c);Yb(d,a,v[f>>2],v[f+4>>2]);rq(e,b);Hb(v[d+8>>2]+c|0,0,192-c|0);Ob(a,v[d+28>>2]);cb=d+32|0}function Taa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{b:{if((b|0)!=437){if((b|0)==1252){break b}d=0;if((b|0)==65001){break a}c:{if((b|0)!=28591){if((b|0)==28605){break c}if((b|0)!=20127){break b}d=1;break a}d=2;break a}d=3;break a}d=5;break a}d=8}aD(a,d,c)}function Me(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-16|0;cb=d;a:{if(b>>>0<4294967280){b:{if(b>>>0<=10){Yd(a,b);e=a;break b}f=Kg(b)+1|0;e=lc(f);qd(a,e);cf(a,f);td(a,b)}c=vB(e,b,c);t[d+15|0]=0;$d(b+c|0,d+15|0);cb=d+16|0;break a}Ye();L()}return a|0}function Ip(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{e=hl(a,b);if((e|0)==255){break a}if(gk(a)){break a}f=rd(a+318|0,e);e=dO(e);if(g=1,h=t[Eb(f,10)|0]&1,i=d,i?g:h){fh(a,b,e- -64&65535,cO(c,w[Eb(f,2)|0]))}if(d){break a}fh(a,b,e+67&65535,cO(c,w[Eb(f,3)|0]))}}function C2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[b+8>>2];e=v[b+4>>2];f=v[b>>2];a=0;a:while(1){b:{b=0;if((a|0)==(e|0)){break b}while(1)if((b|0)==(d|0)){a=a+1|0;continue a}else{c=v[(a<<2)+f>>2]+(b<<3)|0;v[c>>2]=0;v[c+4>>2]=0;b=b+1|0;continue}}break}}function gs(a,b,c){var d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;a:{if(!(c&32)){break a}f=d,g=fd(b),v[f+8>>2]=g;f=d,g=gf(b),v[f>>2]=g;while(1){if(!oj(d+8|0,d)){break a}c=v[d+8>>2];e=w[c|0];if((e-97&255)>>>0<=25){t[c|0]=e-32}Fe(d+8|0);continue}}zc(a,b);cb=d+16|0}function ez(a,b,c){var d=0;a:{switch(c+1|0){case 0:case 3:kO(a,b);return;default:break a}}d=cb-32|0;cb=d;v[d+28>>2]=c;u[d+26>>1]=0;v[d+12>>2]=2;pw(d+16|0,a,d+26|0,v[Bb(d+28|0,d+12|0)>>2]);u[d+16>>1]=x[d+26>>1];u[b>>1]=w[d+16|0]|w[d+17|0]<<8;cb=d+32|0}function aja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=cb-160|0;cb=b;e=-1;c=cb-16|0;cb=c;vT(c+8|0,b);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);f=v[c+4>>2];if((f|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(f|0);if(!a){uT(b)}if(a){e=wT(b)}cb=b+160|0;return e|0}function N1(a){a=a|0;var b=0,c=0,d=0;b=cb-32|0;cb=b;if(!w[a+8|0]){Si(a+12|0,v[a+4>>2]);qe(b+24|0,v[a+12>>2],v[a+16>>2]);c=v[v[a>>2]+40>>2];d=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=d;gb[c|0](b+16|0,a,0,b+8|0);t[a+8|0]=1}cb=b+32|0;return v[a+12>>2]}function Lea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=cb-208|0;cb=b;e=-1;c=cb-16|0;cb=c;WP(c+8|0,b);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);f=v[c+4>>2];if((f|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(f|0);if(!a){VP(b)}if(a){e=XP(b)}cb=b+208|0;return e|0}function SD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=cb-16|0;cb=d;b:{c:{if(!b){b=a;a=Fb(c);Ph(b,a,vb(c)+a|0);break c}lN(d,c);v[22440]=0;U(45,a|0,b|0,d|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}Vc(d)}cb=d+16|0;break a}a=P()|0;O()|0;Vc(d);S(a|0);L()}}function bD(a){var b=0,c=0;a:{if(Mb(a,14264,4)){break a}if(Mb(a+8|0,14185,4)){break a}b=a+4|0;b=Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));if(!b){break a}a=a+12|0;c=(Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|0)!=0&b>>>0>27}return c}function VE(a,b){var c=0,d=0,e=0,f=0;c=cb-16|0;cb=c;v[b>>2]=0;t[c+15|0]=0;Jh(a,c+15|0);d=w[c+15|0];e=d>>>2|0;f=d&3;d=0;while(1){v[b>>2]=e;if((d|0)==(f|0)){cb=c+16|0}else{t[c+15|0]=0;Jh(a,c+15|0);d=d+1|0;e=v[b>>2]|w[c+15|0]<<(d<<3)-2;continue}break}}function rT(a){var b=0,c=0,d=0,e=0;c=w[a+3|0];b=a+196|0;b=kka(c>>>0<3?48:64,0,wb(w[b|0]|w[b+1|0]<<8),0);d=fb;e=b;b=a+198|0;a=a+200|0;b=kka(kka(wb(w[b|0]|w[b+1|0]<<8),0,c>>>0<4?4:5,0),fb,wb(w[a|0]|w[a+1|0]<<8),0);c=e+b|0;c=c+512|0;a=c;fb=0;return a}function UN(a){var b=0,c=0,d=0,e=0,f=0;b=cb-16|0;cb=b;c=a;d=v[a>>2];f=vj(d,v[a+4>>2]);a=yb(d);v[b+8>>2]=a;e=+(f>>>0);c=yb(v[c+4>>2]);while(1){if(Qb(a,c)){A[a>>3]=A[a>>3]/e;A[a+8>>3]=A[a+8>>3]/e;Sp(b+8|0);a=v[b+8>>2];continue}else{cb=b+16|0}break}}
function IV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=cb-48|0;cb=b;e=-1;c=cb-16|0;cb=c;sC(c+8|0,b);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);f=v[c+4>>2];if((f|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(f|0);if(!a){rC(b)}if(a){e=tC(b)}cb=b+48|0;return e|0}function nr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=cb-16|0;cb=f;d=Dc(a);e=vb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Fb(a);Ce(d+e|0,b,c);b=c+e|0;Bf(a,b);t[f+15|0]=0;$d(b+d|0,f+15|0);break a}Mo(a,d,(c+e|0)-d|0,e,e,0,c,b)}cb=f+16|0;return a|0}function QG(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=QG(a*0x10000000000000000,b);c=v[b>>2]+-64|0}v[b>>2]=c;return a}v[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function oF(a,b,c){var d=0,e=0,f=0;a:{if(b>>>0<1073741808){b:{if(b>>>0<=1){Yd(a,1);e=a;break b}d=Pl(b)+1|0;e=Ci(d);qd(a,e);cf(a,d);td(a,b)}f=b;d=e;while(1){v[d>>2]=c;d=d+4|0;f=f-1|0;if(f){continue}break}qd((b<<2)+e|0,0);break a}Ye();L()}return a}function yA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Rb(a+8|0);v[22440]=0;d=T(204,b|0)|0;e=v[22440];v[22440]=0;b:{if((e|0)==1){break b}v[22440]=0;U(250,a|0,b|0,d|0);a=v[22440];v[22440]=0;if((a|0)==1){break b}break a}a=P()|0;O()|0;_b(c);S(a|0);L()}}function sO(a,b,c){var d=0,e=0,f=0,g=0;f=v[b+4>>2];e=b+4|0;Pn(v[a>>2],c,e);g=v[a+4>>2];d=b+8|0;while(1){if((c|0)!=(g|0)){Mi(v[d>>2],x[c>>1]);v[d>>2]=v[d>>2]+2;c=c+2|0;continue}break}ec(a,e);ec(a+4|0,d);ec(xb(a),mc(b));v[b>>2]=v[b+4>>2];return f}function eka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb-32|0;cb=d;e=d+16|0;Dh(e,c);bj(d+8|0,e);v[22440]=0;W(303,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[22440];v[22440]=0;if((a|0)!=1){Ab(d+16|0);cb=d+32|0;break a}a=P()|0;O()|0;Ab(d+16|0);S(a|0);L()}}function Wha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb-32|0;cb=d;e=d+16|0;sA(e,c);bj(d+8|0,e);v[22440]=0;W(116,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[22440];v[22440]=0;if((a|0)!=1){Ab(d+16|0);cb=d+32|0;break a}a=P()|0;O()|0;Ab(d+16|0);S(a|0);L()}}function Rha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb-32|0;cb=d;e=d+16|0;Xm(e,c);bj(d+8|0,e);v[22440]=0;W(116,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[22440];v[22440]=0;if((a|0)!=1){Ab(d+16|0);cb=d+32|0;break a}a=P()|0;O()|0;Ab(d+16|0);S(a|0);L()}}function Rfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb-32|0;cb=d;e=d+16|0;hp(e,c);bj(d+8|0,e);v[22440]=0;W(303,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[22440];v[22440]=0;if((a|0)!=1){Ab(d+16|0);cb=d+32|0;break a}a=P()|0;O()|0;Ab(d+16|0);S(a|0);L()}}function Qj(a,b){var c=0,d=0,e=0,f=0;while(1){if((b|0)!=(e|0)){d=v[a>>2];if(d){c=v[a+4>>2]}else{v[a>>2]=8;c=v[a+12>>2];if((c|0)!=v[a+8>>2]){c=c-1|0;v[a+12>>2]=c}d=8;c=w[c|0]}v[a>>2]=d-1;v[a+4>>2]=c>>>1;f=c&1|f<<1;e=e+1|0;continue}break}return f}function Jea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb-32|0;cb=d;e=d+16|0;US(e,c);bj(d+8|0,e);v[22440]=0;W(116,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[22440];v[22440]=0;if((a|0)!=1){Ab(d+16|0);cb=d+32|0;break a}a=P()|0;O()|0;Ab(d+16|0);S(a|0);L()}}function HR(a,b){var c=0;a:{if(!Sd(b)){break a}if(v[b+20>>2]==v[a+20>>2]){v[a+20>>2]=0}qc(a,v[b>>2]);c=x[a+34>>1]&-2|u[b+34>>1]&1;u[a+34>>1]=c;u[a+34>>1]=c&65471|x[b+34>>1]&64;if(!Lg(a)){break a}ic(v[a+20>>2],v[b+20>>2],Fj(v[a>>2],x[a+34>>1]))}}function D_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=cb-16|0;cb=a;v[a+8>>2]=b;Jc(a,d);v[22440]=0;b=T(1159,a|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){Pb(a);hF(f+20|0,a+8|0,c,e,b);cb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Pb(a);S(b|0);L()}function pC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb-32|0;cb=d;e=d+16|0;Iu(e,c);bj(d+8|0,e);v[22440]=0;W(116,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[22440];v[22440]=0;if((a|0)!=1){Ab(d+16|0);cb=d+32|0;break a}a=P()|0;O()|0;Ab(d+16|0);S(a|0);L()}}function oU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb-32|0;cb=d;e=d+16|0;IB(e,c);bj(d+8|0,e);v[22440]=0;W(116,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[22440];v[22440]=0;if((a|0)!=1){Ab(d+16|0);cb=d+32|0;break a}a=P()|0;O()|0;Ab(d+16|0);S(a|0);L()}}function XD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=cb-32|0;cb=d;e=d+16|0;Dh(e,c);bj(d+8|0,e);v[22440]=0;W(116,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[22440];v[22440]=0;if((a|0)!=1){Ab(d+16|0);cb=d+32|0;break a}a=P()|0;O()|0;Ab(d+16|0);S(a|0);L()}}function NT(a,b,c){var d=0,e=0,f=0,g=0;f=v[b+4>>2];e=b+4|0;Pn(v[a>>2],c,e);g=v[a+4>>2];d=b+8|0;while(1){if((c|0)!=(g|0)){kd(v[d>>2],w[c|0]);v[d>>2]=v[d>>2]+1;c=c+1|0;continue}break}ec(a,e);ec(a+4|0,d);ec(xb(a),mc(b));v[b>>2]=v[b+4>>2];return f}function uD(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function pq(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=cb-16|0;cb=d;v[d+12>>2]=c;c=d+12|0;qc(c,128);qc(c,65535);e=x[d+12>>1];Ff(a,e);c=0;while(1){if((c|0)==(e|0)){cb=d+16|0}else{f=w[b+c|0];g=Oi(v[a>>2],v[a+4>>2],c),h=f,u[g>>1]=h;c=c+1|0;continue}break}}function Ko(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-1.1359647557788195e-11+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function K_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=cb-16|0;cb=a;v[a+8>>2]=b;Jc(a,d);v[22440]=0;b=T(19,a|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){Pb(a);lF(f+20|0,a+8|0,c,e,b);cb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Pb(a);S(b|0);L()}function Gr(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;d=aa(16)|0;AE();a=$b(c+8|0,a,89744);c=v[a+4>>2];a=v[a>>2];v[22440]=0;da(1122,d|0,a|0,c|0,b|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){ia(d|0,87712,1123);L()}a=P()|0;O()|0;ba(d|0);S(a|0);L()}function md(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=cb-16|0;cb=e;f=v[b>>2];g=v[b+8>>2];v[e+12>>2]=d;v[e+8>>2]=c;c=v[v[f>>2]+28>>2];d=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=d;gb[c|0](a,f,g,e);v[b+8>>2]=v[b+8>>2]+v[a+4>>2];cb=e+16|0}function ds(a){var b=0,c=0;b=a+24|0;c=v[b>>2];v[22440]=0;Z(837,c|0);c=v[22440];v[22440]=0;if((c|0)!=1){ad(a+68|0);Rf(a+36|0);_o(a+32|0);qi(b);pi(a+4|0);Ae(a);return}V(0)|0;O()|0;ad(a+68|0);Rf(a+36|0);_o(a+32|0);qi(b);pi(a+4|0);Ae(a);Lb();L()}function zga(a,b){a=a|0;b=b|0;var c=0,d=0;c=yd(a);a:{if(!b){break a}v[22440]=0;R(588,a|0,b|0);d=v[22440];v[22440]=0;if((d|0)!=1){v[22440]=0;R(589,a|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Yz(c);S(a|0);L()}return a|0}function jY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=cb-16|0;cb=e;if(d>>>0<4294967280){a:{if(d>>>0<=10){Yd(a,c);d=a;break a}f=Kg(d)+1|0;d=lc(f);qd(a,d);cf(a,f);td(a,c)}a=Ce(d,b,c);t[e+15|0]=0;$d(a+c|0,e+15|0);cb=e+16|0;return}Ye();L()}function SM(a,b){var c=0,d=0;d=cb-16|0;cb=d;c=v[a+104>>2];a:{if(!c){break a}c=v[c>>2];if(!c){break a}v[a+76>>2]=c;v[a+88>>2]=v[a+88>>2]&-131|128;v[d+12>>2]=b<<8;v[d+8>>2]=c-1;b=c+(v[Bb(d+12|0,d+8|0)>>2]^-1)|0;v[a>>2]=0;v[a+4>>2]=b}cb=d+16|0}function TJ(a,b,c){var d=0,e=0;if(C(D(a))<C(0x8000000000000000)){d=~~a>>>0}else{d=0}e=d&-2147483648;d=e?0-d|0:d;while(1){if(!((d|0)<0|(b|0)<=0)){b=b-1|0;d=d<<1;continue}break}b=(d>>>31|0)+b<<31-c|(d&2147483647)>>>c;return C((e?b^-1|e:b)|0)}function EV(a,b){a=a|0;b=b|0;var c=0,d=0;c=yd(a);a:{if(!b){break a}v[22440]=0;R(232,a|0,b|0);d=v[22440];v[22440]=0;if((d|0)!=1){v[22440]=0;R(233,a|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Ic(c);S(a|0);L()}return a|0}function kN(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+3|0]|w[b+4|0]<<8|(w[b+5|0]<<16|w[b+6|0]<<24);t[a+3|0]=b;t[a+4|0]=b>>>8;t[a+5|0]=b>>>16;t[a+6|0]=b>>>24}function dQ(a){var b=0,c=0;a:{if(w[a+29|0]!=2){break a}b=w[a+28|0];if((b|0)!=26&(b|0)!=2|w[a+30|0]!=2){break a}b=w[a+31|0];if(b>>>0>21|!(1<<b&3146753)|w[a+33|0]>64){break a}b=w[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}c=bQ(a+20|0)}return c}function _2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-32|0;cb=d;_k(d,c);c=d+16|0;v[c>>2]=b;zc(c+4|0,d);v[22440]=0;R(1080,a+4|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){rl(d+16|0);rb(d);cb=d+32|0;return}a=P()|0;O()|0;rl(d+16|0);rb(d);S(a|0);L()}function Ze(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Rb(a+8|0);v[22440]=0;U(250,a|0,b|0,c|0);c=v[22440];v[22440]=0;a:{if((c|0)!=1){a=v[a>>2];v[22440]=0;Q(190,b|0,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;_b(d);S(a|0);L()}}function Vv(a,b){var c=0,d=0,e=0,f=0;c=cb-16|0;cb=c;u[b>>1]=0;t[c+15|0]=0;Jh(a,c+15|0);d=w[c+15|0];e=d>>>1|0;f=d&1;d=0;while(1){u[b>>1]=e;if(d>>>0>=f>>>0){cb=c+16|0}else{t[c+15|0]=0;Jh(a,c+15|0);e=x[b>>1]|w[c+15|0]<<7;d=1;continue}break}}function Hja(a,b){a=a|0;b=b|0;var c=0;b=cb-32|0;cb=b;c=-1;a:{if(!hB(a,b+16|0)){break a}c=0;if(!XT(b+16|0)){break a}if(!Mb(b+16|0,14250,4)){c=-1;if(!Yc(a,4)){break a}}c=-1;if(!Pj(a,b+8|0)){break a}c=!Mb(b+8|0,14226,4)}cb=b+32|0;return c|0}function he(a,b){var c=0,d=0;d=v[a+4>>2];c=d+b|0;v[a+4>>2]=c;if(v[a+8>>2]>=(c|0)){c=d&7;b=c+b|0;d=v[a>>2]+(d>>3)|0;a=w[d|0]&255>>>c;c=0;while(1){if((b|0)>=9){b=b-8|0;c=a<<b|c;d=d+1|0;a=w[d|0];continue}break}a=a>>>8-b|c}else{a=0}return a}function Xd(a){var b=0,c=0,d=0;c=cb-16|0;cb=c;a=Jv(c,a);d=cb-16|0;cb=d;if(!sg(w[v[ac(d+8|0,v[a+4>>2])>>2]])){a:{b:{a=v[a+8>>2];b=w[a|0];if((b|0)!=1){if(b&2){break b}t[a|0]=2;a=1}else{a=0}break a}Kv();L()}b=a}cb=d+16|0;cb=c+16|0;return b}function H9(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-32|0;cb=c;d=-1;a:{if(!WD(a,c+8|0)){break a}d=0;if(!VK(c+8|0)){break a}if(b){a=c+16|0;if(v[b>>2]!=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|v[b+4>>2]){break a}}d=1}cb=c+32|0;return d|0}function CM(a,b){var c=0,d=0;a:{if(!(w[a+89|0]&16)){break a}c=v[a+656>>2];if(!c){break a}c=v[c>>2];b:{if(c){d=a;a=v[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;v[d+696>>2]=a;a=(B(a,v[b>>2])|0)/65536|0;break b}if(v[a+696>>2]){break a}a=0}v[b>>2]=a}}function hi(a,b,c){var d=0,e=0,f=0,g=0;v[a+112>>2]=b;v[a+116>>2]=c;e=v[a+4>>2];d=v[a+44>>2]-e|0;v[a+120>>2]=d;v[a+124>>2]=d>>31;d=a;a=v[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}v[d+104>>2]=a}function RM(a,b){var c=0,d=0;a:{if(!(t[a+851|0]&1)){break a}c=v[a+104>>2];if(!c){break a}d=v[c>>2];if(!d){break a}v[a+76>>2]=d;v[a>>2]=0;v[a+4>>2]=d-1;c=v[a+88>>2];v[a+88>>2]=b?c|134:c&-135|128;if(!b){break a}v[a+84>>2]=d;v[a+80>>2]=0}}function j9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=b;d=cb-16|0;cb=d;b=rf(a,c);ke(d,v[a+36>>2]);a:{b:{if(!b){Cc(d,a+32|0,5);c=-1;if(!tb(v[v[d>>2]>>2],v[d+4>>2])){break b}break a}c=v[b+16>>2]}ez(v[a+36>>2],e,c);f=b}Se(a,f);cb=d+16|0}function Uz(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=cb-1024|0;cb=e;d=cb-16|0;cb=d;Rz(d+8|0,e);f=v[d+12>>2];Yb(d,a,v[d+8>>2],f);g=v[d+4>>2];if((g|0)==(f|0)){Ob(a,v[d+12>>2])}cb=d+16|0;if((f|0)==(g|0)){h=Sz(e,c)>>>0<=b>>>0}cb=e+1024|0;return h}function vha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=cb-16|0;cb=c;while(1){a:{d=v[a>>2];if(pc(d,v[a+4>>2])>>>0>e>>>0){qf(c,v[Ib(d,e)>>2]+40|0);d=Yp(c,b);rb(c);if(!d){break a}f=v[Ib(v[a>>2],e)>>2]}cb=c+16|0;return f|0}e=e+1|0;continue}}function v9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=yd(a);a:{b:{c=pc(v[b>>2],v[b+4>>2]);if(c){v[22440]=0;R(231,a|0,c|0);e=v[22440];v[22440]=0;if((e|0)==1){break b}bA(a,v[b>>2],v[b+4>>2],c)}break a}a=P()|0;O()|0;fc(d);S(a|0);L()}return a|0}function MM(a,b,c){var d=0,e=0;d=cb-16|0;cb=d;e=c&15;if(e){t[b+824|0]=e}c=c&240;if(c){t[b+823|0]=c>>>4}v[b+88>>2]=v[b+88>>2]|131072;ub(d+8|0,a+1074312|0,80);if(!(!e|!tb(v[v[d+8>>2]>>2],v[d+12>>2]))){t[b+824|0]=w[b+824|0]<<2}cb=d+16|0}function D2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=v[b+8>>2];d=v[b+4>>2];e=v[b>>2];a=0;a:while(1){b:{b=0;if((a|0)==(d|0)){break b}while(1)if((b|0)==(c|0)){a=a+1|0;continue a}else{f=Wp(e,a,b),g=0,v[f>>2]=g;b=b+1|0;continue}}break}}function Yg(a,b,c){c=v[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=w[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(w[a+1|0]|32)!=120){break a}a=a+2|0}return a}function R7(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(v[b+4>>2]!=8){break a}b=v[b>>2];if(Mb(b,9585,4)){break a}c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4228>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[a+4232>>2]=c;ps(a)}}function E8(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(v[b+4>>2]!=8){break a}b=v[b>>2];if(Mb(b,9585,4)){break a}c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[a+4264>>2]=c;ts(a)}}function xP(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,872);a=v[c+4>>2];b=v[c+8>>2];while(1){if((a|0)==(b|0)){dc(c);cb=c+16|0}else{wP(Hb(a,0,872));a=a+872|0;v[c+4>>2]=a;continue}break}}function V$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((gb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=uk(b,4,c,v[a+32>>2])}return c|0}function z9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-16|0;cb=d;c=rf(a,c);ke(d,v[a+36>>2]);a:{b:{if(!c){Cc(d,a+32|0,5);e=-1;if(!tb(v[v[d>>2]>>2],v[d+4>>2])){break b}break a}e=v[c+16>>2]}GS(v[a+36>>2],b,e);f=c}Se(a,f);cb=d+16|0}function ZD(){var a=0,b=0,c=0;b=cb-16|0;cb=b;a=Bc(b,14836);a:{if(!vb(a)){break a}c=1;if((Bg(a,14732)|0)!=-1){break a}if((Bg(a,16830)|0)!=-1){break a}if((Bg(a,13794)|0)!=-1){break a}c=(Bg(a,13837)|0)!=-1}rb(a);cb=b+16|0;return c|0}function Kia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=cb-32|0;cb=d;a:{if(a){gb[v[v[a>>2]+8>>2]](a,b,c);break a}if(!fT(Bs(d+8|0),b)){break a}a=d+8|0;Bs(a);v[d+24>>2]=0;e=Bs(d+24|0);LL(a,9182,10860,140,42);hE(e,a,b,13282,c)}cb=d+32|0}function ig(a,b){var c=0,d=0,e=0,f=0;d=x[a+22>>1];e=d+x[a+20>>1]|0;c=x[a+24>>1]<<17;while(1){if((d|0)==(e|0)){a=(c|0)/32768|0}else{f=c;c=((d&127)<<2)+a|0;c=f-B(v[Ib(b,x[c+28>>1])>>2],u[c+26>>1])|0;d=d+1|0;continue}break}return a}function PR(a,b,c){var d=0,e=0,f=0,g=0;while(1){if((b|0)!=(c|0)){e=v[a+4>>2];f=e>>>8|0;d=v[a>>2];e=(e&255)<<24|d>>>8;d=(((d^w[b|0])&255)<<3)+21752|0;g=v[d>>2];d=v[d+4>>2]^f;v[a>>2]=e^g;v[a+4>>2]=d;b=b+1|0;continue}break}return a}function Dea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=cb-16|0;cb=c;v[c+12>>2]=477218588;v[c+8>>2]=2147483647;d=Bb(c+12|0,c+8|0);cb=c+16|0;if(y[d>>2]<b>>>0){nd();L()}c=B(b,9);b=lc(c);v[a>>2]=b;v[a+4>>2]=b;e=xb(a),f=b+c|0,v[e>>2]=f}function nk(a,b){var c=0,d=0;c=cb-32|0;cb=c;v[c+28>>2]=0;Cv(c+8|0,c+28|0);d=c+16|0;kn(d,a,v[c+8>>2],v[c+12>>2]);a=v[c+20>>2];v[c+16>>2]=v[c+28>>2];v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);cb=c+32|0;return(a|0)==4}function iL(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=c;h=c>>31;c=0;while(1){if((b|0)!=(c|0)){d=v[a>>2];e=v[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=yc(lka(kka(d,d>>31,g,h),fb,256,0),fb);v[a+4>>2]=f-d;v[a>>2]=d+f;c=c+1|0;a=a+8|0;continue}break}}function mu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=cb-16|0;cb=f;if(b){e=Dc(a);d=vb(a);g=d+b|0;if(e-d>>>0<b>>>0){fm(a,e,g-e|0,d,d,0,0)}e=d;d=Fb(a);vB(e+d|0,b,c);Bf(a,g);t[f+15|0]=0;$d(d+g|0,f+15|0)}cb=f+16|0;return a|0}function lka(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=nka(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;fb=(g^fb)-((a>>>0<f>>>0)+g|0)|0;return b}function Ly(a,b,c){var d=0,e=0,f=0;d=cb-16|0;cb=d;a:{if(!c){break a}v[b+40>>2]=c;if(!c|v[a+480180>>2]!=256){break a}v[d+12>>2]=c>>>4;v[d+8>>2]=1;e=b,f=v[Pc(d+12|0,d+8|0)>>2],v[e+40>>2]=f;e=b,f=Fz(c&255),v[e+44>>2]=f}cb=d+16|0}function wi(a){var b=0,c=0,d=0,e=0;b=He(a);c=b&63;e=b&128;a:{if(!(b&64)){break a}b=6;while(1){d=He(a);c=(d&127)<<b|c;if(!(d&128)){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}a=e?-2147483648:c;return e?(c|0)>=0?0-c|0:a:a}function wL(a){var b=0,c=0;b=cb-544|0;cb=b;a:{if(!(w[a+480210|0]&128)|!v[a+24668>>2]){break a}vz(b,v[a+24620>>2]);c=a+1298224|0;a=a+1074992|0;while(1){if((a|0)==(c|0)){break a}ic(a+112|0,b,538);a=a+872|0;continue}}cb=b+544|0}function $r(a,b,c){var d=0,e=0,f=0;d=cb-16|0;cb=d;a:{if(!(c&32)){break a}c=fd(b);v[d+8>>2]=c;f=gf(b);while(1){if(!Qb(c,f)){break a}e=w[c|0];if((e-97&255)>>>0<=25){t[c|0]=e-32}Fe(d+8|0);c=v[d+8>>2];continue}}zc(a,b);cb=d+16|0}function lA(a,b){var c=0,d=0,e=0,f=0;c=a<<8;d=c&16711680;c=e;e=a<<24|d;f=c;d=b<<24|a>>>8;c=b<<8|a>>>24;a=f|(((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24));fb=e|(d&65280|c&255);return a}function kia(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;v[a+480180>>2]=b;eq(c,fq(a));d=v[c+12>>2];b=a+1074320|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;b=v[c+4>>2];v[a+1074312>>2]=v[c>>2];v[a+1074316>>2]=b;As(a+8|0,fq(a));cb=c+16|0}
function Id(a,b){var c=0,d=0,e=0,f=0,g=0;d=x[a+22>>1];g=d+x[a+20>>1]|0;c=d;while(1){a:{if((c|0)!=(g|0)){e=((c&127)<<2)+a|0;f=x[e+28>>1]+b|0;u[e+28>>1]=f;if((f&65535)>>>0<2048){break a}u[a+20>>1]=c-d}return}c=c+1|0;continue}}function As(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=43932;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=43784;break a;case 2:c=43780;break a;case 1:break b;case 0:break c}}c=43776;break a}c=43772}v[a>>2]=v[c>>2]}function jia(a){a=a|0;var b=0,c=0,d=0;b=cb-32|0;cb=b;t[b+30|0]=0;u[b+28>>1]=0;c=$b(b+8|0,b+28|0,3);Yb(b+16|0,a,v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=3){break a}if(Mb(b+28|0,14842,3)){break a}Ob(a,3);d=1}cb=b+32|0;return d|0}function fea(a){a=a|0;var b=0,c=0,d=0;b=cb-32|0;cb=b;u[b+28>>1]=0;v[b+24>>2]=0;c=$b(b+8|0,b+24|0,6);Yb(b+16|0,a,v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=6){break a}if(Mb(b+24|0,3856,6)){break a}Ob(a,6);d=1}cb=b+32|0;return d|0}function Gz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=yd(a);a:{c=Uc(v[b>>2],v[b+4>>2]);if(c){v[22440]=0;R(326,a|0,c|0);e=v[22440];v[22440]=0;if((e|0)==1){break a}Qt(a,v[b>>2],v[b+4>>2],c)}return a|0}a=P()|0;O()|0;_b(d);S(a|0);L()}function Gp(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=131072/(A[b-8>>3]-A[a>>3]);b=0;while(1){if((b|0)!=2048){d=-ne(f*A[Xe(a,b)>>3]);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}g=Ib(c,b),h=e,v[g>>2]=h;b=b+1|0;continue}break}}function vz(a,b){var c=0,d=0,e=0,f=0;u[a+24>>1]=0;v[a+20>>2]=0;c=3546895/+(b>>>0);d=c*.25;a:{if(D(d)<2147483648){b=~~d;break a}b=-2147483648}v[a+16>>2]=b;v[a>>2]=0;v[a+4>>2]=0;e=a,f=EP(c-+(b<<2)),v[e+8>>2]=f;v[a+12>>2]=fb}function Y6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=vi(a,b,c,d);v[a+4208>>2]=1017370378;v[a+4212>>2]=0;v[a>>2]=46580;v[22440]=0;R(922,a+44|0,2);c=v[22440];v[22440]=0;if((c|0)!=1){ui(b);return a|0}a=P()|0;O()|0;vf(b);S(a|0);L()}function QM(a,b,c,d){var e=0;a=Wc(Cn(a,x[c+70>>1],v[c+48>>2],b,0)-32768|0);a:{if(!d){break a}d=dl(c)-v[c+16>>2]|0;if((d|0)<2){break a}e=a;a=u[(B(b,872)+c|0)+1390>>1];a=Wc(((e-a|0)/(d|0)|0)+a|0)}u[(B(b,872)+c|0)+1390>>1]=a}function wt(a,b){var c=0,d=0,e=0;if(v[a>>2]){DU(a);c=v[a>>2];wB(a);zb(c);d=xb(a),e=0,v[d>>2]=e;v[a>>2]=0;v[a+4>>2]=0}v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=xb(b);d=xb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0}function rK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;lf(a+12|0,d);if(b){if(b>>>0>=2097152){af(11191);L()}d=lc(b<<11)}else{d=0}v[a>>2]=d;c=d+(c<<11)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=mc(a),f=d+(b<<11)|0,v[e>>2]=f;return a|0}function Yr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=0;c=cb-16|0;cb=c;d=v[b>>2];while(1){if(pc(d,v[b+4>>2])>>>0<=a>>>0){cb=c+16|0}else{v[c+8>>2]=0;hh(c+8|0);d=v[b>>2];e=Ib(d,a),f=v[c+8>>2],v[e>>2]=f;a=a+1|0;continue}break}}function fQ(a,b,c){var d=0;d=cb-16|0;cb=d;t[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){t[d+14|0]=(x[(b<<1)+32734>>1]-x[(c<<1)+32734>>1]|0)/5;a=w[Tb(d+15|0,d+14|0)|0]}cb=d+16|0;return a&255}function ZO(a){var b=0,c=0,d=0;b=a- -64|0;d=w[b|0]|w[b+1|0]<<8;b=a+72|0;a=a+70|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<2|a>>>30;c=c<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;fb=a;return b}function Sz(a,b){var c=0,d=0,e=0,f=0;d=b?224:240;c=a;e=a+1024|0;b=0;a:while(1){if((c|0)!=(e|0)){a=c;f=a+16|0;while(1)if((a|0)==(f|0)){c=c+16|0;continue a}else{b=((w[Eb(a,0)|0]&d)!=0)+b|0;a=a+4|0;continue}}break}return b}function Nr(a){var b=0;a:{b=w[a+1376|0];b:{if(!b){b=-1;if(v[a+1384>>2]){break b}if(!Lw(a)){break b}b=w[a+1376|0];if(!b){break a}}t[a+1376|0]=b-1;v[a+1400>>2]=v[a+1400>>2]+1;b=Ve(a)}return b}ca(15744,13226,1578,5432);L()}function qM(a,b,c,d){var e=0,f=0;e=v[(B(c,872)+b|0)+704>>2];a:{if(!(!(e&134218752)|(d|0)!=1)|e&67108864){break a}b=x[(B(c,872)+b|0)+1402>>1];b=(b?b-1|0:c)&65535;if(b>>>0>126){break a}f=w[((b<<5)+a|0)+480288|0]}return f}function lY(){var a=0;a:{b:{if(t[463628]&1){break b}if(!Xd(463628)){break b}v[22440]=0;X(1240);a=v[22440];v[22440]=0;if((a|0)==1){break a}v[115906]=463620;Wd(463628)}return v[115906]}a=P()|0;O()|0;nf(463628);S(a|0);L()}function cu(a,b,c){var d=0,e=0,f=0;d=cb-16|0;cb=d;if(c>>>0<4294967280){a:{if(c>>>0<=10){Yd(a,c);e=a;break a}f=Kg(c)+1|0;e=lc(f);qd(a,e);cf(a,f);td(a,c)}a=Ce(e,b,c);t[d+15|0]=0;$d(a+c|0,d+15|0);cb=d+16|0;return}Ye();L()}function K7(a){a=a|0;var b=0;gb[v[v[a>>2]+128>>2]](a);sx(a);v[a+4236>>2]=0;t[a+4202|0]=1;b=gb[v[v[a>>2]+192>>2]](a)|0;v[a+4328>>2]=0;v[a+4312>>2]=0;z[a+4240>>2]=b?C(.5):C(1);b=v[a+4256>>2];v[a+4324>>2]=b;v[a+4320>>2]=b}function $R(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function wZ(a){a=a|0;a:{b:{if(t[463712]&1){break b}if(!Xd(463712)){break b}v[22440]=0;X(1233);a=v[22440];v[22440]=0;if((a|0)==1){break a}v[115927]=464064;Wd(463712)}return v[115927]}a=P()|0;O()|0;nf(463712);S(a|0);L()}function uZ(a){a=a|0;a:{b:{if(t[463728]&1){break b}if(!Xd(463728)){break b}v[22440]=0;X(1234);a=v[22440];v[22440]=0;if((a|0)==1){break a}v[115931]=464544;Wd(463728)}return v[115931]}a=P()|0;O()|0;nf(463728);S(a|0);L()}function tq(a){var b=0,c=0,d=0,e=0;c=cb-16|0;cb=c;b=cb-16|0;cb=b;Cq(b+8|0,c+15|0);d=v[b+12>>2];cd(b,a,v[b+8>>2],d);e=v[b+4>>2];if((e|0)==(d|0)){Yc(a,v[b+12>>2])}cb=b+16|0;cb=c+16|0;return((d|0)==(e|0)?w[c+15|0]:0)&255}function sZ(a){a=a|0;a:{b:{if(t[463744]&1){break b}if(!Xd(463744)){break b}v[22440]=0;X(1235);a=v[22440];v[22440]=0;if((a|0)==1){break a}v[115935]=464880;Wd(463744)}return v[115935]}a=P()|0;O()|0;nf(463744);S(a|0);L()}function pQ(a){var b=0,c=0,d=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+36|0;a=a+34|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<1|a>>>31;c=c<<1;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;fb=a;return b}function mZ(a){a=a|0;a:{b:{if(t[463704]&1){break b}if(!Xd(463704)){break b}v[22440]=0;X(1237);a=v[22440];v[22440]=0;if((a|0)==1){break a}v[115925]=463888;Wd(463704)}return v[115925]}a=P()|0;O()|0;nf(463704);S(a|0);L()}function kZ(a){a=a|0;a:{b:{if(t[463720]&1){break b}if(!Xd(463720)){break b}v[22440]=0;X(1238);a=v[22440];v[22440]=0;if((a|0)==1){break a}v[115929]=464240;Wd(463720)}return v[115929]}a=P()|0;O()|0;nf(463720);S(a|0);L()}function iZ(a){a=a|0;a:{b:{if(t[463736]&1){break b}if(!Xd(463736)){break b}v[22440]=0;X(1239);a=v[22440];v[22440]=0;if((a|0)==1){break a}v[115933]=464848;Wd(463736)}return v[115933]}a=P()|0;O()|0;nf(463736);S(a|0);L()}function gO(a,b){a:{if(w[a+76|0]==(b|0)){break a}t[a+76|0]=b;if(b){b=0;if(x[a+24>>1]==15){u[a+20>>1]=0;b=1}v[a+8>>2]=0;v[a+16>>2]=b;return}b:{switch(v[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}v[a+16>>2]=3}}function X2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-16|0;cb=d;a=v[a+24>>2];WI(d,c);a=v[a+1298464>>2];v[22440]=0;U(388,a|0,b|0,d|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(d);cb=d+16|0;return}a=P()|0;O()|0;rb(d);S(a|0);L()}function Sx(a,b,c,d,e){var f=0,g=0,h=0;f=cb-16|0;cb=f;a:{if(!c){a=sd(v[a>>2],b);A[a+8>>3]=e;A[a>>3]=d;break a}g=c>>>1|0;Sx(a,b,g,d,e);h=sd(v[a>>2],c);xi(f,d,e,A[h>>3],A[h+8>>3]);Sx(a,b|c,g,A[f>>3],A[f+8>>3])}cb=f+16|0}function Mp(a,b,c){var d=0;d=cb-16|0;cb=d;ub(d+8|0,c+1074312|0,102);a:{if(!tb(v[v[d+8>>2]>>2],v[d+12>>2])){break a}c=x[a+692>>1]+1|0;u[a+784>>1]=c;if(!(t[a+89|0]&1)){break a}u[a+784>>1]=c|32768}v[a+692>>2]=b;cb=d+16|0}function uK(){var a=0;a:{b:{if(t[463616]&1){break b}if(!Xd(463616)){break b}v[22440]=0;X(67);a=v[22440];v[22440]=0;if((a|0)==1){break a}v[115903]=463608;Wd(463616)}return v[115903]}a=P()|0;O()|0;nf(463616);S(a|0);L()}function kka(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=B(e,f);g=c&65535;h=a&65535;i=B(g,h);f=(i>>>16|0)+B(f,g)|0;e=(f&65535)+B(e,h)|0;fb=(B(b,c)+j|0)+B(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function eV(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;d=Kb(a,120);a:{if(!d){a=b+120|0;while(1){if((a|0)!=(b|0)){ug(b);b=b+1|0;continue}break}break a}Ub(c+8|0,b,120);md(c,a,v[c+8>>2],v[c+12>>2])}cb=c+16|0;return d|0}function kba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Rb(a);e=Jg(a+12|0);t[a+32|0]=c;v[a+28>>2]=0;v[a+24>>2]=b;v[22440]=0;R(789,a|0,1);b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;KN(e);JN(d);S(a|0);L()}function jH(a,b,c){var d=0;d=cb-32|0;cb=d;v[d+28>>2]=c;v[d+24>>2]=0;v[d+12>>2]=4;c=d+16|0;pw(c,a,d+24|0,v[Bb(d+28|0,d+12|0)>>2]);v[d+16>>2]=v[d+24>>2];v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);cb=d+32|0}function dq(a,b,c){var d=0,e=0;e=x[a+480192>>1];a:{if(e){if(!Rc(b)|c>>>0>e>>>0){break a}c=v[((c<<2)+a|0)+900380>>2];if(!c){break a}d=x[Xb(c+236|0,b-1|0)>>1];break a}d=c}return(x[a+480190>>1]<(d&65535)>>>0?0:d)&65535}function Xda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=cb-32|0;cb=d;e=Cf(b);c=gP(d+8|0,c);v[22440]=0;W(749,a|0,b|0,e-1&65535,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){Re(c);cb=d+32|0;return}a=P()|0;O()|0;Re(c);S(a|0);L()}function VG(a,b){var c=0,d=0,e=0;c=cb-256|0;cb=c;if((b|0)>=2){v[(b<<2)+a>>2]=c;ic(c,v[a>>2],4);while(1){e=(d<<2)+a|0;d=d+1|0;ic(v[e>>2],v[(d<<2)+a>>2],4);v[e>>2]=v[e>>2]+4;if((b|0)!=(d|0)){continue}break}}cb=c+256|0}function Jw(a){var b=0;a:{b:{while(1){if(v[a+1380>>2]!=-1){break b}b=0;if(!Mr(a)){break a}if(!(t[a+1375|0]&1)){continue}break}Zb(a,32);return 0}v[a+1396>>2]=0;v[a+1400>>2]=0;v[a+1384>>2]=0;t[a+1376|0]=0;b=1}return b}function QN(a,b){var c=0,d=0,e=0,f=0;e=A[a+48>>3];c=A[a+40>>3];A[a+48>>3]=c;f=A[a+64>>3];d=A[a+56>>3];A[a+64>>3]=d;A[a+40>>3]=b;b=e*A[a+16>>3]+(A[a>>3]*b+c*A[a+8>>3])-d*A[a+24>>3]-f*A[a+32>>3];A[a+56>>3]=b;return b}function yS(a,b,c){var d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;b=bc(b);e=kh(a,lc(32),lh(d+8|0,b));b=v[e>>2]+16|0;a=cb-16|0;cb=a;v[a+8>>2]=v[c>>2];u[b>>1]=x[v[a+8>>2]>>1];Db(b+4|0);cb=a+16|0;f=bc(e),g=1,t[f+4|0]=g;cb=d+16|0}function wp(a,b){a=ic(a,b,88);v[a+88>>2]=v[b+88>>2];ic(a+92|0,b+92|0,576);v[a+668>>2]=v[b+668>>2];ic(a+672|0,b+672|0,52);Fy(a+724|0,b+724|0);Fy(a+732|0,b+732|0);Fy(a+740|0,b+740|0);ic(a+748|0,b+748|0,123);return a}function qja(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;d=Kb(a,64);a:{if(!d){a=b- -64|0;while(1){if((a|0)!=(b|0)){no(b);b=b+2|0;continue}break}break a}ku(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}cb=c+16|0;return d|0}function mn(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return C(b?-1/a:a)}function m_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=No(a);e=vb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Fb(a);ki(d+(e<<2)|0,b,c);b=c+e|0;Bf(a,b);qd(d+(b<<2)|0,0);return a|0}DE(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function dm(a,b){var c=C(0),d=0,e=0;c=C(1);d=u[a+28>>1];a:{if((d|0)>(b|0)){break a}e=v[a+4>>2];if((pc(e,v[a+8>>2])+d<<16)-65536>>16<(b|0)){break a}c=z[Ib(e,b-d|0)>>2];c=c<=C(1.0000000036274937e-15)?C(1):c}return c}function yha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{e=yd(a);b:{d=b+c|0;c=Oh(b,d);if(c){v[22440]=0;R(348,a|0,c|0);f=v[22440];v[22440]=0;if((f|0)==1){break b}Qt(a,b,d,c)}break a}a=P()|0;O()|0;_b(e);S(a|0);L()}}function vu(a,b,c){var d=0;a=a+3|0;a=(w[a|0]|w[a+1|0]<<8)>>>B(c,3)|0;d=a>>>2&1|w[b+12|0]&-8;t[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=w[b+13|0]|w[b+14|0]<<8;t[b+15|0]=a;t[b+16|0]=a>>>8;t[b+12|0]=d|4}}function qZ(a){a=a|0;a:{b:{if(t[463840]&1){break b}if(!Xd(463840)){break b}v[22440]=0;Q(1236,463828,80252)|0;a=v[22440];v[22440]=0;if((a|0)==1){break a}Wd(463840)}return 463828}a=P()|0;O()|0;nf(463840);S(a|0);L()}function pZ(a){a=a|0;a:{b:{if(t[463872]&1){break b}if(!Xd(463872)){break b}v[22440]=0;Q(1236,463860,80336)|0;a=v[22440];v[22440]=0;if((a|0)==1){break a}Wd(463872)}return 463860}a=P()|0;O()|0;nf(463872);S(a|0);L()}function oZ(a){a=a|0;a:{b:{if(t[463776]&1){break b}if(!Xd(463776)){break b}v[22440]=0;Q(1236,463764,80180)|0;a=v[22440];v[22440]=0;if((a|0)==1){break a}Wd(463776)}return 463764}a=P()|0;O()|0;nf(463776);S(a|0);L()}function nZ(a){a=a|0;a:{b:{if(t[463808]&1){break b}if(!Xd(463808)){break b}v[22440]=0;Q(1236,463796,80216)|0;a=v[22440];v[22440]=0;if((a|0)==1){break a}Wd(463808)}return 463796}a=P()|0;O()|0;nf(463808);S(a|0);L()}function UE(a){var b=0,c=0;b=cb-16|0;cb=b;v[b>>2]=465232;c=v[116309];v[b+4>>2]=c;v[b+8>>2]=c+(a<<2);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){dc(b);cb=b+16|0}else{QE(a);a=a+4|0;v[b+4>>2]=a;continue}break}}function Qfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,1030);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){Hb(b,0,1030)}return a|0}function Dha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=cb-16|0;cb=e;c=rf(a,c);ke(e,v[a+36>>2]);a:{if(!c){Cc(e,a+32|0,5);f=0;if(tb(v[v[e>>2]>>2],v[e+4>>2])){break a}}CS(v[a+36>>2],b,d,0);f=c}Se(a,f);cb=e+16|0}function vM(a,b){var c=0,d=0,e=0,f=0;a:{v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];d=xb(a);c=bc(a);if(!v[d>>2]){v[a>>2]=c;break a}v[v[c>>2]+8>>2]=c;a=bc(b);v[b>>2]=a;v[a>>2]=0;e=xb(b),f=0,v[e>>2]=f}}function sS(a,b,c){var d=0,e=0;d=cb-16|0;cb=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,6)+e;a=v[d>>2];while(1){if(v[d+4>>2]!=(a|0)){Ot(a,c);a=v[d>>2]+6|0;v[d>>2]=a;continue}break}Gd(d);cb=d+16|0}function gy(a,b){var c=0;c=v[b+24>>2];c=c?c:1;v[a+24628>>2]=c>>>0<512?c:512;a:{if(!(v[b+16>>2]!=v[a+24620>>2]|v[b+20>>2]!=v[a+24624>>2])){c=0;if(v[b+12>>2]==v[a+24616>>2]){break a}}c=1}ic(a+24604|0,b,40);qL(a,c)}function Qv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=NF(b);if(c>>>0<1073741808){b:{if(c>>>0<=1){Yd(a,c);d=a;break b}e=Pl(c)+1|0;d=Ci(e);qd(a,d);cf(a,e);td(a,c)}ki(d,b,c);qd((c<<2)+d|0,0);break a}Ye();L()}return a|0}function yk(a){qc(a+16|0,v[a>>2]);qc(a+8|0,v[a>>2]);if(y[a+12>>2]>=y[a+16>>2]){v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=x[a+34>>1]&65511}if(y[a+4>>2]>=y[a+8>>2]){v[a+4>>2]=0;v[a+8>>2]=0;u[a+34>>1]=x[a+34>>1]&65529}}function xO(a,b,c,d){var e=0;e=cb-16|0;cb=e;a=Xh(e,a,d);d=cb-16|0;cb=d;v[d+8>>2]=b;while(1){if(Qb(b,c)){Mi(v[a+4>>2],x[b>>1]);Ne(d+8|0);v[a+4>>2]=v[a+4>>2]+2;b=v[d+8>>2];continue}break}cb=d+16|0;dc(a);cb=e+16|0}function gZ(a){a=a|0;a:{b:{if(t[463824]&1){break b}if(!Xd(463824)){break b}v[22440]=0;Q(56,463812,13526)|0;a=v[22440];v[22440]=0;if((a|0)==1){break a}Wd(463824)}return 463812}a=P()|0;O()|0;nf(463824);S(a|0);L()}function dZ(a){a=a|0;a:{b:{if(t[463792]&1){break b}if(!Xd(463792)){break b}v[22440]=0;Q(56,463780,13787)|0;a=v[22440];v[22440]=0;if((a|0)==1){break a}Wd(463792)}return 463780}a=P()|0;O()|0;nf(463792);S(a|0);L()}function Yfa(a){a=a|0;var b=0,c=0,d=0;b=cb-32|0;cb=b;u[b+30>>1]=0;c=$b(b+8|0,b+30|0,2);Yb(b+16|0,a,v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=2){break a}if(Mb(b+30|0,13702,2)){break a}Ob(a,2);d=1}cb=b+32|0;return d|0}function Pja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;gv(c+8|0,b);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;if((d|0)!=(e|0)){t[b+2|0]=0;t[b|0]=0;t[b+1|0]=0}}function Hia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,308);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){Hb(b,0,308)}return a|0}function Hga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,422);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){Hb(b,0,422)}return a|0}function Cga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,826);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){Hb(b,0,826)}return a|0}function u2(a,b){a=a|0;b=b|0;var c=0,d=0;c=js(a);v[a>>2]=73392;d=Db(a+32|0);v[a+44>>2]=0;v[a+48>>2]=8;v[22440]=0;R(94,a|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;rb(d);am(c);S(a|0);L()}function sfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,71);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){Hb(b,0,71)}return a|0}
function nG(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];a:{if(!c){break a}d=v[c+24>>2];b:{if((d|0)==v[c+28>>2]){b=gb[v[v[c>>2]+52>>2]](c,b)|0;break b}v[c+24>>2]=d+4;v[d>>2]=b}if(!jn(b)){break a}v[a>>2]=0}return a|0}function m9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=cb-16|0;cb=e;c=rf(a,c);ke(e,v[a+36>>2]);a:{if(!c){Cc(e,a+32|0,5);f=0;if(tb(v[v[e>>2]>>2],v[e+4>>2])){break a}}yK(d,v[a+36>>2],b);f=c}Se(a,f);cb=e+16|0}function fy(a,b){var c=0,d=0;c=v[b+4>>2];v[a+24648>>2]=v[b>>2];v[a+24652>>2]=c;d=v[b+20>>2];c=a+24664|0;v[c>>2]=v[b+16>>2];v[c+4>>2]=d;d=v[b+12>>2];c=a+24656|0;v[c>>2]=v[b+8>>2];v[c+4>>2]=d;pL(a+24648|0);wL(a)}function fZ(a){a=a|0;a:{b:{if(t[463856]&1){break b}if(!Xd(463856)){break b}v[22440]=0;Q(56,463844,9282)|0;a=v[22440];v[22440]=0;if((a|0)==1){break a}Wd(463856)}return 463844}a=P()|0;O()|0;nf(463856);S(a|0);L()}function eZ(a){a=a|0;a:{b:{if(t[463760]&1){break b}if(!Xd(463760)){break b}v[22440]=0;Q(56,463748,5268)|0;a=v[22440];v[22440]=0;if((a|0)==1){break a}Wd(463760)}return 463748}a=P()|0;O()|0;nf(463760);S(a|0);L()}function P9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,225);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){Hb(b,0,225)}return a|0}function Ofa(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;d=Kb(a,6);a:{if(!d){a=b+6|0;while(1){if((a|0)!=(b|0)){ug(b);b=b+1|0;continue}break}break a}aB(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}cb=c+16|0;return d|0}function M9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,326);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){Hb(b,0,326)}return a|0}function zea(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;nm(a,b);b=yb(v[a>>2]);v[c+8>>2]=b;a=yb(v[a+4>>2]);while(1){if(Qb(b,a)){d=w[b|0]+(d&255)|0;t[b|0]=d;Fe(c+8|0);b=v[c+8>>2];continue}else{cb=c+16|0}break}}function yv(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-12|0;dr(v[d>>2]-12|0,c);v[d>>2]=v[d>>2]-12;continue}break}ec(a,d);ec(a+4|0,b+8|0);ec(xb(a),mc(b));v[b>>2]=v[b+4>>2]}function vd(a,b){var c=0,d=0;c=cb-16|0;cb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Kb(a,1)){break b}t[c+15|0]=0;yg(a,c+15|0);t[c+8|0]=w[c+15|0];d=w[c+8|0]}cb=c+16|0;break a}ca(11259,9108,136,14288);L()}return d}function r8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;a=$j(a);if(a){d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;e=v[v[a>>2]+72>>2];v[c>>2]=b;v[c+4>>2]=d;a=gb[e|0](a,c)|0}else{a=1}cb=c+16|0;return a|0}function pD(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-36|0;jv(v[d>>2]-36|0,c);v[d>>2]=v[d>>2]-36;continue}break}ec(a,d);ec(a+4|0,b+8|0);ec(xb(a),mc(b));v[b>>2]=v[b+4>>2]}function ot(a){var b=0,c=0;a:{if(Mb(a,13630,4)|w[a+4|0]){break a}b=a+6|0;if(wb(w[b|0]|w[b+1|0]<<8)>>>0>1){break a}b=a+12|0;if(wb(w[b|0]|w[b+1|0]<<8)){break a}a=a+16|0;c=(wb(w[a|0]|w[a+1|0]<<8)|0)==20}return c}function lO(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-32|0;gz(v[d>>2]-32|0,c);v[d>>2]=v[d>>2]-32;continue}break}ec(a,d);ec(a+4|0,b+8|0);ec(xb(a),mc(b));v[b>>2]=v[b+4>>2]}function gha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,91);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){Hb(b,0,91)}return a|0}function YA(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-20|0;$A(v[d>>2]-20|0,c);v[d>>2]=v[d>>2]-20;continue}break}ec(a,d);ec(a+4|0,b+8|0);ec(xb(a),mc(b));v[b>>2]=v[b+4>>2]}function Wm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-16|0;cb=d;a:{if(c){Bc(d,c);break a}Db(d)}v[22440]=0;U(11,a|0,b|0,d|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(d);cb=d+16|0;return}a=P()|0;O()|0;rb(d);S(a|0);L()}function Nia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,78);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){Hb(b,0,78)}return a|0}function KC(a,b){var c=0,d=0;c=cb-16|0;cb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Kb(a,1)){break b}t[c+15|0]=0;yg(a,c+15|0);t[c+8|0]=w[c+15|0];d=t[c+8|0]}cb=c+16|0;break a}ca(11259,9108,136,14288);L()}return d}function Fv(a,b,c){var d=0;d=v[a+16>>2];if(!d){v[a+36>>2]=1;v[a+24>>2]=c;v[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(v[a+24>>2]!=2){break a}v[a+24>>2]=c;return}t[a+54|0]=1;v[a+24>>2]=2;v[a+36>>2]=v[a+36>>2]+1}}function taa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=(b-a|0)/160|0;while(1){if((b|0)>0){b=b-1|0;v[a>>2]=v[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){iy(d,v[c+4>>2],v[c+8>>2])}ic(a+16|0,c+16|0,144);a=a+160|0;continue}break}}function l3(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a=v[a+24>>2];WI(c,b);a=v[a+1298464>>2];v[22440]=0;U(388,a|0,1,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(c);cb=c+16|0;return}a=P()|0;O()|0;rb(c);S(a|0);L()}function eia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;oA(c+8|0,b);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){Hb(b,0,4896)}return a|0}function R9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,73);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){Hb(b,0,73)}return a|0}function K9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,60);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){Hb(b,0,60)}return a|0}function EP(a){a=a*4294967296;if(D(a)<0x8000000000000000){fb=D(a)>=1?~~(a>0?F(H(a*2.3283064365386963e-10),4294967295):I((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0}fb=-2147483648;return 0}function zu(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function wT(a){var b=0;a:{if(Mb(a,3873,4)|w[a+68|0]!=13|(w[a+69|0]!=10|w[a+70|0]!=26)){break a}if(Mb(a+71|0,13782,4)|w[a+75|0]!=1|w[a+76|0]){break a}a=a+116|0;b=((w[a|0]|w[a+1|0]<<8)-1&65535)>>>0<9}return b}function mM(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+28>>2];v[a+24>>2]=v[b+24>>2];v[a+28>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function Wz(a,b,c,d){var e=0,f=0;e=cb-16|0;cb=e;f=v[b+12>>2];v[e+12>>2]=d;v[e+8>>2]=c;c=v[v[b>>2]+28>>2];d=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=d;gb[c|0](a,b,f,e);v[b+12>>2]=v[b+12>>2]+v[a+4>>2];cb=e+16|0}function Dg(a){var b=0;v[22440]=0;a=T(836,a|0)|0;b=v[22440];v[22440]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[22440]=0;X(18);b=v[22440];v[22440]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;O()|0;Lb();L()}function gF(a,b,c,d,e,f){var g=0,h=0,i=0;g=cb-16|0;cb=g;t[g+15|0]=0;t[g+14|0]=f;t[g+13|0]=e;t[g+12|0]=37;if(f){xh(g+13|0,g+14|0)}h=c,i=(Za(b|0,Uc(b,v[c>>2])|0,g+12|0,d|0,v[a>>2])|0)+b|0,v[h>>2]=i;cb=g+16|0}function _ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;kA(c+8|0,b);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){Hb(b,0,33)}return a|0}function GV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ku(c+8|0,b);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){Hb(b,0,65)}return a|0}
function xw(a){a=a|0;var b=0;v[a>>2]=74588;v[22440]=0;R(72,a|0,0);b=v[22440];v[22440]=0;if((b|0)!=1){Pb(a+28|0);zb(v[a+32>>2]);zb(v[a+36>>2]);zb(v[a+48>>2]);zb(v[a+60>>2]);return a|0}V(0)|0;O()|0;Lb();L()}function dz(a){var b=0,c=0,d=0;b=x[a+20>>1];u[a+28>>1]=x[a+22>>1]<<1|(w[v[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){if((b|0)!=4){c=(b<<2)+a|0;d=v[c>>2];if(d){Kn(d);hO(v[c>>2])}b=b+1|0;continue}break}}function bea(a){a=a|0;var b=0;b=cb-16|0;cb=b;a:{if(gq(a,10284)){MI(b,17604,a);a=Fb(b);v[22440]=0;R(40,44,a|0);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;rb(b);S(a|0);L()}cb=b+16|0;return}L()}function UM(a,b,c){var d=0;a:{if(v[a+480180>>2]!=67108864){break a}d=B(c,872)+b|0;v[d+704>>2]=v[d+704>>2]&-129;d=x[a+480188>>1];a=c^1;if(d>>>0<=a>>>0){break a}a=B(a,872)+b|0;v[a+704>>2]=v[a+704>>2]&-129}}function TA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Dc(a);e=vb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Fb(a);Ce(d+e|0,b,c);b=c+e|0;Bf(a,b);kd(b+d|0,0);return a|0}cq(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function Nf(a,b,c,d,e){var f=0;f=cb-256|0;cb=f;if(!(e&73728|(c|0)<=(d|0))){c=c-d|0;d=c>>>0<256;Hb(f,b&255,d?c:256);if(!d){while(1){tf(a,f,256);c=c-256|0;if(c>>>0>255){continue}break}}tf(a,f,c)}cb=f+256|0}function zh(a,b){var c=0;a=v[a>>2];b=_d(b);c=v[a+8>>2];if(pc(c,v[a+12>>2])>>>0>b>>>0){c=v[Ib(c,b)>>2]!=0}else{c=0}if(!c){a=aa(4)|0;_l(a);v[a>>2]=88804;ia(a|0,88940,1132);L()}return v[Ib(v[a+8>>2],b)>>2]}function ge(a,b){var c=0,d=0,e=0;b=b+7&-8;v[a+8>>2]=b+v[a+8>>2];d=v[a+80>>2];a:{if(d){c=b;b=v[a+88>>2];e=c+b|0;c=0;if((e|0)>v[a+92>>2]){break a}v[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Hd(b)}return c}function Uda(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;if((b|0)>=0){d=2147483647;a=ft(a);if(a>>>0<=1073741822){v[c+12>>2]=a<<1;v[c+8>>2]=b+31&-32;d=v[Pc(c+12|0,c+8|0)>>2]}cb=c+16|0;return d|0}Bz();L()}function Q6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=cb-16|0;cb=f;b=yc(lka(kka(d,d>>31,b,0),fb,1e3,0),fb);v[a+16>>2]=0;v[a+12>>2]=b+c;IJ(a,e);b=v[a+12>>2];v[f+12>>2]=0;BK(a,b,f+12|0);cb=f+16|0}function M8(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=v[b+52>>2];if(c&16){d=v[b+48>>2];c=v[b+28>>2];if(d>>>0<c>>>0){v[b+48>>2]=c;d=c}Ph(a,v[b+24>>2],d);break a}if(c&8){Ph(a,v[b+12>>2],v[b+20>>2]);break a}Db(a)}}function tL(a,b,c){var d=0,e=0,f=0,g=0;e=cb-16|0;cb=e;d=Dc(a);a:{if(d>>>0>=c>>>0){b=Rh(Fb(a),b,c);t[e+15|0]=0;$d(b+c|0,e+15|0);Bf(a,c);break a}f=d;g=c-d|0;d=vb(a);Mo(a,f,g,d,0,d,c,b)}cb=e+16|0;return a}function a3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=cb-16|0;cb=e;a=ht(e,a,d);v[22440]=0;U(1079,b|0,c|0,a+4|0);b=v[22440];v[22440]=0;if((b|0)!=1){dc(a);cb=e+16|0;return}b=P()|0;O()|0;dc(a);S(b|0);L()}function Yf(a){var b=0,c=0,d=0,e=0;b=cb-16|0;cb=b;c=2;if(a>>>0>=2){v[b+12>>2]=a>>>1;v[b+8>>2]=a^-1;d=b,e=v[Bb(b+12|0,b+8|0)>>2]+a|0,v[d+12>>2]=e;v[b+8>>2]=-1;c=v[Bb(b+12|0,b+8|0)>>2]}cb=b+16|0;return c}function KQ(a){var b=0,c=0,d=0,e=0;fb=0;d=w[a+4|0];e=w[a+92|0];b=w[a+93|0];a=a+94|0;c=w[a|0]|w[a+1|0]<<8;b=b+c|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function F1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=cb-16|0;cb=e;a=tt(e,a,d);v[22440]=0;U(1110,b|0,c|0,a+4|0);b=v[22440];v[22440]=0;if((b|0)!=1){dc(a);cb=e+16|0;return}b=P()|0;O()|0;dc(a);S(b|0);L()}function AT(a){var b=0,c=0;a:{if(Mb(a,21674,11)){break a}b=a+215|0;a=a+63|0;while(1){if((a|0)==(b|0)){return 1}if(w[a+16|0]>3|w[a+17|0]>3){break a}c=a;a=a+19|0;if(w[c+18|0]<16){continue}break}}return 0}function pba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;$N(c+8|0,b);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){Zy(b)}return a|0}function RS(a){var b=0,c=0;b=a+36|0;c=kka(w[b|0]|w[b+1|0]<<8,0,384,0);a=a+34|0;b=w[a|0]|w[a+1|0]<<8;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+fb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;a=b>>>0<256?a+1|0:a;fb=a;return b}function xt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;IQ(c+8|0,b);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){JQ(b)}return a|0}function uX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=cb-16|0;cb=d;f=v[v[b>>2]+20>>2];e=v[c+12>>2];v[d+8>>2]=v[c+8>>2];v[d+12>>2]=e;e=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=e;gb[f|0](a,b,d,8);cb=d+16|0}function qC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;sC(c+8|0,b);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){rC(b)}return a|0}function dh(a,b){var c=0,d=0,e=0;c=vb(a);a:{if((c|0)!=(vb(b)|0)){break a}d=Fb(a);b=Fb(b);if(!Ld(a)){while(1){e=!c;if(!c|w[d|0]!=w[b|0]){break a}b=b+1|0;d=d+1|0;c=c-1|0;continue}}e=!zp(d,b,c)}return e}function Hu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;_B(c+8|0,b);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){ZB(b)}return a|0}function zL(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){if((a|0)!=(c|0)){b=v[a>>2];a:{if(!b){break a}if(!(gb[v[v[b>>2]+116>>2]](b)|0)){break a}gb[v[v[b>>2]+96>>2]](b)}a=a+160|0;continue}break}}function xU(a,b,c,d){var e=0,f=0;lf(a+12|0,d);if(b){if(b>>>0>=153391690){af(11191);L()}d=lc(B(b,28))}else{d=0}v[a>>2]=d;c=d+B(c,28)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=mc(a),f=d+B(b,28)|0,v[e>>2]=f;return a}function vJ(a){var b=0,c=0,d=C(0);if(!a){return C(1)}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(D(c)<2147483648){a=~~c;break a}a=-2147483648}d=C(ni(b-+(a|0)))}else{d=C(0)}return d}function sE(a,b,c,d){var e=0,f=0;lf(a+12|0,d);if(b){if(b>>>0>=178956971){af(11191);L()}d=lc(B(b,24))}else{d=0}v[a>>2]=d;c=d+B(c,24)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=mc(a),f=d+B(b,24)|0,v[e>>2]=f;return a}function qD(a,b,c,d){var e=0,f=0;lf(a+12|0,d);if(b){if(b>>>0>=119304648){af(11191);L()}d=lc(B(b,36))}else{d=0}v[a>>2]=d;c=d+B(c,36)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=mc(a),f=d+B(b,36)|0,v[e>>2]=f;return a}function bU(a,b,c,d){var e=0,f=0;lf(a+12|0,d);if(b){if(b>>>0>=89478486){af(11191);L()}d=lc(B(b,48))}else{d=0}v[a>>2]=d;c=d+B(c,48)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=mc(a),f=d+B(b,48)|0,v[e>>2]=f;return a}function TI(){var a=0,b=0,c=0,d=0;a=cb-16|0;cb=a;b=lc(1298472);v[22440]=0;c=T(1084,b|0)|0;d=v[22440];v[22440]=0;if((d|0)!=1){b=v[Sf(a+8|0,c)>>2];cb=a+16|0;return b|0}a=P()|0;O()|0;zb(b);S(a|0);L()}function SN(a,b,c,d,e,f){v[a+40>>2]=0;v[a+44>>2]=0;A[a+32>>3]=f;A[a+24>>3]=e;A[a+16>>3]=d;A[a+8>>3]=c;A[a>>3]=b;v[a+48>>2]=0;v[a+52>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;a=a- -64|0;v[a>>2]=0;v[a+4>>2]=0}function Jh(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-32|0;cb=c;t[c+24|0]=0;bj(c+8|0,c+24|0);d=c+16|0;kn(d,a,v[c+8>>2],v[c+12>>2]);a=v[c+20>>2];t[c+16|0]=w[c+24|0];t[b|0]=w[d|0];cb=c+32|0;return(a|0)==1|0}function Jd(a,b){var c=0,d=0,e=0;d=x[a+24>>1];if((d|0)!=(b&65535)){c=x[a+22>>1]-1&127;u[a+22>>1]=c;e=x[a+20>>1];if(e>>>0<=127){u[a+20>>1]=e+1}c=(c<<2)+a|0;u[c+26>>1]=b-d;u[c+28>>1]=0;u[a+24>>1]=b}}function pN(a,b,c,d){var e=0,f=0;lf(a+12|0,d);if(b){if(b>>>0>=613566757){af(11191);L()}d=lc(B(b,7))}else{d=0}v[a>>2]=d;c=d+B(c,7)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=mc(a),f=d+B(b,7)|0,v[e>>2]=f;return a}function ej(a){var b=0;b=32767;a:{if(a>=C(32766.5)){break a}b=32768;if(a<=C(-32767.5)){break a}a=C(a+C(.5));b:{if(C(D(a))<C(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function dka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,136);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;if((d|0)!=(e|0)){Hb(b,0,136)}}function Tfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,274);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;if((d|0)!=(e|0)){Hb(b,0,274)}}function NG(a){var b=0,c=0,d=0;d=v[a>>2];while(1){c=t[d|0];if(Yj(c)){d=d+1|0;v[a>>2]=d;if(b>>>0<=214748364){c=c-48|0;b=B(b,10);b=(c|0)>(2147483647-b|0)?-1:c+b|0}else{b=-1}continue}break}return b}
function Lfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,106);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;if((d|0)!=(e|0)){Hb(b,0,106)}}function Bia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,282);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;if((d|0)!=(e|0)){Hb(b,0,282)}}function eu(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Vja(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{if(!Kb(a,64)){a=b- -64|0;while(1){if((a|0)!=(b|0)){ug(b);b=b+1|0;continue}break}break a}ku(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}cb=c+16|0}function QR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,284);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;if((d|0)!=(e|0)){Hb(b,0,284)}}function rO(a){a=a|0;var b=0,c=0;b=cb-32|0;cb=b;t[a+16|0]=0;c=jz(b,v[a+12>>2]);v[22440]=0;R(775,a|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){il(c);cb=b+32|0;return}a=P()|0;O()|0;il(c);S(a|0);L()}function mja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,34);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;if((d|0)!=(e|0)){Hb(b,0,34)}}function kB(a,b){var c=0;c=cb-16|0;cb=c;v[c+12>>2]=1;v[c+8>>2]=a>>>4;b=Vb(128/(B(v[Ke(c+12|0,c+8|0)>>2],b)|0)|0,1,15);t[c+7|0]=1;t[c+6|0]=a&15;a=w[ff(c+7|0,c+6|0)|0];cb=c+16|0;return a|b<<4&240}function Oga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,42);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;if((d|0)!=(e|0)){Hb(b,0,42)}}function Jfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,72);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;if((d|0)!=(e|0)){Hb(b,0,72)}}function uJ(a,b){var c=0,d=0,e=0,f=0;if(a>C(.9999989867210388)){d=0}else{a=C(a*a);c=+a;e=32768/(1-c);f=c;c=We(31415.926535897932/+b);d=tl(e*(1-(f*c+K(+C(a+a)*(1-c)-+C(a*a)*(1-c*c)))))}return d}function oba(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{if(!Kb(a,27)){a=b+27|0;while(1){if((a|0)!=(b|0)){ug(b);b=b+1|0;continue}break}break a}$N(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}cb=c+16|0}function oH(a,b){var c=0,d=0,e=0,f=C(0),g=C(0),h=0;b=(b|0)>0?b:0;h=a+2304|0;while(1){if((b|0)!=(d|0)){c=d<<2;e=c+a|0;f=z[e>>2];c=c+h|0;g=z[c>>2];z[e>>2]=f+g;z[c>>2]=f-g;d=d+1|0;continue}break}}function lT(a){var b=0,c=0,d=0;b=cb-16|0;cb=b;a=a+4|0;c=b,d=Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)),v[c+12>>2]=d;v[b+8>>2]=236;a=v[Pc(b+12|0,b+8|0)>>2];cb=b+16|0;fb=0;return a-216|0}function Z5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=cb-16|0;cb=e;f=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;a=YH(a,e,c,d);cb=e+16|0;return a|0}function GS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=cb-16|0;cb=d;bg(a,d+14|0);e=x[d+14>>1];GL(b,e);c=0;while(1){if((c|0)==(e|0)){jy(b);cb=d+16|0}else{nk(a,Ib(v[b>>2],c));c=c+1|0;continue}break}}function DV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,59);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;if((d|0)!=(e|0)){Hb(b,0,59)}}function AB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,50);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;if((d|0)!=(e|0)){Hb(b,0,50)}}function yc(a,b){var c=0;c=cb-32|0;cb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=-2147483648;v[c+20>>2]=-1;v[c+8>>2]=2147483647;v[c+12>>2]=0;a=jE(c+16|0,uu(c+24|0,c+8|0));cb=c+32|0;return v[a>>2]}function wg(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb+-64|0;cb=c;d=Mx(c+8|0,a);v[22440]=0;U(203,a|0,b|0,d|0);a=v[22440];v[22440]=0;if((a|0)!=1){bl(d);cb=c- -64|0;return}a=P()|0;O()|0;bl(d);S(a|0);L()}function ZQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=65535;a:{if(!ve(a,b)){break a}c=mB(a,v[fg(v[a>>2],b)+12>>2],c);d=65535;if((c|0)==65535){break a}a=v[a>>2];b=fg(a,b);PK(fg(a,c),b);d=c}return d|0}function YQ(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{if(!Kb(a,32)){a=b+32|0;while(1){if((a|0)!=(b|0)){ug(b);b=b+1|0;continue}break}break a}WQ(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}cb=c+16|0}function rE(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-24|0,24)|0;v[c>>2]=f;if((d|0)>0){ic(f,e,d)}ec(a,c);ec(a+4|0,b+8|0);ec(xb(a),mc(b));v[b>>2]=v[b+4>>2]}function pj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=hl(a,b);if((d|0)==255){break a}fk(a,b);Ip(a,b,0,0);if(!c){break a}e=Xb(a+26|0,d),f=65535,u[e>>1]=f;a=Eb(a+62|0,b);t[a|0]=w[a|0]|128}}function aU(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-48|0,48)|0;v[c>>2]=f;if((d|0)>0){ic(f,e,d)}ec(a,c);ec(a+4|0,b+8|0);ec(xb(a),mc(b));v[b>>2]=v[b+4>>2]}function TP(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-12|0,12)|0;v[c>>2]=f;if((d|0)>0){ic(f,e,d)}ec(a,c);ec(a+4|0,b+8|0);ec(xb(a),mc(b));v[b>>2]=v[b+4>>2]}function RT(a){var b=0,c=0;a:{if(Mb(a,17879,8)|w[a+8|0]>1|(w[a+9|0]-1&255)>>>0>7){break a}b=a+10|0;if((w[b|0]|w[b+1|0]<<8)>>>0>4096){break a}a=a+12|0;c=(w[a|0]|w[a+1|0]<<8)>>>0<4097}return c}function R0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(d>>>0<4294967280){a:{if(d>>>0<=10){Yd(a,c);d=a;break a}e=Kg(d)+1|0;d=lc(e);qd(a,d);cf(a,e);td(a,c)}kd(Ce(d,b,c)+c|0,0);return}Ye();L()}function HO(a,b){var c=0;c=w[a+800|0];a:{if(c){break a}c=rg(w[a+797|0]-u[a+770>>1]|0);if(!b|(c<<24)-16777216>>24<0){break a}a=v[a+656>>2];if(!a){break a}c=w[Eb(a+108|0,c-1|0)|0]}return c&255}function EE(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=79944;d=a+8|0;while(1){b=v[a+8>>2];if(pc(b,v[a+12>>2])>>>0>c>>>0){b=v[Ib(b,c)>>2];if(b){Um(b)}c=c+1|0;continue}break}rb(a+152|0);Uv(d);return a|0}function jaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;e=x[a+28>>1];u[d+8>>1]=e;f=d,g=(pc(v[a+4>>2],v[a+8>>2])+e|0)-1|0,u[f+10>>1]=g;a=GK(a,b,c,d+8|0);cb=d+16|0;return a|0}function hy(a,b){var c=0;KP(a,b);t[a+12|0]=w[b+12|0];c=w[b+13|0]|w[b+14|0]<<8|(w[b+15|0]<<16|w[b+16|0]<<24);t[a+13|0]=c;t[a+14|0]=c>>>8;t[a+15|0]=c>>>16;t[a+16|0]=c>>>24;t[a+17|0]=w[b+17|0]}function h7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Dg(4332);if(!d){return 0}v[22440]=0;a=ea(945,d|0,a|0,b|0,c|0,0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;zb(d);S(a|0);L()}function b9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=cb-16|0;cb=d;e=v[b>>2];f=v[a+40>>2];if(e>>>0<Uc(f,v[a+44>>2])>>>0){a=Lk(d,Eb(f,e),x[b+20>>1]);g=Wv(c,a);Ab(a)}cb=d+16|0;return g|0}function _6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Dg(4332);if(!d){return 0}v[22440]=0;a=ea(945,d|0,a|0,b|0,c|0,1)|0;b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;zb(d);S(a|0);L()}function Q7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Dg(4332);if(!d){return 0}v[22440]=0;a=ea(941,d|0,a|0,b|0,c|0,0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;zb(d);S(a|0);L()}function PA(a,b){var c=0,d=0,e=0;c=cb-16|0;cb=c;d=c,e=(jp(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),A[d+8>>3]=e;dN(c+8|0,127);a=rk(A[c+8>>3]);cb=c+16|0;return a}function JU(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{if(!Kb(a,8)){a=b+8|0;while(1){if((a|0)!=(b|0)){ug(b);b=b+1|0;continue}break}break a}Qm(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}cb=c+16|0}function x6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Dg(86224);if(!d){return 0}v[22440]=0;a=da(950,d|0,a|0,b|0,c|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;zb(d);S(a|0);L()}function qn(a){var b=0,c=0;b=cb-16|0;cb=b;a:{if(HI(w[a+20|0])){break a}v[22440]=0;R(1089,b+8|0,a|0);c=v[22440];v[22440]=0;if((c|0)!=1){break a}V(0)|0;O()|0;Lb();L()}t[a+20|0]=255;cb=b+16|0}function oN(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-7|0,7)|0;v[c>>2]=f;if((d|0)>0){ic(f,e,d)}ec(a,c);ec(a+4|0,b+8|0);ec(xb(a),mc(b));v[b>>2]=v[b+4>>2]}function UF(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:t[a|0]=c;return;case 1:u[a>>1]=c;return;case 2:case 3:v[a>>2]=c;return;case 5:break b;default:break a}}v[a>>2]=c;v[a+4>>2]=d}}function LT(a){var b=0,c=0;a:{if(Mb(a,16748,4)){break a}b=a+4|0;if(Wb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-257>>>0<4294967053){break a}a=a+8|0;c=!wb(w[a|0]|w[a+1|0]<<8)}return c}function BC(a){var b=0;b=v[a+72>>2];v[a+72>>2]=b-1|b;b=v[a>>2];if(b&8){v[a>>2]=b|32;return-1}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];return 0}function v7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Dg(4276);if(!d){return 0}v[22440]=0;a=da(943,d|0,a|0,b|0,c|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;zb(d);S(a|0);L()}function o7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Dg(4268);if(!d){return 0}v[22440]=0;a=da(944,d|0,a|0,b|0,c|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;zb(d);S(a|0);L()}function ey(a,b,c,d,e,f,g,h,i){var j=0;j=cb-16|0;cb=j;Eg(j,b,c,d,e,f,g,h,i^-2147483648);d=v[j>>2];c=v[j+4>>2];b=v[j+12>>2];v[a+8>>2]=v[j+8>>2];v[a+12>>2]=b;v[a>>2]=d;v[a+4>>2]=c;cb=j+16|0}function eA(a,b){var c=0,d=0;d=cb-32|0;cb=d;c=xb(a);c=$f(d+8|0,Gg(a,pc(v[a>>2],v[a+4>>2])+1|0),pc(v[a>>2],v[a+4>>2]),c);og(v[c+8>>2],v[b>>2]);v[c+8>>2]=v[c+8>>2]+4;Ad(a,c);_f(c);cb=d+32|0}function _7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Dg(4236);if(!d){return 0}v[22440]=0;a=da(939,d|0,a|0,b|0,c|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;zb(d);S(a|0);L()}function Z6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Dg(4228);if(!d){return 0}v[22440]=0;a=da(946,d|0,a|0,b|0,c|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;zb(d);S(a|0);L()}function X8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Dg(4268);if(!d){return 0}v[22440]=0;a=da(921,d|0,a|0,b|0,c|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;zb(d);S(a|0);L()}function V9(a,b){a=a|0;b=b|0;var c=0;b=cb-16|0;cb=b;c=-1;a:{if(!Pj(a,b+8|0)){break a}c=0;if(!YK(b+8|0)){break a}a=hQ(a,b);if(!a){Bm(b)}c=-1;if(!a){break a}c=XK(b)}a=c;cb=b+16|0;return a|0}function Tw(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+B(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((B(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function Sfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=yd(a);a:{if(b){v[22440]=0;R(634,a|0,b|0);e=v[22440];v[22440]=0;if((e|0)==1){break a}oo(a,b,c)}return a|0}a=P()|0;O()|0;_c(d);S(a|0);L()}function P6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Dg(5048);if(!d){return 0}v[22440]=0;a=da(947,d|0,a|0,b|0,c|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;zb(d);S(a|0);L()}function F7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Dg(4280);if(!d){return 0}v[22440]=0;a=da(942,d|0,a|0,b|0,c|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;zb(d);S(a|0);L()}function E6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Dg(4276);if(!d){return 0}v[22440]=0;a=da(949,d|0,a|0,b|0,c|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;zb(d);S(a|0);L()}function D8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Dg(4304);if(!d){return 0}v[22440]=0;a=da(929,d|0,a|0,b|0,c|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;zb(d);S(a|0);L()}function wia(){var a=0;a:{b:{if(t[89796]&1){break b}if(!Xd(89796)){break b}v[22440]=0;X(27);a=v[22440];v[22440]=0;if((a|0)==1){break a}Wd(89796)}return}a=P()|0;O()|0;nf(89796);S(a|0);L()}function oh(a,b,c){a:{if(b>>>0<=c>>>0){a=aa(8)|0;v[22440]=0;T(195,a|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ba(a|0);S(b|0);L()}return w[a+c|0]}ia(a|0,26168,170);L()}function hu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=yd(a);a:{if(b){v[22440]=0;R(326,a|0,b|0);e=v[22440];v[22440]=0;if((e|0)==1){break a}Jm(a,b,c)}return a|0}a=P()|0;O()|0;_b(d);S(a|0);L()}function QO(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function MF(a,b){var c=0,d=0;d=cb-32|0;cb=d;c=xb(a);c=Sl(d+8|0,Ol(a,Uc(v[a>>2],v[a+4>>2])+1|0),Uc(v[a>>2],v[a+4>>2]),c);kd(v[c+8>>2],w[b|0]);v[c+8>>2]=v[c+8>>2]+1;Ad(a,c);Rl(c);cb=d+32|0}function IS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=yd(a);a:{if(b){v[22440]=0;R(461,a|0,b|0);e=v[22440];v[22440]=0;if((e|0)==1){break a}zA(a,b,c)}return a|0}a=P()|0;O()|0;Th(d);S(a|0);L()}function HG(a,b,c,d){var e=0;e=cb-16|0;cb=e;BG(e+8|0,b);Uk(v[e+12>>2],c,d);b=cb-16|0;cb=b;v[b+12>>2]=v[v[e+12>>2]+4>>2];v[b+8>>2]=0;d=v[Ke(b+8|0,b+12|0)>>2];cb=b+16|0;Ub(a,c,d);cb=e+16|0}function HB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=yd(a);a:{if(b){v[22440]=0;R(266,a|0,b|0);e=v[22440];v[22440]=0;if((e|0)==1){break a}Jm(a,b,c)}return a|0}a=P()|0;O()|0;_b(d);S(a|0);L()}function FV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=yd(a);a:{if(b){v[22440]=0;R(231,a|0,b|0);e=v[22440];v[22440]=0;if((e|0)==1){break a}mC(a,b,c)}return a|0}a=P()|0;O()|0;fc(d);S(a|0);L()}function uS(a,b,c,d){var e=0;e=cb-16|0;cb=e;v[e+12>>2]=b;v[e+8>>2]=d;a=zp(a,c,v[Bb(e+12|0,e+8|0)>>2]);a:{if(a){break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}cb=e+16|0;return a}function tR(a,b){var c=0,d=0,e=0;c=cb-16|0;cb=c;rR(c+8|0,b);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){sR(b)}return a}function rU(a,b){var c=0,d=0,e=0;c=cb-16|0;cb=c;ju(c+8|0,b);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){qB(b)}return a}function jj(a,b){var c=0,d=0;c=w[a|0];d=w[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=w[b+1|0];c=w[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function hB(a,b){var c=0,d=0,e=0;c=cb-16|0;cb=c;kq(c+8|0,b);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){WT(b)}return a}function eQ(a,b){var c=0,d=0,e=0;c=cb-16|0;cb=c;BT(c+8|0,b);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){CT(b)}return a}function cD(a,b){var c=0,d=0,e=0;c=cb-16|0;cb=c;Jq(c+8|0,b);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){Kq(b)}return a}function XA(a,b){var c=0,d=0,e=0;c=cb-16|0;cb=c;BT(c+8|0,b);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){CT(b)}return a}function WD(a,b){var c=0,d=0,e=0;c=cb-16|0;cb=c;UD(c+8|0,b);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){uv(b)}return a}function RR(a,b){var c=0,d=0,e=0;c=cb-16|0;cb=c;TR(c+8|0,b);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){SR(b)}return a}function Pj(a,b){var c=0,d=0,e=0;c=cb-16|0;cb=c;Qm(c+8|0,b);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){Rj(b)}return a}function Ou(a,b){var c=0;c=cb-16|0;cb=c;a:{if(!Kb(a,256)){a=b+256|0;while(1){if((a|0)!=(b|0)){ug(b);b=b+1|0;continue}break}break a}Ub(c+8|0,b,256);md(c,a,v[c+8>>2],v[c+12>>2])}cb=c+16|0}function MQ(a,b){var c=0,d=0,e=0;c=cb-16|0;cb=c;IQ(c+8|0,b);d=v[c+12>>2];cd(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;a=(d|0)==(e|0);if(!a){JQ(b)}return a}function I$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a+84>>2];d=c+256|0;f=ys(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;ic(b,e,c);b=e+d|0;v[a+84>>2]=b;v[a+8>>2]=b;v[a+4>>2]=c+e;return c|0}function wx(a){var b=0,c=0,d=0;A[a+4272>>3]=A[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){if(a>>>0<32){a=a+15|0;b=yn(d)|b<<15;continue}break}A[c+4280>>3]=C(C(b|0)*C(-4.656612873077393e-10))}function O_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=cb-16|0;cb=g;v[g+8>>2]=624576549;v[g+12>>2]=1394948685;h=a;a=g+16|0;b=Wj(h,b,c,d,e,f,g+8|0,a);cb=a;return b|0}function $5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=cb-16|0;cb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;a=mJ(f,b,c,d,0,0,0,0,e);cb=f+16|0;return a|0}function Yb(a,b,c,d){var e=0,f=0;e=cb-16|0;cb=e;f=v[b>>2];b=v[b+8>>2];v[e+12>>2]=d;v[e+8>>2]=c;c=v[v[f>>2]+28>>2];d=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=d;gb[c|0](a,f,b,e);cb=e+16|0}function Tr(a){var b=0,c=0,d=0;c=1;while(1){if(c){c=0;b=v[a+4>>2];d=((b<<2)+(Wu(v[a>>2],1)^270549120)|0)+2019860093|0;v[a>>2]=d;b=b+B(Wu(d,16),5)|0;v[a+4>>2]=b;continue}break}return b}function J2(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;d=v[13459];v[c+8>>2]=v[13458];v[c+12>>2]=d;d=v[13457];v[c>>2]=v[13456];v[c+4>>2]=d;gb[v[Lh(c,bh(w[b+20|0]))>>2]](a,b);cb=c+16|0}function Cfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;Ub(c+8|0,b,1100);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)|0}function dE(a,b){var c=0,d=0;d=cb-32|0;cb=d;c=xb(a);c=Ll(d+8|0,Io(a,gd(v[a>>2],v[a+4>>2])+1|0),gd(v[a>>2],v[a+4>>2]),c);dr(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;yv(a,c);cr(c);cb=d+32|0}function bg(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-32|0;cb=c;u[c+30>>1]=0;ci(c+8|0,c+30|0);d=c+16|0;kn(d,a,v[c+8>>2],v[c+12>>2]);u[c+16>>1]=x[c+30>>1];u[b>>1]=w[d|0]|w[d+1|0]<<8;cb=c+32|0}function Nh(a){var b=0;a=zf(a);b=2147483647;a:{if(a>=C(2147483648)){break a}b=-2147483648;if(a<=C(-2147483648)){break a}b=~~a;if(C(D(a))<C(2147483648)){break a}b=-2147483648}return b}function sJ(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=cb-16|0;cb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;c=rJ(f,b,c,d,e,0,0,0,0);cb=f+16|0;return+c}function rZ(){var a=0;a:{if(t[464904]&1){break a}if(!Xd(464904)){break a}a=464880;while(1){a=Db(a)+12|0;if((a|0)!=464904){continue}break}Wd(464904)}hd(464880,85216);hd(464892,85228)}function hZ(){var a=0;a:{if(t[464872]&1){break a}if(!Xd(464872)){break a}a=464848;while(1){a=Db(a)+12|0;if((a|0)!=464872){continue}break}Wd(464872)}dd(464848,13944);dd(464860,13923)}function Tl(a,b){v[a+28>>2]=0;u[a+24>>1]=65535;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;t[a|0]=0;v[a+32>>2]=11;v[a+36>>2]=b;Rb(a+40|0);Rb(a+52|0);Hb(a- -64|0,0,48);return a}function MS(a){var b=0,c=0;a:{if(Mb(a,13921,4)){b=0;if(Mb(a,16311,4)){break a}}c=a+34|0;b=0;if((w[c|0]|w[c+1|0]<<8)>>>0>255){break a}a=a+36|0;b=(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return b}function DB(a,b){var c=0;c=cb-16|0;cb=c;a:{if(!Kb(a,512)){a=b+512|0;while(1){if((a|0)!=(b|0)){Bm(b);b=b+4|0;continue}break}break a}ru(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}cb=c+16|0}function $f(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;lf(a+12|0,d);if(b){d=Ci(b)}else{d=0}v[a>>2]=d;c=d+(c<<2)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=mc(a),f=d+(b<<2)|0,v[e>>2]=f;return a|0}function zW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-16|0;cb=d;v[d+12>>2]=c;c=0;a=gb[v[v[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Bb(d+12|0,d+8|0)>>2]}cb=d+16|0;return c|0}function wv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=cb-16|0;cb=e;v[e+12>>2]=d;d=vb(b);if(d>>>0<c>>>0){tk();L()}b=Fb(b);v[e+8>>2]=d-c;cu(a,b+c|0,v[Bb(e+12|0,e+8|0)>>2]);cb=e+16|0}function vE(a,b){var c=0,d=0;c=cb-16|0;cb=c;v[c+12>>2]=b;d=b;b=kE();if(d>>>0<=b>>>0){a=fr(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}cb=c+16|0;return b}nd();L()}function uC(a,b){var c=0,d=0,e=0;c=cb-16|0;cb=c;Ub(c+8|0,b,37);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;if((d|0)!=(e|0)){Hb(b,0,37)}}function tA(a,b){var c=0,d=0;c=cb-16|0;cb=c;v[c+12>>2]=b;d=b;b=jB();if(d>>>0<=b>>>0){a=du(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}cb=c+16|0;return b}nd();L()}function sP(a,b){var c=0,d=0;c=cb-16|0;cb=c;v[c+12>>2]=b;d=b;b=qP();if(d>>>0<=b>>>0){a=it(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}cb=c+16|0;return b}nd();L()}function rD(a,b){var c=0,d=0;c=cb-16|0;cb=c;v[c+12>>2]=b;d=b;b=oD();if(d>>>0<=b>>>0){a=iv(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}cb=c+16|0;return b}nd();L()}function iX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=cb-16|0;cb=e;v[e+12>>2]=d;d=vb(b);if(d>>>0<c>>>0){tk();L()}b=Fb(b);v[e+8>>2]=d-c;KD(a,b+c|0,v[Bb(e+12|0,e+8|0)>>2]);cb=e+16|0}function _A(a,b){var c=0,d=0;c=cb-16|0;cb=c;v[c+12>>2]=b;d=b;b=iC();if(d>>>0<=b>>>0){a=kC(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}cb=c+16|0;return b}nd();L()}function Rq(a,b){var c=0,d=0;c=cb-16|0;cb=c;v[c+12>>2]=b;d=b;b=xD();if(d>>>0<=b>>>0){a=Vm(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}cb=c+16|0;return b}nd();L()}function Qp(a,b){var c=0,d=0;c=cb-16|0;cb=c;v[c+12>>2]=b;d=b;b=nP();if(d>>>0<=b>>>0){a=Tn(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}cb=c+16|0;return b}nd();L()}function Ol(a,b){var c=0,d=0;c=cb-16|0;cb=c;v[c+12>>2]=b;d=b;b=DF();if(d>>>0<=b>>>0){a=Qo(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}cb=c+16|0;return b}nd();L()}function Nj(a,b){var c=0,d=0;c=cb-16|0;cb=c;v[c+12>>2]=b;d=b;b=av();if(d>>>0<=b>>>0){a=Lm(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}cb=c+16|0;return b}nd();L()}function MK(a,b){var c=0,d=0;c=cb-16|0;cb=c;v[c+12>>2]=b;d=b;b=LK();if(d>>>0<=b>>>0){a=Cs(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}cb=c+16|0;return b}nd();L()}function Io(a,b){var c=0,d=0;c=cb-16|0;cb=c;v[c+12>>2]=b;d=b;b=bE();if(d>>>0<=b>>>0){a=Ek(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}cb=c+16|0;return b}nd();L()}function Gg(a,b){var c=0,d=0;c=cb-16|0;cb=c;v[c+12>>2]=b;d=b;b=Qn();if(d>>>0<=b>>>0){a=vh(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Pc(c+8|0,c+12|0)>>2]}cb=c+16|0;return b}nd();L()}function FL(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;CL(c,b+80|0);v[22440]=0;U(11,a|0,0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){rb(c);cb=c+16|0;return}a=P()|0;O()|0;rb(c);S(a|0);L()}function Wy(a){var b=0,c=0;b=v[a>>2];c=v[b>>2];a:{if(c){while(1){b=c;c=v[b+4>>2];if(c){continue}break}break a}while(1){c=wh(b);b=v[b+8>>2];if(c){continue}break}}v[a>>2]=b;return a}function ue(a,b){var c=0;a:{c=Rg(b);if((c|0)==(vb(a)|0)){v[22440]=0;a=Y(372,a|0,b|0,c|0)|0;b=v[22440];v[22440]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;O()|0;Lb();L()}function oo(a,b,c){var d=0,e=0;d=cb-16|0;cb=d;b=Xh(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){dc(b);cb=d+16|0}else{Mi(a,x[c>>1]);a=a+2|0;v[b+4>>2]=a;continue}break}}function mC(a,b,c){var d=0,e=0;d=cb-16|0;cb=d;b=uh(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){dc(b);cb=d+16|0}else{og(a,v[c>>2]);a=a+4|0;v[b+4>>2]=a;continue}break}}function Ot(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+4|0]|w[b+5|0]<<8;t[a+4|0]=b;t[a+5|0]=b>>>8}function Jx(a,b,c){var d=0,e=0;d=cb-16|0;cb=d;b=uh(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){dc(b);cb=d+16|0}else{bk(a,z[c>>2]);a=a+4|0;v[b+4>>2]=a;continue}break}}function yt(a){var b=0,c=0,d=0,e=0;d=a+32|0;while(1){a:{if((a|0)==(d|0)){e=b;break a}c=w[a|0];if((c-1&255)>>>0<31|((b^1)&1?0:c)){break a}a=a+1|0;b=!c|b;continue}break}return e&1}function vja(a,b){a=a|0;b=b|0;var c=0,d=0;c=yd(a);a:{if(b){v[22440]=0;R(348,a|0,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break a}Lv(a,b)}return a|0}a=P()|0;O()|0;_b(c);S(a|0);L()}function tc(a,b){var c=0,d=0;c=cb-16|0;cb=c;if(Ld(a)){zb(v[a>>2])}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;Yd(b,0);t[c+15|0]=0;$d(b,c+15|0);cb=c+16|0;return a}function kx(a){a=a|0;var b=0;a:{if(!a){a=aa(8)|0;v[22440]=0;T(976,a|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ba(a|0);S(b|0);L()}return}ia(a|0,49064,975);L()}function kJ(a){a=a|0;var b=0;a:{if(!a){a=aa(8)|0;v[22440]=0;T(974,a|0)|0;b=v[22440];v[22440]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ba(a|0);S(b|0);L()}return}ia(a|0,49008,975);L()}function iia(){var a=0,b=0,c=0;a=cb-16|0;cb=a;b=lc(1);v[22440]=0;X(31);c=v[22440];v[22440]=0;if((c|0)!=1){b=v[Sf(a+8|0,b)>>2];cb=a+16|0;return b|0}a=P()|0;O()|0;zb(b);S(a|0);L()}function XR(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;aB(c+8|0,b);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)|0}function Vha(a,b){a=a|0;b=b|0;var c=0;c=cb-32|0;cb=c;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;FS(b,c);ES(a,c);cb=c+32|0}function Kda(a,b){a=a|0;b=b|0;var c=0,d=0;c=yd(a);a:{if(b){v[22440]=0;R(231,a|0,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break a}WO(a,b)}return a|0}a=P()|0;O()|0;fc(c);S(a|0);L()}function Jm(a,b,c){var d=0,e=0;d=cb-16|0;cb=d;b=Ok(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){dc(b);cb=d+16|0}else{kd(a,w[c|0]);a=a+1|0;v[b+4>>2]=a;continue}break}}function GY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];if(a>>>0<=127){a=x[(a<<1)+75904>>1]}else{a=0}u[d>>1]=a;d=d+2|0;b=b+4|0;continue}break}return c|0}function Dga(a,b){a=a|0;b=b|0;var c=0,d=0;c=yd(a);a:{if(b){v[22440]=0;R(587,a|0,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break a}nA(a,b)}return a|0}a=P()|0;O()|0;fc(c);S(a|0);L()}function Ch(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;Qm(c+8|0,b);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)|0}function jX(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;SD(b,0,a);v[22440]=0;a=T(127,b|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){rb(b);cb=b+16|0;return a|0}a=P()|0;O()|0;rb(b);S(a|0);L()}function Ur(a){var b=0,c=0,d=0;b=cb-16|0;cb=b;v[b+12>>2]=12;while(1){v[b+8>>2]=32;if(y[Bb(b+12|0,b+8|0)>>2]<=c>>>0){cb=b+16|0}else{c=c+15|0;d=yn(a)&4095;continue}break}return d}function JS(a,b){a=a|0;b=b|0;var c=0,d=0;c=yd(a);a:{if(b){v[22440]=0;R(326,a|0,b|0);d=v[22440];v[22440]=0;if((d|0)==1){break a}Lv(a,b)}return a|0}a=P()|0;O()|0;_b(c);S(a|0);L()}function Bga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-16|0;cb=d;v[d+8>>2]=b;while(1){if(Qb(b,c)){v[d+4>>2]=v[b>>2];rA(a,d+4|0);Ge(d+8|0);b=v[d+8>>2];continue}else{cb=d+16|0}break}}function $D(a){var b=0;a:{b:{if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a&-256)!=(a|0)}return b}function pja(a,b){a=a|0;b=b|0;if(!ST(a,b)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0}}function V1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-16|0;cb=d;v[d+12>>2]=c;Xw(a,b,c);c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Bb(d+8|0,d+12|0)>>2]}cb=d+16|0;return c|0}function Kl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Sq(b);d=Dc(a);a:{if(c>>>0<=d>>>0){kd(Rh(Fb(a),b,c)+c|0,0);Bf(a,c);break a}e=d;f=c-d|0;d=vb(a);cq(a,e,f,d,0,d,c,b)}return a|0}function lL(a){var b=0,c=0,d=0;b=cb-16|0;cb=b;while(1){v[b+12>>2]=7;v[b+8>>2]=32;if(y[Bb(b+12|0,b+8|0)>>2]<=c>>>0){cb=b+16|0}else{c=c+15|0;d=yn(a)&127;continue}break}return d}function hY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-16|0;cb=d;gb[v[v[a>>2]+12>>2]](d+8|0,a,b);a=v[d+8>>2];b=v[c>>2];a=hc(v[d+12>>2],v[c+4>>2])&(a|0)==(b|0);cb=d+16|0;return a|0}function cd(a,b,c,d){var e=0,f=0;e=cb-16|0;cb=e;f=v[b+12>>2];v[e+12>>2]=d;v[e+8>>2]=c;c=v[v[b>>2]+28>>2];d=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=d;gb[c|0](a,b,f,e);cb=e+16|0}function Cea(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;b=-1;a:{if(!Pj(a,c+8|0)){break a}b=0;if(!LP(c+8|0)){break a}b=-1;if(!gg(a,4)){break a}b=iQ(a)>>>31|0}cb=c+16|0;return b|0}function rba(a,b){a=a|0;b=b|0;var c=0;c=If(a);t[a+534|0]=0;v[a+4>>2]=0;v[22440]=0;R(780,a|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;sl(c);S(a|0);L()}function Wo(a){var b=0,c=0;b=v[22359];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(Bw()>>>0<a>>>0){if(!(ta(a|0)|0)){break a}}v[22359]=a;return b}v[114922]=48;return-1}function zg(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=oh(v[d>>2],v[d+4>>2],a);return((oh(v[d>>2],v[d+4>>2],a+1|0)<<8|e<<16|oh(v[d>>2],v[d+4>>2],a+2|0))<<(b&7)&16777215)>>>24-c|0}function zA(a,b,c){var d=0,e=0;d=cb-16|0;cb=d;b=nq(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){dc(b);cb=d+16|0}else{Ot(a,c);a=a+6|0;v[b+4>>2]=a;continue}break}}function oM(a,b,c){var d=0,e=0;d=cb-16|0;cb=d;b=Oq(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){dc(b);cb=d+16|0}else{nM(a,c);a=a+8|0;v[b+4>>2]=a;continue}break}}function lR(a,b){var c=0,d=0,e=0;c=cb-16|0;cb=c;rR(c+8|0,b);d=v[c+12>>2];Yb(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;if((d|0)!=(e|0)){sR(b)}}function aT(a,b,c){var d=0,e=0;d=cb-16|0;cb=d;b=uh(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){dc(b);cb=d+16|0}else{sm(a,c);a=a+4|0;v[b+4>>2]=a;continue}break}}function Oy(a,b){var c=0;c=cb-32|0;cb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=-1;v[c+12>>2]=0;a=jE(c+16|0,uu(c+24|0,c+8|0));cb=c+32|0;return v[a>>2]}function Is(a,b){var c=0;a:{if(v[b+88>>2]&134218752){break a}b=v[b+656>>2];if(!dk(b)){break a}b=w[b+34|0];if((b+5&255)>>>0<6){break a}c=v[(B(b,160)+a|0)+906140>>2]}return c}function IR(a){var b=0,c=0;a:{if(Mb(a,15102,3)){break a}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-2147483647>>>0<2147484072){break a}c=w[a+3|0]<6}return c}function Caa(a,b){a=a|0;b=b|0;var c=0,d=0;c=lM(a);d=qk(b);b=Af(b);v[22440]=0;U(831,a|0,d|0,b|0);b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;zM(c);S(a|0);L()}function wS(a,b,c){var d=0;d=cb-32|0;cb=d;v[d+28>>2]=c;t[d+24|0]=0;v[d+12>>2]=1;c=d+16|0;pw(c,a,d+24|0,v[Bb(d+28|0,d+12|0)>>2]);t[d+16|0]=w[d+24|0];t[b|0]=w[c|0];cb=d+32|0}function aq(a){var b=0,c=0;c=v[a+4>>2];b=v[c>>2];v[a+4>>2]=b;if(b){bm(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(wh(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c>>2]=a;bm(a,c)}function Sl(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;lf(a+12|0,d);if(b){d=lc(b)}else{d=0}v[a>>2]=d;c=c+d|0;v[a+8>>2]=c;v[a+4>>2]=c;e=mc(a),f=b+d|0,v[e>>2]=f;return a|0}function $p(a){var b=0,c=0;c=v[a>>2];b=v[c+4>>2];v[a>>2]=b;if(b){bm(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(wh(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c+4>>2]=a;bm(a,c)}function df(a,b,c){var d=0,e=0,f=0;d=cb-16|0;cb=d;v[d+8>>2]=c;v[d+4>>2]=31;e=d,f=CU(b,c),v[e+12>>2]=f;c=b;b=xB(d+4|0);zk(c,c+b|0,a);e=Eb(a,b),f=0,t[e|0]=f;EU(a);cb=d+16|0}function Pf(a,b,c,d,e){a:{if(d>>>0<e>>>0){v[22440]=0;W(1099,17413,9139,394,6384);a=v[22440];v[22440]=0;if((a|0)==1){break a}L()}KL(a,b,c,d,e);return}V(0)|0;O()|0;Lb();L()}function EY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=v[c>>2];if(!(a>>>0>127|!(x[(a<<1)+75904>>1]&b))){c=c+4|0;continue}break}d=c}return d|0}function q3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=cb-16|0;cb=b;v[b+8>>2]=e;v[b+12>>2]=f;e=a;a=$b(b,c,d);a=zs(e,v[a>>2],v[a+4>>2],b+8|0);cb=b+16|0;return a|0}function Wl(a){a=a<<8&16711680|a<<24|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function Fba(a,b){a=a|0;b=b|0;var c=0;c=Rb(a);t[a+16|0]=0;v[a+12>>2]=b;v[22440]=0;Z(774,a|0);b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;qO(c);S(a|0);L()}function Eha(){var a=0,b=0,c=0;a=cb-16|0;cb=a;b=Bc(a,10284);v[22440]=0;Z(35,b|0);c=v[22440];v[22440]=0;if((c|0)!=1){rb(b);cb=a+16|0;return}a=P()|0;O()|0;rb(b);S(a|0);L()}function AW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=gb[v[v[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function nA(a,b){var c=0,d=0;c=cb-16|0;cb=c;b=uh(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){dc(b);cb=c+16|0}else{Bm(a);a=a+4|0;v[b+4>>2]=a;continue}break}}function fC(a,b){var c=0,d=0;c=cb-16|0;cb=c;b=Xh(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){dc(b);cb=c+16|0}else{eC(a);a=a+2|0;v[b+4>>2]=a;continue}break}}function WO(a,b){var c=0,d=0;c=cb-16|0;cb=c;b=uh(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){dc(b);cb=c+16|0}else{TO(a);a=a+4|0;v[b+4>>2]=a;continue}break}}function Lv(a,b){var c=0,d=0;c=cb-16|0;cb=c;b=Ok(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){dc(b);cb=c+16|0}else{BE(a);a=a+1|0;v[b+4>>2]=a;continue}break}}function KD(a,b,c){var d=0,e=0;if(c>>>0<4294967280){a:{if(c>>>0<=10){Yd(a,c);d=a;break a}e=Kg(c)+1|0;d=lc(e);qd(a,d);cf(a,e);td(a,c)}kd(Ce(d,b,c)+c|0,0);return}Ye();L()}function FY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=v[c>>2];if(a>>>0>127|!(x[(a<<1)+75904>>1]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function pH(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=w[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function bia(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;d=Kb(a,12);a:{if(!d){t[c|0]=0;_h(b,12,c);break a}kq(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}cb=c+16|0;return d|0}function zC(a,b,c){var d=0;d=cb-16|0;cb=d;b=uo(d,a+8|0,b);a=v[b>>2];while(1){if((a|0)!=v[b+4>>2]){Mi(a,x[c>>1]);a=v[b>>2]+2|0;v[b>>2]=a;continue}break}Gd(b);cb=d+16|0}function vD(a,b){var c=0,d=0;c=cb-16|0;cb=c;Ub(c+8|0,b,20);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function aS(a,b){var c=0,d=0;c=cb-16|0;cb=c;Ub(c+8|0,b,18);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function WS(a,b){var c=0,d=0;c=cb-16|0;cb=c;Ub(c+8|0,b,56);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function Pea(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-48|0;cb=c;d=-1;a:{if(!eQ(a,c)){break a}d=0;if(!dQ(c)){break a}d=ye(a,b,cQ(w[c+31|0],w[c+33|0]),fb)}cb=c+48|0;return d|0}function Mb(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=w[a|0];e=w[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}f=d-e|0}return f}function t8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=dp(d,a);VJ(a,c);v[22440]=0;R(72,b|0,1);a=v[22440];v[22440]=0;if((a|0)==1){a=P()|0;O()|0;Pb(d);S(a|0);L()}}function qga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Rb(a+8|0);v[22440]=0;U(250,a|0,b|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;_b(d);S(a|0);L()}}function oS(a,b,c){var d=0;d=cb-16|0;cb=d;b=Iv(d,a+8|0,b);a=v[b>>2];while(1){if((a|0)!=v[b+4>>2]){kd(a,w[c|0]);a=v[b>>2]+1|0;v[b>>2]=a;continue}break}Gd(b);cb=d+16|0}function nW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-16|0;cb=d;v[d+12>>2]=c;c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Bb(d+12|0,d+8|0)>>2]}cb=d+16|0;return c|0}function gia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-16|0;cb=d;hS(b,c);c=Kb(a,c<<2);if(c){gS(d+8|0,v[b>>2],v[b+4>>2]);md(d,a,v[d+8>>2],v[d+12>>2])}cb=d+16|0;return c|0}function eea(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;d=Kb(a,4);a:{if(!d){t[c|0]=0;iD(b,4,c);break a}Eh(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}cb=c+16|0;return d|0}function rA(a,b){a=a|0;b=b|0;var c=0;if(y[a+4>>2]<y[xb(a)>>2]){c=cb-16|0;cb=c;a=uh(c,a,1);og(v[a+4>>2],v[b>>2]);v[a+4>>2]=v[a+4>>2]+4;dc(a);cb=c+16|0;return}eA(a,b)}function W1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;Xw(a,b,c);a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Uh(a,b){var c=0;c=v[b+4>>2];b=v[b>>2];t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24;b=c;t[a+4|0]=b;t[a+5|0]=b>>>8;t[a+6|0]=b>>>16;t[a+7|0]=b>>>24}function Ue(a,b){var c=0;c=v[a>>2];v[a>>2]=b;a:{if(!c){break a}a=v[bc(a)>>2];v[22440]=0;Z(a|0,c|0);a=v[22440];v[22440]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Lb();L()}}function M0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=cb-16|0;cb=e;a=Ew(Pa(v[a+60>>2],b|0,c|0,d&255,e+8|0)|0);cb=e+16|0;fb=a?-1:v[e+12>>2];return(a?-1:v[e+8>>2])|0}function LW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-16|0;cb=d;zD(b,c);c=Kb(a,c<<3);if(c){yD(d+8|0,v[b>>2],v[b+4>>2]);md(d,a,v[d+8>>2],v[d+12>>2])}cb=d+16|0;return c|0}function G_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=gb[v[v[a+8>>2]+20>>2]](a+8|0)|0;b=Fb(a);return Vj(g,h,c,d,e,f,b,b+(vb(a)<<2)|0)|0}function BW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-16|0;cb=d;v[d+12>>2]=c;c=0;a=v[a+8>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Bb(d+12|0,d+8|0)>>2]}cb=d+16|0;return c|0}function zo(a,b){var c=0,d=0;c=cb-16|0;cb=c;Eh(c+8|0,b);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function yg(a,b){var c=0,d=0;c=cb-16|0;cb=c;Cq(c+8|0,b);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function vo(a,b){var c=0,d=0;c=cb-16|0;cb=c;Km(c+8|0,b);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function uG(a,b){var c=0,d=0,e=0,f=0;c=v[a+24>>2];if((c|0)==v[a+28>>2]){return e=a,f=sg(b),d=v[v[a>>2]+52>>2],gb[d](e|0,f|0)|0}v[a+24>>2]=c+1;t[c|0]=b;return sg(b)}function tu(a,b){var c=0,d=0;c=cb-16|0;cb=c;ko(c+8|0,b);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function su(a,b){var c=0,d=0;c=cb-16|0;cb=c;mo(c+8|0,b);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function mS(a,b){var c=0,d=0;c=cb-16|0;cb=c;lS(c+8|0,b);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function mD(a,b){var c=0,d=0;c=cb-16|0;cb=c;UD(c+8|0,b);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function jR(a,b){var c=0,d=0;c=cb-16|0;cb=c;iR(c+8|0,b);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function hea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-16|0;cb=d;JP(b,c);if(Kb(a,c<<8)){c=v[b>>2];Ub(d+8|0,c,th(c,v[b+4>>2])<<8);md(d,a,v[d+8>>2],v[d+12>>2])}cb=d+16|0}function hU(a,b){var c=0,d=0;c=cb-16|0;cb=c;Ju(c+8|0,b);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function hQ(a,b){var c=0,d=0;c=cb-16|0;cb=c;Eh(c+8|0,b);b=v[c+12>>2];cd(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yc(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function dD(a,b){var c=0,d=0;c=cb-16|0;cb=c;Jq(c+8|0,b);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function ZT(a,b){var c=0,d=0;c=cb-16|0;cb=c;ju(c+8|0,b);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function TT(a,b){var c=0,d=0;c=cb-16|0;cb=c;ku(c+8|0,b);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function TB(a,b){var c=0,d=0;c=cb-16|0;cb=c;SB(c+8|0,b);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function ST(a,b){var c=0,d=0;c=cb-16|0;cb=c;kq(c+8|0,b);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function QQ(a,b){var c=0,d=0;c=cb-16|0;cb=c;cA(c+8|0,b);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Ob(a,v[c+12>>2])}cb=c+16|0;return(b|0)==(d|0)}function wP(a){v[a>>2]=0;v[a+4>>2]=0;v[a+88>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;vz(a+112|0,48e3);v[a+668>>2]=0;uz(a+724|0);uz(a+732|0);uz(a+740|0);tg(a+788|0);return a}function Ob(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Kb(a,b);if(c){v[a+8>>2]=v[a+8>>2]+b;return c|0}b=a;a=v[a>>2];d=b,e=gb[v[v[a>>2]+24>>2]](a)|0,v[d+8>>2]=e;return c|0}function DI(a,b){var c=0,d=0;c=cb-16|0;cb=c;b=Ok(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){dc(b);cb=c+16|0}else{a=a+1|0;v[b+4>>2]=a;continue}break}}function xB(a){var b=0,c=0;a:{c=Ib(a,3);if((c|0)==(a|0)){break a}b=a;while(1){b=b+4|0;if((c|0)==(b|0)){break a}a=Yn(v[b>>2],v[a>>2])?b:a;continue}}return v[a>>2]}function lc(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=Hd(a);if(b){break a}b=v[116350];if(b){gb[b|0]();continue}break}a=aa(4)|0;tn(a);ia(a|0,88360,26);L()}return b|0}function iaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-16|0;cb=c;d=c,e=Ei(b),v[d+12>>2]=e;v[c+8>>2]=0;d=a,e=v[Gj(c+12|0,c+8|0,43936)>>2],v[d+36>>2]=e;ip(a);cb=c+16|0}function Op(a){v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=128;v[a+4>>2]=256;v[a+32>>2]=363;v[a+36>>2]=952;v[a+16>>2]=48e3;v[a+20>>2]=2;v[a+24>>2]=128;v[a+28>>2]=0;return a}function OX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-16|0;cb=d;v[d+12>>2]=v[c>>2];a=gb[v[v[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){v[c>>2]=v[d+12>>2]}cb=d+16|0;return a|0}function RA(a){var b=0,c=0;b=cb-16|0;cb=b;u[b+14>>1]=a;Kf(b+14|0,4095);a=x[b+14>>1];c=nT(ni(+((a&255)>>>0)*.00390625)*32768);cb=b+16|0;return c>>>15-(a>>>8|0)|0}function NL(a){var b=0,c=0,d=0;b=v[a+112>>2];if((b|0)>=11){c=378;while(1){if(c|d){ML(a);b=c;c=b-1|0;d=d-!b|0;continue}break}b=0}v[a+112>>2]=b+1;a=ML(a);return a}function Ix(a,b){var c=0,d=0;a:{if(a>>>0<=99999999){a=Aw(b,a);break a}c=(a>>>0)/1e8|0;d=B(c,-1e8)+a|0;a=(d>>>0)/1e4|0;a=aj(aj(JG(b,c),a),d+B(a,-1e4)|0)}return a}function Ifa(a,b){a=a|0;b=b|0;var c=0,d=0;d=cb-80|0;cb=d;c=-1;a:{if(!rU(a,d+8|0)){break a}c=0;if(!VQ(d+8|0)){break a}c=ye(a,b,UQ(d+8|0),fb)}cb=d+80|0;return c|0}function nha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Rb(a);v[22440]=0;U(36,a|0,b|0,c|0);b=v[22440];v[22440]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;fc(d);S(a|0);L()}function iN(a,b){a=a|0;b=b|0;var c=0;if(y[a+4>>2]<y[xb(a)>>2]){c=cb-16|0;cb=c;a=tt(c,a,1);dr(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;dc(a);cb=c+16|0;return}dE(a,b)}function bI(a,b){var c=0,d=0;d=a+4|0;c=Uc(v[d>>2],v[a+8>>2]);a=v[a+16>>2]+b|0;if(c>>>0<a>>>0){a:{if(c){b=Yf(c);if(a>>>0<=b>>>0){break a}}b=cI(a,65536)}Si(d,b)}}function N_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=gb[v[v[a+8>>2]+20>>2]](a+8|0)|0;b=Fb(a);return Wj(g,h,c,d,e,f,b,vb(a)+b|0)|0}function Mr(a){var b=0;a:{if((Ve(a)|0)!=79){break a}if((Ve(a)|0)!=103){break a}if((Ve(a)|0)!=103){break a}b=(Ve(a)|0)==83}if(!b){Zb(a,30);return 0}return hH(a)}function Dy(a,b){var c=0,d=0;c=v[a+656>>2];a:{if(!c){break a}b:{if((b|0)!=1){break b}a=v[a+104>>2];if(!a){break b}if(w[a+35|0]&4){break a}}d=w[c+34|0]}return d}function DD(a,b,c,d,e){var f=0;f=cb-16|0;cb=f;v[f+12>>2]=e;v[f+8>>2]=d;v[f+4>>2]=c;v[f>>2]=b;Wf(a,f);v[a+8>>2]=0;b=a+12|0;a=f+8|0;Wf(b,a);Md(a);Md(f);cb=f+16|0}function BN(a,b,c,d){var e=0,f=0;e=cb-16|0;cb=e;while(1){if(c){f=Vs(c+16|0,a,b);d=f?d:c;c=v[(f?4:0)+c>>2];continue}break}a=v[ac(e+8|0,d)>>2];cb=e+16|0;return a}function yE(a,b,c,d){var e=0,f=0;f=v[a+4>>2];e=0;a:{if(!c){break a}e=f>>8;if(!(f&1)){break a}e=Ev(v[c>>2],e)}a=v[a>>2];gb[v[v[a>>2]+28>>2]](a,b,c+e|0,f&2?d:2)}function w8(a){a=a|0;var b=0,c=0,d=0;b=cb-16|0;cb=b;jK(b+8|0,a,0);c=v[b+12>>2];if(c){a=v[a+20>>2];v[a+148>>2]=-1;d=a+4|0;a=v[b+8>>2];iy(d,a,Eb(a,c))}cb=b+16|0}function tm(a){var b=0;b=2147483647;a:{if(a>=2147483647){break a}b=-2147483648;if(a<=-2147483648){break a}if(D(a)<2147483648){return~~a}b=-2147483648}return b}function nV(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;v[c+12>>2]=-1;if(yg(a,c+8|0)){v[c+4>>2]=w[c+8|0];d=UB(a,b,v[Bb(c+4|0,c+12|0)>>2])}cb=c+16|0;return d|0}function eE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Dc(a);d=vb(a);e=d+1|0;if((c|0)==(d|0)){Sy(a,c,e-c|0,c,c,0)}c=Fb(a);UI(c+d|0,1,b);Bf(a,e);kd(c+e|0,0);return a|0}function YB(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;v[c+12>>2]=-1;if(yg(a,c+8|0)){v[c+4>>2]=w[c+8|0];d=RB(a,b,v[Bb(c+4|0,c+12|0)>>2])}cb=c+16|0;return d|0}function VI(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function SO(a,b){var c=0;c=v[a+4>>2];a:{if((b|0)>=0){b=b+c|0;v[a>>2]=v[a>>2]+(b>>>3&536870908);break a}b=b+c|0;v[a>>2]=v[a>>2]+((b-31|0)/32<<2)}v[a+4>>2]=b&31}function Pd(a,b){var c=0,d=0,e=C(0);c=cb-16|0;cb=c;v[c+8>>2]=1065353216;z[c+12>>2]=b;d=c,e=Qf(a),z[d+4>>2]=e;a=z[pA(c+4|0,c+12|0,c+8|0)>>2];cb=c+16|0;return a}function HL(a,b){var c=0,d=0;c=cb-16|0;cb=c;a:{if(Ld(a)){d=v[a>>2];t[c+15|0]=0;$d(b+d|0,c+15|0);td(a,b);break a}t[c+14|0]=0;$d(a+b|0,c+14|0);Yd(a,b)}cb=c+16|0}function zz(a){var b=0;a=ne(a);b=32767;a:{if(a>=32767){break a}b=32768;if(a<=-32768){break a}b=~~a;if(D(a)<2147483648){break a}b=-2147483648}return b<<16>>16}function tr(a){a=a|0;var b=0;b=aa(8)|0;v[22440]=0;Q(1025,b|0,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){ia(b|0,88708,170);L()}a=P()|0;O()|0;ba(b|0);S(a|0);L()}function lk(a,b){var c=0,d=0,e=0,f=0;d=yd(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=xb(b);e=xb(d),f=v[c>>2],v[e>>2]=f;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function lD(a){var b=0;if(!(Mb(a,15558,4)|(w[a+4|0]-16&255)>>>0<249|((w[a+5|0]-16&255)>>>0<249|(w[a+6|0]-16&255)>>>0<249))){b=(w[a+7|0]-9&255)>>>0<7}return b}function hX(a,b){a=a|0;b=b|0;var c=0;if(y[a+4>>2]<y[xb(a)>>2]){c=cb-16|0;cb=c;a=zv(c,a);dr(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;dc(a);cb=c+16|0;return}dE(a,b)}function c2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=cb-16|0;cb=e;v[e+8>>2]=c;v[e+12>>2]=d;a=$b(e,a,b);a=zs(3,v[a>>2],v[a+4>>2],e+8|0);cb=e+16|0;return a|0}function ZA(a,b,c,d){var e=0,f=0;lf(a+12|0,d);if(b){d=hC(b)}else{d=0}v[a>>2]=d;c=d+B(c,20)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=mc(a),f=d+B(b,20)|0,v[e>>2]=f;return a}function Ll(a,b,c,d){var e=0,f=0;lf(a+12|0,d);if(b){d=aE(b)}else{d=0}v[a>>2]=d;c=d+B(c,12)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=mc(a),f=d+B(b,12)|0,v[e>>2]=f;return a}function I6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;if((b|0)<=12){c=Pd(c,C(0));d=((b<<2)+a|0)+4208|0;if((b|0)==12){c=C(zf(C(c*C(3)))/C(3))}z[d>>2]=c;t[a+5046|0]=1}}function BJ(a){a=a|0;var b=0;v[a+4240>>2]=0;v[a+4244>>2]=0;b=a+4264|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4256|0;v[b>>2]=0;v[b+4>>2]=0;a=a+4248|0;v[a>>2]=0;v[a+4>>2]=0}function B$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function _da(a,b){a=a|0;b=b|0;var c=0,d=0;d=cb-48|0;cb=d;c=-1;a:{if(!eQ(a,d)){break a}c=0;if(!iP(d)){break a}c=ye(a,b,hP(w[d+47|0]),fb)}cb=d+48|0;return c|0}function Gu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-16|0;cb=d;Si(b,c);if(Kb(a,c)){c=v[b>>2];Ub(d+8|0,c,Uc(c,v[b+4>>2]));md(d,a,v[d+8>>2],v[d+12>>2])}cb=d+16|0}function E$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=t[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function DR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-16|0;cb=d;while(1){if((b|0)==(c|0)){cb=d+16|0}else{v[d+12>>2]=v[b>>2];rA(a,d+12|0);b=b+4|0;continue}break}}function $2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((a|0)!=(b|0)){d=v[c>>2];v[d>>2]=v[a>>2];qf(d+4|0,a+4|0);v[c>>2]=v[c>>2]+16;a=a+16|0;continue}break}}function tS(a,b,c,d){var e=0,f=0;lf(a+12|0,d);if(b){d=pS(b)}else{d=0}v[a>>2]=d;c=d+B(c,6)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=mc(a),f=d+B(b,6)|0,v[e>>2]=f;return a}function rP(a,b,c,d){var e=0,f=0;lf(a+12|0,d);if(b){d=pP(b)}else{d=0}v[a>>2]=d;c=d+(c<<4)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=mc(a),f=d+(b<<4)|0,v[e>>2]=f;return a}function q9(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-32|0;cb=c;d=c+24|0;t[d|0]=b;t[d+1|0]=b>>>8;Km(c+16|0,d);b=v[c+16>>2];Km(c+8|0,d);Lk(a,b,v[c+12>>2]);cb=c+32|0}function nD(a){a=a|0;var b=0,c=0;b=Db(a);v[22440]=0;T(176,a+12|0)|0;c=v[22440];v[22440]=0;if((c|0)!=1){If(a+32|0);return a|0}a=P()|0;O()|0;rb(b);S(a|0);L()}function mx(a,b,c,d){var e=0,f=0,g=0;a:{b:{e=c-b|0;if((e|0)<=4){if((Kx(d)|0)>(e|0)){break b}}f=a,g=Ix(d,b),v[f>>2]=g;b=0;break a}v[a>>2]=c;b=61}v[a+4>>2]=b}function gt(a,b,c,d){var e=0,f=0;lf(a+12|0,d);if(b){d=kP(b)}else{d=0}v[a>>2]=d;c=d+(c<<5)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=mc(a),f=d+(b<<5)|0,v[e>>2]=f;return a}function bY(a,b,c){a=a|0;b=b|0;c=c|0;a:{if((c|0)>=257){AE();b=89744;break a}b:{if(t[465392]&1){break b}if(!Xd(465392)){break b}Wd(465392)}b=89740}$b(a,c,b)}function TL(){var a=0,b=0,c=0,d=0;a=cb-16|0;cb=a;b=a+8|0;while(1){if(c>>>0<32){c=c+48|0;d=my(89800);continue}break}v[b>>2]=d;yn(b);cb=a+16|0;return v[b>>2]}function Qq(a,b,c,d){var e=0,f=0;lf(a+12|0,d);if(b){d=wD(b)}else{d=0}v[a>>2]=d;c=d+(c<<3)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=mc(a),f=d+(b<<3)|0,v[e>>2]=f;return a}function Nx(a,b,c,d){var e=0,f=0,g=0;a:{b:{e=c-b|0;if((e|0)<=9){if((Kx(d)|0)>(e|0)){break b}}f=a,g=Ix(d,b),v[f>>2]=g;b=0;break a}v[a>>2]=c;b=61}v[a+4>>2]=b}function Mj(a,b,c,d){var e=0,f=0;lf(a+12|0,d);if(b){d=TC(b)}else{d=0}v[a>>2]=d;c=d+(c<<1)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=mc(a),f=d+(b<<1)|0,v[e>>2]=f;return a}function HJ(a,b,c,d){var e=0,f=0,g=0;a:{b:{e=c-b|0;if((e|0)<=2){if((Kx(d)|0)>(e|0)){break b}}f=a,g=Ix(d,b),v[f>>2]=g;b=0;break a}v[a>>2]=c;b=61}v[a+4>>2]=b}function y1(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=qf(a,b);v[22440]=0;Q(55,a+12|0,c|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){break a}a=P()|0;O()|0;rb(b);S(a|0);L()}}function oW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function kD(a,b){a=a|0;b=b|0;var c=0,d=0;c=a;a=v[b>>2];d=(gb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0;a=v[b>>2];$b(c,d,(gb[v[v[a>>2]+24>>2]](a)|0)-v[b+8>>2]|0)}function ij(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;A[a>>3]=A[a>>3]-c;A[a+8>>3]=A[a+8>>3]-d}function iba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-32|0;cb=c;if(Vm(a)>>>0<b>>>0){d=xb(a);e=a;a=Qq(c+8|0,b,Vg(v[a>>2],v[a+4>>2]),d);Ad(e,a);Pq(a)}cb=c+32|0}function ei(a){var b=0,c=0;b=a*a;c=b*a;return C(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function caa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-32|0;cb=c;if(Ek(a)>>>0<b>>>0){d=xb(a);e=a;a=Ll(c+8|0,b,gd(v[a>>2],v[a+4>>2]),d);yv(e,a);cr(a)}cb=c+32|0}function ap(a,b){var c=0,d=0;a:{if(!a){break a}c=kka(a,0,b,0);d=fb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=Hd(c);if(!(!a|!(w[a-4|0]&3))){Hb(a,0,c)}return a}function aba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-32|0;cb=c;if(Qy(a)>>>0<b>>>0){d=xb(a);e=a;a=pN(c+8|0,b,Ry(v[a>>2],v[a+4>>2]),d);oN(e,a);nN(a)}cb=c+32|0}function aaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-32|0;cb=c;if(vh(a)>>>0<b>>>0){d=xb(a);e=a;a=$f(c+8|0,b,pc(v[a>>2],v[a+4>>2]),d);Ad(e,a);_f(a)}cb=c+32|0}function HU(a,b,c){var d=0;b=b-a>>2;while(1){if((b|0)>0){d=v[c>>2];t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;b=b-1|0;a=a+4|0;continue}break}}function Gea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-32|0;cb=c;if(Ek(a)>>>0<b>>>0){d=xb(a);e=a;a=Ll(c+8|0,b,gd(v[a>>2],v[a+4>>2]),d);TP(e,a);SP(a)}cb=c+32|0}function jg(a,b,c){a:{switch(b-1|0){case 0:if(c){return nj(a,1)}return nj(a,0);case 1:if(c){return nj(a,3)}return nj(a,2);default:break a}}return nj(a,4)}function dn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-32|0;cb=c;if(Qo(a)>>>0<b>>>0){d=xb(a);e=a;a=Sl(c+8|0,b,Uc(v[a>>2],v[a+4>>2]),d);Ad(e,a);Rl(a)}cb=c+32|0}function Ow(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=C(a*C(z[((c&3)<<2)+61760>>2]*C(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function Oaa(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;d=Kb(a,16);a:{if(!d){cC(b);break a}Ju(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}cb=c+16|0;return d|0}function MR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=cb-32|0;cb=c;if(Lm(a)>>>0<b>>>0){d=xb(a);e=a;a=Mj(c+8|0,b,Fc(v[a>>2],v[a+4>>2]),d);Ad(e,a);Pi(a)}cb=c+32|0}function CW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function y6(a){a=a|0;var b=0,c=C(0);t[a+4202|0]=1;b=a,c=Ny(C(C(C(C(y[v[a+16>>2]+24620>>2])/C(3))+C(-80))/C(15920)),C(0),C(1)),z[b+4272>>2]=c;DJ(a);BJ(a)}function nn(a,b){var c=0,d=0;b=b+7&-8;d=v[a+80>>2];a:{if(d){b=v[a+92>>2]-b|0;c=0;if((b|0)<v[a+88>>2]){break a}v[a+92>>2]=b;return b+d|0}c=Hd(b)}return c}function hL(a,b){var c=0,d=0,e=C(0);c=cb-16|0;cb=c;v[c+12>>2]=b;v[c+8>>2]=127;d=a,e=C(C(C(y[Bb(c+12|0,c+8|0)>>2])/C(-127))+C(1)),z[d+144>>2]=e;cb=c+16|0}function Xz(a){var b=0,c=0;b=a+26|0;b=wb(w[b|0]|w[b+1|0]<<8);c=(w[a+24|0]>15)+(w[a+25|0]>64)|0;a=a+22|0;return c+(wb(w[a|0]|w[a+1|0]<<8)<<1>>>0<b>>>0)|0}function CY(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];if(a>>>0<=127){a=v[(a<<2)+78464>>2]}v[b>>2]=a;b=b+4|0;continue}break}return c|0}function AY(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];if(a>>>0<=127){a=v[(a<<2)+76928>>2]}v[b>>2]=a;b=b+4|0;continue}break}return c|0}function xm(a,b){var c=0,d=0,e=0;eB(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=xb(b);d=xb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function xY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];t[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function um(a){var b=0,c=0;b=v[a>>2];c=v[b+4>>2];a:{if(c){b=XS(c);break a}while(1){if(!wh(b)){b=v[b+8>>2];continue}break}b=v[b+8>>2]}v[a>>2]=b;return a}function e9(a){a=a|0;var b=0;b=cb-16|0;cb=b;Cc(b,a+32|0,4);if(!tb(v[v[b>>2]>>2],v[b+4>>2])){Pv(a)}a=v[ac(b+8|0,yb(v[a+52>>2]))>>2];cb=b+16|0;return a|0}function c9(a){a=a|0;var b=0;b=cb-16|0;cb=b;Cc(b,a+32|0,4);if(!tb(v[v[b>>2]>>2],v[b+4>>2])){Pv(a)}a=v[ac(b+8|0,yb(v[a+56>>2]))>>2];cb=b+16|0;return a|0}function ad(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;Ab(b);continue}break}v[a+4>>2]=c;b=v[a>>2];Ek(a);zb(b)}}function _r(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-16|0;rl(b);continue}break}v[a+4>>2]=c;b=v[a>>2];it(a);zb(b)}}function Yz(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-24|0;sb(b);continue}break}v[a+4>>2]=c;b=v[a>>2];fr(a);zb(b)}}function Wn(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;d=Kb(a,4);a:{if(!d){jS(b);break a}Eh(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}cb=c+16|0;return d|0}function Tc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(y[a+8>>2]<b>>>0){d=v[a>>2];c=0;if(gb[v[v[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}v[a+8>>2]=b;c=1}return c|0}function Q$(a,b){a=a|0;b=b|0;var c=0,d=0;b=iw(b);v[a+36>>2]=b;c=a,d=sp(b),v[c+44>>2]=d;c=a,d=en(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){tr(5566);L()}}function Oz(a,b,c){var d=0;d=cb-16|0;cb=d;v[d+8>>2]=a;while(1){if(!(!Qb(a,b)|x[a>>1]==x[c>>1])){Ne(d+8|0);a=v[d+8>>2];continue}break}cb=d+16|0;return a}function M$(a,b){a=a|0;b=b|0;var c=0,d=0;b=ow(b);v[a+36>>2]=b;c=a,d=sp(b),v[c+44>>2]=d;c=a,d=en(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){tr(5566);L()}}function EQ(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-56|0;vt(b);continue}break}v[a+4>>2]=c;b=v[a>>2];DQ(a);zb(b)}}function zT(a,b){var c=0;c=kka(b&255,0,9,0);b=a&255;a=b>>>31|0;b=b<<1;c=c+b|0;a=a+fb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;a=b>>>0<11?a+1|0:a;fb=a;return b}function un(a,b){v[a+20>>2]=0;v[a+24>>2]=b;v[a+12>>2]=0;v[a+4>>2]=4098;v[a+8>>2]=6;v[a+16>>2]=!b;Hb(a+32|0,0,40);ww(a+28|0);v[a+72>>2]=0;v[a+76>>2]=-1}function tj(a){var b=0;a=zf(a);b=-1;a:{if(a>=C(4294967296)){break a}b=0;if(a<=C(0)){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function Y3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=cb-32|0;cb=h;i=h+8|0;UH(i,b,c,d,e,f,g);zc(a,h+20|0);jm(i);cb=h+32|0}function Kfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-16|0;cb=d;zD(b,c);if(Kb(a,c<<3)){yD(d+8|0,v[b>>2],v[b+4>>2]);md(d,a,v[d+8>>2],v[d+12>>2])}cb=d+16|0}function qJ(a,b){a=a|0;b=b|0;var c=0,d=0;d=cb-16|0;cb=d;c=lc(12);fx(c);v[c+8>>2]=b;v[c+4>>2]=a;v[c>>2]=49084;a=v[Sf(d+8|0,c)>>2];cb=d+16|0;return a|0}function po(a){var b=0;b=aa(8)|0;v[22440]=0;Q(215,b|0,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){ia(b|0,88640,25);L()}a=P()|0;O()|0;ba(b|0);S(a|0);L()}function pY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=t[b|0];t[e|0]=(a|0)>=0?a:d;e=e+1|0;b=b+1|0;continue}break}return c|0}function lE(a){v[a>>2]=0;v[a+4>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;u[a+20>>1]=0;v[a+16>>2]=-1;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0}function hA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-16|0;cb=d;hS(b,c);if(Kb(a,c<<2)){gS(d+8|0,v[b>>2],v[b+4>>2]);md(d,a,v[d+8>>2],v[d+12>>2])}cb=d+16|0}function OM(a,b,c){var d=0,e=0;v[b+56>>2]=0;d=b,e=Cn(a,x[b+70>>1],v[b+48>>2],c,0),u[d+68>>1]=e;if(!(!(w[a+480180|0]&5)|v[b+60>>2]==-1)){v[b+60>>2]=0}}function ufa(a,b){a=a|0;b=b|0;var c=0,d=0;d=cb-96|0;cb=d;c=-1;a:{if(!MQ(a,d)){break a}c=0;if(!LQ(d)){break a}c=ye(a,b,KQ(d),fb)}cb=d+96|0;return c|0}function uY(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=t[b|0];if((a|0)>=0){a=v[(a<<2)+78464>>2]}t[b|0]=a;b=b+1|0;continue}break}return c|0}function tC(a){var b=0,c=0;a:{if(Mb(a,14260,3)){break a}b=w[a+3|0];if(b>>>0<8&(b|0)!=1|b>>>0>14){break a}c=(w[a+40|0]-1&255)>>>0<32|b>>>0<9}return c}function sY(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=t[b|0];if((a|0)>=0){a=v[(a<<2)+76928>>2]}t[b|0]=a;b=b+1|0;continue}break}return c|0}function dg(a){var b=0,c=0;b=cb-16|0;cb=b;a:{if(Ld(a)){c=v[a>>2];t[b+15|0]=0;$d(c,b+15|0);td(a,0);break a}t[b+14|0]=0;$d(a,b+14|0);Yd(a,0)}cb=b+16|0}function cv(a,b,c,d,e){var f=0;while(1){if((d|0)!=(f|0)){z[b>>2]=C(v[a>>2])*e;z[c>>2]=C(v[a+4>>2])*e;f=f+1|0;c=c+4|0;a=a+8|0;b=b+4|0;continue}break}}function af(a){var b=0;b=aa(8)|0;v[22440]=0;Q(24,b|0,a|0)|0;a=v[22440];v[22440]=0;if((a|0)!=1){ia(b|0,88588,25);L()}a=P()|0;O()|0;ba(b|0);S(a|0);L()}function Xea(a,b){a=a|0;b=b|0;var c=0,d=0;d=cb-96|0;cb=d;c=-1;a:{if(!MQ(a,d)){break a}c=0;if(!qQ(d)){break a}c=ye(a,b,pQ(d),fb)}cb=d+96|0;return c|0}function Pia(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{if(!Kb(b,12)){u[c>>1]=0;TS(a,6,c);break a}kq(c+8|0,a);md(c,b,v[c+8>>2],v[c+12>>2])}cb=c+16|0}function Eaa(a,b){a=a|0;b=b|0;var c=0;c=tM(a);v[22440]=0;R(828,c|0,b|0);b=v[22440];v[22440]=0;if((b|0)==1){b=P()|0;O()|0;yp(a);S(b|0);L()}return a|0}function yfa(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{if(!Kb(b,8)){u[c>>1]=0;TS(a,4,c);break a}Qm(c+8|0,a);md(c,b,v[c+8>>2],v[c+12>>2])}cb=c+16|0}function wU(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-28|0;v[a+8>>2]=b;Xc(b);continue}break}c=v[a>>2];if(c){mc(a);zb(c)}}function kv(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-36|0;v[a+8>>2]=b;Mq(b);continue}break}c=v[a>>2];if(c){mc(a);zb(c)}}function fz(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-32|0;v[a+8>>2]=b;il(b);continue}break}c=v[a>>2];if(c){br(a);zb(c)}}function cr(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;Ab(b);continue}break}c=v[a>>2];if(c){br(a);zb(c)}}function Zt(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-20|0;v[a+8>>2]=b;sb(b);continue}break}c=v[a>>2];if(c){mc(a);zb(c)}}function XX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Wg(a,v[b+8>>2],f)){Hv(b,c,d,e);return}a=v[a+8>>2];gb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)}function JK(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-52|0;v[a+8>>2]=b;bl(b);continue}break}c=v[a>>2];if(c){mc(a);zb(c)}}function JJ(a){var b=0;b=y[v[a+16>>2]+24620>>2]/(tj(C(z[a+4208>>2]*C(999)))+1>>>0)|0;b=b>>>0>2?b:2;v[a+4216>>2]=b;v[a+4220>>2]=b>>>1;qc(a+4224|0,b)}function CQ(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-56|0;v[a+8>>2]=b;vt(b);continue}break}c=v[a>>2];if(c){mc(a);zb(c)}}function BL(a){if(w[a+480224|0]==2){return+y[a+1074420>>2]/1e4}return+y[a+24620>>2]/(+y[a+1074404>>2]*+(B(v[a+1074408>>2],v[a+1074416>>2])>>>0))*60}function tE(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function qfa(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{if(!Kb(b,5)){t[c|0]=0;_h(a,5,c);break a}ko(c+8|0,a);md(c,b,v[c+8>>2],v[c+12>>2])}cb=c+16|0}function oq(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];d=v[a+4>>2];if(Fc(c,d)>>>0>b>>>0){a=ve(v[a+24>>2]+484344|0,x[Oi(c,d,b)>>1])}else{a=0}return a|0}function mka(a,b,c){var d=0;d=b>>31;a=a^d;ika(a-d|0,(b^d)-((a>>>0<d>>>0)+d|0)|0,c,0);fb=eb;a=d^db;b=a-d|0;fb=(d^fb)-((a>>>0<d>>>0)+d|0)|0;return b}function lja(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{if(!Kb(b,6)){t[c|0]=0;_h(a,6,c);break a}aB(c+8|0,a);md(c,b,v[c+8>>2],v[c+12>>2])}cb=c+16|0}function bz(a,b,c){var d=0,e=0,f=0;d=hl(a,b);if((d|0)!=255){e=Xb(a+26|0,d),f=c,u[e>>1]=f;a=a+62|0;e=Eb(a,b),f=255,t[e|0]=f;e=Eb(a,c),f=d,t[e|0]=f}}function bO(a){var b=0,c=0,d=0;d=w[a+26|0];b=d+27|0;while(1){if((c|0)==(d|0)){a=b&65535}else{b=w[(a+c|0)+27|0]+b|0;c=c+1|0;continue}break}return a}function _$(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;gb[v[v[a+32>>2]+d>>2]](b,a,v[d+v[a+36>>2]>>2]);continue}break}}function WT(a){t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function Se(a,b){var c=0;c=cb-16|0;cb=c;a:{if(!b){Cc(c+8|0,a+32|0,5);if(tb(v[v[c+8>>2]>>2],v[c+12>>2])){break a}}v[a+28>>2]=v[a+28>>2]+1}cb=c+16|0}function Ox(a,b,c,d){var e=0;e=cb-16|0;cb=e;a=nq(e,a,d);c=c-b|0;if((c|0)>0){ic(v[a+4>>2],b,c);v[a+4>>2]=v[a+4>>2]+B((c>>>0)/6|0,6)}dc(a);cb=e+16|0}function ZB(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0}function Y4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=cb-32|0;cb=h;i=h+8|0;UH(i,b,c,d,e,f,g);zc(a,i);jm(i);cb=h+32|0}function Rja(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;Qm(c+8|0,b);b=v[c+12>>2];Yb(c,a,v[c+8>>2],b);if((b|0)==v[c+4>>2]){Ob(a,v[c+12>>2])}cb=c+16|0}function Gm(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{if(!Kb(b,4)){t[c|0]=0;_h(a,4,c);break a}Eh(c+8|0,a);md(c,b,v[c+8>>2],v[c+12>>2])}cb=c+16|0}function zK(a){var b=0;b=cb-16|0;cb=b;z[b+12>>2]=D(a);v[b+8>>2]=646978941;v[b+4>>2]=1259902592;a=z[pA(b+12|0,b+8|0,b+4|0)>>2];cb=b+16|0;return a}function ww(a){var b=0,c=0;v[22440]=0;c=ha(1124)|0;b=v[22440];v[22440]=0;if((b|0)!=1){b=a;a=v[c>>2];v[b>>2]=a;Rm(a);return}V(0)|0;O()|0;Lb();L()}function lw(a){var b=0,c=0;b=cb-16|0;cb=b;c=-1;a:{if(yw(a)){break a}if((gb[v[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=w[b+15|0]}cb=b+16|0;return c}function gh(a){var b=0;a=zf(a);b=255;a:{if(a>=C(255)){break a}b=0;if(a<=C(0)){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function b8(a){a=a|0;var b=0,c=0,d=0;b=cb-32|0;cb=b;if(vh(a)>>>0<=12){c=xb(a);d=a;a=$f(b+8|0,13,pc(v[a>>2],v[a+4>>2]),c);Ad(d,a);_f(a)}cb=b+32|0}function Zo(a,b){var c=0;a:{if(!pH(b)|(w[b+1|0]^w[a+1|0])>>>0>1){break a}b=w[b+2|0];a=w[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function uk(a,b,c,d){var e=0;e=B(b,c);a:{if(v[d+76>>2]<0){a=Fu(a,e,d);break a}a=Fu(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function qK(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-2048|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){mc(a);zb(b)}}function gj(a,b,c){if(a>>>0<b>>>0){ic(a,b,c);return}if(c){a=a+c|0;b=b+c|0;while(1){a=a-1|0;b=b-1|0;t[a|0]=w[b|0];c=c-1|0;if(c){continue}break}}}function fk(a,b){var c=0,d=0,e=0;a:{c=hl(a,b);if((c|0)==255){break a}if(gk(a)){break a}d=Eb(a+8|0,c);e=w[d|0]&223;t[d|0]=e;fh(a,b,$s(c)|176,e)}}function e6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!b){hx(a,0,0,0,0,0,0,c,d);return}hx(a,v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2],v[b+24>>2],b,c,d)}
function Nu(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;a:{if(!Kb(b,2)){t[c|0]=0;dC(a,c);break a}Km(c+8|0,a);md(c,b,v[c+8>>2],v[c+12>>2])}cb=c+16|0}function lj(a){var b=0,c=0;b=cb-16|0;cb=b;ub(b+8|0,a+1074312|0,7);if(tb(v[v[b+8>>2]>>2],v[b+12>>2])){c=vm(v[a+480180>>2])^1}cb=b+16|0;return c}function ZG(a,b,c,d,e,f){var g=0,h=0;g=v[a+32>>2];if(!w[a+23|0]){v[(c<<2)+g>>2]=b;return}h=g;g=d<<2;v[h+g>>2]=b;t[v[a+8>>2]+d|0]=e;v[f+g>>2]=c}function Uy(a){var b=0,c=0;b=cb-16|0;cb=b;v[b+8>>2]=a;c=b+8|0;a=1;while(1){if((a|0)>0){um(c);a=a-1|0;continue}break}cb=b+16|0;return v[b+8>>2]}function Nfa(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=Ag(b);Ag(b);break a}a=Sg(b);Sg(b)}while(1){if(a){if(a&1){Ob(b,260)}a=a>>>1|0;continue}break}}function KP(a,b){var c=0,d=0,e=0;St(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=xb(b);d=xb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0}function vba(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-32|0;cb=c;d=c+24|0;t[d|0]=b;Cq(c+16|0,d);b=v[c+16>>2];Cq(c+8|0,d);Lk(a,b,v[c+12>>2]);cb=c+32|0}function sV(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;v[c+12>>2]=-1;if(yg(a,c+8|0)){v[c+4>>2]=w[c+8|0];WB(a,b,v[Bb(c+4|0,c+12|0)>>2])}cb=c+16|0}function oP(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-32|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){br(a);zb(b)}}function nE(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-24|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){mc(a);zb(b)}}function di(a){var b=0;a=a*a;b=a*a;return C(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function SP(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){br(a);zb(b)}}function NU(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;v[c+12>>2]=-1;if(yg(a,c+8|0)){v[c+4>>2]=w[c+8|0];FU(a,b,v[Bb(c+4|0,c+12|0)>>2])}cb=c+16|0}function Am(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;if(zo(a,b+8|0)){c=Wb(w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))}cb=b+16|0;return c|0}function $T(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-48|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){mc(a);zb(b)}}function rS(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-6|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){mc(a);zb(b)}}function nN(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-7|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){mc(a);zb(b)}}function _y(a,b,c){var d=0;while(1){if((b|0)!=(c|0)){d=v[a>>2];v[a>>2]=d<<8^v[((w[b|0]^d>>>24)<<2)+29308>>2];b=b+1|0;continue}break}return a}function W3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=cb-32|0;cb=g;h=g+8|0;VH(h,b,c,d,e,f);zc(a,g+20|0);jm(h);cb=g+32|0}function Pq(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-8|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){mc(a);zb(b)}}function Pi(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-2|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){mc(a);zb(b)}}function hga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(kE()>>>0<b>>>0){nd();L()}c=B(b,24);b=lc(c);v[a>>2]=b;v[a+4>>2]=b;d=xb(a),e=b+c|0,v[d>>2]=e}function dea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(oD()>>>0<b>>>0){nd();L()}c=B(b,36);b=lc(c);v[a>>2]=b;v[a+4>>2]=b;d=xb(a),e=b+c|0,v[d>>2]=e}function Pm(a,b){var c=0;Sm(a);v[a>>2]=58316;c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function Je(a,b,c){t[a+11|0]=c;t[a+10|0]=b;t[a+12|0]=w[a+12|0]&251;u[a+8>>1]=65535;v[a>>2]=0;v[a+4>>2]=0;t[a+12|0]=w[a+12|0]&252|1;return a}function Gb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=cb-16|0;cb=d;if(b>>>0>=117){po(12178);L()}e=d+8|0;ub(e,a,b);Te(e,c);cb=d+16|0;return a|0}function eP(a,b,c){var d=0;d=Rb(a);v[22440]=0;U(43,a|0,b|0,c|0);b=v[22440];v[22440]=0;if((b|0)!=1){return a}a=P()|0;O()|0;fc(d);S(a|0);L()}function dl(a){var b=0,c=0,d=0;b=cb-16|0;cb=b;c=v[a+24>>2];d=v[a+40>>2];v[b+12>>2]=1;a=v[Pc(a+20|0,b+12|0)>>2];cb=b+16|0;return B(a,c+d|0)}function Jja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(jB()>>>0<b>>>0){nd();L()}c=B(b,6);b=lc(c);v[a>>2]=b;v[a+4>>2]=b;d=xb(a),e=b+c|0,v[d>>2]=e}function IY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=cb-16|0;cb=a;v[a+12>>2]=e;v[a+8>>2]=d-c;b=Bb(a+12|0,a+8|0);cb=a+16|0;return v[b>>2]}function iQ(a){var b=0,c=0;b=cb-16|0;cb=b;if(hQ(a,b+8|0)){a=b+8|0;c=Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}cb=b+16|0;return c}function Yaa(a){a=a|0;var b=0;b=v[a>>2];if(gb[v[v[b>>2]+32>>2]](b,0,32)|0){a=v[a>>2];a=gb[v[v[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function Wc(a){var b=0;b=cb-16|0;cb=b;v[b+12>>2]=a;v[b+8>>2]=-32768;v[b+4>>2]=32767;a=u[Ke(b+8|0,ld(b+12|0,b+4|0))>>1];cb=b+16|0;return a}function Jj(a,b,c){var d=0,e=0,f=0;d=cb-16|0;cb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[Tb(d+15|0,d+14|0)|0]|(c?-128:0),t[e+21|0]=f;cb=d+16|0}function Ij(a,b,c){var d=0,e=0,f=0;d=cb-16|0;cb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[Tb(d+15|0,d+14|0)|0]|(c?-128:0),t[e+22|0]=f;cb=d+16|0}function Fz(a){a=50-(B(w[(a>>>4|0)+31648|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return yc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function zw(a,b){var c=0;if(b>>>0<=99){return JG(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return Hr(IG(c,a),B(a,-100)+b|0)}return aj(a,b)}function v8(a,b){a=a|0;b=b|0;var c=0;b=cb-16|0;cb=b;c=v[a+20>>2];qe(b,v[c+4>>2],v[c+8>>2]);iK(a,$b(b+8|0,v[b>>2],v[b+4>>2]),0);cb=b+16|0}function nT(a){var b=0;a=ne(a);b=65535;a:{if(a>=65535){break a}b=0;if(a<=0){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b}function n3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=cb-16|0;cb=b;e=a;a=$b(b+8|0,c,d);a=zs(e,v[a>>2],v[a+4>>2],0);cb=b+16|0;return a|0}function iu(a){var b=0,c=0,d=0;b=cb-16|0;cb=b;u[b+14>>1]=1;c=b,d=yl(a),u[c+12>>1]=d;a=x[ie(b+14|0,b+12|0)>>1];cb=b+16|0;return a-1&65535}function Tia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(av()>>>0<b>>>0){nd();L()}c=b<<1;b=lc(c);v[a>>2]=b;v[a+4>>2]=b;d=xb(a),e=b+c|0,v[d>>2]=e}function PT(a){var b=0,c=0,d=0;c=cb-16|0;cb=c;b=c+8|0;hv(b,a);a=w[Eb(b,0)|0];d=w[Eb(b,1)|0];b=w[Eb(b,2)|0];cb=c+16|0;return a|d<<8|b<<16}function bQ(a){var b=0,c=0,d=0;c=a+8|0;while(1){b=(a|0)==(c|0);if(!b){d=w[a|0];a=a+1|0;if((d-127&255)>>>0>160){continue}}break}return b}function Yc(a,b){var c=0,d=0,e=0;c=gg(a,b);if(c){v[a+12>>2]=v[a+12>>2]+b;return c}d=a,e=gb[v[v[a>>2]+24>>2]](a)|0,v[d+12>>2]=e;return c}function Xs(a){var b=0,c=0;c=Cf(a);while(1){a:{b=c;if(!(b&65535)){b=0;break a}c=b-1|0;if(!ve(a,c&65535)){continue}}break}return b&65535}function W4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=cb-32|0;cb=g;h=g+8|0;VH(h,b,c,d,e,f);zc(a,h);jm(h);cb=g+32|0}function J0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=v[b>>2]+7&-8;v[c>>2]=b+16;d=a,e=Sw(v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2]),A[d>>3]=e}function Dq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((b|0)<0){Bz();L()}b=(b-1>>>5|0)+1|0;c=PC(b);v[a+4>>2]=0;v[a>>2]=c;d=xb(a),e=b,v[d>>2]=e}function yV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(iC()>>>0<b>>>0){nd();L()}c=hC(b);v[a>>2]=c;v[a+4>>2]=c;d=xb(a),e=B(b,20)+c|0,v[d>>2]=e}function sM(a,b){var c=0;c=cb-16|0;cb=c;v[c+8>>2]=a;v[c+12>>2]=b;v[c>>2]=2147483647;v[c+4>>2]=0;a=Dl(c+8|0,c);cb=c+16|0;return v[a>>2]}function qN(a){var b=0;a:{if(w[a|0]<24){break a}b=15;b:{switch(w[a+3|0]){case 3:b=14;break;case 0:break b;default:break a}}t[a+3|0]=b}}function iga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Qn()>>>0<b>>>0){nd();L()}c=PC(b);v[a>>2]=c;v[a+4>>2]=c;d=xb(a),e=(b<<2)+c|0,v[d>>2]=e}function fU(a,b){var c=0,d=0;d=cb-16|0;cb=d;c=d+8|0;Uh(c,b);cb=d+16|0;return v[a>>2]==(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))}function Rl(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-1|0;v[a+8>>2]=b;continue}break}a=v[a>>2];if(a){zb(a)}}function Lr(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a+4>>2];c=a;break a}b=b-32|0;c=a+4|0}c=v[c>>2];v[a+4>>2]=d>>>b;v[a>>2]=d<<32-b|c>>>b}function G1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(bE()>>>0<b>>>0){nd();L()}c=aE(b);v[a>>2]=c;v[a+4>>2]=c;d=xb(a),e=B(b,12)+c|0,v[d>>2]=e}function n8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Rc(c&255))){kK(a,8,C(0))}a=$j(a);if(a){gb[v[v[a>>2]+92>>2]](a,b,c,d,e)}}function hv(a,b){var c=0;c=cb-16|0;cb=c;a:{if(!Kb(b,3)){t[c|0]=0;_h(a,3,c);break a}gv(c+8|0,a);md(c,b,v[c+8>>2],v[c+12>>2])}cb=c+16|0}function YD(a){a=a|0;var b=0;a=Db(a);v[22440]=0;Q(138,a|0,13740)|0;b=v[22440];v[22440]=0;if((b|0)==1){b=P()|0;O()|0;rb(a);S(b|0);L()}}function RN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(xD()>>>0<b>>>0){nd();L()}c=wD(b);v[a>>2]=c;v[a+4>>2]=c;d=xb(a),e=(b<<3)+c|0,v[d>>2]=e}function PN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(qP()>>>0<b>>>0){nd();L()}c=pP(b);v[a>>2]=c;v[a+4>>2]=c;d=xb(a),e=(b<<4)+c|0,v[d>>2]=e}function Lz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(av()>>>0<b>>>0){nd();L()}c=TC(b);v[a>>2]=c;v[a+4>>2]=c;d=xb(a),e=(b<<1)+c|0,v[d>>2]=e}function Em(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Qn()>>>0<b>>>0){nd();L()}c=Ci(b);v[a>>2]=c;v[a+4>>2]=c;d=xb(a),e=(b<<2)+c|0,v[d>>2]=e}function Dv(a,b,c,d,e,f){var g=0,h=0;g=v[a+4>>2];h=g>>8;if(g&1){h=Ev(v[d>>2],h)}a=v[a>>2];gb[v[v[a>>2]+20>>2]](a,b,c,d+h|0,g&2?e:2,f)}function DS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(jB()>>>0<b>>>0){nd();L()}c=pS(b);v[a>>2]=c;v[a+4>>2]=c;d=xb(a),e=B(b,6)+c|0,v[d>>2]=e}function Ag(a){var b=0,c=0;b=cb-16|0;cb=b;if(zo(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}cb=b+16|0;return c}function xq(a,b){return(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0?b:a}function xR(a){var b=0;b=cb-16|0;cb=b;v[b+12>>2]=a;v[b+8>>2]=-128;v[b+4>>2]=127;a=t[Ke(b+8|0,ld(b+12|0,b+4|0))|0];cb=b+16|0;return a}function wq(a,b,c){var d=0;d=cb-16|0;cb=d;if(!(!b|!c)){t[d+15|0]=0;wM(a+36|0,b,yi(b,b+c|0,d+15|0))}cb=d+16|0;return(b|0)!=0&(c|0)!=0}function rk(a){var b=0;a=ne(a);b=255;a:{if(a>=255){break a}b=0;if(a<=0){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b}function Ui(a,b){var c=0;if(Ld(a)){c=v[a>>2];Lj(a);zb(c)}v[a+8>>2]=v[b+8>>2];c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;Yd(b,0);qd(b,0)}function $aa(a,b){a=a|0;b=b|0;a=su(a,b);if(!a){t[b+6|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0}return a|0}function uw(a){a=a|0;var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return gb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+1;return sg(t[b|0])|0}function l7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;if((b|0)<=4){c=Pd(c,C(0));d=((b<<2)+a|0)+4220|0;if((b|0)==4){c=zf(c)}z[d>>2]=c;MJ(a)}}function W6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;if((b|0)<=1){c=Pd(c,C(0));d=((b<<2)+a|0)+4208|0;if((b|0)==1){c=zf(c)}z[d>>2]=c;JJ(a)}}function Vf(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;if(b>>>0>=117){po(12143);L()}d=c+8|0;ub(d,a,b);Te(d,0);cb=c+16|0;return a|0}function Mh(a,b){var c=0,d=0;c=v[a>>2];d=v[a+4>>2];b=v[a+16>>2]+b|0;a=v[a+12>>2];b=(b|0)%(a|0)|0;return z[Gc(c,d,(b>>31&a)+b|0)>>2]}function Jr(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=v[c>>2];v[a>>2]=d<<b;v[a+4>>2]=c<<b|d>>>32-b}function Cb(a,b){var c=0;if(Ld(a)){zb(v[a>>2])}v[a+8>>2]=v[b+8>>2];c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;Yd(b,0);kd(b,0);return a}function oK(a){a=a|0;a=cb-16|0;cb=a;v[a+12>>2]=1869112133;cb=a+16|0;a=a+12|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function YG(a,b){a:{if(a&255){a=1;if((b|0)!=255){break a}ca(14312,13226,1180,5737);L()}if((b|0)==255){return 0}a=b>>>0>10}return a}function Wd(a){var b=0,c=0;b=cb-16|0;cb=b;a=Jv(b,a);c=cb-16|0;cb=c;zE(v[ac(c+8|0,v[a+4>>2])>>2]);zE(v[a+8>>2]);cb=c+16|0;cb=b+16|0}function Haa(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;if(b>>>0>=250){po(12178);L()}d=c+8|0;ub(d,a,b);rm(d);cb=c+16|0;return a|0}function D0(a){a=a|0;var b=0;if((gb[v[v[a>>2]+36>>2]](a)|0)!=-1){b=a;a=v[a+12>>2];v[b+12>>2]=a+1;a=sg(t[a|0])}else{a=-1}return a|0}function uja(a){a=a|0;var b=0,c=0,d=0;if(Qn()>>>0<=8191){nd();L()}b=lc(32768);v[a>>2]=b;v[a+4>>2]=b;c=xb(a),d=b+32768|0,v[c>>2]=d}function rg(a){var b=0;b=cb-16|0;cb=b;v[b+12>>2]=a;v[b+8>>2]=0;v[b+4>>2]=255;a=w[Ke(b+8|0,ld(b+12|0,b+4|0))|0];cb=b+16|0;return a}function ir(a,b,c,d,e){var f=0,g=0;f=v[a+4>>2];g=f>>8;if(f&1){g=Ev(v[c>>2],g)}a=v[a>>2];gb[v[v[a>>2]+24>>2]](a,b,c+g|0,f&2?d:2,e)}function IT(a){var b=0;a:{if(Mb(a,3863,4)){break a}if(Mb(a+44|0,17871,3)){break a}a=a+47|0;b=(w[a|0]|w[a+1|0]<<8)>>>0>97}return b}function y$(a){a=a|0;var b=0,c=0;b=v[v[a>>2]>>2];c=v[b+8>>2];a=v[b+4>>2];b=v[b>>2]+(c>>1)|0;if(c&1){a=v[a+v[b>>2]>>2]}gb[a|0](b)}function x1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ix(a+8|0,b,c,d,2);if(a>>>0<=15){a=w[a+43840|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function SI(a){a=a|0;var b=0,c=0;c=cb-16|0;cb=c;b=lc(8);zI(b);v[b+4>>2]=a;v[b>>2]=53848;a=v[Sf(c+8|0,b)>>2];cb=c+16|0;return a|0}function Hz(a,b){var c=0,d=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[b>>2]=0;v[b+4>>2]=0;c=xb(b),d=0,v[c>>2]=d}function Gl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(DF()>>>0<b>>>0){nd();L()}c=lc(b);v[a>>2]=c;v[a+4>>2]=c;d=xb(a),e=b+c|0,v[d>>2]=e}function GC(a,b){var c=0;c=kka(b&255,0,1536,0);b=fb;a=kka(a&255,0,25,0);c=a+c|0;b=fb+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;fb=b;return a}function zY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d>>2]=t[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function z0(a){a=a|0;var b=0;if((gb[v[v[a>>2]+36>>2]](a)|0)!=-1){b=a;a=v[a+12>>2];v[b+12>>2]=a+4;a=v[a>>2]}else{a=-1}return a|0}function ox(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=b-24|0;fc(b);if((b|0)!=(c|0)){continue}break}vf(a);return a|0}function mF(a,b,c,d,e,f){a=gb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=qr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function iF(a,b,c,d,e,f){a=gb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=or(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function av(){var a=0,b=0;a=cb-16|0;cb=a;v[a+12>>2]=2147483647;v[a+8>>2]=2147483647;b=Bb(a+12|0,a+8|0);cb=a+16|0;return v[b>>2]}function Qn(){var a=0,b=0;a=cb-16|0;cb=a;v[a+12>>2]=1073741823;v[a+8>>2]=2147483647;b=Bb(a+12|0,a+8|0);cb=a+16|0;return v[b>>2]}function NV(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;b=v[v[b>>2]-12>>2]+b|0;if(Gh(b)){b=v[b+72>>2];if(b){_u(b)}t[a|0]=1}return a|0}function NM(a,b,c,d){a:{if(d>>>0>=64){d=-1;if(w[a+480180|0]&2){break a}}v[b+56>>2]=0;d=Cn(a,x[b+70>>1],v[b+48>>2],c,0)}return d}function Md(a){var b=0;a=v[a+4>>2];if(a){if(Um(a)){a:{b=a+8|0;if(v[b>>2]){if((nv(b)|0)!=-1){break a}}gb[v[v[a>>2]+16>>2]](a)}}}}function Kw(a,b,c){var d=0;d=v[a+32>>2];if(y[a+40>>2]<d+c>>>0){v[a+96>>2]=1;return 0}ic(b,d,c);v[a+32>>2]=v[a+32>>2]+c;return 1}function $j(a){var b=0,c=0;b=Mm(v[a+20>>2]);if(!(b>>>0>249|w[a+4200|0]>=b>>>0)){c=v[(v[a+16>>2]+B(b,160)|0)+906300>>2]}return c}function xD(){var a=0,b=0;a=cb-16|0;cb=a;v[a+12>>2]=536870911;v[a+8>>2]=2147483647;b=Bb(a+12|0,a+8|0);cb=a+16|0;return v[b>>2]}function wc(a,b){var c=0;c=cb-16|0;cb=c;v[c+8>>2]=a;v[c+12>>2]=b;v[c>>2]=-1;v[c+4>>2]=0;a=Dl(c+8|0,c);cb=c+16|0;return v[a>>2]}function rs(a){var b=0;b=A[a+4248>>3]/+y[v[a+16>>2]+24620>>2];A[a+4264>>3]=b;if(w[a+4240|0]){A[a+4264>>3]=b*(A[a+4288>>3]/60)}}function rY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function qP(){var a=0,b=0;a=cb-16|0;cb=a;v[a+12>>2]=268435455;v[a+8>>2]=2147483647;b=Bb(a+12|0,a+8|0);cb=a+16|0;return v[b>>2]}function oD(){var a=0,b=0;a=cb-16|0;cb=a;v[a+12>>2]=119304647;v[a+8>>2]=2147483647;b=Bb(a+12|0,a+8|0);cb=a+16|0;return v[b>>2]}function nP(){var a=0,b=0;a=cb-16|0;cb=a;v[a+12>>2]=134217727;v[a+8>>2]=2147483647;b=Bb(a+12|0,a+8|0);cb=a+16|0;return v[b>>2]}function kE(){var a=0,b=0;a=cb-16|0;cb=a;v[a+12>>2]=178956970;v[a+8>>2]=2147483647;b=Bb(a+12|0,a+8|0);cb=a+16|0;return v[b>>2]}function jO(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(b){td(b,a)}if(c){td(c,a)}if(d){td(d,a)}if(e){td(e,a)}}function jB(){var a=0,b=0;a=cb-16|0;cb=a;v[a+12>>2]=715827882;v[a+8>>2]=2147483647;b=Bb(a+12|0,a+8|0);cb=a+16|0;return v[b>>2]}function iC(){var a=0,b=0;a=cb-16|0;cb=a;v[a+12>>2]=214748364;v[a+8>>2]=2147483647;b=Bb(a+12|0,a+8|0);cb=a+16|0;return v[b>>2]}function hq(a){var b=0;b=-1;a:{if(a>=4294967295){break a}b=0;if(a<=0){break a}if(a<4294967296&a>=0){return~~a>>>0}b=0}return b}function bE(){var a=0,b=0;a=cb-16|0;cb=a;v[a+12>>2]=357913941;v[a+8>>2]=2147483647;b=Bb(a+12|0,a+8|0);cb=a+16|0;return v[b>>2]}function _D(){var a=0,b=0,c=0;a=cb-16|0;cb=a;b=Bc(a,14836);if(vb(b)){c=(Bg(b,13945)|0)!=-1}else{c=0}rb(b);cb=a+16|0;return c|0}function XB(a,b){var c=0;c=v[b+4>>2];if(c){Ub(a,c,v[b>>2]);return}c=v[b+8>>2];b=v[b+12>>2];if(!hc(c,b)){qe(a,c,b);return}ee(a)}function Mv(a,b){var c=0,d=0,e=0,f=0;c=Rg(b);d=lc(c+13|0);v[d+8>>2]=0;v[d+4>>2]=c;v[d>>2]=c;e=a,f=ic(d+12|0,b,c+1|0),v[e>>2]=f}function LY(a){a=a|0;var b=0;b=cb-16|0;cb=b;fi(gi(b+8|0,v[a+8>>2]));cb=b+16|0;a=v[a+8>>2];if(!a){return 1}return(IE(a)|0)==1|0}function ql(a,b){var c=0;a:{if(y[a+12>>2]<b>>>0){c=0;if(gb[v[v[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}v[a+12>>2]=b;c=1}return c}function VX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Wg(a,v[b+8>>2],0)){Fv(b,c,d);return}a=v[a+8>>2];gb[v[v[a>>2]+28>>2]](a,b,c,d)}function LK(){var a=0,b=0;a=cb-16|0;cb=a;v[a+12>>2]=82595524;v[a+8>>2]=2147483647;b=Bb(a+12|0,a+8|0);cb=a+16|0;return v[b>>2]}function nF(a,b,c,d,e,f){a=gb[v[v[a+8>>2]>>2]](a+8|0)|0;a=qr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function js(a){v[a>>2]=73264;ww(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function jF(a,b,c,d,e,f){a=gb[v[v[a+8>>2]>>2]](a+8|0)|0;a=or(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function al(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;Rx(a,c,d)}function Mc(a,b,c){var d=0;d=a;a=c&31;if((c&63)>>>0>=32){c=b>>31;a=b>>a}else{c=b>>a;a=((1<<a)-1&b)<<32-a|d>>>a}fb=c;return a}function AG(a){v[a>>2]=73328;ww(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function ro(a,b){var c=0;a:{if(!b){break a}if(!Kb(a,b)){break a}if(b>>>0<=3){c=JC(a,b);break a}c=Ag(a);Ob(a,b-4|0)}return c}function mQ(a,b,c){var d=0;if(!(w[b+31|0]&6|w[b+30|0]!=4)){Nc(a,8,1,0,10);return}d=a;a=w[b+31|0];Nc(d,a&4?16:8,a&2|1,0,c^1)}function gQ(a,b){var c=0;c=cb-16|0;cb=c;PQ(c+8|0,a);se(c,b);a=Hc(v[c+8>>2],v[c+12>>2],v[c>>2],v[c+4>>2]);cb=c+16|0;return a}function Yt(a,b,c){c=w[c|0];while(1){a:{if(!b){a=0;break a}if(hc(w[a|0],c)){break a}b=b-1|0;a=a+1|0;continue}break}return a}function Ru(a,b){var c=0;a:{if(!b){break a}if(!Kb(a,b)){break a}if(b>>>0<=1){c=IC(a,1);break a}c=Sg(a);Ob(a,b-2|0)}return c}function EM(a,b,c){var d=0,e=0,f=0;d=t[c+26|0];if(d){e=a,f=Vb(v[a>>2]+((B((w[c+27|0]^-1)+b|0,d)|0)/2|0)|0,0,256),v[e>>2]=f}}function cL(a,b){var c=0;if(!(w[a|0]!=w[b|0]|A[a+8>>3]!=A[b+8>>3]|w[a+16|0]!=w[b+16|0])){c=v[a+20>>2]==v[b+20>>2]}return c}function Y7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if((b|0)<=2){d=(a+b|0)+4232|0,e=gh(C(Pd(c,C(0))*C(127))),t[d|0]=e;ps(a)}}function S8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if((b|0)<=3){d=(a+b|0)+4264|0,e=gh(C(Pd(c,C(0))*C(255))),t[d|0]=e;ts(a)}}function Mz(a){v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function $M(a){Iy(a);v[a>>2]=0;v[a+4>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;Jg(a);Jg(a+12|0);t[a+24|0]=1}function xo(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=v[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}v[a>>2]=b}}function oe(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=v[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}v[a>>2]=b}}function UO(a,b){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24}function wR(a,b){var c=0;c=cb-16|0;cb=c;a:{if(!gg(a,4)){jS(b);break a}Eh(c+8|0,b);Wz(c,a,v[c+8>>2],v[c+12>>2])}cb=c+16|0}function rG(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return gb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+4;return v[b>>2]}function Lf(a,b,c,d,e){var f=0;f=cb-16|0;cb=f;v[f+12>>2]=e;c=gi(f+8|0,c);a=rr(a,b,d,v[f+12>>2]);fi(c);cb=f+16|0;return a}function E1(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((a|0)!=(b|0)){qf(v[c>>2],a);v[c>>2]=v[c>>2]+12;a=a+12|0;continue}break}}function BO(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){yO(a,1);yO(a,0)}}function AO(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){zO(a,1);zO(a,0)}}function yi(a,b,c){c=w[c|0];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=w[a|0]){break a}}else{a=b}return a}a=a+1|0;continue}}function xL(a,b){var c=0;c=21685;a:{if(b>>>0>255){break a}a=v[((b<<2)+a|0)+900380>>2];if(!a){break a}c=a+492|0}return c}function qQ(a){var b=0;if(!(Mb(a+44|0,13906,4)|w[a+29|0]!=16)){a=a+42|0;b=((w[a|0]|w[a+1|0]<<8)-1&65535)>>>0<2}return b}function SA(a){var b=0,c=0;b=cb-16|0;cb=b;if(vo(a,b+8|0)){a=b+8|0;c=Rd((w[a|0]|w[a+1|0]<<8)<<16>>16)}cb=b+16|0;return c}function DF(){var a=0,b=0;a=cb-16|0;cb=a;v[a+12>>2]=-1;v[a+8>>2]=2147483647;b=Bb(a+12|0,a+8|0);cb=a+16|0;return v[b>>2]}function yX(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return gb[a|0](h|b,c,d,e,b|f,g)|0}function xga(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;if(vo(a,b+8|0)){c=(w[b+8|0]|w[b+9|0]<<8)<<16>>16}cb=b+16|0;return c|0}function Zs(a){var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return b}function Ve(a){var b=0;b=v[a+32>>2];a:{if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1;a=0;break a}v[a+32>>2]=b+1;a=w[b|0]}return a}function VQ(a){var b=0;if(!(Mb(a,13897,3)|w[a+3|0]>31|(t[a+27|0]<0|w[a+32|0]>64))){b=(w[a+33|0]-1&255)>>>0<32}return b}function TS(a,b,c){var d=0;while(1){if(b){d=w[c|0]|w[c+1|0]<<8;t[a|0]=d;t[a+1|0]=d>>>8;b=b-1|0;a=a+2|0;continue}break}}function LP(a){if(Mb(a,13879,4)){a=0}else{a=a+4|0;a=(Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|0)==1}return a}function z7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if((b|0)<=5){d=((b<<2)+a|0)+4208|0,e=Pd(c,C(0)),z[d>>2]=e;UJ(a)}}function u6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if((b|0)<=3){d=((b<<2)+a|0)+4208|0,e=Pd(c,C(0)),z[d>>2]=e;AJ(a)}}function sF(a,b,c){var d=0;d=cb-16|0;cb=d;v[d+12>>2]=c;b=gi(d+8|0,b);a=TF(a,9291,v[d+12>>2]);fi(b);cb=d+16|0;return a}function s7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if((b|0)<=4){d=((b<<2)+a|0)+4208|0,e=Pd(c,C(0)),z[d>>2]=e;OJ(a)}}function oc(a,b){var c=0;_l(a);v[a+4>>2]=0;v[a>>2]=49184;c=a;a=Hd(vb(b)+1|0);v[c+4>>2]=a;if(a){ic(a,Fb(b),vb(b)+1|0)}}function Ji(a){var b=0;while(1){a:{if((b|0)!=46){if(w[b+43872|0]!=(a|0)){break a}}else{b=0}return b}b=b+1|0;continue}}function B6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if((b|0)<=2){d=((b<<2)+a|0)+4208|0,e=Pd(c,C(0)),z[d>>2]=e;DJ(a)}}function SQ(a){var b=0;a=a+1104|0;a=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))+8|0;b=a>>>0<8?1:b;fb=b;return a}function Lg(a){var b=0;pm(a);b=nt(v[a>>2],Ak(x[a+34>>1]));v[a+20>>2]=b;if(!b){return 0}return Fj(v[a>>2],x[a+34>>1])}function IO(a){v[a+700>>2]=0;u[a+842>>1]=0;v[a+688>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0}function Fo(a){var b=0,c=0;c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-36|0;Mq(b);continue}break}v[a+4>>2]=c}function DU(a){var b=0,c=0;c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-28|0;Xc(b);continue}break}v[a+4>>2]=c}function CU(a,b){var c=0;c=cb-16|0;cb=c;t[c+15|0]=0;if(b){b=qp(a,b,c+15|0);a=b?b-a|0:-1}else{a=-1}cb=c+16|0;return a}function wO(a){var b=0,c=0,d=0;if(v[a>>2]){Ac(a);b=v[a>>2];Lm(a);zb(b);c=xb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function lu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=cb-16|0;cb=d;Gm(d+8|0,b);v[d+4>>2]=v[d+8>>2];_t(a,d+4|0,c);cb=d+16|0}function YF(a,b,c,d,e,f,g,h,i){v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function St(a){var b=0,c=0,d=0;if(v[a>>2]){Ac(a);b=v[a>>2];vh(a);zb(b);c=xb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function QK(a){var b=0,c=0,d=0;if(v[a>>2]){Ac(a);b=v[a>>2];du(a);zb(b);c=xb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function Ei(a){var b=0;b=cb-16|0;cb=b;v[b+12>>2]=a;v[b+8>>2]=2147483647;a=v[Bb(b+12|0,b+8|0)>>2];cb=b+16|0;return a}function DN(a){var b=0,c=0,d=0;if(v[a>>2]){Ac(a);b=v[a>>2];Vm(a);zb(b);c=xb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function ic(a,b,c){var d=0;if(c){d=a;while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function XG(a,b,c){var d=0,e=0,f=0;e=c*c;A[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;A[b>>3]=d*d+((c+c)*d+(c*c-e))}function GU(a,b,c,d,e){t[a+4|0]=b;t[a|0]=69;t[a+1|0]=99;t[a+2|0]=104;t[a+3|0]=111;t[a+7|0]=e;t[a+6|0]=d;t[a+5|0]=c}function Ad(a,b){var c=0;c=b+4|0;Pn(v[a>>2],v[a+4>>2],c);ec(a,c);ec(a+4|0,b+8|0);ec(xb(a),mc(b));v[b>>2]=v[b+4>>2]}function $O(a){var b=0;b=a+68|0;if(((w[b|0]|w[b+1|0]<<8)-128&65535)>>>0>=65409){a=Mb(a,17714,17)}else{a=1}return!a}function pr(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}ec(a,b);a=a+4|0;continue}}}function oG(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];a:{if(!c){break a}if(!hc(uG(c,b),-1)){break a}v[a>>2]=0}return a|0}function nl(a,b){var c=0;c=cb-16|0;cb=c;v[c+8>>2]=v[a>>2];a=c+8|0;v[a>>2]=v[a>>2]+(b<<2);cb=c+16|0;return v[a>>2]}function cl(a,b){var c=0;c=b&15;if(c){t[a+824|0]=c<<2}b=b&240;if(b){t[a+823|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|131072}function Nl(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}xh(a,b);a=a+1|0;continue}}}function NJ(a){a=a|0;v[a+4244>>2]=0;v[a+4248>>2]=0;v[a+4228>>2]=0;v[a+4232>>2]=0;a=a+4252|0;v[a>>2]=0;v[a+4>>2]=0}function LM(a,b){var c=0;c=b&15;if(c){t[a+827|0]=c<<2}b=b&240;if(b){t[a+826|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|262144}function YK(a){if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179011410){a=om(a)>>>0>80}else{a=0}return a}function US(a,b){var c=0,d=0,e=0;c=cb-16|0;cb=c;d=c,e=wb(w[b|0]|w[b+1|0]<<8),u[d+14>>1]=e;CJ(a,c+14|0);cb=c+16|0}function RP(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-4|0;v[a+8>>2]=b;continue}break}}function wI(a){var b=0;while(1){a:{if((b|0)!=4){if(v[(b<<2)+a>>2]){break a}}else{b=4}return b}b=b+1|0;continue}}function _i(a){a:{a=v[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function Zv(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(v[a>>2]!=(c|0)){break a}}else{a=b}return a}a=a+4|0;continue}}function W$(a,b){a=a|0;b=b|0;var c=0,d=0;gb[v[v[a>>2]+24>>2]](a)|0;b=iw(b);v[a+36>>2]=b;c=a,d=en(b),t[c+44|0]=d}function T$(a,b){a=a|0;b=b|0;var c=0,d=0;gb[v[v[a>>2]+24>>2]](a)|0;b=ow(b);v[a+36>>2]=b;c=a,d=en(b),t[c+44|0]=d}function Rs(a){var b=0;b=1;a:{switch(w[a+3|0]-4|0){default:b=w[a+2|0]==11;break;case 0:case 2:break a}}return b}function Ii(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;if(vo(a,b+8|0)){c=wb(w[b+8|0]|w[b+9|0]<<8)}cb=b+16|0;return c|0}function Hm(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function xl(a){var b=0;b=cb-16|0;cb=b;v[b+12>>2]=a;v[b+8>>2]=65535;a=x[Bb(b+12|0,b+8|0)>>1];cb=b+16|0;return a}function j3(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;c=Bc(b,12557);oc(a,c);rb(c);v[a>>2]=49144;cb=b+16|0;return a|0}function gu(a,b){var c=0;c=cb-16|0;cb=c;v[c+12>>2]=(B(a,b)>>>0)/255;oe(c+12|0,0,15);cb=c+16|0;return w[c+12|0]}function cQ(a,b){var c=0;c=b&255;b=c>>>24|0;a=a&255?1120:1056;c=a+(c<<8)|0;b=a>>>0>c>>>0?b+1|0:b;fb=b;return c}function bp(a,b){var c=0,d=0,e=0;c=cb-16|0;cb=c;d=c,e=Vd(b),v[d+12>>2]=e;v[a>>2]=v[c+12>>2];cb=c+16|0;return a}function Wg(a,b,c){if(!c){return v[a+4>>2]==v[b+4>>2]}if((a|0)==(b|0)){return 1}return!jj(v[a+4>>2],v[b+4>>2])}function Te(a,b){var c=0;c=v[a+4>>2];if(b){a=v[a>>2];v[a>>2]=v[a>>2]|c;return}a=v[a>>2];v[a>>2]=v[a>>2]&(c^-1)}function SF(a,b){var c=0;c=cb-16|0;cb=c;a=Ok(c,a,1);kd(v[a+4>>2],w[b|0]);v[a+4>>2]=v[a+4>>2]+1;dc(a);cb=c+16|0}function HK(a){var b=0;b=cb-16|0;cb=b;v[b+12>>2]=a;v[b+8>>2]=32767;a=u[Bb(b+12|0,b+8|0)>>1];cb=b+16|0;return a}function kL(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function k3(a,b){a=a|0;b=b|0;if(a){b=gb[v[v[b>>2]+8>>2]](b)|0;a:{if(b){b=le(b);break a}b=le(21685)}v[a>>2]=b}}function h3(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;c=Bc(b,8220);oc(a,c);rb(c);v[a>>2]=49164;cb=b+16|0;return a|0}function gp(a,b){var c=0;c=cb-32|0;cb=c;Eh(c+16|0,b);kn(c+24|0,a,v[c+16>>2],v[c+20>>2]);Eh(c+8|0,b);cb=c+32|0}function fl(a,b,c,d){var e=0;e=cb-16|0;cb=e;v[e+12>>2]=d;v[e+8>>2]=c;$b(a,b,v[Bb(e+12|0,e+8|0)>>2]);cb=e+16|0}function au(a){var b=0;b=cb-16|0;cb=b;u[b+14>>1]=a;u[b+12>>1]=255;a=w[Kc(b+14|0,b+12|0)|0];cb=b+16|0;return a}function _n(a){var b=0,c=0;b=a+68|0;a=0;while(1){if((a|0)!=9){c=Ib(b,a);a=a+1|0;v[c>>2]=a<<16;continue}break}}function Jz(a){var b=0,c=0;b=a+68|0;a=0;while(1){if((a|0)!=9){c=Ib(b,a);a=a+1|0;v[c>>2]=a<<11;continue}break}}function DL(a,b){var c=0;c=cb-16|0;cb=c;a=pz(c,a);og(v[a+4>>2],v[b>>2]);v[a+4>>2]=v[a+4>>2]+4;dc(a);cb=c+16|0}function zda(){var a=0;a=cb-16|0;cb=a;if(Ya(a+12|0,4)|0){Gr(v[114922],12678);L()}cb=a+16|0;return v[a+12>>2]}function wG(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return gb[v[v[a>>2]+36>>2]](a)|0}return sg(t[b|0])}function ui(a){var b=0,c=0;v[v[a+20>>2]>>2]=a;c=v[a+12>>2];b=v[c>>2];v[a+4>>2]=b;if(b){v[b+8>>2]=a}v[c>>2]=a}function lF(a,b,c,d,e){b=Wi(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function hO(a){var b=0;b=v[a+4>>2];u[a+70>>1]=w[((x[b+20>>1]>>>6|x[b+22>>1]<<4)&65535)+29168|0]>>>x[a+68>>1]}function hF(a,b,c,d,e){b=Vi(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function NR(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;u[c+14>>1]=b;if((yl(a)|0)!=65535){LB(a,c+14|0)}cb=c+16|0}function Aw(a,b){var c=0;if(b>>>0<=9999){return zw(a,b)}c=a;a=(b>>>0)/1e4|0;return aj(zw(c,a),B(a,-1e4)+b|0)}function yZ(){var a=0;if(Qn()>>>0<=29){nd();L()}a=PE(Tv(465232),30);v[116308]=a;v[116309]=a;v[116310]=a+120}function mR(a,b){t[a+6|0]=255;v[a+16>>2]=0;u[a+4>>1]=0;v[a>>2]=0;if(b>=0){A[a+8>>3]=b;v[a+16>>2]=3}return a}function lH(a,b,c,d){z[d+4>>2]=a+c;a=C(a+C(c*C(-.5)));b=C(b*C(.8660253882408142));z[d+8>>2]=a-b;z[d>>2]=b+a}function Tga(a,b){a=a|0;b=b|0;if(!XR(a,b)){t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0}}function El(a){var b=0;b=cb-16|0;cb=b;v[b+12>>2]=a;v[b+8>>2]=255;a=w[Bb(b+12|0,b+8|0)|0];cb=b+16|0;return a}function Tja(a,b){a=a|0;b=b|0;var c=0;b=cb-80|0;cb=b;c=-1;if(rU(a,b+8|0)){c=qU(b+8|0)}cb=b+80|0;return c|0}function Qu(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function Os(a){var b=0,c=0;while(1){if(b>>>0>=8){a=c<<24>>24}else{b=b+15|0;c=yn(a);continue}break}return a}function Lga(a,b){a=a|0;b=b|0;var c=0;b=cb-16|0;cb=b;c=-1;if(Pj(a,b+8|0)){c=IR(b+8|0)}cb=b+16|0;return c|0}function LQ(a){var b=0;if(!(Mb(a,17866,4)|w[a+5|0]!=16|(w[a+54|0]-33&255)>>>0<224)){b=w[a+4|0]>95}return b}function AS(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){zS(c+52|0);rb(c+40|0);fc(c+16|0);fc(c+4|0)}zb(c)}}function _R(a,b){var c=0;c=cb-16|0;cb=c;a=uh(c,a,1);sm(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+4;dc(a);cb=c+16|0}function YU(a,b){a=a|0;b=b|0;var c=0;b=cb-16|0;cb=b;c=-1;if(Pj(a,b+8|0)){c=BB(b+8|0)}cb=b+16|0;return c|0}function Sk(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return gb[v[v[a>>2]+36>>2]](a)|0}return v[b>>2]}function Sg(a){var b=0,c=0;b=cb-16|0;cb=b;if(vo(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8}cb=b+16|0;return c}function Mx(a,b){Rb(a);v[a+20>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;bf(a+24|0);Db(a+36|0);v[a+48>>2]=b;return a}function HE(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;v[e>>2]=c;v[h>>2]=f;return 3}function oO(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-32|0;il(c);continue}break}v[a+4>>2]=b}function jC(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-20|0;sb(c);continue}break}v[a+4>>2]=b}function XK(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return(a|0)==1179012417|(a|0)==538987841}function PP(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;OP(c);continue}break}v[a+4>>2]=b}function OL(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-52|0;bl(c);continue}break}v[a+4>>2]=b}function Jb(a,b,c){var d=0;c=v[a+4>>2]+c|0;d=b;b=v[a>>2]+b|0;c=d>>>0>b>>>0?c+1|0:c;v[a>>2]=b;v[a+4>>2]=c}function GN(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;Re(c);continue}break}v[a+4>>2]=b}function dN(a,b){var c=0,d=0;a:{if(b<0){break a}c=A[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}A[a>>3]=d}}function XT(a){a:{if(Mb(a,14269,4)){break a}if(Mb(a+8|0,14250,4)){break a}return 1}return!Mb(a,14250,4)}function PO(a,b,c){var d=0;return(a&255)!=255|(b&224)!=224|(!(b&6)|(b&24)==8)|(c&12)==12?d:(c&240)!=240}function Mm(a){a=a+28|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return(a>>>0>127?a^128:-1)&255}function be(a,b){Jl(a,v[b>>2],v[b+4>>2]);v[a+8>>2]=v[b+8>>2];Jl(a+12|0,v[b+12>>2],v[b+16>>2]);return a}function IE(a){var b=0,c=0;b=cb-16|0;cb=b;a=gi(b+8|0,a);c=v[v[114924]>>2];fi(a);cb=b+16|0;return c?4:1}function CN(a,b,c,d){a=a&65535;c=c&65535;if(a>>>0>=c>>>0){a=b>>>0<d>>>0&a>>>0<=c>>>0}else{a=1}return a}function iW(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;c=-1;if(Pj(a,b+8|0)){c=lD(b+8|0)}cb=b+16|0;return c|0}function fB(a,b){if(b>>>0<=126){$e(((b<<5)+a|0)+480280|0);Ln((B(b,872)+a|0)+1074992|0,a,b,134217728)}}function eB(a){var b=0,c=0;if(v[a>>2]){Ac(a);zb(v[a>>2]);b=xb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function QW(a){a=a|0;var b=0,c=0;b=cb-32|0;cb=b;c=-1;if(WD(a,b+8|0)){c=VD(b+8|0)}cb=b+32|0;return c|0}function QA(a){a=a|0;var b=0;u[a+34>>1]=0;b=a+43|0;em(b,b+22|0,58412);v[a+20>>2]=0;ed(a,0);return a|0}function Hb(a,b,c){var d=0;if(c){d=a;while(1){t[d|0]=b;d=d+1|0;c=c-1|0;if(c){continue}break}}return a}function yu(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0}function vR(a){u[a+10>>1]=0;u[a+12>>1]=0;u[a+8>>1]=1084;v[a>>2]=0;v[a+4>>2]=40;u[a+14>>1]=0;return a}function bP(a){Qd(a+140|0);sb(a+120|0);sb(a+100|0);sb(a+80|0);sb(a+60|0);sb(a+40|0);sb(a+20|0);sb(a)}function VV(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;Im(c+8|0,b);Gq(a,v[c+8>>2],v[c+12>>2]);cb=c+16|0}function VA(a,b){var c=0;c=cb-16|0;cb=c;v[c+8>>2]=v[a>>2];a=v[xT(c+8|0,0-b|0)>>2];cb=c+16|0;return a}function UV(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;og(a+8|0,0);Dq(a,127);QC(a,127,w[b|0]);return a|0}function Rj(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function A1(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;VB(c+8|0,b);Gq(a,v[c+8>>2],v[c+12>>2]);cb=c+16|0}function qS(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]+B((b|0)/-6|0,6)|0;v[d>>2]=c;if((b|0)>0){ic(c,a,b)}}function pM(a,b,c,d){a=a&255;c=c&255;if(a>>>0>=c>>>0){a=(b|0)<(d|0)&a>>>0<=c>>>0}else{a=1}return a}function lg(a,b,c){var d=0;d=c;c=v[a>>2];d=v[a+4>>2]-(d+(c>>>0<b>>>0)|0)|0;v[a>>2]=c-b;v[a+4>>2]=d}function l8(a,b,c){a=a|0;b=b|0;c=c|0;a=$j(a);if(!a){return 0}return gb[v[v[a>>2]+100>>2]](a,b,c)|0}function f3(a,b){a=a|0;b=b|0;var c=0;b=Fb(b);c=v[a+4>>2];if(c){gb[c|0](b,v[a+8>>2]);return}hs(b,a)}function _fa(a,b){a=a|0;b=b|0;var c=0;b=cb-16|0;cb=b;c=-1;if(hB(a,b)){c=cR(b)}cb=b+16|0;return c|0}function Su(a){a=a|0;var b=0;b=cb-16|0;cb=b;a=yg(a,b+15|0);cb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function LN(a,b,c){var d=0;d=cb-16|0;cb=d;a=v[ac(d+8|0,BN(b,c,Kd(a),bc(a)))>>2];cb=d+16|0;return a}function JE(a,b,c,d,e){var f=0;f=cb-16|0;cb=f;e=gi(f+8|0,e);a=sr(a,b,c,d);fi(e);cb=f+16|0;return a}function j8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;gb[v[v[b>>2]+8>>2]](b,c);d=a;a=b+4|0;dp(d,a);VJ(a,c)}function Rw(a,b,c){b=(B(B(Pw(a),Qw(a,b)),125)>>>0)/(sH(a,b)>>>0)|0;a=(a&6)==6?b&-4:b;return a?a:c}function w0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;gb[v[v[a>>2]+12>>2]](a,b,c,d,e,f)|0}function v0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;gb[v[v[a>>2]+24>>2]](a,b,c,d,e,f)|0}function u0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;gb[v[v[a>>2]+16>>2]](a,b,c,d,e,f)|0}function t0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;gb[v[v[a>>2]+28>>2]](a,b,c,d,e,f)|0}function s0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;gb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0}function r0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;gb[v[v[a>>2]+44>>2]](a,b,c,d,e,f)|0}function pw(a,b,c,d){var e=0;e=cb-16|0;cb=e;Ub(e+8|0,c,d);HG(a,b,v[e+8>>2],v[e+12>>2]);cb=e+16|0}function kn(a,b,c,d){var e=0;e=cb-16|0;cb=e;_g(e+8|0,c,d);HG(a,b,v[e+8>>2],v[e+12>>2]);cb=e+16|0}function ki(a,b,c){if(c){while(1){v[a>>2]=v[b>>2];a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}}function je(a,b){var c=0;c=cb-16|0;cb=c;v[c+8>>2]=v[a>>2];a=v[VT(c+8|0,b)>>2];cb=c+16|0;return a}function Pz(a,b,c){b=b-a>>2;while(1){if((b|0)>0){v[a>>2]=v[c>>2];b=b-1|0;a=a+4|0;continue}break}}function oha(a){a=a|0;var b=0;b=cb-16|0;cb=b;a=zo(a,b+8|0);cb=b+16|0;return C(a?z[b+8>>2]:C(0))}function h0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;gb[v[v[b>>2]+16>>2]](a,b,v[c+8>>2],v[c+12>>2],0,d)}function dt(a,b){b=kka(a,a>>31,b,b>>31)+5e5|0;a=fb;return yc(lka(b,b>>>0<5e5?a+1|0:a,1e6,0),fb)}function cV(a,b){a=a|0;b=b|0;if(!tu(a,b)){t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b|0]=0}}function baa(a,b){a=a|0;b=b|0;wi(a);wi(a);a:{if(b>>>0>=60){Ob(a,4);break a}wi(a)}return wi(a)|0}function _G(a){var b=0;b=+((a&2097151)>>>0);return C(Tj(+C((a|0)>=0?b:-b),(a>>>21&1023)-788|0))}function XQ(a){var b=0,c=0;b=1;c=v[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}v[a>>2]=b}}function SV(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;if(yg(a,b+8|0)){c=w[b+8|0]}cb=b+16|0;return c|0}function PX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Wg(a,v[b+8>>2],f)){Hv(b,c,d,e)}}function L2(a){a=a|0;var b=0;b=cb-16|0;cb=b;a=v[Sf(b+8|0,lk(lc(12),a))>>2];cb=b+16|0;return a|0}function KB(a,b){a=a|0;b=b|0;if(!tu(a,b)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0}}function JV(a){a=a|0;var b=0;b=v[a+76>>2];if(hc(-1,b)){b=SC(a,32);v[a+76>>2]=b}return b<<24>>24}function w1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=rz(ix(a+8|0,b,c,d,3));return(a>>>0<5?a+1|0:0)|0}function vU(a){var b=0;if(!(Mb(a,26436,20)|(w[a+25|0]-9&255)>>>0<248)){b=t[a+47|0]>=0}return b}function oi(a){if(HI(w[a+20|0])){a=aa(4)|0;v[a>>2]=0;_l(a);v[a>>2]=87928;ia(a|0,87964,26);L()}}function lz(a){Rb(a);t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=255}function kU(a,b){return(Vb((B(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Vb((B(a&15,b)>>>0)/15|0,1,15))&255}function LF(a){var b=0;b=v[114924];if(a){v[114924]=(a|0)==-1?463412:a}return(b|0)==463412?-1:b}function Kx(a){var b=0;b=B(32-E(a|1)|0,1233)>>>12|0;return(b-(y[(b<<2)+25856>>2]>a>>>0)|0)+1|0}function xC(a){var b=0;b=a&255;a=b>>>21|0;b=(b<<11)+2624|0;a=b>>>0<2624?a+1|0:a;fb=a;return b}function nu(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;d=a;a=Bc(c,b);zc(d,a);rb(a);cb=c+16|0}function ev(a,b){eD(a,v[b>>2],v[b+4>>2]);v[a+8>>2]=v[b+8>>2];eD(a+12|0,v[b+12>>2],v[b+16>>2])}function em(a,b,c){b=b-a|0;while(1){if((b|0)>0){t[a|0]=w[c|0];b=b-1|0;a=a+1|0;continue}break}}function Xf(a,b){a=a|0;b=b|0;var c=0,d=0;c=cb-16|0;cb=c;d=a;a=jc(c,b);zc(d,a);rb(a);cb=c+16|0}function NP(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=B(c,12)+d;return a}function Mk(a){var b=0;b=cb-16|0;cb=b;a=v[ac(b+8|0,Fb(a)+(vb(a)<<2)|0)>>2];cb=b+16|0;return a}function CE(a){var b=0;b=a;a=0;while(1){if((a|0)!=3){v[(a<<2)+b>>2]=0;a=a+1|0;continue}break}}function uo(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<1)+d;return a}function n0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return gb[v[v[a>>2]+32>>2]](a,b,c,d,e)|0}function mP(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<5)+d;return a}function fga(a){a=a|0;var b=0,c=0;b=cb-32|0;cb=b;c=a;a=ai(b+8|0);GR(c,a,0,0);sb(a);cb=b+32|0}function NF(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(v[b>>2]){continue}break}return b-a>>2}function Fl(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<2)+d;return a}function FE(a){a=a|0;var b=0;v[a>>2]=79964;b=v[a+8>>2];if(!(!b|!w[a+12|0])){zb(b)}return a|0}function CL(a,b){var c=0;c=cb-16|0;cb=c;Nz(c,1,b);xc(a,v[c>>2],v[c+4>>2],w[c+8|0]);cb=c+16|0}function jx(a,b,c,d,e){if(!((b|0)==(c|0)|(d|0)>=0)){t[b|0]=45;d=SK(d);b=b+1|0}bJ(a,b,c,d,e)}function eg(a){var b=0,c=0;while(1){c=b&65535;if(c>>>0<127){fB(a,c);b=b+1|0;continue}break}}function Yp(a,b){var c=0;c=vb(a);if((c|0)==(vb(b)|0)){a=xv(Fb(a),Fb(b),c)}else{a=1}return!a}function VL(a){v[a+20>>2]=0;t[a+16|0]=7;v[a+8>>2]=1889785610;v[a+12>>2]=1072630333;t[a|0]=3}function Qw(a,b){a=a&255;return w[(B(a>>>3&1,45)+B(a>>>1&3,15)+((b&240)>>>4)|0)+60657|0]<<1}function Pfa(a){a=a|0;var b=0;b=cb-16|0;cb=b;a=Ch(a,b+8|0);cb=b+16|0;return+(a?A[b+8>>3]:0)}function NC(a,b){if((a&4088)>>>0>=520){b=Wu(0-oka(b^1230262859,25)|0,4)^1247037516}return b}function Kb(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];return gb[v[v[c>>2]+32>>2]](c,v[a+8>>2],b)|0}function Iu(a,b){a=a|0;b=b|0;var c=0;c=cb-16|0;cb=c;t[c+15|0]=w[b|0];KJ(a,c+15|0);cb=c+16|0}function Hy(a){var b=0;v[a+84>>2]=0;v[a+88>>2]=0;b=v[a+80>>2];v[a+92>>2]=b;v[a+96>>2]=b<<12}function HQ(a){a:{if(Mb(a,17659,4)){break a}if(Mb(a+8|0,14307,4)){break a}return 1}return 0}function zc(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];CE(b)}function xS(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[bc(a)+4|0]){rl(b+16|0)}if(b){zb(b)}}}function vG(a){var b=0;b=v[a>>2];if(b){if(!hc(wG(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function o6(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;hx(a,b,c,d,e,0,0,f,g)}function lga(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;c=a;a=jc(b,16850);zc(c,a);rb(a);cb=b+16|0}function hP(a){var b=0;b=a&255;a=b>>>27|0;b=(b<<5)+259|0;a=b>>>0<259?a+1|0:a;fb=a;return b}function dL(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[bc(a)+4|0]){Ab(b+16|0)}if(b){zb(b)}}}function _ha(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;c=a;a=jc(b,16219);zc(c,a);rb(a);cb=b+16|0}function Nv(a,b,c){var d=0;d=cb-16|0;cb=d;c=gi(d+8|0,c);a=Cw(a,b);fi(c);cb=d+16|0;return a}function Kg(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function IJ(a,b){var c=0;c=v[a+12>>2];if((c|0)>0){v[a+20>>2]=(v[a+16>>2]+(b+c|0)|0)%(c|0)}}function EN(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[bc(a)+4|0]){FN(b+16|0)}if(b){zb(b)}}}function Bv(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=v[(b<<2)+21732>>2]}else{b=9761}jc(a,b)}function xja(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;c=a;a=jc(b,3892);zc(c,a);rb(a);cb=b+16|0}function q8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=$j(a);if(a){gb[v[v[a>>2]+76>>2]](a,b,c,d)}}function p8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=$j(a);if(a){gb[v[v[a>>2]+84>>2]](a,b,c,d)}}function oka(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function o8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=$j(a);if(a){gb[v[v[a>>2]+88>>2]](a,b,c,d)}}function np(a,b,c){a=a+1074992|0;return v[(a+B(b,872)|0)+680>>2]>v[(a+B(c,872)|0)+680>>2]}function mga(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;c=a;a=jc(b,3988);zc(c,a);rb(a);cb=b+16|0}function lM(a){var b=0,c=0;v[a>>2]=0;YS(a+4|0);og(a+8|0,0);b=a,c=bc(a),v[b>>2]=c;return a}function hw(a,b,c,d){var e=0;e=cb-16|0;cb=e;v[e+12>>2]=d;a=rr(a,b,c,d);cb=e+16|0;return a}function gx(a){a=a|0;var b=0;v[a>>2]=49184;b=v[a+4>>2];if(b){zb(b);v[a+4>>2]=0}return a|0}function Xha(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;c=a;a=jc(b,4487);zc(c,a);rb(a);cb=b+16|0}function Vea(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;c=a;a=jc(b,4168);zc(c,a);rb(a);cb=b+16|0}function VW(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;c=a;a=jc(b,16877);zc(c,a);rb(a);cb=b+16|0}function Sq(a){var b=0;while(1){if(!hc(w[a|0],0)){a=a+1|0;b=b+1|0;continue}break}return b}function Pha(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;c=a;a=jc(b,4381);zc(c,a);rb(a);cb=b+16|0}function Gga(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;c=a;a=Bc(b,3883);zc(c,a);rb(a);cb=b+16|0}function Ega(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;c=a;a=Bc(b,4890);zc(c,a);rb(a);cb=b+16|0}function $K(a,b){a=a|0;b=b|0;var c=0;c=vb(a);if(c>>>0<b>>>0){mu(a,b-c|0,0);return}HL(a,b)}function sv(){var a=0,b=0;a=cb-16|0;cb=a;b=Sf(a+8|0,Rb(lc(12)));cb=a+16|0;return v[b>>2]}function gf(a){var b=0;b=cb-16|0;cb=b;a=v[ac(b+8|0,Fb(a)+vb(a)|0)>>2];cb=b+16|0;return a}function gV(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;c=a;a=jc(b,4361);zc(c,a);rb(a);cb=b+16|0}function dR(a){var b=0;b=a+512|0;while(1){if((a|0)!=(b|0)){ug(a);a=a+1|0;continue}break}}function b0(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)==1|(c|0)>256)){nw(a,c);return}Bc(a,7914)}function _L(a,b){var c=0;c=w[a+851|0];if(c&1){t[a+851|0]=c|64;v[a+852>>2]=v[a+852>>2]+b}}function WW(a){a=a|0;var b=0,c=0;b=cb-16|0;cb=b;c=a;a=jc(b,4535);zc(c,a);rb(a);cb=b+16|0}function PQ(a,b){var c=0;c=cb-16|0;cb=c;Im(c+8|0,b);vS(a,v[c+8>>2],v[c+12>>2]);cb=c+16|0}function Js(a,b){var c=0;c=Fb(a);if(c>>>0<=b>>>0){a=vb(a)+c>>>0>=b>>>0}else{a=0}return a}function He(a){var b=0;b=cb-16|0;cb=b;a=yg(a,b+15|0);cb=b+16|0;return(a?w[b+15|0]:0)&255}function vp(a,b,c){a=dl(a)-v[a+16>>2]|0;if(a>>>0>=2){c=C(C(C(c-b)/C(a>>>0))+b)}return c}function tg(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;return a}function sG(a){var b=0;b=v[a>>2];if(b){if(!jn(Sk(b))){return!v[a>>2]}v[a>>2]=0}return 1}function s8(a,b){a=a|0;b=b|0;a=$j(a);if(!a){return 1}return gb[v[v[a>>2]+68>>2]](a,b)|0}function rW(a){a=a|0;var b=0;b=v[a+4>>2];return(gb[v[v[b>>2]+20>>2]](b)|0)+v[a+12>>2]|0}function pA(a,b,c){var d=C(0);d=z[a>>2];if(!Mt(d,z[b>>2])){b=Mt(z[c>>2],d)?c:a}return b}function cC(a){var b=0;b=a+16|0;while(1){if((a|0)!=(b|0)){ug(a);a=a+1|0;continue}break}}function Ux(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>=0)){t[b|0]=45;d=SK(d);b=b+1|0}Nx(a,b,c,d)}function Um(a){var b=0;b=nv(a+4|0);if((b|0)==-1){gb[v[v[a>>2]+8>>2]](a)}return(b|0)==-1}function RF(a,b){var c=0;c=cb-16|0;cb=c;v[c+12>>2]=b;a=TF(a,11144,b);cb=c+16|0;return a}function NN(a,b){a=v[a+24>>2]+484344|0;if(ve(a,b)){a=v[Sb(a,b)+12>>2]}else{a=1}return a}function Iv(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=c+d;return a}function GA(a){var b=0;b=oz(a);while(1){if((a|0)!=(b|0)){EU(a);a=a+32|0;continue}break}}function uc(a,b){var c=0,d=0;c=cb-16|0;cb=c;d=c+8|0;Im(d,a);Kj(d,b);cb=c+16|0;return a}function sH(a,b){a=a&255;return v[(b&12)+60660>>2]>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function jS(a){var b=0;b=a+4|0;while(1){if((a|0)!=(b|0)){ug(a);a=a+1|0;continue}break}}function hf(a){var b=0;b=a+24|0;while(1){b=rb(b-12|0);if((b|0)!=(a|0)){continue}break}}function gz(a,b){lk(a,b);zc(a+12|0,b+12|0);u[a+28>>1]=x[b+28>>1];v[a+24>>2]=v[b+24>>2]}function fE(a){var b=0;b=a+48|0;while(1){b=rb(b-12|0);if((b|0)!=(a|0)){continue}break}}function el(a,b){var c=0,d=0;c=cb-16|0;cb=c;d=c+8|0;ub(d,a,b);rm(d);cb=c+16|0;return a}function cO(a,b){return(a>>>0<=62?63-(B((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function aN(a,b){var c=0,d=0;c=cb-16|0;cb=c;d=c+8|0;Cc(d,a,b);rm(d);cb=c+16|0;return a}function ZW(){var a=0;a:{if($D(19988487)){break a}if(_D()){break a}a=ZD()^1}return a|0}function Xy(a,b){a=a+484360|0;b=b&255;if(qj(a)>>>0<=b>>>0){return Nb(a)}return xj(a,b)}function WL(a){Db(a);Db(a+12|0);Db(a+24|0);Db(a+36|0);Db(a+48|0);v[a+60>>2]=0;return a}function Dk(a){var b=0;b=a+36|0;while(1){b=rb(b-12|0);if((b|0)!=(a|0)){continue}break}}function CB(a,b,c){t[a+2|0]=1;b=b&15;if(c){b=w[b+26384|0]}else{b=(b<<2)+4|0}t[a+4|0]=b}function vY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[((b&255)<<2)+78464>>2]}return b<<24>>24}function ut(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function tY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[((b&255)<<2)+76928>>2]}return b<<24>>24}function mO(a,b,c,d){var e=0;e=cb-16|0;cb=e;a=Xh(e,a,d);Pt(b,c,a+4|0);dc(a);cb=e+16|0}function hs(a,b){a=a|0;b=b|0;b=cb-16|0;cb=b;v[b>>2]=a;nJ(17888,b);fs(89288);cb=b+16|0}function bA(a,b,c,d){var e=0;e=cb-16|0;cb=e;a=uh(e,a,d);Pt(b,c,a+4|0);dc(a);cb=e+16|0}function aF(a,b){var c=0,d=0;Ue(a,Vd(b));b=bc(b);c=bc(a),d=v[b>>2],v[c>>2]=d;return a}function WG(a){var b=0;b=UG(v[a>>2]-1|0);if(!b){a=UG(v[a+4>>2]);b=a?a+32|0:0}return b}function Qt(a,b,c,d){var e=0;e=cb-16|0;cb=e;a=Ok(e,a,d);Pt(b,c,a+4|0);dc(a);cb=e+16|0}function Q0(a,b){a=a|0;b=b|0;a=x[a>>1];b=x[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function Pn(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]-b|0;v[d>>2]=c;if((b|0)>0){ic(c,a,b)}}function Pl(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function P0(a,b){a=a|0;b=b|0;a=v[a>>2];b=v[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function Oi(a,b,c){a=a|0;b=b|0;c=c|0;if(Fc(a,b)>>>0<=c>>>0){Pu();L()}return(c<<1)+a|0}function Ns(a,b){if(!(t[b+851|0]&1&v[a+480180>>2]==8)){cy(a,b,0);cy(a,b,1);cy(a,b,2)}}function Kt(a,b){var c=0;c=cb-16|0;cb=c;u[c+14>>1]=b;Ft(a+236|0,128,c+14|0);cb=c+16|0}function yn(a){var b=0;b=a;a=v[a>>2];v[b>>2]=B(a,214013)+2531011;return a>>>16&32767}function _e(a){a=a|0;var b=0;b=v[a>>2];return(gb[v[v[b>>2]+24>>2]](b)|0)-v[a+8>>2]|0}function PE(a,b){a:{if(!(w[a+120|0]|b>>>0>30)){t[a+120|0]=1;break a}a=Ci(b)}return a}function Gj(a,b,c){var d=0;d=v[a>>2];if(!So(d,v[b>>2])){b=So(v[c>>2],d)?c:a}return b}function Fg(a,b,c){var d=0;d=A[a>>3];if(!aP(d,A[b>>3])){b=aP(A[c>>3],d)?c:a}return b}function Ej(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;tg(a)}function Dz(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function vl(a,b){var c=0,d=0,e=0;c=v[a+24>>2];d=a,e=Le(ni(b)*+(c>>>0)),v[d+24>>2]=e}function uf(a){a=a|0;v[a+60>>2]=74092;v[a>>2]=74072;os(a+8|0);$k(a+60|0);return a|0}function rt(a,b,c){b=Bo(a,b,c);a=cb-16|0;cb=a;v[a+8>>2]=c;je(a+8|0,b-c|0);cb=a+16|0}function ep(a){a=a|0;v[a+56>>2]=73928;v[a>>2]=73908;os(a+4|0);$k(a+56|0);return a|0}function X7(a,b){a=a|0;b=b|0;return C((b|0)<=2?C(C(w[(a+b|0)+4232|0])/C(127)):C(0))}function X5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return lJ(a,b,c,d,0,0,0,0,e)|0}function Wf(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[b>>2]=0;v[b+4>>2]=0;return a}function Q8(a,b){a=a|0;b=b|0;return C((b|0)<=3?C(C(w[(a+b|0)+4264|0])/C(255)):C(0))}function PF(a){return(a|0)!=0&(a|0)!=85424&(a|0)!=85448&(a|0)!=463328&(a|0)!=463352}function Od(a){var b=0;b=cb-16|0;cb=b;v[b+12>>2]=49352;On(a,49248,b+12|0);cb=b+16|0}function KE(a){a=a|0;v[a>>2]=80016;if(v[a+8>>2]!=(pd()|0)){OF(v[a+8>>2])}return a|0}function AX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=gb[a|0](b,c,d)|0;ua(fb|0);return a|0}function yP(a,b,c,d,e,f){ac(a,b);ac(a+4|0,c);ac(a+8|0,d);ac(a+12|0,e);ac(a+16|0,f)}function my(a){var b=0;b=cb-16|0;cb=b;ac(b+8|0,a+116|0);a=NL(a);cb=b+16|0;return a}function i7(a){a=a|0;t[a+4202|0]=1;v[a+4256>>2]=v[v[a+16>>2]+24620>>2];MJ(a);LJ(a)}function bq(a){var b=0;b=cb-16|0;cb=b;a=v[ac(b+8|0,v[a>>2])>>2];cb=b+16|0;return a}function bH(a,b){b=v[a+32>>2]+b|0;v[a+32>>2]=b;if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1}}function a0(a,b){a=a|0;b=b|0;jG(a,v[b>>2],v[b+4>>2],8972);v[a>>2]=74268;return a|0}function KM(a,b){var c=0;c=b&15;if(c){t[a+830|0]=c}b=b&240;if(b){t[a+829|0]=b>>>4}}function G8(a){a=a|0;t[a+4202|0]=1;v[a+4232>>2]=v[v[a+16>>2]+24620>>2];ts(a);mK(a)}function tt(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,12);return a}function mE(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,24);return a}function iP(a){if((w[a+14|0]-53&255)>>>0>=252){a=Mb(a,15605,14)}else{a=1}return!a}function eU(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,48);return a}function eD(a,b,c){var d=0;d=cb-16|0;cb=d;b=Jl(d+8|0,b,c);OD(b,a);Md(b);cb=d+16|0}function Sn(a,b){a=ic(a,b,34);u[a+34>>1]=x[b+34>>1];ic(a+36|0,b+36|0,68);return a}function Lu(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,20);return a}function Ft(a,b,c){while(1){if(b){u[a>>1]=x[c>>1];b=b-1|0;a=a+2|0;continue}break}}function AK(a,b,c){while(1){if(b){z[a>>2]=z[c>>2];b=b-1|0;a=a+4|0;continue}break}}function uh(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<2);return a}function uO(a){var b=0;b=cb-16|0;cb=b;a=v[ac(b+8|0,yb(a))>>2];cb=b+16|0;return a}function sz(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<5);return a}function sB(a){a=a+4|0;return Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}function qk(a){var b=0;b=cb-16|0;cb=b;a=v[ac(b+8|0,bq(a))>>2];cb=b+16|0;return a}function nq(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,6);return a}function nJ(a,b){var c=0;c=cb-16|0;cb=c;v[c+12>>2]=b;PG(89288,a,b,0,0);cb=c+16|0}function ht(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<4);return a}function fd(a){var b=0;b=cb-16|0;cb=b;a=v[ac(b+8|0,Fb(a))>>2];cb=b+16|0;return a}function cg(a){var b=0;b=cb-16|0;cb=b;a=v[ac(b+8|0,bc(a))>>2];cb=b+16|0;return a}function Xh(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<1);return a}function Oq(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<3);return a}function Cj(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;cc(a+8|0,b+8|0)}function Af(a){var b=0;b=cb-16|0;cb=b;a=v[ac(b+8|0,cg(a))>>2];cb=b+16|0;return a}function zX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;gb[a|0](b,c,d,e,f)}function iD(a,b,c){while(1){if(b){t[a|0]=w[c|0];b=b-1|0;a=a+1|0;continue}break}}function Yh(a){return(Oj(v[a>>2],v[a+4>>2])|0)!=(0-Oj(v[a+12>>2],v[a+16>>2])|0)}function Jg(a){var b=0,c=0;YS(a+4|0);og(a+8|0,0);b=a,c=bc(a),v[b>>2]=c;return a}function HY(a,b,c){a=a|0;b=b|0;c=c|0;return(x[(c<<1)+75904>>1]&b)!=0&c>>>0<=127}function wX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return gb[a|0](b,c,d,e)|0}function vX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;gb[v[v[b>>2]+16>>2]](a,b,c,d,1,8)}function paa(a,b){a=a|0;b=b|0;if(y[a+4>>2]<y[xb(a)>>2]){DL(a,b);return}eA(a,b)}function d1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return BH(a-88|0,b,c,d,e)|0}function YZ(){var a=0,b=0;Zd(464960);v[116240]=80016;a=464968,b=pd(),v[a>>2]=b}function Wx(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[xb(a)>>2]){DL(a,b);return}eA(a,b)}function Rn(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0}function MT(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[xb(a)>>2]){SF(a,b);return}MF(a,b)}function Eu(a,b){return Le(ni((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function wn(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function wN(a){v[a>>2]=0;v[a+4>>2]=0;v[a>>2]=-2078137563;v[a+4>>2]=-873292572}function pe(a,b){var c=0,d=0;c=cb-16|0;cb=c;d=c+8|0;Xu(d,a);Kj(d,b);cb=c+16|0}function ns(a){a=a|0;v[a>>2]=46356;fc(a+4276|0);fc(a+4264|0);vf(a);return a|0}function eY(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Bc(a,7950);return}nw(a,c)}function cj(a,b,c){if(v[a+80>>2]){v[a+92>>2]=v[a+92>>2]+(c+7&-8);return}zb(b)}function cY(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Bc(a,7880);return}nw(a,c)}function aj(a,b){var c=0;c=a;a=(b>>>0)/100|0;return Hr(Hr(c,a),B(a,-100)+b|0)}function UX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Wg(a,v[b+8>>2],0)){Fv(b,c,d)}}function PD(a,b){var c=0;c=cb-16|0;cb=c;b=Wf(c+8|0,b);OD(b,a);Md(b);cb=c+16|0}function My(a){var b=0;if(!(w[a+2|0]|(w[a|0]|w[a+1|0]))){b=!w[a+3|0]}return b}function H6(a,b){a=a|0;b=b|0;return C((b|0)<=12?z[((b<<2)+a|0)+4208>>2]:C(0))}function Gx(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function Al(a,b){var c=0,d=0;c=cb-16|0;cb=c;d=c+8|0;VB(d,a);Kj(d,b);cb=c+16|0}function yj(a){var b=0;b=cb-16|0;cb=b;a=v[Sf(b+8|0,a)>>2];cb=b+16|0;return a}function yb(a){var b=0;b=cb-16|0;cb=b;a=v[ac(b+8|0,a)>>2];cb=b+16|0;return a}function y7(a,b){a=a|0;b=b|0;return C((b|0)<=5?z[((b<<2)+a|0)+4208>>2]:C(0))}function vF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;gb[v[v[a>>2]+32>>2]](a,b,c,d)|0}function t6(a,b){a=a|0;b=b|0;return C((b|0)<=3?z[((b<<2)+a|0)+4208>>2]:C(0))}function rF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;gb[v[v[a>>2]+48>>2]](a,b,c,d)|0}function r7(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4208>>2]:C(0))}function om(a){a=a+4|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function k7(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4220>>2]:C(0))}function ce(a){var b=0;b=cb-16|0;cb=b;Au(b+8|0,a);cb=b+16|0;return v[b+8>>2]}function XE(a){var b=0;b=cb-16|0;cb=b;v[b+8>>2]=a;cb=b+16|0;return v[b+8>>2]}function V6(a,b){a=a|0;b=b|0;return C((b|0)<=1?z[((b<<2)+a|0)+4208>>2]:C(0))}function Td(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+8>>2];Ob(b,c);pv(a,b,d,c)}function M7(a,b){a=a|0;b=b|0;return C((b|0)<=6?z[((b<<2)+a|0)+4208>>2]:C(0))}function AE(){a:{if(t[465396]&1){break a}if(!Xd(465396)){break a}Wd(465396)}}function A6(a,b){a=a|0;b=b|0;return C((b|0)<=2?z[((b<<2)+a|0)+4208>>2]:C(0))}function xr(a,b,c,d,e,f,g,h){return gb[v[v[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function mG(a,b,c,d,e,f,g,h){return gb[v[v[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function kY(a,b){a=a|0;b=b|0;_l(a);v[a>>2]=88400;Mv(a+4|0,Fb(b));return a|0}function hn(a,b,c){var d=0,e=0;v[a>>2]=b;d=a,e=Oh(b,c),v[d+4>>2]=e;return a}function gP(a,b){BQ(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function ZN(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);SN(a,b,0,0,b+-1,0)}function Xq(a,b){a=a|0;b=b|0;a=v[a>>2];return gb[v[v[a>>2]+32>>2]](a,0,b)|0}function XS(a){var b=0;while(1){b=a;a=v[a>>2];if(a){continue}break}return b}function Vp(a,b,c){a=wb(w[a|0]|w[a+1|0]<<8);return(a|0)>=(b|0)&(a|0)<=(c|0)}function QI(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){qn(c+120|0)}zb(c)}}function Ok(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+c;return a}function DY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[(b<<2)+78464>>2]}return b|0}function BY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[(b<<2)+76928>>2]}return b|0}function Az(a,b){return(+(a>>>0)+ +(b|0)*4294967296)*2.3283064365386963e-10}function zv(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+12;return a}function zU(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+28;return a}function xg(a,b){var c=0;c=a;a=v[a+8>>2];b=a-b|0;v[c+8>>2]=a>>>0<b>>>0?0:b}function sN(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;SO(a,c)}function sD(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+36;return a}function gY(a,b,c){a=a|0;b=b|0;c=c|0;return hc(a,v[b+4>>2])&v[b>>2]==(c|0)}function Xg(a,b,c){v[a+8>>2]=b;v[a+12>>2]=c;v[a>>2]=0;v[a+4>>2]=0;return a}function Jv(a,b){v[a+12>>2]=0;v[a+4>>2]=b;v[a>>2]=b;v[a+8>>2]=b+1;return a}function Hr(a,b){b=x[(b<<1)+73056>>1];t[a|0]=b;t[a+1|0]=b>>>8;return a+2|0}function yN(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+8;return a}function q0(a,b,c){a=a|0;b=b|0;c=c|0;return gb[v[v[a>>2]+32>>2]](a,b,c)|0}function pz(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+4;return a}function nR(a,b){t[a+6|0]=255;v[a+16>>2]=b;u[a+4>>1]=0;v[a>>2]=0;return a}function mt(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a}function Rk(a,b,c){a=a|0;b=b|0;c=c|0;return gb[v[v[a>>2]+12>>2]](a,b,c)|0}function Pt(a,b,c){b=b-a|0;if((b|0)>0){ic(v[c>>2],a,b);v[c>>2]=b+v[c>>2]}}function Nc(a,b,c,d,e){t[a+3|0]=e;t[a+2|0]=d;t[a+1|0]=c;t[a|0]=b;return a}function Lha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=ro(a,b),v[d>>2]=e}function Kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Ru(a,b),u[d>>1]=e}function Cm(a,b,c){a=a|0;b=b|0;c=c|0;return gb[v[v[a>>2]+48>>2]](a,b,c)|0}function tB(a){return Wb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}function kw(a,b){var c=0;c=qs(a+4|0);v[a>>2]=74920;v[c>>2]=74940;un(c,b)}function jw(a,b){var c=0;c=dG(a+4|0);v[a>>2]=75088;v[c>>2]=75108;un(c,b)}function gC(a,b){return(w[a|0]|w[a+1|0]<<8)>>>0<(w[b|0]|w[b+1|0]<<8)>>>0}function e8(a,b){a=a|0;b=b|0;a=v[a+20>>2]+24|0;t[a|0]=w[a|0]&253|(b?2:0)}function Ov(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[e>>2]=c;return 3}
function EG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Xg(a,-1,-1)}function nc(a,b){var c=0,d=0;v[a>>2]=b;c=a,d=Rg(b),v[c+4>>2]=d;return a}function lB(a,b,c){var d=0;d=(b|0)/(c|0)|0;v[a>>2]=d;v[a+4>>2]=b-B(c,d)}function iO(a,b){v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=b?b:49716;v[a+12>>2]=0}function gU(a,b,c){a=a&255;return a>>>0>=(b&255)>>>0&a>>>0<=(c&255)>>>0}function dO(a){if(a>>>0<=8){return w[a+29296|0]}return w[a+29287|0]|256}function W2(a,b,c){a=a|0;b=b|0;c=c|0;MO(a,0,v[v[b+24>>2]+1298404>>2],c)}function Sc(a,b){PD(a,b);v[a+8>>2]=v[b+8>>2];PD(a+12|0,b+12|0);return a}function QP(a){var b=0;if(v[a>>2]){PP(a,v[a>>2]);b=v[a>>2];Ek(a);zb(b)}}function KH(a){a=a|0;return+(+y[v[a+32>>2]+480240>>2]*152587890625e-16)}function Ic(a){var b=0;if(v[a>>2]){jC(a,v[a>>2]);b=v[a>>2];kC(a);zb(b)}}function Hw(a){return((rh(a)+(rh(a)<<8)|0)+(rh(a)<<16)|0)+(rh(a)<<24)|0}function HD(a,b){a=a|0;b=b|0;_l(a);v[a>>2]=88400;Mv(a+4|0,b);return a|0}function xA(a,b){if(b){xA(a,v[b>>2]);xA(a,v[b+4>>2]);rl(b+16|0);zb(b)}}function vV(a){a=a|0;v[a+16>>2]=v[a+16>>2]|1;if(t[a+20|0]&1){xa();L()}}function uA(a,b){if(b){uA(a,v[b>>2]);uA(a,v[b+4>>2]);rl(b+16|0);zb(b)}}function jD(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function hl(a,b){a=w[Eb(a+62|0,b)|0];return(a<<24>>24>=0?a&127:-1)&255}function cR(a){if(Mb(a,13901,4)){a=1}else{a=Mb(a+8|0,13954,4)}return!a}function Zc(a,b,c){return Cd(v[a>>2],B(Hj(v[v[a+48>>2]+12>>2]),b)+c|0)}function Vx(a,b){if(b){Vx(a,v[b>>2]);Vx(a,v[b+4>>2]);Ab(b+16|0);zb(b)}}function Py(a,b){if(b){Py(a,v[b>>2]);Py(a,v[b+4>>2]);jm(b+16|0);zb(b)}}function Kk(a,b){a=a|0;b=b|0;t[a|0]=2;t[a+1|0]=3;t[a+2|0]=0;t[a+3|0]=4}function Gv(a,b,c){if(!(v[a+28>>2]==1|v[a+4>>2]!=(b|0))){v[a+28>>2]=c}}function Fy(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];t[a+6|0]=w[b+6|0]}function Fp(a,b){if(b){Fp(a,v[b>>2]);Fp(a,v[b+4>>2]);FN(b+16|0);zb(b)}}function qh(a,b,c){return(x[v[a+8>>2]+((c&255)<<1)>>1]&b)!=0&(c|0)>=0}function gL(a,b,c,d){if((b|0)==(d|0)){a=cN(a,b,c,d)}else{a=1}return!a}function ZC(a){return(w[v[a+104>>2]+34|0]&8)>>>3&(v[a+88>>2]&2050)==2}function Sv(a){a=a|0;if(v[a+8>>2]!=(pd()|0)){OF(v[a+8>>2])}return a|0}function QD(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){_b(c)}zb(c)}}function PL(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){sl(c)}zb(c)}}function NX(a){a=a|0;if(!a){return 0}return(Ey(a,88012,88156)|0)!=0|0}function KL(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b}function Hc(a,b,c,d){if((b|0)==(d|0)){a=uS(a,b,c,d)}else{a=1}return!a}function Dt(a){if(Ld(a)){kd(v[a>>2],0);td(a,0);return}kd(a,0);Yd(a,0)}function BX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;gb[a|0](b,c,d,e)}function z$(a){a=a|0;var b=0;b=v[115908]+1|0;v[115908]=b;v[a+4>>2]=b}function yB(a,b){var c=0;c=cb-16|0;cb=c;MC(c,a,32);RC(c,b);cb=c+16|0}function xX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return gb[a|0](b,c,d)|0}function pk(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){bc(a);if(b){zb(b)}}}function ou(a,b){var c=0;c=cb-16|0;cb=c;MC(c,a,64);RC(c,b);cb=c+16|0}function jz(a,b){Rb(a);Db(a+12|0);u[a+28>>1]=0;v[a+24>>2]=b;return a}function hC(a){if(a>>>0>=214748365){af(11191);L()}return lc(B(a,20))}function d_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;qf(a,f)}function aE(a){if(a>>>0>=357913942){af(11191);L()}return lc(B(a,12))}function WR(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];cc(a+8|0,b+8|0)}function RK(a,b,c){b=b-a|0;if(b){gj(c,a,b)}return B((b|0)/6|0,6)+c|0}function Ql(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function zP(a,b,c,d,e){ac(a,b);ac(a+4|0,c);ac(a+8|0,d);ac(a+12|0,e)}function uu(a,b){return er(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?b:a}function sm(a,b){b=x[b>>1]|x[b+2>>1]<<16;u[a>>1]=b;u[a+2>>1]=b>>>16}function pS(a){if(a>>>0>=715827883){af(11191);L()}return lc(B(a,6))}function nf(a){var b=0;b=cb-16|0;cb=b;ug(v[Jv(b,a)+8>>2]);cb=b+16|0}function jE(a,b){return er(v[a>>2],v[a+4>>2],v[b>>2],v[b+4>>2])?b:a}function iE(a,b){return v[b+8>>2]==v[a+8>>2]&v[a+12>>2]==v[b+12>>2]}function dS(a){t[a+4|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function ZL(a,b){v[a+852>>2]=v[a+852>>2]+b;t[a+851|0]=w[a+851|0]|64}function Xk(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(b){Rf(b)}zb(b)}}function KK(a){if(a>>>0>=82595525){af(11191);L()}return lc(B(a,52))}function Gc(a,b,c){if(pc(a,b)>>>0<=c>>>0){Pu();L()}return(c<<2)+a|0}function Dl(a,b){return Uu(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?b:a}function AM(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(b){Ms(b)}zb(b)}}function yY(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function ve(a,b){if(Dm(a,b)){a=Vh(fg(v[a>>2],b))}else{a=0}return a}function pn(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(v[a+12>>2]+c<<1)|0}function dP(a,b){Hz(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2]}function SE(a,b,c){a:{if((a|0)==(b|0)){t[a+120|0]=0;break a}zb(b)}}function OK(a,b){if((a|0)!=(b|0)){JR(a,v[b>>2],v[b+4>>2])}return a}function Laa(a,b){a=a|0;b=b|0;if(!v[22440]){v[22441]=b;v[22440]=a}}function Ci(a){if(a>>>0>=1073741824){af(11191);L()}return lc(a<<2)}function wD(a){if(a>>>0>=536870912){af(11191);L()}return lc(a<<3)}function tW(a){a=a|0;a=v[a+4>>2];return gb[v[v[a>>2]+12>>2]](a)|0}function tQ(a){a=a+34|0;a=kka(w[a|0]|w[a+1|0]<<8,0,80,0);return a}function sW(a){a=a|0;a=v[a+4>>2];return gb[v[v[a>>2]+16>>2]](a)|0}function pP(a){if(a>>>0>=268435456){af(11191);L()}return lc(a<<4)}function kP(a){if(a>>>0>=134217728){af(11191);L()}return lc(a<<5)}function dJ(a,b,c){a=a|0;b=b|0;c=c|0;return cJ(a,b,Fb(c),vb(c))|0}function cn(a,b){if(y[a+4>>2]<y[xb(a)>>2]){SF(a,b);return}MF(a,b)}function Ni(a,b){v[a>>2]=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];return a}function IH(a){a=a|0;return+(+v[v[a+32>>2]+1074456>>2]*.00390625)}function Hi(a,b){if(ag(v[a>>2],v[a+4>>2])>>>0>b>>>0){t[a+16|0]=b}}function HT(a){fb=0;a=a+47|0;a=(w[a|0]|w[a+1|0]<<8)-98|0;return a}function uW(a){a=a|0;a=v[a+4>>2];return gb[v[v[a>>2]+8>>2]](a)|0}function on(a,b,c){return yR(v[a>>2],v[a+4>>2],b,v[a+12>>2]+c|0)}function ik(a){a=qz(a)?a+172|0:a+156|0;return w[a|0]|w[a+1|0]<<8}function er(a,b,c,d){return a>>>0<c>>>0&(b|0)<=(d|0)|(b|0)<(d|0)}function _S(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c}function Yw(a,b,c){return Kh(v[a>>2],v[a+4>>2],b,v[a+12>>2]+c|0)}function Gs(a){rb(a+48|0);rb(a+36|0);rb(a+24|0);rb(a+12|0);rb(a)}function $c(a){a=(a|0)<32767?a:32767;return(a|0)>-32768?a:-32768}function yz(a){var b=0;if(v[a>>2]){Ac(a);b=v[a>>2];iv(a);zb(b)}}function wr(a,b){a=a|0;b=b|0;return gb[v[v[a>>2]+44>>2]](a,b)|0}function vx(a){var b=0;if(v[a>>2]){Ac(a);b=v[a>>2];Dx(a);zb(b)}}function qt(a){var b=0;if(v[a>>2]){Ac(a);b=v[a>>2];tz(a);zb(b)}}function qO(a){var b=0;if(v[a>>2]){pO(a);b=v[a>>2];Tn(a);zb(b)}}function pg(a,b,c,d){v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function oy(a){var b=0;if(v[a>>2]){Ac(a);b=v[a>>2];_T(a);zb(b)}}function ny(a){var b=0;if(v[a>>2]){Ds(a);b=v[a>>2];Cs(a);zb(b)}}function ml(a){var b=0;if(v[a>>2]){Ac(a);b=v[a>>2];it(a);zb(b)}}function mN(a){var b=0;if(v[a>>2]){Ac(a);b=v[a>>2];Qy(a);zb(b)}}function m6(a,b){a=a|0;b=b|0;if(!b){return 3}v[b>>2]=a;return 0}function gr(a){var b=0;b=cb-16|0;A[b+8>>3]=a;return A[b+8>>3]*a}function fc(a){var b=0;if(v[a>>2]){Ac(a);b=v[a>>2];vh(a);zb(b)}}function de(a){var b=0;if(v[a>>2]){Ac(a);b=v[a>>2];Vm(a);zb(b)}}function bw(a,b){a=a|0;b=b|0;return gb[v[v[a>>2]+12>>2]](a,b)|0}function bba(a,b){a=a|0;b=b|0;a=aS(a,b);if(!a){$R(b)}return a|0}function _c(a){var b=0;if(v[a>>2]){Ac(a);b=v[a>>2];Lm(a);zb(b)}}function ZJ(a){a=a|0;return C(C(C(z[a+4228>>2]*C(198))+C(-99)))}function Vc(a){var b=0;if(Ld(a)){b=v[a>>2];Lj(a);zb(b)}return a}function Uu(a,b,c,d){return(b|0)==(d|0)&a>>>0<c>>>0|b>>>0<d>>>0}function Un(a){var b=0;if(v[a>>2]){Ac(a);b=v[a>>2];ZR(a);zb(b)}}function Tp(a){var b=0;if(v[a>>2]){Ac(a);b=v[a>>2];xb(a);zb(b)}}function Th(a){var b=0;if(v[a>>2]){Ac(a);b=v[a>>2];du(a);zb(b)}}function SG(a){var b=0;b=cb-16|0;z[b+12>>2]=a;return z[b+12>>2]}function Rf(a){var b=0;if(v[a>>2]){Ac(a);b=v[a>>2];fr(a);zb(b)}}function Qd(a){var b=0;if(v[a>>2]){DU(a);b=v[a>>2];wB(a);zb(b)}}function OP(a){var b=0;if(v[a>>2]){Ac(a);b=v[a>>2];Ek(a);zb(b)}}function M2(a,b){a=a|0;b=b|0;cu(a,v[b>>2],v[b+4>>2]);return a|0}function Jia(a,b){a=a|0;b=b|0;a=WS(a,b);if(!a){VS(b)}return a|0}function JY(a){a=a|0;a=v[a+8>>2];if(!a){return 1}return IE(a)|0}function JN(a){var b=0;if(v[a>>2]){IN(a);b=v[a>>2];Ek(a);zb(b)}}function GR(a,b,c,d){be(a,b);u[a+22>>1]=d;u[a+20>>1]=c;return a}function EL(a){var b=0;if(v[a>>2]){Fo(a);b=v[a>>2];iv(a);zb(b)}}function Di(a){var b=0;if(v[a>>2]){Ac(a);b=v[a>>2];Tn(a);zb(b)}}function Cl(a,b){a=a|0;b=b|0;return gb[v[v[a>>2]+28>>2]](a,b)|0}function Ck(a){a=a|0;a=v[a>>2];return gb[v[v[a>>2]+24>>2]](a)|0}function w_(a,b){a=a|0;b=b|0;rM(a,uw(v[b>>2])<<24>>24,v[b>>2])}function rL(a,b,c,d){u[a+4>>1]=c;t[a+6|0]=b;v[a>>2]=d;return a}function qv(a,b){a=a|0;b=b|0;a=vD(a,b);if(!a){uD(b)}return a|0}function os(a){a=a|0;v[a>>2]=73392;rb(a+32|0);am(a);return a|0}function nQ(a){return w[a+15|0]<<12|w[a+14|0]<<4|w[a+13|0]<<20}function jN(a,b){a=a|0;b=b|0;a=hU(a,b);if(!a){eu(b)}return a|0}function gg(a,b){return gb[v[v[a>>2]+32>>2]](a,v[a+12>>2],b)|0}function fv(a,b){a=a|0;b=b|0;a=dD(a,b);if(!a){Kq(b)}return a|0}function fA(a,b){a=a|0;b=b|0;a=zo(a,b);if(!a){Bm(b)}return a|0}function ao(a,b){a=a|0;b=b|0;a=ST(a,b);if(!a){WT(b)}return a|0}function Yq(a,b){a=a|0;b=b|0;a=mD(a,b);if(!a){uv(b)}return a|0}function Wb(a){return a<<8&16711680|a<<24|(a>>>8&65280|a>>>24)}function Qja(a,b){a=a|0;b=b|0;fu(a,b);v[a>>2]=88556;return a|0}function OB(a,b){a=a|0;b=b|0;a=su(a,b);if(!a){yu(b)}return a|0}function MD(a,b,c){Sm(a);v[a+8>>2]=c;v[a+4>>2]=b;v[a>>2]=58316}function Lq(a){a=a|0;a=v[a>>2];return gb[v[v[a>>2]+8>>2]](a)|0}function Iq(a,b){var c=0;c=b+1|0;v[a>>2]=v[a>>2]>(c|0)?c:b+2|0}function Gq(a,b,c){a=a|0;b=b|0;c=c|0;Ph(a,b,yi(b,b+c|0,58412))}function FD(a,b){Wf(a,b);v[a+8>>2]=v[b+8>>2];Wf(a+12|0,b+12|0)}function FA(a,b){a=a|0;b=b|0;a=mS(a,b);if(!a){qA(b)}return a|0}function At(a,b){a=a|0;b=b|0;a=TT(a,b);if(!a){bu(b)}return a|0}function $h(a,b){a=a|0;b=b|0;a=Ch(a,b);if(!a){Rj(b)}return a|0}function yL(a,b){return b>>>0<4e3?((b<<5)+a|0)+946304|0:21685}function fo(a,b){b=w[b|0]|w[b+1|0]<<8;t[a|0]=b;t[a+1|0]=b>>>8}function cI(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function MV(a,b){a=a|0;b=b|0;fu(a,b);v[a>>2]=88608;return a|0}function Jl(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(c){Rm(c)}return a}function EO(a,b){a=a|0;b=b|0;fu(a,b);v[a>>2]=88420;return a|0}function yx(a){a=a|0;v[a+32>>2]=0;v[a+28>>2]=v[a+28>>2]&-7|2}function qp(a,b,c){if(!b){return 0}return ys(a,sg(t[c|0]),b)}function qE(a,b,c){b=Oa(980,a|0,b|0,c|0)|0;fb=O()|0;return b}function lW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Ub(a,v[d>>2],0)}function jv(a,b){zc(a,b);cc(a+12|0,b+12|0);bi(a+32|0,b+32|0)}function ec(a,b){var c=0;c=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=c}function ay(a,b){var c=0;c=x[a>>1];u[a>>1]=x[b>>1];u[b>>1]=c}function XL(a){v[a>>2]=0;Rb(a+4|0);Hb(a+16|0,0,144);return a}function UG(a){return t[(B(0-a&a,124511785)>>>27|0)+69696|0]}function Tg(a,b,c,d){fb=b-((a>>>0<c>>>0)+d|0)|0;return a-c|0}function MH(a){a=a|0;return+(65536/+y[v[a+32>>2]+480244>>2])}function xz(a,b){if(b){xz(a,v[b>>2]);xz(a,v[b+4>>2]);zb(b)}}function wz(a,b){if(b){wz(a,v[b>>2]);wz(a,v[b+4>>2]);zb(b)}}function vn(a,b){return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function qY(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)>=0?b:c)|0}function qU(a){return!Mb(a,14255,4)&(w[a+4|0]-1&255)>>>0<10}function nv(a){var b=0;b=a;a=v[a>>2]-1|0;v[b>>2]=a;return a}function m8(a){a=a|0;a=$j(a);if(a){gb[v[v[a>>2]+96>>2]](a)}}function lq(a){return v[a+20>>2]+(v[a+8>>2]-v[a+24>>2]|0)|0}function gi(a,b){var c=0,d=0;c=a,d=LF(b),v[c>>2]=d;return a}function dA(a,b){if(b){dA(a,v[b>>2]);dA(a,v[b+4>>2]);zb(b)}}function NA(a,b){if(b){NA(a,v[b>>2]);NA(a,v[b+4>>2]);zb(b)}}function MA(a,b){if(b){MA(a,v[b>>2]);MA(a,v[b+4>>2]);zb(b)}}function Ls(a,b){if(b){Ls(a,v[b>>2]);Ls(a,v[b+4>>2]);zb(b)}}function Ks(a,b){if(b){Ks(a,v[b>>2]);Ks(a,v[b+4>>2]);zb(b)}}function JG(a,b){if(b>>>0<=9){return IG(a,b)}return Hr(a,b)}function ER(a){var b=0;b=v[a+100>>2];v[a+100>>2]=0;return b}function CI(a,b){a=a|0;b=b|0;return Uc(v[b>>2],v[b+4>>2])|0}function vb(a){if(Ld(a)){return v[a+4>>2]}return w[a+11|0]}function vaa(a){a=a|0;fu(a,21685);v[a>>2]=88500;return a|0}function rm(a){var b=0;b=v[a>>2];v[b>>2]=v[b>>2]|v[a+4>>2]}function qz(a){a=a+156|0;return(w[a|0]|w[a+1|0]<<8)==65534}function fn(a,b,c,d){v[a+16>>2]=d;v[a+12>>2]=c;v[a+8>>2]=b}function cw(){var a=0;a=aa(4)|0;tn(a);ia(a|0,88360,26);L()}function c3(a,b,c){a=a|0;b=b|0;c=c|0;zc(a,cJ(c,0,b,Rg(b)))}function Y$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;fb=0;return 0}function V2(a){a=a|0;ZI(a,2,100);Hi(v[a+24>>2]+484360|0,0)}function Rx(a,b,c){A[a>>3]=A[a>>3]+b;A[a+8>>3]=A[a+8>>3]+c}function rw(a,b,c){v[a+28>>2]=c;v[a+20>>2]=b;v[a+24>>2]=b}function gH(a){while(1){if((Nr(a)|0)!=-1){continue}break}}function _f(a){var b=0;RP(a);b=v[a>>2];if(b){Cz(a);zb(b)}}function _V(a){a=a|0;ID(a,13363);v[a>>2]=26188;return a|0}function Uv(a){if(v[a>>2]){Ac(a);SE(Tv(a),v[a>>2],vh(a))}}function TE(a,b,c){a=a|0;b=b|0;c=c|0;cu(a,b,c);return a|0}function Sd(a){if(!v[a+20>>2]){return 0}return v[a>>2]!=0}function PI(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){ms(c)}}function Nn(a){v[a>>2]=0;v[a+4>>2]=0;og(a+8|0,0);return a}function Mw(a,b){return v[((a>>>24^b)<<2)+458640>>2]^a<<8}function Iha(a,b,c){a=a|0;b=b|0;c=c|0;Ph(a,b,Uc(b,c)+b|0)}function Dp(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function AU(a,b){t[a|0]=w[b|0];t[a+1|0]=w[b+1|0];return a}function AA(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){zb(c)}}function zaa(a,b,c){a=a|0;b=b|0;c=c|0;return tL(a,b,c)|0}function xh(a,b){var c=0;c=w[a|0];t[a|0]=w[b|0];t[b|0]=c}function pt(a,b){ec(a,b);ec(a+4|0,b+4|0);ec(xb(a),xb(b))}function ph(a,b,c){t[a|0]=w[a|0]|b;v[a+4>>2]=v[a+4>>2]|c}function mX(a){a=a|0;EO(a,7985);v[a>>2]=41944;return a|0}function dj(a){return Ve(a)|Ve(a)<<8|Ve(a)<<16|Ve(a)<<24}function cB(a,b){t[v[a>>2]]=w[b|0];t[v[a+4>>2]]=w[b+1|0]}function _H(a){a=a|0;v[a>>2]=57660;_b(a+12|0);return a|0}function Yy(a,b){A[a>>3]=A[a>>3]*b;A[a+8>>3]=A[a+8>>3]*b}function VJ(a,b){Rm(v[b>>2]);Um(v[a>>2]);v[a>>2]=v[b>>2]}function U0(a,b,c){a=a|0;b=b|0;c=c|0;return Hd(B(b,c))|0}function TC(a){if((a|0)<0){af(11191);L()}return lc(a<<1)}function ME(a){a=a|0;v[a>>2]=80104;rb(a+16|0);return a|0}function LE(a){a=a|0;v[a>>2]=80064;rb(a+12|0);return a|0}function JW(a,b,c){a=a|0;b=b|0;c=c|0;pv(a,b,v[b+8>>2],c)}function Hha(a,b){a=a|0;b=b|0;Bc(a,b?b:21685);return a|0}function HW(a){a=a|0;ID(a,8733);v[a>>2]=30612;return a|0}function DG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Xg(a,-1,-1)}function Bm(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function yd(a){v[a>>2]=0;v[a+4>>2]=0;Rp(a+8|0);return a}function xE(a){a=Vw(v[a>>2]);if((nv(a+8|0)|0)<0){zb(a)}}function wd(a,b,c){return a>>>0<b>>>0?b:a>>>0>c>>>0?c:a}function rH(a,b,c){v[a+4>>2]=0;v[a>>2]=b;v[a+8>>2]=c<<3}function nB(a){a=a|0;v[a>>2]=88380;xE(a+4|0);return a|0}function fI(a){a=a|0;v[a>>2]=58124;_b(a+4|0);return a|0}function am(a){a=a|0;v[a>>2]=73264;Pb(a+4|0);return a|0}function Xr(a){a=a|0;v[a>>2]=49396;_r(a+4|0);return a|0}function Uo(a){a=a|0;v[a>>2]=73328;Pb(a+4|0);return a|0}function UA(a){a=a&255;return Rc(a)^1|(a-49&255)>>>0<36}function Tq(a){a=a|0;v[a>>2]=88400;xE(a+4|0);return a|0}function S6(a){a=a|0;JJ(a);t[a+4202|0]=1;v[a+4224>>2]=0}function RE(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Um(b)}}function On(a,b,c){v[a>>2]=b;v[a+4>>2]=v[c>>2];return a}function Eo(a){var b=0;b=v[a+8>>2];v[a+8>>2]=0;return b}function Dc(a){if(Ld(a)){a=Lj(a)-1|0}else{a=10}return a}function CD(a){a=a|0;v[a>>2]=43216;Md(a+4|0);return a|0}function Bo(a,b,c){b=b-a|0;if(b){gj(c,a,b)}return b+c|0}function BG(a,b){ac(a,v[v[b>>2]-12>>2]+b|0);v[a+4>>2]=b}function Ae(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){ms(b)}}function zG(a){a=a|0;return Dr(v[v[a>>2]-12>>2]+a|0)|0}function xM(a,b){vM(a,b);vM(a+12|0,b+12|0);t[a+24|0]=1}function rh(a){var b=0;b=Nr(a);v[a+1396>>2]=0;return b}function qG(a){a=a|0;return Br(v[v[a>>2]-12>>2]+a|0)|0}function p_(a,b){a=a|0;b=b|0;$b(a,rG(v[b>>2]),v[b>>2])}function ii(a,b){v[a+16>>2]=!v[a+24>>2]|(v[a+16>>2]|b)}function g0(a){a=a|0;return ep(v[v[a>>2]-12>>2]+a|0)|0}function e0(a){a=a|0;return uf(v[v[a>>2]-12>>2]+a|0)|0}function _w(a,b,c){return Wp(v[a>>2],b,v[a+12>>2]+c|0)}function Zg(a,b){a=a|0;b=b|0;gb[v[v[b>>2]+20>>2]](a,b)}function Yo(a){return w[a+2|0]&2?(w[a+1|0]&6)==6?4:1:0}function XJ(a){a=a|0;return tj(C(z[a+4224>>2]*C(4)))|0}function Vb(a,b,c){return(a|0)<(b|0)?b:(a|0)>(c|0)?c:a}function UK(a,b){return(b>>>0<=15?t[a+b|0]:63)<<24>>24}function TK(a,b){return(b>>>0<=45?t[a+b|0]:63)<<24>>24}function Pw(a){return(a&6)==6?384:1152>>>((a&14)==2)|0}function No(a){if(Ld(a)){a=Lj(a)-1|0}else{a=1}return a}function Ih(a,b){a=a|0;b=b|0;gb[v[v[b>>2]+24>>2]](a,b)}function Ida(a,b){a=a|0;b=b|0;if(!QQ(a,b)){Hb(b,0,40)}}function Hh(a,b){a=a|0;b=b|0;gb[v[v[b>>2]+28>>2]](a,b)}function F$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Ph(a,c,d)}function CX(a){a=a|0;a=gb[a|0]()|0;ua(fb|0);return a|0}function C$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;HF(a,c,d)}function sp(a){a=a|0;return gb[v[v[a>>2]+24>>2]](a)|0}function pf(a,b,c,d){t[a+8|0]=d;v[a+4>>2]=c;v[a>>2]=b}function lv(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(c){Rm(c)}}function jc(a,b){a=a|0;b=b|0;KD(a,b,Sq(b));return a|0}function gK(a){fc(a+36|0);fc(a+24|0);vx(a+12|0);vx(a)}function e2(a,b){a=a|0;b=b|0;iN(v[a>>2],b);return a|0}function Zm(a,b){return gb[v[v[a>>2]+36>>2]](a,b,0)|0}function Zi(a){a=a|0;return gb[v[v[a>>2]+16>>2]](a)|0}function Ym(a,b){return gb[v[v[a>>2]+52>>2]](a,b,0)|0}function Yi(a){a=a|0;return gb[v[v[a>>2]+12>>2]](a)|0}function S7(a,b,c){a=a|0;b=b|0;c=c|0;$b(a,b+4228|0,7)}function Rga(a,b,c){a=a|0;b=b|0;c=c|0;JR(a,b,Ib(b,c))}function Mga(a,b,c){a=a|0;b=b|0;c=c|0;zc(a,dJ(c,0,b))}function IF(a,b,c){a=JF(a,b,c,0,-2147483648);return a}function F8(a,b,c){a=a|0;b=b|0;c=c|0;$b(a,b+4260|0,8)}function Bc(a,b){a=a|0;b=b|0;cu(a,b,Rg(b));return a|0}function uN(a,b,c,d){return(a|0)==(c|0)&(b|0)==(d|0)}function tD(a){return TG(a,C(2.524354896707238e-29))}function k8(a){a=a|0;t[a+4202|0]=1;rs(a);wx(a);hK(a)}function jq(a,b,c,d,e){$b(a,b+d|0,(e|0)==-1?c-d|0:e)}function jka(a){if(a){return 31-E(a-1^a)|0}return 32}function ae(a,b,c){t[a|0]=b;t[a+1|0]=w[c|0];return a}function YJ(a){a=a|0;return C(C(z[a+4216>>2]*C(10)))}function TD(a){return TG(a,C(1.5845632502852868e29))}function L8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function G7(a){a=a|0;return C(C(z[a+4232>>2]*C(20)))}function zp(a,b,c){if(!c){return 0}return Mb(a,b,c)}function vv(a,b){a=a|0;b=b|0;return TA(a,b,Sq(b))|0}function uz(a){t[a+6|0]=0;u[a+4>>1]=65535;v[a>>2]=0}function uj(a){if(!a){return 0}return v[a+44>>2]!=0}function ub(a,b,c){$b(a,(c>>>3&536870908)+b|0,1<<c)}function to(a,b,c){$b(a,(c>>>3&536870908)+b|0,c&31)}function iB(a,b){be(a,b);Hb(a+20|0,0,1040);return a}function h1(a,b,c){a=a|0;b=b|0;c=c|0;FH(a-88|0,b,c)}function f1(a,b,c){a=a|0;b=b|0;c=c|0;DH(a-88|0,b,c)}function dp(a,b){b=v[b>>2];v[a>>2]=b;Rm(b);return a}function dk(a){if(!a){return 0}return sj(w[a+31|0])}function dd(a,b){a=a|0;b=b|0;return tL(a,b,Rg(b))|0}function d3(a){a=a|0;a=v[a+4>>2];return(a?a:5014)|0}function Yda(a,b,c){a=a|0;b=b|0;c=c|0;zc(a,vv(b,c))}function XN(a,b){v[a+8>>2]=0;v[a+12>>2]=0;A[a>>3]=b}function Ws(a,b,c){return CN(a,b,x[c>>1],v[c+4>>2])}function Vs(a,b,c){return CN(x[a>>1],v[a+4>>2],b,c)}function Vq(a,b){cc(a,b);Hb(a+20|0,0,1040);return a}function Vd(a){var b=0;b=v[a>>2];v[a>>2]=0;return b}function Re(a){var b=0;b=v[a>>2];if(b){xb(a);zb(b)}}function MC(a,b,c){t[a+8|0]=1;v[a+4>>2]=c;v[a>>2]=b}function Fr(a,b){v[a>>2]=b;v[a+4>>2]=b>>31;return a}function Ew(a){if(!a){return 0}v[114922]=a;return-1}function EZ(){Zd(465176);OE(465184);v[116294]=82720}function CZ(){Zd(465192);OE(465200);v[116298]=82876}function Bs(a){v[a>>2]=49504;v[a>>2]=49476;return a}function Ao(a){a=a|0;a=mc(a);gb[v[v[a>>2]>>2]](a)|0}function $6(a){a=a|0;return C(C(z[a+4232>>2]*C(4)))}function yy(a,b,c){return pM(a,b,w[c|0],v[c+4>>2])}function xy(a,b,c){return pM(w[a|0],v[a+4>>2],b,c)}function xx(a){a=a|0;_b(a+4208|0);vf(a);return a|0}function xs(a){a=a|0;ai(a);v[a+20>>2]=0;return a|0}function wl(a){a=(a|0)<120?a:120;return(a|0)>1?a:1}function rx(a){a=a|0;fc(a+4256|0);vf(a);return a|0}function ms(a){a=a|0;if(a){gb[v[v[a>>2]+4>>2]](a)}}function jk(a){a=a+158|0;return w[a|0]|w[a+1|0]<<8}function j1(a,b,c){a=a|0;b=b|0;c=+c;HH(a-88|0,b,c)}function hm(a){mj(a+724|0);mj(a+732|0);mj(a+740|0)}function g1(a,b){a=a|0;b=b|0;return EH(a-88|0,b)|0}function fp(a){a=a|0;fc(a+4208|0);vf(a);return a|0}function e1(a,b){a=a|0;b=b|0;return CH(a-88|0,b)|0}function cE(a,b,c){a=a|0;b=b|0;c=c|0;zc(a,GD(b,c))}function Y0(a,b,c){a=a|0;b=b|0;c=+c;xH(a-92|0,b,c)}function W0(a,b,c){a=a|0;b=b|0;c=+c;uH(a-92|0,b,c)}function Mn(a){a=a+170|0;return w[a|0]|w[a+1|0]<<8}function KR(a,b,c){a=a|0;b=b|0;c=c|0;zc(a,qF(b,c))}function Hl(a,b){return(a&65535)>>>0<(b&65535)>>>0}function Ep(a){a=a+168|0;return w[a|0]|w[a+1|0]<<8}function yC(a){return!Mb(a,26272,25)&w[a+34|0]<65}function wB(a){return(v[xb(a)>>2]-v[a>>2]|0)/28|0}function uE(a){return(a<<1)+16777216>>>0<16777217}function lm(a,b,c){A[a+8>>3]=c;A[a>>3]=b;return a}function km(a,b,c){v[a+4>>2]=c;u[a>>1]=b;return a}function kC(a){return(v[xb(a)>>2]-v[a>>2]|0)/20|0}function iv(a){return(v[xb(a)>>2]-v[a>>2]|0)/36|0}function fr(a){return(v[xb(a)>>2]-v[a>>2]|0)/24|0}function fj(a){return hc(v[a+36>>2],v[a+40>>2])^1}function bha(a,b){a=a|0;b=b|0;if(!aS(a,b)){$R(b)}}function _T(a){return(v[xb(a)>>2]-v[a>>2]|0)/48|0}function Zl(a,b,c){v[a>>2]=b;v[a+4>>2]=c;return a}function ZR(a){return(v[xb(a)>>2]-v[a>>2]|0)/33|0}function ZF(a){return(Yj(a)|0)!=0|(a|32)-97>>>0<6}function Wp(a,b,c){return v[(b<<2)+a>>2]+(c<<2)|0}function Ufa(a,b){a=a|0;b=b|0;if(!su(a,b)){yu(b)}}function Oia(a,b){a=a|0;b=b|0;if(!WS(a,b)){VS(b)}}function OS(a){if(!(a&255)){return 1}return Rc(a)}function Mja(a,b){a=a|0;b=b|0;if(!hU(a,b)){eu(b)}}function Hg(a,b,c){b=v[b>>2];t[a+4|0]=c;v[a>>2]=b}function Ek(a){return(v[xb(a)>>2]-v[a>>2]|0)/12|0}function DQ(a){return(v[xb(a)>>2]-v[a>>2]|0)/56|0}function Cs(a){return(v[xb(a)>>2]-v[a>>2]|0)/52|0}function Cf(a){return vk(v[a>>2],v[a+4>>2])&65535}function Bp(a,b){v[a+4>>2]=256;v[a>>2]=b;return a}function Bf(a,b){if(Ld(a)){td(a,b);return}Yd(a,b)}function $b(a,b,c){v[a+4>>2]=c;v[a>>2]=b;return a}function xT(a,b){v[a>>2]=v[a>>2]+B(b,6);return a}function vS(a,b,c){$b(a,b,yi(b,b+c|0,58412)-b|0)}function vO(a,b){v[a>>2]=v[a>>2]+(b<<1);return a}function ul(a,b,c){t[a+2|0]=c;u[a>>1]=b;return a}function rM(a,b,c){v[a+4>>2]=c;t[a|0]=b;return a}function pU(a,b){a=ZT(a,b);if(!a){qB(b)}return a}function mV(a,b){a=a|0;b=b|0;if(!TB(a,b)){zu(b)}}function iA(a,b){a=a|0;b=b|0;if(!mS(a,b)){qA(b)}}function i1(a,b){a=a|0;b=b|0;return+GH(a-88|0,b)}function fu(a,b){_l(a);v[a>>2]=88380;Mv(a+4|0,b)}function ex(a,b){v[a>>2]=v[b>>2];zc(a+4|0,b+4|0)}function du(a){return(v[xb(a)>>2]-v[a>>2]|0)/6|0}function dT(a,b){a=a|0;b=b|0;if(!dD(a,b)){Kq(b)}}function cz(a){v[a+24>>2]=x[a+20>>1]<<x[a+22>>1]}function co(a,b){a=a|0;b=b|0;if(!Ch(a,b)){Rj(b)}}function aL(a){return B(jk(a),Mn(a))+7>>>3&65535}function _ja(a,b){a=a|0;b=b|0;return mu(a,1,b)|0}function X9(a,b){a=a|0;b=b|0;if(!mD(a,b)){uv(b)}}function X0(a,b){a=a|0;b=b|0;return+vH(a-92|0,b)}function V0(a,b){a=a|0;b=b|0;return+tH(a-92|0,b)}function UT(a,b){a=a|0;b=b|0;if(!TT(a,b)){bu(b)}}function Qy(a){return(v[xb(a)>>2]-v[a>>2]|0)/7|0}function NB(a,b){a=a|0;b=b|0;if(!vD(a,b)){uD(b)}}function Fb(a){if(Ld(a)){return v[a>>2]}return a}function ES(a,b){a=a|0;b=b|0;return wq(a,b,32)|0}function Du(a,b){a=a|0;b=b|0;if(!vo(a,b)){no(b)}}function Do(a,b,c){a=ee(a);v[a+4>>2]=c;v[a>>2]=b}function CO(a,b){ac(a,v[b>>2]);t[a+4|0]=w[b+4|0]}function yl(a){return xl(Fc(v[a>>2],v[a+4>>2]))}function vB(a,b,c){if(b){Hb(a,sg(c),b)}return a}function ux(a,b){return Mt(z[a>>2],z[b>>2])?b:a}function tx(a,b){a=a|0;b=b|0;qf(a,b);return a|0}function qj(a){return ag(v[a>>2],v[a+4>>2])&255}function ld(a,b){return So(v[b>>2],v[a>>2])?b:a}function kh(a,b,c){ac(a,b);_S(a+4|0,c);return a}function iq(a,b,c){b=b-a|0;if(b){gj(c-b|0,a,b)}}function ie(a,b){return Hl(x[a>>1],x[b>>1])?b:a}function en(a){return gb[v[v[a>>2]+28>>2]](a)|0}function eS(a){return!Mb(a,13959,4)&w[a+4|0]<32}function b7(a){a=a|0;return z[a+4212>>2]<C(1)|0}function RV(a,b){a=a|0;b=b|0;Kp(a,b);return a|0}function Pc(a,b){return Yn(v[a>>2],v[b>>2])?b:a}function OE(a){var b=0,c=0;b=a,c=pd(),v[b>>2]=c}function Mg(a,b){a=a|0;b=b|0;MB(a,v[a+16>>2]|b)}function LG(a,b){if(!a){return 0}return Cw(a,b)}function Ke(a,b){return So(v[a>>2],v[b>>2])?b:a}function Kc(a,b){return Hl(x[b>>1],x[a>>1])?b:a}function Jt(a){fc(a+88|0);fc(a+68|0);fc(a+48|0)}function Iy(a){if(w[a+24|0]){BM(a);t[a+24|0]=0}}function I7(a){a=a|0;return z[a+4220>>2]<C(1)|0}function Hk(a){return gb[v[v[a>>2]+36>>2]](a)|0}function FG(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function Bb(a,b){return Yn(v[b>>2],v[a>>2])?b:a}function BR(a){var b=0;b=v[a>>2];Fe(a);return b}function $l(a,b){return Mt(z[b>>2],z[a>>2])?b:a}function w7(a){a=a|0;t[a+4202|0]=1;SJ(a);UJ(a)}function tf(a,b,c){if(!(w[a|0]&32)){Fu(b,c,a)}}function rz(a){return a>>>0<=45?w[a+43792|0]:0}function qu(a,b,c){a=a|0;b=b|0;c=c|0;FU(a,b,c)}function p7(a){a=a|0;t[a+4202|0]=1;OJ(a);NJ(a)}function nU(a,b,c){a=a|0;b=b|0;c=c|0;UB(a,b,c)}function lh(a,b){t[a+4|0]=0;v[a>>2]=b;return a}function kg(a,b,c){a=lka(a,b,c,c>>31);return a}function iY(a,b,c){a=a|0;b=b|0;c=c|0;$b(a,c,b)}function aO(a){Zy(a);Hb(a+27|0,0,255);return a}function _O(a){v[a>>2]=0;v[a+4>>2]=-1;return a}function P2(a,b){a=a|0;b=b|0;zc(a,YI(b,17674))}function Fi(a,b){return(B(b,104)+a|0)+484380|0}function F6(a){a=a|0;GJ(a);nx(a);t[a+4202|0]=1}function Dfa(a,b){a=a|0;b=b|0;return QQ(a,b)|0}function Co(a){ND(a);v[a+8>>2]=0;v[a>>2]=85348}function BB(a){return!Mb(a,15509,4)&w[a+4|0]<4}function BA(a,b,c){a=a|0;b=b|0;c=c|0;RB(a,b,c)}function Ar(a,b){return(a&255)>>>0<(b&255)>>>0}function $s(a){return(a>>>0<9?a:a-9|256)&65535}function yG(a){a=a|0;vw(v[v[a>>2]-12>>2]+a|0)}function y9(a,b){a=a|0;b=b|0;jy(OK(a+24|0,b))}function wH(a,b){a=a|0;b=b|0;return GD(a,b)|0}function rb(a){if(Ld(a)){zb(v[a>>2])}return a}function qc(a,b){if(y[a>>2]>b>>>0){v[a>>2]=b}}function pJ(a,b){a=a|0;b=b|0;return YI(a,b)|0}function pG(a){a=a|0;sw(v[v[a>>2]-12>>2]+a|0)}function ol(a,b,c,d){return(b-d|0)+(a-c<<3)|0}function nka(a,b,c,d){a=ika(a,b,c,d);return a}function nX(a,b){a=a|0;b=b|0;return eE(a,b)|0}function mU(a){t[a+12|0]=w[a+12|0]|2;return a}function fx(a){a=a|0;v[a>>2]=49228;return a|0}function fw(a,b,c){a=JF(a,b,c,-1,-1);return a}function ff(a,b){return Ar(w[a|0],w[b|0])?b:a}function fS(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function f0(a){a=a|0;lG(v[v[a>>2]-12>>2]+a|0)}function ee(a){v[a>>2]=0;v[a+4>>2]=0;return a}function d0(a){a=a|0;kG(v[v[a>>2]-12>>2]+a|0)}function cs(a){return x[v[a+24>>2]+480192>>1]}function bs(a){return x[v[a+24>>2]+480190>>1]}function aI(a){a=a|0;v[a>>2]=57760;return a|0}function _b(a){if(v[a>>2]){Ac(a);zb(v[a>>2])}}function Zh(a,b){if(v[a>>2]>(b|0)){v[a>>2]=b}}function ZH(a){a=a|0;v[a>>2]=57260;return a|0}function Xj(a,b){a=a|0;b=b|0;return xG(a,b)|0}function WE(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function Vh(a){return hc(v[a>>2],v[a+4>>2])^1}function UP(a){return Le(443250/+(a>>>0)*1e4)}function To(a,b){a=a|0;b=b|0;return xG(a,b)^1}function Tb(a,b){return Ar(w[b|0],w[a|0])?b:a}function Qk(a,b){a=a|0;b=b|0;return tG(a,b)|0}function Kf(a,b){if(x[a>>1]>b>>>0){u[a>>1]=b}}function JD(a){a=a|0;v[a>>2]=58180;return a|0}function Dx(a){return v[xb(a)>>2]-v[a>>2]>>11}function Cr(a,b){a=a|0;b=b|0;return tG(a,b)^1}function BU(a,b){a=a|0;b=b|0;return qF(a,b)|0}function BD(a){a=a|0;v[a>>2]=43080;return a|0}function AD(a){a=a|0;v[a>>2]=42840;return a|0}function $o(a){return x[v[a+24>>2]+480188>>1]}function $W(a,b){a=a|0;b=b|0;return vv(a,b)|0}function zx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function yo(a,b,c,d){a=lka(a,b,c,d);return a}function yR(a,b,c,d){return(B(b,d)+c<<1)+a|0}function wh(a){return v[v[a+8>>2]>>2]==(a|0)}function vh(a){return v[xb(a)>>2]-v[a>>2]>>2}function tz(a){return v[xb(a)>>2]-v[a>>2]>>8}function tM(a){t[a+24|0]=0;t[a|0]=0;return a}function px(a){return C(C(a*C(7900))+C(100))}function pE(a){a=Ia(a|0)|0;fb=O()|0;return a}function lx(a){return C(C(a*C(1e4))+C(-1e4))}function it(a){return v[xb(a)>>2]-v[a>>2]>>4}function fT(a,b){a=a|0;b=b|0;return(b|0)<6|0}function bh(a){a=a&255;return(a|0)==255?-1:a}function ah(a,b,c,d){return(B(b,d)+c<<3)+a|0}function Y1(a){a=a|0;dI(a);return v[a+16>>2]}function Vm(a){return v[xb(a)>>2]-v[a>>2]>>3}function Tn(a){return v[xb(a)>>2]-v[a>>2]>>5}function Of(a){return v[a+8>>2]-v[a+12>>2]|0}function O0(a){a=a|0;return Ga(v[a+60>>2])|0}function Ms(a){yp(a+223860|0);_b(a+223848|0)}function Lm(a){return v[xb(a)>>2]-v[a>>2]>>1}function Kh(a,b,c,d){return(B(b,d)+c<<2)+a|0}function EJ(a){return C(C(a*C(19980))+C(20))}function EF(a,b,c){ac(a,b);ac(a+4|0,v[c>>2])}function Cz(a){return v[mc(a)>>2]-v[a>>2]>>2}function CR(a){if(a){kH(a);ze(v[a+80>>2],a)}}function yf(a,b){if(w[a|0]>b>>>0){t[a|0]=b}}function wj(a,b){return a<<16>>16<b<<16>>16}function vI(a){t[a+4|0]=0;t[a|0]=0;return a}function tJ(a){return Nh(C(vJ(a)*C(32768)))}function si(a,b){a=a|0;b=b|0;return C(C(0))}function qs(a){QJ(a);v[a>>2]=74560;return a}function ll(a,b){return a<<24>>24<b<<24>>24}function ih(a,b){return Qb(v[a>>2],v[b>>2])}function gn(a){a=a|0;rG(v[a>>2]);return a|0}function dG(a){QJ(a);v[a>>2]=74784;return a}function a7(a){a=a|0;return C(z[a+4220>>2])}function _J(a){a=a|0;return C(z[a+4208>>2])}function Z1(a){a=a|0;dI(a);return v[a+4>>2]}function YE(a,b,c){return Bo(XE(a),XE(b),c)}function VT(a,b){v[a>>2]=v[a>>2]+b;return a}function Ul(a){a=a|0;uw(v[a>>2]);return a|0}function Rh(a,b,c){if(c){gj(a,b,c)}return a}function Qo(a){return v[xb(a)>>2]-v[a>>2]|0}function Nb(a){return we(v[a>>2],w[a+16|0])}function Hn(a,b,c){b=b-a|0;if(b){gj(c,a,b)}}function H7(a){a=a|0;return C(z[a+4212>>2])}function Dd(a){return pc(v[a>>2],v[a+4>>2])}function Ce(a,b,c){if(c){ic(a,b,c)}return a}function BI(a,b){a=a|0;b=b|0;return Dd(b)|0}function yJ(a){return C(C(a*C(96))+C(-96))}function x0(a){a=a|0;return zh(a,463456)|0}function vt(a){Re(a+24|0);_b(a+12|0);_b(a)}function tw(a){a=a|0;return zh(a,463636)|0}function pm(a){kz(v[a+20>>2]);v[a+20>>2]=0}function ow(a){a=a|0;return zh(a,463652)|0}function o0(a){a=a|0;return zh(a,463472)|0}function kaa(a,b){a=a|0;b=b|0;Ho(a+40|0,b)}function jr(a,b){gb[v[v[b>>2]+40>>2]](a,b)}function iw(a){a=a|0;return zh(a,463660)|0}function hka(a,b){a=a|0;b=b|0;sq(a+36|0,b)}function dw(a){a=a|0;return zh(a,463684)|0}function dv(a,b,c){a=kka(c,0,a,b);return a}function d8(a,b,c){a=a|0;b=b|0;c=c|0;ee(a)}function ct(a){em(a,a+32|0,58412);return a}function bl(a){rb(a+36|0);fc(a+24|0);Th(a)}function _v(a){a=a|0;return zh(a,463692)|0}function Vu(a){a=a|0;return zh(a,463644)|0}function TG(a,b){return C(SG(a?C(-b):b)*b)}function RJ(a){return C(C(a*C(60))+C(-60))}function Qr(a){return(a|0)<=65535&(a|0)>=0}function QB(a){return w[a+1|0]==2&w[a|0]<3}function Mq(a){Wq(a+32|0);sb(a+12|0);rb(a)}function Lj(a){return v[a+8>>2]&2147483647}function Jk(a,b){gb[v[v[b>>2]+44>>2]](a,b)}function J8(a,b){a=a|0;b=b|0;t[a+4201|0]=b}function Ik(a,b){gb[v[v[b>>2]+32>>2]](a,b)}function GP(a,b,c,d){$b(a,b,(d|0)==-1?c:d)}function EW(a){a=a|0;return v[a+4>>2]!=0|0}function zJ(a){a=a|0;Hb(a+4296|0,0,81928)}function xn(a,b){return v[a>>2]-v[b>>2]|0}function tO(a){v[a>>2]=v[a>>2]-2;return a}function s1(a,b){a=a|0;b=b|0;PH(a-88|0,b)}function r9(a,b){a=a|0;b=b|0;qf(a,b+36|0)}function r1(a,b){a=a|0;b=b|0;OH(a-88|0,b)}function qF(a,b){return nr(a,Fb(b),vb(b))}function of(a){a=a|0;ai(a+8|0);return a|0}function kj(a,b){v[a>>2]=v[b>>2];return a}function bZ(a,b){a=a|0;b=b|0;qf(a,b+16|0)}function bN(a,b){if(z[a>>2]>b){z[a>>2]=b}}function b1(a,b){a=a|0;b=b|0;AH(a-88|0,b)}function _0(a,b){a=a|0;b=b|0;zH(a-92|0,b)}function Z0(a,b){a=a|0;b=b|0;yH(a-92|0,b)}function YC(a){return(w[a+24|0]&16)>>>4|0}function WH(a,b){a=a|0;b=b|0;qf(a,b+12|0)}function Tk(a){a=a|0;return wG(a)<<24>>24}function Sh(a){return x[a+480190>>1]<3999}function Sda(a){a=a|0;return Lq(a+20|0)|0}function Rd(a){return wb(a&65535)<<16>>16}function RU(a,b){a=a|0;b=b|0;Ho(a+12|0,b)}function Pr(a){a=a|0;ds(a+8|0);return a|0}function IG(a,b){t[a|0]=b+48;return a+1|0}function Ge(a){v[a>>2]=v[a>>2]+4;return a}function GD(a,b){return TA(a,Fb(b),vb(b))}function Fe(a){v[a>>2]=v[a>>2]+1;return a}function Dr(a){a=a|0;$k(a+8|0);return a|0}function Br(a){a=a|0;$k(a+4|0);return a|0}function zr(a,b){v[a+24>>2]=v[a+24>>2]+b}function u1(a){a=a|0;return Pr(a-88|0)|0}function q1(a,b){a=a|0;b=+b;NH(a-88|0,b)}function oj(a,b){return v[a>>2]!=v[b>>2]}function oE(a,b,c){Ha(109,a|0,b|0,c|0,0)}function o1(a,b){a=a|0;b=+b;LH(a-88|0,b)}function mj(a){u[a+4>>1]=65535;v[a>>2]=0}function l1(a,b){a=a|0;b=+b;JH(a-88|0,b)}function jd(a,b){return wo(v[a+12>>2],b)}function eK(a){return(w[a+24|0]&8)>>>3|0}function dc(a){v[v[a>>2]+4>>2]=v[a+4>>2]}function cf(a,b){v[a+8>>2]=b|-2147483648}function aZ(a,b){a=a|0;b=b|0;Qv(a,80136)}function a1(a){a=a|0;return Pr(a-92|0)|0}function Zf(a,b){a=lka(0,a,b,0);return a}function XY(a,b){a=a|0;b=b|0;Bc(a,11316)}function WY(a,b){a=a|0;b=b|0;Bc(a,11433)}function T7(a){a=a|0;t[a+4202|0]=1;cK(a)}function Pk(a){return(a|0)==32|a-9>>>0<5}function OI(a){return(Fb(a)+vb(a)|0)-1|0}function OD(a,b){ec(a,b);ec(a+4|0,b+4|0)}function ND(a){v[a+4>>2]=0;v[a>>2]=87908}function K6(a){a=a|0;return v[a+4260>>2]}function Cia(a,b){a=a|0;b=b|0;wq(a,b,17)}function Ak(a){return B(Nm(a),zd(a))&255}function $Y(a,b){a=a|0;b=b|0;Qv(a,80156)}function yQ(a,b,c,d){return ol(c,d,a,b)}function wb(a){return(a<<8|a>>>8)&65535}function qV(a,b){a=a|0;b=b|0;wq(a,b,11)}function mi(a,b,c){zc(a,b);zc(a+12|0,c)}function kM(a,b){return(hl(a,b)|0)!=255}function k6(a){a=a|0;return(a|0)==277|0}function fF(a,b){a=a|0;b=b|0;Me(a,1,45)}function ek(a,b){return Gy(a&255,b&255)}function eF(a,b){a=a|0;b=b|0;oF(a,1,45)}function aha(a,b){a=a|0;b=b|0;WB(a,b,8)}function Wt(a,b,c){return a<b?b:a>c?c:a}function Tm(a){a=v[a+8>>2];if(a){zb(a)}}function Ny(a,b,c){return a<b?b:a>c?c:a}function I8(a){a=a|0;return w[a+4201|0]}function H8(a){a=a|0;return w[a+4202|0]}function GE(a,b){a=a|0;b=b|0;return b|0}function Fw(a){return(p(a),j(2))>>>20|0}function Dm(a,b){return Cf(a)>>>0>b>>>0}function AQ(a,b,c,d){return yQ(a,b,c,d)}function AI(a){v[a+4>>2]=v[a+4>>2]|8192}function v6(a){a=a|0;return-2013527448}function qe(a,b,c){hn(a,b,Uc(b,c)+b|0)}function qW(a){a=a|0;return v[a+16>>2]}function p1(a){a=a|0;return+MH(a-88|0)}function m1(a){a=a|0;return+KH(a-88|0)}function ks(a){a=a|0;if(a){vf(a)}zb(a)}function kr(a){a=a|0;return 2147483647}function kV(a){a=a|0;return v[a+12>>2]}function k1(a){a=a|0;return+IH(a-88|0)}function hk(a,b){return Fb(a)+(b<<2)|0}function e7(a){a=a|0;if(a){ns(a)}zb(a)}function dB(a,b,c){ac(a,b);ac(a+4|0,c)}function ci(a,b){v[a+4>>2]=2;v[a>>2]=b}function bj(a,b){v[a+4>>2]=1;v[a>>2]=b}function _q(a,b){v[a+4>>2]=3;v[a>>2]=b}function Zj(a){return(v[a+16>>2]&5)!=0}function ZS(a,b,c){ul(a,b&65535,c&255)}function M6(a){a=a|0;if(a){ox(a)}zb(a)}function LI(a){return a?(a|0)==2?3:2:1}function ID(a,b){HD(a,b);v[a>>2]=88660}function Gd(a){v[v[a+8>>2]>>2]=v[a>>2]}function Cv(a,b){v[a+4>>2]=4;v[a>>2]=b}function C7(a){a=a|0;if(a){rx(a)}zb(a)}function Bx(a){a=a|0;if(a){fp(a)}zb(a)}function Ada(a){a=a|0;oQ(a);return a|0}function A8(a){a=a|0;if(a){xx(a)}zb(a)}function z8(a){a=a|0;return 542066252}function yD(a,b,c){Ub(a,b,Vg(b,c)<<3)}function xj(a,b){return we(v[a>>2],b)}function xG(a,b){return vG(a)^vG(b)^1}function wA(a,b){return Hl(a,x[b>>1])}function vm(a){return(a&740327453)!=0}function vA(a,b){return Hl(x[a>>1],b)}function tG(a,b){return sG(a)^sG(b)^1}function t7(a){a=a|0;return-284078960}function sj(a){return(a-1&255)>>>0<17}function re(a,b,c){EF(a,b,c);return a}function rN(a,b){a=a|0;b=b|0;return 0}function oJ(a){a=C(a-a);return C(a/a)}function n6(a,b){a=a|0;b=b|0;return 3}function mw(a){a=a|0;Tq(a);return a|0}function m7(a){a=a|0;return-281111764}function l6(a,b){a=a|0;b=b|0;return 2}function jba(a,b){a=a|0;b=b|0;HN(a,b)}function iG(a){a=a|0;mw(a);return a|0}function gS(a,b,c){Ub(a,b,pc(b,c)<<2)}function fi(a){a=v[a>>2];if(a){LF(a)}}function d7(a){a=a|0;return-271958638}function bo(a,b){u[a+8>>1]=b;return a}function bi(a,b){og(a,Vd(b));return a}function ai(a){a=a|0;ED(a);return a|0}function YI(a,b){return nr(a,b,Rg(b))}function X6(a){a=a|0;return-620920304}function WM(a,b){return(0-b|0)!=(a|0)}function Vt(a,b){a=a|0;b=b|0;return 1}function Ud(a,b){return wo(v[a>>2],b)}function U1(a){a=a|0;return w[a+40|0]}function Sb(a,b){return fg(v[a>>2],b)}function RH(a){v[a>>2]=58976;return a}function QH(a){v[a>>2]=59056;return a}function Pe(a,b){v[a+4>>2]=b;return a}function P$(a){a=a|0;return $F(a,0)|0}function O7(a){a=a|0;return-270114148}function O$(a){a=a|0;return $F(a,1)|0}function Nt(a){a=a|0;return Kb(a,1)^1}function Lk(a,b,c){TE(a,b,c);return a}function Ld(a){return w[a+11|0]>>>7|0}function LD(a){a=a|0;return v[a+8>>2]}function L6(a){a=a|0;return-275227023}function L$(a){a=a|0;return _F(a,0)|0}function K$(a){a=a|0;return _F(a,1)|0}function FK(a,b){return wj(a,x[b>>1])}function Er(a,b){a=a|0;b=b|0;return-1}function EK(a,b){return wj(x[a>>1],b)}function C6(a){a=a|0;return 302837129}function B7(a){a=a|0;return-285139079}function Aq(a){a=a|0;return v[a+4>>2]}function $k(a){a=a|0;xw(a);return a|0}function $ja(a,b){a=a|0;b=b|0;at(a,b)}function wJ(a){v[a>>2]=0;v[a+4>>2]=0}function sA(a,b){a=a|0;b=b|0;CJ(a,b)}function qR(a,b){if(!jR(a,b)){Qz(b)}}function oX(a,b){a=a|0;b=b|0;tN(a,b)}function nK(a,b,c){a=a|0;b=b|0;c=c|0}function lQ(a){return(a|0)<120?a:120}function jh(a){Rf(a+52|0);_b(a+40|0)}function ft(a){return v[xb(a)>>2]<<5}function eaa(a){a=a|0;return wi(a)|0}function cx(a){return bh(w[a+140|0])}function a8(a,b){a=a|0;b=b|0;tx(a,b)}function _W(a,b){a=a|0;b=b|0;gE(a,b)}function ZY(a){a=a|0;return t[a+8|0]}function Yx(a,b){a=a|0;b=b|0;Cg(a,b)}function YY(a){a=a|0;return t[a+9|0]}function Xt(a,b){return w[a+b|0]!=63}function Xia(a){a=a|0;return SA(a)|0}function XO(a,b,c,d){SO($b(a,b,c),d)}function Sea(a){a=a|0;return Ci(a)|0}function Rm(a){v[a+4>>2]=v[a+4>>2]+1}function Qx(a,b){a=a|0;b=b|0;$K(a,b)}function O1(a){a=a|0;return w[a+8|0]}function Naa(a){a=a|0;return Ck(a)|0}function LL(a,b,c,d,e){KL(a,b,c,d,e)}function IW(a){a=a|0;XC(Fb(a),vb(a))}function Hj(a){return x[a+480188>>1]}function GM(a){return(a+5&255)>>>0<2}function FP(a,b){return B(b,872)+a|0}function Dh(a,b){a=a|0;b=b|0;Yx(a,b)}function Cg(a,b){a=a|0;b=b|0;qf(a,b)}function By(a,b){return Ar(a,w[b|0])}function Bq(a,b){a=a|0;b=b|0;hv(a,b)}function Bja(a){a=a|0;return PT(a)|0}function Ay(a,b){return Ar(w[a|0],b)}function $I(a,b,c,d,e){bJ(a,b,c,d,e)}function zZ(){fe(465216,_d(463592))}function zB(a){a=a|0;return lc(a)|0}function yp(a){if(w[a+24|0]){BM(a)}}function xv(a,b,c){return Mb(a,b,c)}function ws(a,b){return B(b,28)+a|0}function vq(a){a=a|0;return He(a)|0}function vk(a,b){return(b-a|0)/52|0}function st(a,b){return B(b,36)+a|0}function rd(a,b){return B(b,12)+a|0}function qq(a,b){return(b-a|0)/28|0}function pp(a){return gU(a,251,255)}function p0(a){a=a|0;return Sk(a)|0}function ng(a){return C(D(a))==C(N)}function mq(a,b){return(b-a|0)/48|0}function jf(a,b){return B(b,24)+a|0}function jW(a){a=a|0;nD(Hb(a,0,36))}function hc(a,b){return(a|0)==(b|0)}function gd(a,b){return(b-a|0)/12|0}function fg(a,b){return B(b,52)+a|0}function cS(a,b){return B(b,33)+a|0}function b_(){fe(464912,_d(463440))}function ac(a,b){v[a>>2]=b;return a}function a_(){fe(464920,_d(463448))}function _z(a,b){return je(a,0-b|0)}function _Z(){fe(464944,_d(463636))}function Zu(a){t[a+2|0]=0;u[a>>1]=0}function Zp(a){return(a&255)==1?1:2}function ZZ(){fe(464952,_d(463652))}function Yn(a,b){return a>>>0<b>>>0}function YM(a){return Ed(w[a+24|0])}function XZ(){fe(464960,_d(463660))}function WZ(){fe(464976,_d(463668))}function WC(a){a=a|0;return Sg(a)|0}function VZ(){fe(464984,_d(463676))}function Up(a,b){return(b-a|0)/56|0}function UZ(){fe(464992,_d(463684))}function TZ(){fe(465016,_d(463692))}function SZ(){fe(465048,_d(463456))}function Ri(a,b){return(b-a|0)/24|0}function RZ(){fe(465056,_d(463464))}function R6(a){a=a|0;v[a+4224>>2]=0}function Qi(a,b,c){return Bo(a,b,c)}function QZ(){fe(465064,_d(463472))}function PZ(){fe(465072,_d(463480))}function PU(a){a=a|0;return Lq(a)|0}function Og(a){return yb(v[a+4>>2])}function OZ(){fe(465080,_d(463520))}function Nq(a,b){return(b-a|0)/36|0}function Ng(a,b){return B(b,20)+a|0}function NZ(){fe(465088,_d(463528))}function MZ(){fe(465096,_d(463536))}function MW(a){a=a|0;return Ag(a)|0}function Lt(a,b){return(b-a|0)/33|0}function LZ(){fe(465104,_d(463544))}function KZ(){fe(465112,_d(463552))}function JZ(){fe(465120,_d(463560))}function Iz(a,b){return B(b,56)+a|0}function Iw(a){return!Mb(a,89276,6)}function IZ(){fe(465128,_d(463568))}function HZ(){fe(465136,_d(463576))}function HA(a,b,c){return ys(a,b,c)}function GZ(){fe(465144,_d(463488))}function FZ(){fe(465160,_d(463496))}function FF(a,b){EF(a,0,b);return a}function Df(a,b){return(b-a|0)/20|0}function DZ(){fe(465176,_d(463504))}function BZ(){fe(465192,_d(463512))}function AZ(){fe(465208,_d(463584))}function $Z(){fe(464928,_d(463644))}function wo(a,b){return(b<<11)+a|0}function vs(a,b){return(a-b|0)/6|0}function tn(a){_l(a);v[a>>2]=88320}function tT(a){return w[a+1|0]!=63}function t9(a){a=a|0;wq(a,21685,1)}function se(a,b){$b(a,Fb(b),vb(b))}function rn(a,b){v[a+1298464>>2]=b}function ri(a){a=a|0;t[a+4202|0]=0}function qw(a){return hc(a,-1)?0:a}function ok(a,b){return(b-a|0)/6|0}function od(a){return v[a>>2]+16|0}function no(a){t[a|0]=0;t[a+1|0]=0}function nj(a,b){return(b<<13)+a|0}function lf(a,b){hh(a);ac(a+4|0,b)}function jL(a){return Ed(w[a+4|0])}function eX(a){a=a|0;Wm(a,1,13485)}function cm(a){return C(D(a))<C(N)}function cF(a){return zh(a,463528)}function bF(a){return zh(a,463520)}function _E(a){return zh(a,463536)}function Zk(a,b){return(a+b|0)-1|0}function Zd(a){ND(a);v[a>>2]=80392}function Xn(a){return v[a>>2]+14|0}function So(a,b){return(a|0)<(b|0)}function S0(a,b){a=a|0;b=b|0;zb(b)}function Ry(a,b){return(b-a|0)/7|0}function Rv(a,b){return!(b>>>31|0)}function HM(a){de(a+8|0);AM(a+4|0)}function HI(a){return(bh(a)|0)==-1}function Gk(a){return(a&255)>>>0>1}function Fj(a,b){return B(Ak(b),a)}function Fh(a,b){a=a|0;b=b|0;Db(a)}function FI(a,b){a=a|0;b=b|0;_b(b)}function Eq(a){return(a&128)>>>7|0}function Eia(a){a=a|0;return+eI(a)}function EI(a,b){a=a|0;b=b|0;fc(b)}function Cd(a,b){return B(b,6)+a|0}function $E(a){return zh(a,463544)}function zm(a){v[a>>2]=v[a>>2]+28}function ym(a){v[a>>2]=2;return a}function yh(a){v[a>>2]=1;return a}function wk(a){u[a>>1]=0;return a}function we(a,b){return(b<<5)+a|0}function up(a){_b(a+4|0);return a}function sd(a,b){return(b<<4)+a|0}function rc(a,b){return Fb(a)+b|0}function oaa(a){a=a|0;Ff(a,rj(a))}function mm(a,b){return(b<<8)+a|0}function me(a,b){return!Mb(a,b,4)}function kz(a){if(a){zb(a+-64|0)}}function kfa(a){a=a|0;NR(a,65535)}function iz(a){v[a>>2]=v[a>>2]+32}function hh(a){v[a>>2]=0;return a}function gq(a,b){return ue(a,b)^1}function fY(a){a=a|0;return 13174}function dx(a,b){return cL(a,b)^1}function dY(a){a=a|0;return 10305}function cc(a,b){FD(a,b);return a}function c0(a){a=a|0;return 10425}function bv(a){return t[a+24|0]&1}function aC(a){return w[a+1|0]==1}function Yj(a){return a-48>>>0<10}function Xe(a,b){return(b<<3)+a|0}function Xb(a,b){return(b<<1)+a|0}function Ww(a){return a+1298408|0}function Vn(a){v[a>>2]=v[a>>2]+12}function Uf(a){v[a>>2]=v[a>>2]+20}function Sp(a){v[a>>2]=v[a>>2]+16}function Sf(a,b){og(a,b);return a}function Rc(a){return gU(a,1,120)}function Qf(a){return a!=a?C(0):a}function Qb(a,b){return hc(a,b)^1}function Pg(a){return yb(v[a>>2])}function LX(a){a=a|0;return 13060}function Kd(a){return v[bc(a)>>2]}function Jo(a){a=a|0;nB(a);zb(a)}
function JL(a){v[a>>2]=v[a>>2]+52}function Ib(a,b){return(b<<2)+a|0}function Gf(a,b){return Zc(a,b,0)}function Fx(a){v[a>>2]=v[a>>2]+24}function FJ(a){return C(a*C(100))}function Ev(a,b){return v[a+b>>2]}function An(a){return a+1074328|0}function mv(a){a=a|0;Tq(a);zb(a)}function ls(a){a=a|0;vf(a);zb(a)}function jQ(a){return w[a|0]<129}function hr(a){t[a|0]=0;return a}function g3(a){a=a|0;fx(a);zb(a)}function fG(a){v[a+72>>2]=462456}function f7(a){a=a|0;ns(a);zb(a)}function eo(a){return Hb(a,0,48)}function ef(a,b,c,d){pf(a,c,d,b)}function eG(a){v[a+72>>2]=462540}function cG(a){a=a|0;Uo(a);zb(a)}function aG(a){a=a|0;am(a);zb(a)}function _g(a,b,c){hn(a,b,b+c|0)}function _X(a){a=a|0;return 6869}function _1(a){a=a|0;fI(a);zb(a)}function Ys(a){v[a>>2]=v[a>>2]+8}function XI(a){a=a|0;gx(a);zb(a)}function Wu(a,b){return oka(a,b)}function P1(a){a=a|0;_H(a);zb(a)}function OR(a,b){ic(a,b+4|0,256)}function Ne(a){v[a>>2]=v[a>>2]+2}function NW(a){a=a|0;XC(a,Rg(a))}function MX(a){a=a|0;return 9864}function Ki(a){v[a>>2]=v[a>>2]+6}function IX(a){a=a|0;return 5723}function Gh(a){return!v[a+16>>2]}function Bd(a){return v[a>>2]!=0}function AC(a){em(a,Go(a),58412)}function zi(a,b){return(a|b)!=0}function xp(a){KN(a+12|0);JN(a)}function uB(a,b){return go(b,a)}function tl(a){return tm(ne(a))}function tb(a,b){return(a&b)!=0}function t1(a){a=a|0;Uw(a-88|0)}function sk(a,b,c){pf(a,c,12,b)}function sf(a){a=a|0;return a|0}function sb(a){Md(a+12|0);Md(a)}function pu(a,b,c){pf(a,c,30,b)}function op(a){u[a+480214>>1]=0}function nS(a,b){hn(a,b,b+16|0)}function mg(a){return Qh(a)?0:a}function mf(a,b){return yg(a,b)}function mL(a,b){return kL(a,b)}function lr(a){a=a|0;return 127}function jt(a,b){return Fc(a,b)}function jm(a){rb(a+12|0);rb(a)}function il(a){rb(a+12|0);_c(a)}function iT(a,b,c){pf(a,c,24,b)}function eh(a){return GM(a&255)}function Wv(a,b){return dh(a,b)}function Wh(a,b,c){pf(a,c,13,b)}function Vo(a){return a<<24>>24}function Tv(a){return xb(a+8|0)}function Tu(a,b){return JC(a,b)}function Ti(a,b){return a>>>b&1}function TH(a,b){return Vg(a,b)}function Oj(a,b){return b-a>>11}function Oh(a,b){return Uc(a,b)}function OT(a,b){return $n(b,a)}function OF(a){if(PF(a)){zb(a)}}function Nz(a,b,c){pf(a,c,64,b)}function NO(a){return 31-E(a)|0}function Lh(a,b){return Ib(a,b)}function Le(a){return hq(ne(a))}function LC(a,b){return IC(a,b)}function Jf(a){rb(a+20|0);rb(a)}function If(a){og(a,0);return a}function Ie(a,b,c){pf(a,c,32,b)}function Gt(a,b){return pc(a,b)}function Gi(a,b,c){pf(a,c,28,b)}function GF(a,b){return gd(a,b)}function Ed(a){return(a&255)!=0}function Cc(a,b,c){$b(a,b,1<<c)}function Bl(a,b,c){pf(a,c,22,b)}function Bj(a,b,c){pf(a,c,20,b)}function Bh(a,b){return Qu(a,b)}function BM(a){zM(a+12|0);yM(a)}function $0(a){a=a|0;Uw(a-92|0)}function ze(a,b){if(!a){zb(b)}}function zd(a){return a&64?2:1}function yW(a){a=a|0;zb(JD(a))}function wY(a){a=a|0;zb(FE(a))}function vw(a){a=a|0;zb(Dr(a))}function vj(a,b){return b-a>>4}function vW(a){a=a|0;zb(CD(a))}function th(a,b){return b-a>>8}function sw(a){a=a|0;zb(Br(a))}function pc(a,b){return b-a>>2}function oz(a){return a+4896|0}function oY(a){a=a|0;zb(EE(a))}function mW(a){a=a|0;zb(BD(a))}function lG(a){a=a|0;zb(ep(a))}function kW(a){a=a|0;zb(AD(a))}function kG(a){a=a|0;zb(uf(a))}function jn(a){return(a|0)==-1}function i0(a){a=a|0;zb(os(a))}function go(a,b){return a-b>>1}function e3(a){a=a|0;zb(gx(a))}function cZ(a){a=a|0;zb(ME(a))}function ag(a,b){return b-a>>5}function _Y(a){a=a|0;zb(LE(a))}function Zb(a,b){v[a+100>>2]=b}function Z$(a){a=a|0;zb(xw(a))}function Vg(a,b){return b-a>>3}function Uw(a){a=a|0;zb(Pr(a))}function R1(a){a=a|0;zb(aI(a))}function PY(a){a=a|0;zb(KE(a))}function PC(a){return lc(a<<2)}function P7(a){a=a|0;zb(ns(a))}function NE(a){a=a|0;zb(Sv(a))}function N6(a){a=a|0;zb(ox(a))}function KX(a){a=a|0;zb(nB(a))}function JX(a){a=a|0;zb(Tq(a))}function J6(a){a=a|0;return 13}function J1(a){a=a|0;zb(ZH(a))}function It(a,b){return a-b>>2}function HP(a){return a+4096|0}function Gy(a,b){return a<<8|b}function GG(a){a=a|0;zb($k(a))}function Fc(a,b){return b-a>>1}function F0(a){a=a|0;zb(am(a))}function E2(a){a=a|0;zb(Xr(a))}function D7(a){a=a|0;zb(rx(a))}function Cx(a){a=a|0;zb(fp(a))}function Bt(a){return a>>>27^a}function B8(a){a=a|0;zb(xx(a))}function B0(a){a=a|0;zb(Uo(a))}function $d(a,b){t[a|0]=w[b|0]}function $X(a){a=a|0;zb(mw(a))}function $$(a){a=a|0;zb(iG(a))}function y8(a){a=a|0;return 9}function us(a){a=a|0;return 4}function qy(a){jD(a);return a}function qo(a){return a>>>0<5}function oA(a,b){Ub(a,b,4896)}function mY(){dp(463620,uK())}function kf(a){return D(a)==N}function iS(a){eo(Hb(a,0,48))}function i6(){return 19988487}function gk(a){return Bd(a)^1}function gc(a){a=a|0;return 0}function et(a){return a+256|0}function dK(a){a=a|0;return 3}function bf(a){Rb(a);return a}function bL(a,b,c){lm(a,b,-c)}function aK(a){a=a|0;return 7}function Zr(a,b){v[a+32>>2]=b}function Wk(a){return a+120|0}function Uc(a,b){return b-a|0}function Rz(a,b){Ub(a,b,1024)}function Rp(a){hh(a);return a}function Rb(a){yd(a);return a}function RQ(a,b){Ub(a,b,1108)}function Qe(a,b){u[a+28>>1]=b}function PJ(a){a=a|0;return 5}function OC(a){return(a|0)!=0}function Nm(a){return a&1?2:1}function Mu(a){return!v[a>>2]}function Jn(a,b){v[a+36>>2]=b}function Jc(a,b){dp(a,b+28|0)}function Hq(a,b){pf(a,b,26,3)}function GQ(a,b){pf(a,b,33,1)}function FB(a,b){Ub(a,b,1954)}function Eb(a,b){return a+b|0}function ET(a,b){pf(a,b,40,2)}function De(a){a=a|0;return 1}function Db(a){CE(a);return a}function CG(a){a=a|0;return-1}function Bw(){return hb()<<16}function Be(a){a=a|0;return 2}function A7(a){a=a|0;return 6}function $n(a,b){return a-b|0}function zk(a,b,c){Bo(a,b,c)}function zI(a){v[a>>2]=49560}function yr(a,b){dp(a,b+4|0)}function yT(a,b){Ub(a,b,218)}function xN(a,b,c){Zl(a,b,c)}function wQ(a,b){Ub(a,b,146)}function vT(a,b){Ub(a,b,157)}function uU(a,b){Ub(a,b,610)}function td(a,b){v[a+4>>2]=b}function sQ(a,b){Ub(a,b,608)}function sL(a){return a-32|0}function rv(a,b){QD(a,Vd(b))}function ru(a,b){Ub(a,b,512)}function rq(a,b){Ub(a,b,192)}function qT(a,b){Ub(a,b,206)}function pl(a,b,c){to(a,b,c)}function pO(a){oO(a,v[a>>2])}function mp(a,b){z[a+8>>2]=b}function mc(a){return a+12|0}function mA(a,b){AA(a,Vd(b))}function lp(a,b){z[a+4>>2]=b}function kp(a,b){t[a+33|0]=b}function kT(a,b){Ub(a,b,236)}function kS(a,b){Ub(a,b,128)}function jP(a){return a+48|0}function iR(a,b){Ub(a,b,130)}function ho(a,b){be(a,b+8|0)}function gT(a){return a+10|0}function gR(a,b){Ub(a,b,600)}function bm(a,b){v[a+8>>2]=b}function bd(a,b){return a>>b}function bT(a,b){Ub(a,b,102)}function aR(a,b){Ub(a,b,126)}function _x(a,b){t[a+34|0]=b}function _l(a){v[a>>2]=88960}function _h(a,b,c){iD(a,b,c)}function Zx(a,b){t[a+32|0]=b}function Yd(a,b){t[a+11|0]=b}function Xx(a,b){t[a+35|0]=b}function Xp(a,b){return a<<b}function XH(a){return a-48|0}function WP(a,b){Ub(a,b,204)}function WA(a,b){pf(a,b,8,2)}function Vw(a){return a-12|0}function Vr(a){v[a>>2]=54728}function Ub(a,b,c){$b(a,b,c)}function UI(a,b,c){Hb(a,c,b)}function Ty(a){t[a+6152|0]=0}function Sm(a){v[a>>2]=57712}function Sj(a){return a-36|0}function SH(a){v[a>>2]=58952}function RO(a,b){Ub(a,b,263)}function QS(a,b){Ub(a,b,576)}function QJ(a){v[a>>2]=74588}function Pp(a){return a+32|0}function ON(a){return D(a)<N}function NS(a,b){Ub(a,b,674)}function LA(a){return a-28|0}function KO(a,b,c){Jp(a,c,b)}function JO(a,b,c){Np(a,c,b)}function IN(a){GN(a,v[a>>2])}function II(a,b,c){GI(a,b,c)}function HS(a){return a+36|0}function Go(a){return a+20|0}function FC(a,b){Ub(a,b,497)}function Ee(a,b){a=a|0;b=b|0}function Ds(a){OL(a,v[a>>2])}function Ac(a){td(a,v[a>>2])}function zj(a){return a-4|0}function xd(a){return!vb(a)}function xb(a){return a+8|0}function wC(a,b){Ub(a,b,38)}function tp(a){Hb(a,0,8192)}function tk(){po(11003);L()}function so(a,b){t[a+1|0]=b}function sg(a){return a&255}function sC(a,b){Ub(a,b,41)}function rR(a,b){Ub(a,b,30)}function py(a){Hb(a,0,4096)}function pK(a){Hb(a,0,2048)}function lo(a){v[a+12>>2]=0}function lS(a,b){Ub(a,b,80)}function ku(a,b){Ub(a,b,64)}function kq(a,b){Ub(a,b,12)}function kA(a,b){Ub(a,b,33)}function ju(a,b){Ub(a,b,66)}function hT(a){return a+6|0}function h6(){return 458752}function dU(a,b){ic(a,b,48)}function cA(a,b){Ub(a,b,40)}function bc(a){return a+4|0}function aP(a,b){return a<b}function _B(a,b){Ub(a,b,11)}function Ye(){af(11003);L()}function Xu(a,b){$b(a,b,22)}function WQ(a,b){Ub(a,b,32)}function VB(a,b){$b(a,b,20)}function UD(a,b){Ub(a,b,24)}function TR(a,b){Ub(a,b,52)}function SK(a){return 0-a|0}function SB(a,b){Ub(a,b,17)}function Oe(a){return a+2|0}function Mt(a,b){return a<b}function Li(a){return a+3|0}function L0(){return 459688}function Ku(a,b){Ub(a,b,65)}function Ju(a,b){Ub(a,b,16)}function Jq(a,b){Ub(a,b,36)}function Im(a,b){$b(a,b,32)}function IQ(a,b){Ub(a,b,96)}function Hf(a,b){t[a+3|0]=b}function GT(a,b){Ub(a,b,98)}function Fq(a){return a&127}function Ec(a){return a+1|0}function EB(a){Hb(a,0,1954)}function BT(a,b){Ub(a,b,48)}function $t(a,b){Ub(a,b,22)}function $N(a,b){Ub(a,b,27)}function zS(a){xA(a,Kd(a))}function zM(a){Ks(a,Kd(a))}function yM(a){Ls(a,Kd(a))}function xV(a){a=a|0;ai(a)}function vQ(a){Hb(a,0,146)}function uT(a){Hb(a,0,157)}function tU(a){Hb(a,0,610)}function tP(a){Hb(a,0,256)}function sc(a){v[a+8>>2]=0}function rQ(a){Hb(a,0,608)}function qd(a,b){v[a>>2]=b}function pT(a){Hb(a,0,206)}function mo(a,b){Ub(a,b,7)}function ko(a,b){Ub(a,b,5)}function kk(a,b){to(a,b,0)}function kda(){return cb|0}function jT(a){Hb(a,0,236)}function gv(a,b){Ub(a,b,3)}function gl(a){Py(a,Kd(a))}function fR(a){Hb(a,0,600)}function fL(a){Vx(a,Kd(a))}function dC(a,b){_h(a,2,b)}function bk(a,b){z[a>>2]=b}function aB(a,b){Ub(a,b,6)}function VP(a){Hb(a,0,204)}function Ut(a){MA(a,Kd(a))}function Qz(a){Hb(a,0,130)}function Qm(a,b){Ub(a,b,8)}function Qh(a){return a!=a}function Pu(){po(7678);L()}function Pb(a){Um(v[a>>2])}function PS(a){Hb(a,0,576)}function Oc(a){a=a|0;zb(a)}function Mi(a,b){u[a>>1]=b}function Km(a,b){Ub(a,b,2)}function KS(a){Hb(a,0,192)}function KN(a){Fp(a,Kd(a))}function Ht(a){dA(a,Kd(a))}function Hba(a){a=a|0;cb=a}function Eh(a,b){Ub(a,b,4)}function EC(a){Hb(a,0,497)}function Cq(a,b){Ub(a,b,1)}function Bz(){af(7678);L()}function BS(a){uA(a,Kd(a))}function BP(a){wz(a,Kd(a))}function AP(a){xz(a,Kd(a))}function $q(a){a=a|0;ar(a)}function $S(a){NA(a,Kd(a))}function $Q(a){Hb(a,0,126)}function $J(a,b){AK(a,3,b)}function vC(a){Hb(a,0,38)}function rC(a){Hb(a,0,41)}function qB(a){Hb(a,0,66)}function qA(a){Hb(a,0,80)}function o3(){return 2048}function kd(a,b){t[a|0]=b}function bu(a){Hb(a,0,64)}function YR(a){Hb(a,0,33)}function VS(a){Hb(a,0,56)}function SR(a){Hb(a,0,52)}function Qc(a){rb(a+16|0)}function Kq(a){Hb(a,0,36)}function JQ(a){Hb(a,0,96)}function FT(a){Hb(a,0,98)}function CT(a){Hb(a,0,48)}function vc(a){_b(a+8|0)}function rl(a){rb(a+4|0)}function rB(a,b){Cj(a,b)}function og(a,b){ac(a,b)}function nO(a,b){oO(a,b)}function nM(a,b){_S(a,b)}function li(a,b){Jh(a,b)}function kO(a,b){bg(a,b)}function jA(a,b){WR(a,b)}function dr(a,b){zc(a,b)}function Xc(a){sb(a+8|0)}function Ug(a){a=a|0;L()}function Ts(a,b){vL(a,b)}function QE(a){v[a>>2]=0}function Nd(a,b){td(a,b)}function NQ(a,b){be(a,b)}function NK(a,b){OL(a,b)}function Ml(a,b){MB(a,b)}function IB(a,b){KJ(a,b)}function FN(a){de(a+8|0)}function Ex(a,b){bi(a,b)}function Au(a,b){XB(a,b)}function $A(a,b){cc(a,b)}function zE(a){t[a|0]=1}function ug(a){t[a|0]=0}function Uha(){xa();L()}function sl(a){AA(a,0)}function qi(a){RI(a,0)}function qg(a){AS(a,0)}function pi(a){PI(a,0)}function pL(a){UL(a,0)}function nd(){Bz();L()}function _o(a){QI(a,0)}function ZX(){Kv();L()}function Wq(a){QD(a,0)}function Lc(a){Ue(a,0)}function Kv(){ya();L()}function Fs(a){RL(a,0)}function Es(a){PL(a,0)}function wf(a){a=a|0}function uM(a){tM(a)}function mk(a){um(a)}function iJ(a){Fe(a)}function eC(a){wk(a)}function br(a){mc(a)}function YS(a){Rp(a)}function TO(a){hh(a)}function MP(a){Rb(a)}function IP(a){Ge(a)}function BE(a){hr(a)}function Ab(a){rb(a)}function AN(a){Nn(a)}
// EMSCRIPTEN_END_FUNCS
e=w;var gb=c([null,jc,cE,qf,bX,Wm,PW,NW,SD,IW,GW,aD,ZV,NV,JV,Fm,Mg,vV,$,Vu,Cl,oG,sp,Cm,Qja,nB,sf,via,iia,Uha,Nha,Eha,rA,nha,jha,bea,Bga,DR,I0,H0,Gr,wia,$da,DR,zda,Hca,EO,at,Kp,sba,qba,jba,fba,zB,wM,qf,Bc,Gaa,zaa,Yx,$K,Qx,Cg,uK,T8,R8,M8,nY,t8,j8,o0,n0,_$,Yx,T6,tN,q6,b6,Y5,dJ,P4,v4,m4,K3,r3,i3,Y2,R2,N2,K2,Cg,F2,A2,u2,l2,g2,S1,M1,D1,v1,wH,n1,c1,T0,R0,TA,uw,xa,q0,vX,uX,tX,sX,rX,qX,Dh,pX,oX,nX,wH,mX,ia,kX,jX,iX,Cg,hX,gX,fX,_D,ZD,eX,wv,dX,Xm,$W,$q,Ho,Kl,Xf,YW,Xm,_W,ZW,XW,cX,WW,XD,VW,XD,aX,YD,UW,TW,SW,Dh,RW,Tc,Kb,MW,qv,LW,Ck,KW,RD,JW,Bk,RD,Uq,HW,Tq,ov,jW,FW,xW,wW,ai,Si,eW,dW,Lq,nD,cW,caa,daa,iN,aaa,baa,Wx,xs,Ob,eaa,Td,kD,$V,_V,WC,XV,WV,WC,SV,Su,RV,u9,_e,qga,Oaa,YV,vq,Ze,$U,Naa,Ija,E9,t9,MV,pC,oC,GV,FV,nC,EV,vg,DV,CV,xc,BV,AV,wg,nh,zV,Em,yV,lC,xV,tV,YB,sV,rV,qV,Gu,MO,DC,eJ,pV,oV,nV,mV,lV,Iu,jV,OB,ud,sq,gV,fV,xu,wu,eV,dV,cV,NB,bV,LB,Hu,aV,Gl,Nu,WU,jo,VU,Gb,Vf,Xf,UU,qu,TU,dd,Ii,SU,RU,QU,PU,AB,ed,OU,Am,NU,hka,gka,JU,IU,Si,nu,fka,eka,Cba,dka,Qg,cka,bka,Zja,Dj,aka,$ja,_ja,BU,Ch,of,Wja,Vja,Uja,oU,Rja,Dj,Aj,Pja,Oja,oq,Nja,oB,nU,Mja,Lja,Kja,Jja,Gl,YT,UT,Fja,Cja,dn,Aja,Ff,sU,Bja,Gu,QT,zja,yja,gB,xja,ov,wja,vja,MT,oT,uja,Gl,rja,jo,Zn,qja,pja,AB,oja,nja,mja,JT,lja,Gm,kja,jja,ija,gja,Dj,bB,hja,Ch,of,mB,bja,_ia,pC,Wia,Via,Uia,Tia,Qia,jo,Pia,Oia,co,JT,Nia,Mia,Xf,Lia,Kia,Jia,Iia,Hia,eT,Gia,Fia,TE,Eia,Dia,Cia,KB,dT,Bia,Aia,zia,Gba,yia,cT,xia,cT,Xia,uia,Dj,Ch,of,Ah,pia,oia,nia,kia,jia,hia,gia,fia,co,eia,dia,cia,FA,TV,bia,aia,$ha,_ha,Zha,QV,Yha,Xha,Wha,Vha,JS,IS,Tha,Sha,Xf,Rha,Qha,pB,Pha,qia,Oha,ria,Mha,Lha,Kha,CA,CA,CA,BA,Jha,Iha,GS,DS,Hha,J_,Gha,Fha,Dha,Cha,Bha,Aha,zha,CS,md,Wn,oha,sA,yha,e9,c9,b9,a9,$8,_8,xha,wha,bg,vha,uha,tha,sha,cE,Bba,zba,q9,C9,D9,rha,qha,pha,maa,Y8,Cg,xba,wba,vba,uba,iha,hha,gha,fha,eha,dha,cha,bha,aha,$ga,_ga,Yga,Xga,Zga,XR,of,QR,iA,Uga,hA,Tga,Sga,Rga,Qga,gA,Pga,Su,nC,Oga,NR,MR,Gq,fA,Nga,Me,Mga,KR,co,Du,co,dT,Bq,Xf,oU,co,dn,Jga,Iga,Hga,Gga,aA,Et,Fga,Ega,Dga,Cga,Aga,zga,qC,yga,xga,wga,vga,uga,tga,sga,rga,yA,pga,oga,nga,Xf,FS,ES,IA,mga,lga,xu,ov,kga,jga,iga,hga,gga,eba,Dh,fga,hu,lu,Ph,Maa,kba,Us,vN,Kaa,Jaa,XM,Qs,TM,Iaa,JM,eO,Haa,$y,pj,$h,Yfa,Xfa,At,dga,Nt,Ufa,HB,Tfa,Sfa,ZQ,Wn,Rfa,Qfa,Pfa,Ofa,Nfa,YQ,Mfa,Lfa,Kfa,zt,Jfa,Lz,Efa,Kz,Dfa,Cfa,Bfa,Dj,Ch,of,$h,yfa,xfa,wfa,vfa,hA,sfa,rfa,zt,qfa,Em,F9,nfa,mfa,Aj,OQ,Kz,Hu,lfa,kfa,jfa,ifa,xt,hfa,xt,gfa,Xq,UV,dfa,Dj,efa,ffa,Gz,BQ,Ch,of,At,afa,Zea,iA,Yea,Vea,Uea,oQ,YQ,FA,Tea,xu,Xf,Jea,Iea,NB,Hea,Gea,Fea,Eea,QA,Dea,Am,Aea,zea,yea,xea,wea,vea,nm,JP,uea,tea,sea,rea,qea,pea,oea,nea,mea,lea,kea,jea,iea,hA,hea,gea,fea,Nt,eea,dea,cea,jo,Yaa,qv,Sda,dba,cba,jo,bba,$h,qv,aba,$aa,_aa,aea,xP,Yda,Xda,Wda,Vda,Uda,Tda,Dq,Pda,Oda,Nda,Mda,Lda,Kda,Jda,Ida,Hda,Gda,Fda,lX,gE,Eda,Xf,Dda,Cda,Oi,gba,Iba,zB,rO,Eba,Dba,Aba,yba,tba,fO,pba,oba,_N,nba,mba,lba,RN,PN,In,MN,iba,hba,ao,Waa,Aj,jN,Yq,$9,_9,Z9,Taa,VV,Y9,fv,Yq,OB,X9,jN,Uaa,W9,Zaa,Dj,Ch,of,Xaa,Dj,Ch,of,Vaa,Dj,Ch,of,Raa,BU,Dh,Faa,Eaa,Daa,Caa,Baa,Aaa,Fba,Ada,uP,yaa,lc,waa,x9,vaa,QW,iW,bW,gW,taa,saa,aW,hW,OW,fW,GL,raa,qaa,paa,FL,ly,oaa,naa,rba,laa,kaa,jaa,iaa,IK,o9,vv,eE,hE,Wx,faa,Cg,YL,mu,yq,Qaa,Saa,T9,S9,Aj,R9,Kz,Q9,P9,O9,At,N9,$h,M9,L9,K9,J9,I9,Dj,Ch,of,U9,B9,A9,z9,y9,Jh,Vl,w9,v9,s9,m9,l9,k9,j9,h9,GK,p9,ip,DK,Fk,Jh,bg,f9,Z8,g9,n9,W8,V8,h8,U8,ak,rK,$f,BK,C8,i8,Sl,c8,Cg,b8,a8,$7,Wx,tx,Z7,iy,bK,E7,u7,n7,g7,Y6,O6,Q6,D6,w6,qJ,hs,p6,o6,b2,d2,f6,e6,c6,pJ,gaa,f2,_5,qJ,Z5,W5,S2,I1,G2,V2,kJ,kx,U5,j3,gx,h3,MI,S5,haa,P5,i9,Q5,d9,N5,M2,c3,L5,P2,jJ,KR,hJ,gJ,fJ,B5,z5,kJ,kx,w5,v5,u5,t5,s5,r5,q5,p5,o5,n5,m5,l5,k5,j5,i5,h5,g5,f5,e5,d5,c5,b5,a5,$4,Y4,W4,U4,HD,A1,W2,S4,D4,L2,B4,z4,_k,B1,C1,x4,H1,p4,n4,r9,j4,kx,e4,b4,_3,sn,WH,Y3,W3,U3,S3,Q3,O3,M3,J3,H3,F3,D3,B3,_I,w3,u3,AL,Ct,ZI,q3,p3,n3,m3,l3,k3,hp,Paa,Zq,lN,jl,PN,a3,$2,Z2,kl,HN,U2,xaa,Q2,jY,nr,O2,J2,Em,Gl,Gl,H2,uaa,T2,b3,X2,Bv,ca,e2,TI,SI,c2,gI,a2,$1,Q1,G1,F1,E1,z1,y1,uL,Bda,YH,U0,S0,Q0,P0,K0,J0,jG,mw,lY,x0,w0,v0,u0,t0,s0,r0,sf,aY,kY,a0,iG,X$,ow,iw,I$,H$,dw,Ih,Hh,qr,zb,cw,To,Xj,Tk,bw,Ul,z$,y$,Zi,Zg,vF,Yi,tw,_v,Ih,Hh,or,Cr,Qk,p0,Cl,gn,Zi,Zg,rF,Yi,e$,$_,nG,W_,wr,Cm,R_,_m,wf,y_,tr,x_,w_,v_,dF,t_,r_,q_,Rk,p_,dF,n_,m_,k_,j_,g_,f_,b_,a_,$Z,_Z,ZZ,YZ,XZ,WZ,VZ,UZ,TZ,SZ,RZ,QZ,PZ,OZ,NZ,MZ,LZ,KZ,JZ,IZ,HZ,GZ,FZ,EZ,DZ,CZ,BZ,AZ,zZ,yZ,xZ,vZ,tZ,rZ,Qv,lZ,jZ,hZ,mY,zB,Sea,Kv,mv,Aq,yda,xda,wda,vda,uda,tda,sda,rda,qda,pda,oda,nda,mda,lda,jda,ida,hda,gda,fda,eda,dda,cda,bda,ada,$ca,_ca,Zca,Yca,Xca,Wca,Vca,Uca,Tca,Sca,Rca,Qca,Pca,Oca,Nca,Mca,Lca,Kca,Jca,Ica,Gca,Fca,Eca,Dca,Cca,Bca,Aca,zca,yca,xca,wca,vca,uca,tca,sca,rca,qca,pca,oca,nca,mca,lca,kca,jca,ica,hca,gca,fca,eca,dca,cca,bca,aca,$ba,_ba,Zba,Yba,Xba,Wba,Vba,Uba,Tba,Sba,Rba,Qba,Pba,Oba,Nba,Mba,Lba,Kba,Jba,mv,Rda,Qda,mia,lia,Xea,Wea,Pea,Oea,Wga,Vga,Ifa,Hfa,lha,kha,YU,XU,fja,eja,wV,uV,iV,hV,Afa,zfa,$ea,_ea,_da,Zda,Tja,Sja,Hja,Gja,LV,KV,IV,HV,pfa,ofa,cfa,bfa,Wfa,Vfa,mha,fS,aja,$ia,tia,sia,Yja,Xja,tja,sja,ufa,tfa,V9,H9,G9,Sia,Ria,Zia,Yia,_fa,Zfa,Cea,Bea,Gfa,Ffa,dja,cja,Rea,Qea,Lea,Kea,Eja,Dja,Nea,Mea,ega,aga,$fa,PV,OV,_U,ZU,Lga,Kga,cga,bga,Jo,Aq,AD,kW,Ao,rN,Oc,sf,Oc,gc,De,De,gc,gc,lW,AW,zW,BD,mW,Ao,Oc,CD,vW,uW,tW,sW,rW,qW,pW,oW,nW,fp,Cx,Bx,oK,gc,wf,gc,gc,gc,Ee,us,S8,Q8,P8,O8,N8,si,Vt,Vt,zx,nK,zx,zx,L8,wf,fS,K8,J8,I8,H8,G8,ri,mK,e8,gc,gc,De,yx,Be,Be,De,F8,E8,Ee,wf,Ee,wf,xx,B8,A8,z8,gc,wf,gc,gc,gc,Ee,y8,kK,x8,w8,v8,u8,si,s8,r8,q8,p8,o8,n8,m8,l8,k8,ri,hK,gc,gc,De,Be,Be,De,jK,iK,vf,Ug,ZX,g8,Ax,f8,gc,d8,nK,Q7,F7,v7,o7,h7,Z6,P6,E6,x6,_6,X8,D8,_7,fp,Cx,Bx,oK,gc,wf,gc,gc,gc,Ee,dK,Y7,X7,W7,V7,U7,si,T7,ri,cK,gc,gc,De,Be,Be,De,S7,R7,rx,D7,C7,B7,gc,wf,gc,gc,gc,Ee,A7,z7,y7,x7,si,w7,ri,SJ,gc,gc,De,Be,Be,ls,ks,t7,gc,wf,gc,gc,gc,Ee,PJ,s7,r7,q7,si,p7,ri,NJ,gc,gc,De,Be,Be,fp,Cx,Bx,m7,gc,wf,gc,gc,gc,Ee,PJ,l7,k7,j7,si,i7,ri,LJ,gc,gc,De,Be,Be,ns,f7,e7,d7,gc,wf,gc,gc,gc,Ee,aK,c7,M7,L7,si,K7,ri,J7,gc,gc,De,Be,Be,Ee,wf,_J,b7,a7,ZJ,$6,YJ,XJ,P7,ms,O7,aK,N7,_J,I7,H7,ZJ,G7,YJ,XJ,ls,ks,X6,gc,wf,gc,gc,gc,Ee,Be,W6,V6,U6,si,S6,ri,R6,gc,gc,De,Be,Be,ox,N6,M6,L6,gc,wf,gc,gc,K6,Ee,J6,I6,H6,G6,si,F6,ri,nx,gc,gc,De,Be,Be,Ee,wf,ls,ks,C6,gc,wf,gc,gc,gc,Ee,dK,B6,A6,z6,si,y6,ri,BJ,gc,gc,De,Be,Be,ls,ks,v6,gc,wf,gc,gc,gc,Ee,us,u6,t6,s6,si,r6,ri,zJ,gc,gc,De,Be,Be,fx,g3,f3,XI,d3,XI,e3,Ug,Xr,E2,_2,sf,Oc,fT,Vt,Ug,sf,Ug,sf,Oc,D2,C2,Ug,CI,BI,CI,BI,Ee,Yr,Ee,Yr,FI,EI,FI,EI,Oc,I2,sf,Oc,B2,z2,Oc,uI,tI,Ug,w2,rI,v2,rI,y2,sI,x2,sI,Oc,t2,s2,Oc,qI,pI,Sr,Sr,Sr,Sr,r2,$w,$w,$w,Oc,q2,p2,Oc,nI,mI,m2,kI,k2,kI,o2,lI,n2,lI,Oc,j2,i2,Oc,iI,hI,Rr,Rr,Rr,Rr,h2,Zw,Zw,Zw,ZH,J1,Ao,Oc,_H,P1,De,De,O1,N1,Aq,L1,K1,Ug,Ug,aI,R1,Ao,Oc,fI,_1,De,gc,De,Z1,Y1,X1,W1,V1,U1,T1,Ug,JD,yW,Ao,Oc,Oc,EW,De,De,Aq,LD,DW,CW,BW,Ee,Yr,Ee,Yr,Pr,Uw,x1,w1,PH,OH,NH,MH,LH,KH,JH,IH,HH,GH,FH,EH,DH,CH,BH,AH,zH,yH,xH,vH,uH,tH,u1,t1,s1,r1,q1,p1,o1,m1,l1,k1,j1,i1,h1,g1,f1,e1,d1,b1,a1,$0,_0,Z0,Y0,X0,W0,V0,sf,Ug,sf,Ug,sf,Ug,O0,N0,M0,am,F0,Ee,FG,EG,DG,gc,gc,E0,CG,D0,Er,C0,Er,Uo,B0,Ee,FG,EG,DG,gc,gc,A0,CG,z0,Er,y0,Er,os,i0,j0,h0,m0,l0,k0,ep,lG,g0,f0,Br,sw,qG,pG,uf,kG,e0,d0,Dr,vw,zG,yG,sf,Oc,c0,iY,hY,gY,b0,$$,G0,gc,Y$,aG,M$,L$,K$,J$,$k,GG,xw,Z$,cG,Q$,P$,O$,N$,Dr,vw,zG,yG,$k,GG,aG,T$,bG,S$,R$,cG,W$,bG,V$,U$,Br,sw,qG,pG,EE,oY,ms,FE,wY,vY,uY,tY,sY,GE,rY,qY,pY,KE,PY,OY,NY,MY,LY,gc,KY,JY,LE,_Y,ZY,YY,WH,XY,WY,ME,cZ,LD,kV,bZ,aZ,$Y,sf,Oc,Oc,HY,GY,FY,EY,DY,CY,BY,AY,GE,zY,yY,xY,Oc,HE,HE,Ov,De,De,IY,De,Oc,SY,RY,Ov,gc,gc,QY,us,Oc,VY,UY,Ov,gc,gc,TY,us,sf,Oc,G$,F$,E$,sf,Oc,D$,C$,B$,Oc,A$,x$,w$,v$,zF,zF,u$,t$,s$,r$,q$,Oc,p$,o$,n$,m$,pF,pF,l$,k$,j$,i$,h$,Oc,g$,f$,d$,c$,b$,a$,__,Z_,Oc,Y_,X_,V_,U_,T_,S_,Q_,P_,sf,Oc,Be,O_,N_,M_,L_,K_,I_,mZ,kZ,iZ,gZ,fZ,eZ,dZ,sf,Oc,Be,H_,G_,F_,E_,D_,C_,wZ,uZ,sZ,qZ,pZ,oZ,nZ,Sv,NE,B_,Sv,NE,A_,Oc,lr,lr,Fh,Fh,Fh,fF,gc,Kk,Kk,Oc,lr,lr,Fh,Fh,Fh,fF,gc,Kk,Kk,Oc,kr,kr,Fh,Fh,Fh,eF,gc,Kk,Kk,Oc,kr,kr,Fh,Fh,Fh,eF,gc,Kk,Kk,Oc,z_,u_,Oc,s_,o_,Oc,l_,i_,Oc,h_,e_,Oc,WE,d_,Ee,Oc,WE,c_,Ee,sf,Ug,Oc,fY,eY,Oc,dY,bY,cY,$X,Ug,Oc,_X,ya,sf,Oc,wf,wf,YX,QX,SX,TX,Oc,LX,KX,JX,Jo,Jo,Jo,Jo,mv,Oc,IX,Oc,PX,RX,UX,Oc,XX,WX,VX,Oc,MX]);function hb(){return s.byteLength/65536|0}function mb(nb){nb=nb|0;var ib=hb()|0;var jb=ib+nb|0;if(ib<jb&&jb<65536){var kb=new ArrayBuffer(B(jb,65536));var lb=new Int8Array(kb);lb.set(t);t=new Int8Array(kb);u=new Int16Array(kb);v=new Int32Array(kb);w=new Uint8Array(kb);x=new Uint16Array(kb);y=new Uint32Array(kb);z=new Float32Array(kb);A=new Float64Array(kb);s=kb;r.buffer=s;e=w}return ib}return{"ra":MU,"sa":h6,"ta":i6,"ua":Oc,"va":zb,"wa":g6,"xa":d6,"ya":a6,"za":hs,"Aa":Ee,"Ba":k6,"Ca":j6,"Da":n6,"Ea":Vt,"Fa":l6,"Ga":rN,"Ha":m6,"Ia":sf,"Ja":sJ,"Ka":rJ,"La":sJ,"Ma":o3,"Na":HX,"Oa":GX,"Pa":FX,"Qa":$5,"Ra":mJ,"Sa":X5,"Ta":lJ,"Ua":H5,"Va":y3,"Wa":z3,"Xa":F5,"Ya":E5,"Za":D5,"_a":G5,"$a":A3,"ab":a4,"bb":s3,"cb":d4,"db":E4,"eb":v3,"fb":g4,"gb":x3,"hb":f4,"ib":t3,"jb":G3,"kb":C3,"lb":E3,"mb":V3,"nb":R3,"ob":T3,"pb":I3,"qb":L3,"rb":N3,"sb":P3,"tb":y4,"ub":A4,"vb":L4,"wb":G4,"xb":F4,"yb":K4,"zb":J4,"Ab":H4,"Bb":I4,"Cb":Q4,"Db":R4,"Eb":M4,"Fb":O4,"Gb":N4,"Hb":q4,"Ib":w4,"Jb":t4,"Kb":s4,"Lb":u4,"Mb":r4,"Nb":$3,"Ob":V4,"Pb":o4,"Qb":k4,"Rb":C4,"Sb":c4,"Tb":l4,"Ub":i4,"Vb":h4,"Wb":X4,"Xb":X3,"Yb":Z4,"Zb":Z3,"_b":T4,"$b":V5,"ac":T5,"bc":EX,"cc":R5,"dc":O5,"ec":M5,"fc":K5,"gc":DX,"hc":J5,"ic":I5,"jc":C5,"kc":A5,"lc":y5,"mc":_4,"nc":x5,"oc":Hd,"pc":L0,"qc":gb,"rc":Laa,"sc":kda,"tc":Hba,"uc":OX,"vc":NX,"wc":CX,"xc":BX,"yc":AX,"zc":zX,"Ac":yX,"Bc":xX,"Cc":wX,"Dc":wX}}return ob(qb)}
// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


